@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: HelpWindow.cpp,v 1.1 2001/08/22 04:01:50 jeroen Exp $                    *
+* $Id: HelpWindow.cpp,v 1.3 2001/11/21 06:21:31 jeroen Exp $                    *
 ********************************************************************************/
 #include "fx.h"
 #include "HelpWindow.h"
@@ -37,11 +37,11 @@ FXIMPLEMENT(HelpWindow,FXDialogBox,NULL,0)
 
 // Construct help dialog box
 HelpWindow::HelpWindow(FXWindow *owner):
-  FXDialogBox(owner,"Help on TextEdit",DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,0,0,0,0, 6,6,6,6, 4,4){
+  FXDialogBox(owner,"Help on Adie",DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,0,0,0,0, 6,6,6,6, 4,4){
   
   // Bottom part
   FXHorizontalFrame *closebox=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|PACK_UNIFORM_WIDTH);
-  new FXButton(closebox,"&Close",NULL,this,FXDialogBox::ID_ACCEPT,LAYOUT_RIGHT|FRAME_RAISED|FRAME_THICK,0,0,0,0, 20,20,5,5);
+  FXButton *button=new FXButton(closebox,"&Close",NULL,this,FXDialogBox::ID_ACCEPT,BUTTON_INITIAL|BUTTON_DEFAULT|LAYOUT_RIGHT|FRAME_RAISED|FRAME_THICK,0,0,0,0, 20,20,5,5);
 
   // Editor part
   FXHorizontalFrame *editbox=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN|FRAME_THICK,0,0,0,0, 0,0,0,0);
@@ -52,6 +52,7 @@ HelpWindow::HelpWindow(FXWindow *owner):
   // Fill with help
   helptext->setText(help,strlen(help));
   helptext->setTabColumns(35);
+  button->setFocus();
   }
 
 
