@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: help.cpp,v 1.1 2001/08/22 04:01:50 jeroen Exp $                         *
+* $Id: help.cpp,v 1.4.4.1 2002/04/04 14:10:33 fox Exp $                          *
 ********************************************************************************/
 #include "help.h"
 
@@ -52,6 +52,9 @@ const char help[]=
 "\n"
 "General Features.\n"
 "\n"
+"  - Programmable syntax coloring and text styles.\n"
+"  - Active or current text line highlighting.\n"
+"  - Optional line number display.\n"
 "  - Preferences are configurable with convenient dialogs.\n"
 "  - Text size only limited by available memory.\n"
 "  - Persistent bookmarks may be set for each file.\n"
@@ -90,6 +93,14 @@ const char help[]=
 "  - Customizable word-delimiters to select words by double-clicks.\n"
 "  - Insert files or extract highlighted text to file.\n"
 "\n"
+"Syntax Coloring Features.\n"
+"\n"
+"  - Syntax coloring is programmable, using PERL-like regular expressions.\n"
+"  - Syntax patterns are keyed to language or file extension.\n"
+"  - Text styles including foreground, background, selection colors, as well as underlining and strike-throughs.\n"
+"  - Syntax expressions, text styles, and language modes can be set up from convenient dialogs.\n"
+"  - Color fallback mechanism to minimize style setup hassles.\n"
+"\n"
 "\n"
 "Starting a New Document.\n"
 "\n"
@@ -249,6 +260,86 @@ const char help[]=
 "quickly return to this special version of the text by means of the revert command.\n"
 "\n"
 "\n"
+"Search and Replace.\n"
+"\n"
+"Adie uses the standard Search Dialog for searching strings. The search dialog offers"
+"forward and backward searches (relative to the current cursor location), and three "
+"search modes:\n"
+"\n"
+"Exact. In the Exact mode, a search looks for a verbatim occurrence of the search string in "
+"the text.\n"
+"\n"
+"Ignore Case. In the Ignore Case mode, a search looks for a verbatim occurrence also, but while "
+"disregarding the uppercase/lowercase distinctions.\n"
+"\n"
+"Expression. In the Expression mode, the the search performs a full regular expression match.  "
+"The regular expression syntax being used is very similar to PERL and is as follows:\n"
+"\n"
+"  ^\tMatch begin of line\n"
+"  $\tMatch end of line\n"
+"  .\tMatch any character\n"
+"  |\tAlternation\n"
+"  ( ... )\tGrouping sub pattern\n"
+"  (?i ... )\tMatch sub pattern case insensitive\n"
+"  (?I ... )\tMatch sub pattern case sensitive\n"
+"  (?n ... )\tMatch sub pattern with newlines\n"
+"  (?N ... )\tMatch sub pattern with no newlines\n"
+"  (?: ... )\tNon-capturing parentheses\n"
+"  (?= ... )\tZero width positive lookahead\n"
+"  (?! ... )\tZero width negative lookahead\n"
+"  []\tCharacter class\n"
+"\n"
+"  *\tMatch 0 or more [greedy]\n"
+"  +\tMatch 1 or more [greedy]\n"
+"  ?\tMatch 0 or 1 [greedy]\n"
+"  {}\tMatch 0 or more [greedy]\n"
+"  {n}\tMatch n times [greedy]\n"
+"  {,m}\tMatch no more than m times [greedy]\n"
+"  {n,}\tMatch n or more [greedy]\n"
+"  {n,m}\tMatch at least n but no more than m times [greedy]\n"
+"\n"
+"  *?\tMatch 0 or more [lazy]\n"
+"  +?\tMatch 1 or more [lazy]\n"
+"  ??\tMatch 0 or 1 [lazy]\n"
+"  {}?\tMatch 0 or more times [lazy]\n"
+"  {n}?\tMatch n times [lazy]\n"
+"  {,m}?\tMatch no more than m times [lazy]\n"
+"  {n,}?\tMatch n or more [lazy]\n"
+"  {n,m}?\tMatch at least n but no more than m times [lazy]\n"
+"\n"
+"  \\a\tAlarm, bell\n"
+"  \\e\tEscape character\n"
+"  \\t\tTab\n"
+"  \\f\tForm feed\n"
+"  \\n\tNewline\n"
+"  \\r\tReturn\n"
+"  \\v\tVertical tab\n"
+"  \\cx\tControl character\n"
+"  \\033\tOctal\n"
+"  \\x1b\tHex\n"
+"  \\w\tWord character [a-zA-Z_0-9]\n"
+"  \\W\tNon-word character\n"
+"  \\l\tLetter [a-zA-Z]\n"
+"  \\L\tNon-letter\n"
+"  \\s\tSpace\n"
+"  \\S\tNon-space\n"
+"  \\d\tDigit [0-9]\n"
+"  \\D\tNon-digit\n"
+"  \\h\tHex digit [0-9a-fA-F]\n"
+"  \\H\tNon-hex digit\n"
+"  \\b\tWord boundary\n"
+"  \\B\tWord interior\n"
+"  \\u\tSingle uppercase character\n"
+"  \\U\tSingle lowercase character\n"
+"  \\p\tPunctuation (not including '_')\n"
+"  \\P\tNon punctuation\n"
+"  \\<\tBegin of word\n"
+"  \\>\tEnd of word\n"
+"  \\A\tMatch only beginning of string\n"
+"  \\Z\tMatch only and end of string\n"
+"  \\1...\\9\tBack reference\n"
+"\n"
+"\n"
 "Keyboard Bindings.\n"
 "\n"
 "The following table lists the keyboard bindings.\n"
