@@ -3,7 +3,7 @@
 *                     A p p l i c a t i o n   O b j e c t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,14 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXApp.h,v 1.125 2001/08/29 04:12:42 jeroen Exp $                         *
+* $Id: FXApp.h,v 1.135 2002/01/18 22:42:51 jeroen Exp $                         *
 ********************************************************************************/
 #ifndef FXAPP_H
 #define FXAPP_H
 
+#ifndef FXOBJECT_H
+#include "FXObject.h"
+#endif
 
 
 
@@ -41,6 +44,7 @@ class FXVisual;
 class FXGLVisual;
 class FXGLContext;
 
+
 // Opaque FOX objects
 struct FXTimer;
 struct FXChore;
@@ -50,6 +54,54 @@ struct FXInput;
 struct FXInvocation;
 
 
+
+/// File input modes for addInput
+enum FXInputMode {
+  INPUT_NONE   = 0,                 /// Inactive
+  INPUT_READ   = 1,                 /// Read input fd
+  INPUT_WRITE  = 2,                 /// Write input fd
+  INPUT_EXCEPT = 4                  /// Except input fd
+  };
+
+
+/// All ways of being modal
+enum FXModality {
+  MODAL_FOR_NONE,                 /// Non modal event loop (dispatch normally)
+  MODAL_FOR_WINDOW,               /// Modal dialog (beep if outside of modal dialog)
+  MODAL_FOR_POPUP                 /// Modal for popup (always dispatch to popup)
+  };
+
+
+/// Default cursors provided by the application
+enum FXDefaultCursor {
+  DEF_ARROW_CURSOR,                     /// Arrow cursor
+  DEF_RARROW_CURSOR,                    /// Reverse arrow cursor
+  DEF_TEXT_CURSOR,                      /// Text cursor
+  DEF_HSPLIT_CURSOR,                    /// Horizontal split cursor
+  DEF_VSPLIT_CURSOR,                    /// Vertical split cursor
+  DEF_XSPLIT_CURSOR,                    /// Cross split cursor
+  DEF_SWATCH_CURSOR,                    /// Color swatch drag cursor
+  DEF_MOVE_CURSOR,                      /// Move cursor
+  DEF_DRAGH_CURSOR,                     /// Resize horizontal edge
+  DEF_DRAGV_CURSOR,                     /// Resize vertical edge
+  DEF_DRAGTL_CURSOR,                    /// Resize upper-leftcorner
+  DEF_DRAGBR_CURSOR=DEF_DRAGTL_CURSOR,  /// Resize bottom-right corner
+  DEF_DRAGTR_CURSOR,                    /// Resize upper-right corner
+  DEF_DRAGBL_CURSOR=DEF_DRAGTR_CURSOR,  /// Resize bottom-left corner
+  DEF_DNDSTOP_CURSOR,                   /// Drag and drop stop
+  DEF_DNDCOPY_CURSOR,                   /// Drag and drop copy
+  DEF_DNDMOVE_CURSOR,                   /// Drag and drop move
+  DEF_DNDLINK_CURSOR,                   /// Drag and drop link
+  DEF_CROSSHAIR_CURSOR,                 /// Cross hair cursor
+  DEF_CORNERNE_CURSOR,                  /// North-east cursor
+  DEF_CORNERNW_CURSOR,                  /// North-west cursor
+  DEF_CORNERSE_CURSOR,                  /// South-east cursor
+  DEF_CORNERSW_CURSOR,                  /// South-west cursor
+  DEF_ROTATE_CURSOR                     /// Rotate cursor
+  };
+
+
+
 /// FOX Event
 struct FXAPI FXEvent {
   FXuint      type;           /// Event type
@@ -60,6 +112,7 @@ struct FXAPI FXEvent {
   FXint       root_y;         /// Root y-coord
   FXint       state;          /// Keyboard/Modifier state
   FXint       code;           /// Button, Keysym, or mode; DDE Source
+  FXString    text;           /// Text of keyboard event
   FXint       last_x;         /// Window-relative x-coord of previous mouse location
   FXint       last_y;         /// Window-relative y-coord of previous mouse location
   FXint       click_x;        /// Window-relative x-coord of mouse press
@@ -214,6 +267,8 @@ private:
   void            *r_fds;               // Set of file descriptors for read
   void            *w_fds;               // Set of file descriptors for write
   void            *e_fds;               // Set of file descriptors for exceptions
+  void            *xim;                 // Input method
+  void            *xic;                 // Input method context
   FXbool           shmi;                // Use XSHM Image possible
   FXbool           shmp;                // Use XSHM Pixmap possible
   FXbool           synchronize;         // Synchronized
@@ -277,7 +332,7 @@ protected:
   virtual FXbool getNextEvent(FXRawEvent& ev,FXbool blocking=TRUE);
 
   /// Dispatch raw event
-  virtual void dispatchEvent(FXRawEvent& ev);
+  virtual FXbool dispatchEvent(FXRawEvent& ev);
 
 public:
   long onCmdQuit(FXObject*,FXSelector,void*);
@@ -295,7 +350,6 @@ public:
 public:
 
   /// Information
-  static const FXuchar version[3];      /// Version number of library
   static const FXuchar copyright[];     /// Copyright notice of library
 
 public:
@@ -420,7 +474,7 @@ public:
   * Run event loop while there are events are available in the queue.
   * Returns 1 when all events in the queue have been handled, and 0 when
   * the event loop was terminated due to stop() or stopModal().
-  * Except for the modal window and its children, user input to all windows 
+  * Except for the modal window and its children, user input to all windows
   * is blocked; if the modal window is NULL all user input is blocked.
   */
   FXint runWhileEvents(FXWindow* window=NULL);
@@ -432,14 +486,14 @@ public:
   FXint runModal();
 
   /**
-  * Run a modal event loop for the given window, until stop() or stopModal() is 
+  * Run a modal event loop for the given window, until stop() or stopModal() is
   * called. Except for the modal window and its children, user input to all
   * windows is blocked; if the modal window is NULL all user input is blocked.
   */
   FXint runModalFor(FXWindow* window);
 
   /**
-  * Run modal while window is shown, or until stop() or stopModal() is called. 
+  * Run modal while window is shown, or until stop() or stopModal() is called.
   * Except for the modal window and its children, user input to all windows
   * is blocked; if the modal window is NULL all user input is blocked.
   */
@@ -456,7 +510,7 @@ public:
 
   /// Return window of current modal loop
   FXWindow* modalWindow() const;
-  
+
   /// Return mode of current modal loop
   FXModality modalModality() const;
 
@@ -488,11 +542,17 @@ public:
   void flush(FXbool sync=FALSE);
 
   /**
-  * Initialize application.
-  * Parses and removes common command line arguments,
-  * opens the display, and reads the registry.
+  * Paint all windows marked for repainting.
+  * On return all the applications windows have been painted.
   */
-  virtual void init(int& argc,char** argv);
+  void repaint();
+
+  /**
+  * Initialize application.
+  * Parses and removes common command line arguments, reads the registry.
+  * Finally, if connect is TRUE, it opens the display.
+  */
+  virtual void init(int& argc,char** argv,FXbool connect=TRUE);
 
   /**
   * Exit application.
