@@ -3,7 +3,7 @@
 *                     A r r o w   B u t t o n   W i d g e t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,15 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXArrowButton.h,v 1.19 2001/08/23 04:53:15 jeroen Exp $                  *
+* $Id: FXArrowButton.h,v 1.22 2002/01/18 22:42:51 jeroen Exp $                  *
 ********************************************************************************/
 #ifndef FXARROWBUTTON_H
 #define FXARROWBUTTON_H
 
+#ifndef FXFRAME_H
+#include "FXFrame.h"
+#endif
+
 
 struct FXTimer;
 
@@ -52,11 +56,13 @@ enum {
 class FXAPI FXArrowButton : public FXFrame {
   FXDECLARE(FXArrowButton)
 protected:
-  FXColor  arrowColor;
-  FXint    arrowSize;
-  FXTimer *repeater;
-  FXbool   state;
-  FXbool   fired;
+  FXColor   arrowColor;     // Arrow color
+  FXint     arrowSize;      // Arrow size
+  FXTimer  *repeater;       // Timer for auto-repeat
+  FXString  tip;            // Tooltip value
+  FXString  help;           // Help value
+  FXbool    state;          // State of button
+  FXbool    fired;          // Timer has fired
 protected:
   FXArrowButton();
 private:
@@ -75,6 +81,8 @@ public:
   long onKeyRelease(FXObject*,FXSelector,void*);
   long onHotKeyPress(FXObject*,FXSelector,void*);
   long onHotKeyRelease(FXObject*,FXSelector,void*);
+  long onQueryHelp(FXObject*,FXSelector,void*);
+  long onQueryTip(FXObject*,FXSelector,void*);
 public:
   enum {
     ID_REPEAT=FXFrame::ID_LAST,
@@ -106,6 +114,18 @@ public:
   /// Get the button state (where TRUE means the button is down)
   FXbool getState() const { return state; }
 
+  /// Set status line help text for this arrow button
+  void setHelpText(const FXString& text){ help=text; }
+
+  /// Get status line help text for this arrow button
+  FXString getHelpText() const { return help; }
+
+  /// Set tool tip message for this arrow button
+  void setTipText(const FXString& text){ tip=text; }
+
+  /// Get tool tip message for this arrow button
+  FXString getTipText() const { return tip; }
+
   /// Set the arrow style flags
   void setArrowStyle(FXuint style);
 
@@ -117,7 +137,7 @@ public:
 
   /// Get the default arrow size
   FXint getArrowSize() const { return arrowSize; }
-  
+
   /// Set the current justification mode.
   void setJustify(FXuint mode);
 
@@ -135,7 +155,7 @@ public:
 
   /// Load label from a stream
   virtual void load(FXStream& store);
-  
+
   /// Destructor
   virtual ~FXArrowButton();
   };
