@@ -3,7 +3,7 @@
 *                            B M P   I m a g e   O b j e c t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,15 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXBMPImage.h,v 1.4 2001/01/25 19:48:27 jeroen Exp $                      *
+* $Id: FXBMPImage.h,v 1.7 2002/01/18 22:42:51 jeroen Exp $                      *
 ********************************************************************************/
 #ifndef FXBMPIMAGE_H
 #define FXBMPIMAGE_H
 
+#ifndef FXIMAGE_H
+#include "FXImage.h"
+#endif
+
 
 
 /// Microsoft Bitmap image
@@ -35,21 +39,21 @@ private:
   FXBMPImage(const FXBMPImage&);
   FXBMPImage &operator=(const FXBMPImage&);
 public:
-  
-  /// Construct image from memory stream formatted in Microsoft bitmap format
+
+  /// Construct image from memory stream formatted in Microsoft BMP format
   FXBMPImage(FXApp* a,const void *pix=NULL,FXuint opts=0,FXint w=1,FXint h=1);
 
   /// Save pixels into stream in Microsoft bitmap format
   virtual void savePixels(FXStream& store) const;
-  
+
   /// Load pixels from stream in Microsoft bitmap format
   virtual void loadPixels(FXStream& store);
-  
+
   /// Destroy icon
   virtual ~FXBMPImage();
   };
 
-  
+
 /// Load a bmp file from a stream
 extern FXAPI FXbool fxloadBMP(FXStream& store,FXuchar*& data,FXColor& transp,FXint& width,FXint& height);
 
@@ -57,5 +61,5 @@ extern FXAPI FXbool fxloadBMP(FXStream& store,FXuchar*& data,FXColor& transp,FXi
 /// Save a bmp file to a stream
 extern FXAPI FXbool fxsaveBMP(FXStream& store,const FXuchar *data,FXColor transp,FXint width,FXint height);
 
-    
+
 #endif
