@@ -3,7 +3,7 @@
 *                             B i t m a p    O b j e c t                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,15 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXBitmap.h,v 1.15 2001/08/23 16:24:51 jeroen Exp $                       *
+* $Id: FXBitmap.h,v 1.19 2002/01/18 22:42:51 jeroen Exp $                       *
 ********************************************************************************/
 #ifndef FXBITMAP_H
 #define FXBITMAP_H
 
+#ifndef FXDRAWABLE_H
+#include "FXDrawable.h"
+#endif
+
 
 // Image rendering hints
 enum {
@@ -59,11 +63,6 @@ private:
 protected:
   FXuchar *data;                // Pixel data
   FXuint   options;             // Options
-protected:
-  enum {
-    MAXWIDTH  = 2048,           // Maximum image size
-    MAXHEIGHT = 2048
-    };
 protected:
   FXBitmap();
 private:
@@ -86,6 +85,12 @@ public:
   /// Render pixels
   virtual void render();
 
+  /// Get pixel at x,y
+  FXbool getPixel(FXint x,FXint y) const;
+
+  /// Change pixel at x,y
+  void setPixel(FXint x,FXint y,FXbool color);
+
   /// Resize bitmap to the specified width and height; the contents become undefined
   virtual void resize(FXint w,FXint h);
 
