@@ -3,7 +3,7 @@
 *                          C o l o r   S e l e c t o r                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,15 +19,21 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXColorSelector.h,v 1.14 2001/03/23 07:02:41 jeroen Exp $                *
+* $Id: FXColorSelector.h,v 1.20 2002/01/18 22:42:51 jeroen Exp $                *
 ********************************************************************************/
 #ifndef FXCOLORSELECTOR_H
 #define FXCOLORSELECTOR_H
 
+#ifndef FXPACKER_H
+#include "FXPacker.h"
+#endif
+
 
 
 class FXTabBook;
+class FXColorBar;
 class FXColorWell;
+class FXColorWheel;
 class FXList;
 class FXSlider;
 class FXTextField;
@@ -40,24 +46,28 @@ class FXLabel;
 class FXAPI FXColorSelector : public FXPacker {
   FXDECLARE(FXColorSelector)
 protected:
-  FXTabBook   *panels;                // Color panes
-  FXColorWell *well;                  // Main well
-  FXList      *list;                  // List of color names
-  FXSlider    *rgbaslider[4];         // RGBA sliders
-  FXTextField *rgbatext[4];           // RGBA text fields
-  FXSlider    *hsvaslider[4];         // HSVA sliders
-  FXTextField *hsvatext[4];           // HSVA text fields
-  FXSlider    *cmyslider[4];          // CMY sliders
-  FXTextField *cmytext[4];            // CMY text fields
-  FXColorWell *colorwells[24];        // Custom color wells
-  FXIcon      *rgbmodeicon;           // Icon for RGB mode
-  FXIcon      *hsvmodeicon;           // Icon for HSV mode
-  FXIcon      *cmymodeicon;           // Icon for CMY mode
-  FXIcon      *txtmodeicon;           // Icon for TEXT mode
-  FXButton    *accept;                // Accept button
-  FXButton    *cancel;                // Cancel button
-  FXfloat      rgba[4];               // Accurate RGBA color
-  FXfloat      hsva[4];               // Accurate HSVA color
+  FXTabBook    *panels;               // Color panes
+  FXColorWell  *well;                 // Main well
+  FXList       *list;                 // List of color names
+  FXColorBar   *bar;                  // Color bar
+  FXColorWheel *wheel;                // Color wheel
+  FXSlider     *rgbaslider[4];        // RGBA sliders
+  FXTextField  *rgbatext[4];          // RGBA text fields
+  FXSlider     *hsvaslider[4];        // HSVA sliders
+  FXTextField  *hsvatext[4];          // HSVA text fields
+  FXSlider     *cmyslider[4];         // CMY sliders
+  FXTextField  *cmytext[4];           // CMY text fields
+  FXColorWell  *colorwells[24];       // Custom color wells
+  FXIcon       *eyedropicon;          // Icon for eye dropper
+  FXIcon       *dialmodeicon;         // Icon for dial mode
+  FXIcon       *rgbmodeicon;          // Icon for RGB mode
+  FXIcon       *hsvmodeicon;          // Icon for HSV mode
+  FXIcon       *cmymodeicon;          // Icon for CMY mode
+  FXIcon       *txtmodeicon;          // Icon for TEXT mode
+  FXButton     *accept;               // Accept button
+  FXButton     *cancel;               // Cancel button
+  FXfloat       rgba[4];              // Accurate RGBA color
+  FXfloat       hsva[4];              // Accurate HSVA color
 protected:
   static const FXchar* wellname[24];  // Well names
 protected:
@@ -93,6 +103,11 @@ public:
   long onCmdAlphaText(FXObject*,FXSelector,void*);
   long onUpdAlphaText(FXObject*,FXSelector,void*);
   long onUpdAlphaLabel(FXObject*,FXSelector,void*);
+  long onCmdWheel(FXObject*,FXSelector,void*);
+  long onUpdWheel(FXObject*,FXSelector,void*);
+  long onCmdBar(FXObject*,FXSelector,void*);
+  long onUpdBar(FXObject*,FXSelector,void*);
+  long onCmdColorPick(FXObject*,FXSelector,void*);
 public:
   enum {
     ID_CUSTOM_FIRST=FXPacker::ID_LAST,
@@ -115,6 +130,8 @@ public:
     ID_CMY_CYAN_TEXT,
     ID_CMY_MAGENTA_TEXT,
     ID_CMY_YELLOW_TEXT,
+    ID_DIAL_WHEEL,
+    ID_COLOR_BAR,
     ID_COLOR_LIST,
     ID_WELL_CHANGED,
     ID_COLOR,
@@ -122,6 +139,7 @@ public:
     ID_ALPHA_SLIDER,
     ID_ALPHA_TEXT,
     ID_ALPHA_LABEL,
+    ID_COLORPICK,
     ID_LAST
     };
 public:
