@@ -3,7 +3,7 @@
 *                         C o l o r W e l l   W i d g e t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,15 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXColorWell.h,v 1.17 2001/06/07 12:59:37 jeroen Exp $                    *
+* $Id: FXColorWell.h,v 1.22 2002/01/18 22:42:51 jeroen Exp $                    *
 ********************************************************************************/
 #ifndef FXCOLORWELL_H
 #define FXCOLORWELL_H
 
+#ifndef FXFRAME_H
+#include "FXFrame.h"
+#endif
+
 
 
 // Color Well Styles
@@ -122,20 +126,26 @@ public:
   /// Returns true because a color well can receive focus
   virtual FXbool canFocus() const;
 
+  /// Move the focus to this window
+  virtual void setFocus();
+
+  /// Remove the focus from this window
+  virtual void killFocus();
+
   /// Set color
   void setRGBA(FXColor clr);
 
   /// Get color
-  FXColor getRGBA() const;
+  FXColor getRGBA() const { return rgba; }
 
   /// Set status line help text for this color well
-  void setHelpText(const FXString& text);
+  void setHelpText(const FXString& text){ help=text; }
 
   /// Get status line help text for this color well
   FXString getHelpText() const { return help; }
 
   /// Set tool tip message for this color well
-  void setTipText(const FXString& text);
+  void setTipText(const FXString& text){ tip=text; }
 
   /// Get tool tip message for this color well
   FXString getTipText() const { return tip; }
