@@ -3,7 +3,7 @@
 *                       C o m b o   B o x   W i d g e t                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,14 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXComboBox.h,v 1.15 2001/06/15 05:09:47 jeroen Exp $                     *
+* $Id: FXComboBox.h,v 1.22 2002/02/11 06:38:02 fox Exp $                        *
 ********************************************************************************/
 #ifndef FXCOMBOBOX_H
 #define FXCOMBOBOX_H
 
+#ifndef FXPACKER_H
+#include "FXPacker.h"
+#endif
 
 
 
@@ -50,7 +53,7 @@ class FXPopup;
 class FXAPI FXComboBox : public FXPacker {
   FXDECLARE(FXComboBox)
 protected:
-  FXTextField   *text;
+  FXTextField   *field;
   FXMenuButton  *button;
   FXList        *list;
   FXPopup       *pane;
@@ -63,8 +66,6 @@ private:
 public:
   long onFocusUp(FXObject*,FXSelector,void*);
   long onFocusDown(FXObject*,FXSelector,void*);
-  long onChanged(FXObject*,FXSelector,void*);
-  long onCommand(FXObject*,FXSelector,void*);
   long onTextButton(FXObject*,FXSelector,void*);
   long onTextChanged(FXObject*,FXSelector,void*);
   long onTextCommand(FXObject*,FXSelector,void*);
@@ -110,7 +111,7 @@ public:
   void setEditable(FXbool edit=TRUE);
 
   /// Set the text
-  void setText(const FXString& txt);
+  void setText(const FXString& text);
 
   /// Get the text
   FXString getText() const;
@@ -134,7 +135,7 @@ public:
   FXbool isItemCurrent(FXint index) const;
 
   /// Set the current item (index is zero-based)
-  void setCurrentItem(FXint index);
+  void setCurrentItem(FXint indexz);
 
   /// Get the current item's index
   FXint getCurrentItem() const;
@@ -172,6 +173,12 @@ public:
   /// Get data pointer for specified item
   void* getItemData(FXint index) const;
 
+  /// Is the pane shown
+  FXbool isPaneShown() const;
+
+  /// Sort items using current sort function
+  void sortItems();
+
   /// Set text font
   void setFont(FXFont* fnt);
 
@@ -208,6 +215,12 @@ public:
   /// Return selected text color
   FXColor getSelTextColor() const;
 
+  /// Return sort function
+  FXListSortFunc getSortFunc() const;
+
+  /// Change sort function
+  void setSortFunc(FXListSortFunc func);
+
   /// Set the combobox help text
   void setHelpText(const FXString& txt);
 
