@@ -3,7 +3,7 @@
 *                       C o m p o s i t e   W i d g e t                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,15 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXComposite.h,v 1.13 2001/08/29 04:12:43 jeroen Exp $                    *
+* $Id: FXComposite.h,v 1.17 2002/01/18 22:42:51 jeroen Exp $                    *
 ********************************************************************************/
 #ifndef FXCOMPOSITE_H
 #define FXCOMPOSITE_H
 
+#ifndef FXWINDOW_H
+#include "FXWindow.h"
+#endif
+
 
 
 /// Base composite
