@@ -3,7 +3,7 @@
 *                              D i a l o g   B o x                              *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,15 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDialogBox.h,v 1.14 2001/03/23 07:02:41 jeroen Exp $                    *
+* $Id: FXDialogBox.h,v 1.16 2002/01/18 22:42:52 jeroen Exp $                    *
 ********************************************************************************/
 #ifndef FXDIALOGBOX_H
 #define FXDIALOGBOX_H
 
+#ifndef FXTOPWINDOW_H
+#include "FXTopWindow.h"
+#endif
+
 
 
 /**
