@@ -3,7 +3,7 @@
 *                    D i r e c t o r y   B o x   W i d g e t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,15 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDirBox.h,v 1.11 2001/08/21 22:37:54 jeroen Exp $                       *
+* $Id: FXDirBox.h,v 1.13 2002/01/18 22:42:52 jeroen Exp $                       *
 ********************************************************************************/
 #ifndef FXDIRBOX_H
 #define FXDIRBOX_H
 
+#ifndef FXTREELISTBOX_H
+#include "FXTreeListBox.h"
+#endif
+
 
 
 class FXIcon;
