@@ -3,7 +3,7 @@
 *                     D i r e c t o r y   L i s t   W i d g e t                 *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,15 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDirList.h,v 1.28 2001/08/23 16:24:51 jeroen Exp $                      *
+* $Id: FXDirList.h,v 1.30 2002/01/18 22:42:52 jeroen Exp $                      *
 ********************************************************************************/
 #ifndef FXDIRLIST_H
 #define FXDIRLIST_H
 
+#ifndef FXTREELIST_H
+#include "FXTreeList.h"
+#endif
+
 
 
 struct FXTimer;
