@@ -3,31 +3,40 @@
 *                           D r a w a b l e   A r e a                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997 by Jeroen van der Zijp.   All Rights Reserved.             *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Library General Public                   *
+* modify it under the terms of the GNU Lesser General Public                    *
 * License as published by the Free Software Foundation; either                  *
-* version 2 of the License, or (at your option) any later version.              *
+* version 2.1 of the License, or (at your option) any later version.            *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Library General Public License for more details.                              *
+* Lesser General Public License for more details.                               *
 *                                                                               *
-* You should have received a copy of the GNU Library General Public             *
-* License along with this library; if not, write to the Free                    *
-* Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.            *
+* You should have received a copy of the GNU Lesser General Public              *
+* License along with this library; if not, write to the Free Software           *
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDrawable.h,v 1.4 1999/11/04 20:46:37 jeroen Exp $                     *
+* $Id: FXDrawable.h,v 1.17 2002/01/18 22:42:52 jeroen Exp $                     *
 ********************************************************************************/
 #ifndef FXDRAWABLE_H
 #define FXDRAWABLE_H
 
+#ifndef FXID_H
+#include "FXId.h"
+#endif
+
+
 
 class FXVisual;
 
 
+/**
+* Drawable is an abstract base class for any surface that can be
+* drawn upon, such as a FXWindow, or FXImage.
+*/
 class FXAPI FXDrawable : public FXId {
   FXDECLARE_ABSTRACT(FXDrawable)
   friend class FXDC;
@@ -42,42 +51,36 @@ protected:
 private:
   FXDrawable(const FXDrawable&);
   FXDrawable &operator=(const FXDrawable&);
-#ifdef FX_NATIVE_WIN32
-  virtual HDC GetDC() const { return NULL; }
-  virtual int ReleaseDC(HDC) const { return 0; }
+#ifdef WIN32
+  virtual FXID GetDC() const { return NULL; }
+  virtual int ReleaseDC(FXID) const { return 0; }
 #endif
 public:
-  
-  // Width of drawable
+
+  /// Width of drawable
   FXint getWidth() const { return width; }
 
-  // Height of drawable
+  /// Height of drawable
   FXint getHeight() const { return height; }
 
-  // Get the visual
+  /// Get the visual
   FXVisual* getVisual() const { return visual; }
 
-  // Change visual
+  /// Change visual
   void setVisual(FXVisual* vis);
-  
-  // Create drawable surface
-  virtual void create();
-  
-  // Detach from drawable surface
-  virtual void detach();
 
-  // Destroy drawable surface
-  virtual void destroy();
-  
-  // Save object to stream
+  /// Resize drawable to the specified width and height
+  virtual void resize(FXint w,FXint h);
+
+  /// Save object to stream
   virtual void save(FXStream& store) const;
-  
-  // Load object from stream
+
+  /// Load object from stream
   virtual void load(FXStream& store);
-  
-  // Cleanup
+
+  /// Cleanup
   virtual ~FXDrawable();
   };
-  
-    
+
+
 #endif
