@@ -3,7 +3,7 @@
 *                   F i l e   S e l e c t i o n   D i a l o g                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXFileDialog.h,v 1.16 2001/02/28 01:40:29 jeroen Exp $                   *
+* $Id: FXFileDialog.h,v 1.18 2002/01/18 22:42:53 jeroen Exp $                   *
 ********************************************************************************/
 #ifndef FXFILEDIALOG_H
 #define FXFILEDIALOG_H
 
+#ifndef FXDIALOGBOX_H
+#include "FXDialogBox.h"
+#endif
+
+
 
 class FXFileSelector;
 
@@ -39,25 +44,25 @@ private:
   FXFileDialog(const FXFileDialog&);
   FXFileDialog &operator=(const FXFileDialog&);
 public:
-  
+
   /// Construct File Dialog Box
   FXFileDialog(FXWindow* owner,const FXString& name,FXuint opts=0,FXint x=0,FXint y=0,FXint w=500,FXint h=300);
 
   /// Change file name
   void setFilename(const FXString& path);
-  
+
   /// Return file name, if any
   FXString getFilename() const;
-  
+
   /// Return empty-string terminated list of selected file names, or NULL if none selected
   FXString* getFilenames() const;
 
   /// Change file pattern
   void setPattern(const FXString& ptrn);
-  
+
   /// Return file pattern
   FXString getPattern() const;
-  
+
   /**
   * Change the list of file patterns shown in the file dialog.
   * Each pattern comprises an optional name, followed by a pattern in
@@ -125,10 +130,10 @@ public:
 
   /// Show readonly button
   void showReadOnly(FXbool show);
-  
+
   /// Return TRUE if readonly is shown
   FXbool shownReadOnly() const;
-  
+
   /// Set initial state of readonly button
   void setReadOnly(FXbool state);
 
