@@ -3,7 +3,7 @@
 *                  F i l e   S e l e c t i o n   W i d g e t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,15 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXFileSelector.h,v 1.31 2001/07/24 21:49:23 jeroen Exp $                 *
+* $Id: FXFileSelector.h,v 1.38 2002/02/26 17:20:12 fox Exp $                 *
 ********************************************************************************/
 #ifndef FXFILESELECTOR_H
 #define FXFILESELECTOR_H
 
+#ifndef FXPACKER_H
+#include "FXPacker.h"
+#endif
+
 
 class FXFileList;
 class FXTextField;
@@ -40,6 +44,7 @@ enum {
   SELECTFILE_ANY,             /// A single file, existing or not (to save to)
   SELECTFILE_EXISTING,        /// An existing file (to load)
   SELECTFILE_MULTIPLE,        /// Multiple existing files
+  SELECTFILE_MULTIPLE_ALL,    /// Multiple existing files or directories
   SELECTFILE_DIRECTORY        /// Existing directory
   };
 
@@ -67,6 +72,10 @@ protected:
   FXIcon        *hiddenicon;      // Files hidden icon
   FXIcon        *markicon;        // Book mark icon
   FXIcon        *clearicon;       // Book clear icon
+  FXIcon        *deleteicon;      // Delete file icon
+  FXIcon        *moveicon;        // Rename file icon
+  FXIcon        *copyicon;        // Copy file icon
+  FXIcon        *linkicon;        // Link file icon
   FXRecentFiles  mrufiles;        // Recently visited places
   FXuint         selectmode;      // Select mode
 protected:
@@ -91,8 +100,12 @@ public:
   long onCmdVisit(FXObject*,FXSelector,void*);
   long onCmdNew(FXObject*,FXSelector,void*);
   long onUpdNew(FXObject*,FXSelector,void*);
+  long onCmdMove(FXObject*,FXSelector,void*);
+  long onCmdCopy(FXObject*,FXSelector,void*);
+  long onCmdLink(FXObject*,FXSelector,void*);
   long onCmdDelete(FXObject*,FXSelector,void*);
-  long onUpdDelete(FXObject*,FXSelector,void*);
+  long onUpdSelected(FXObject*,FXSelector,void*);
+  long onPopupMenu(FXObject*,FXSelector,void*);
 public:
   enum {
     ID_FILEFILTER=FXPacker::ID_LAST,
@@ -106,6 +119,9 @@ public:
     ID_VISIT,
     ID_NEW,
     ID_DELETE,
+    ID_MOVE,
+    ID_COPY,
+    ID_LINK,
     ID_LAST
     };
 public:
