@@ -3,7 +3,7 @@
 *                               F o n t   O b j e c t                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXFont.h,v 1.20 2001/01/29 16:51:59 jeroen Exp $                         *
+* $Id: FXFont.h,v 1.23 2002/01/18 22:42:53 jeroen Exp $                         *
 ********************************************************************************/
 #ifndef FXFONT_H
 #define FXFONT_H
 
+#ifndef FXID_H
+#include "FXId.h"
+#endif
+
+
 
 /// Font style hints which influence the matcher
 enum FXFontHint {
@@ -41,9 +46,9 @@ enum FXFontHint {
   FONTHINT_SCALABLE    = 512,       /// Scalable fonts
   FONTHINT_POLYMORPHIC = 1024       /// Polymorphic fonts
   };
-  
 
-/// Font slant 
+
+/// Font slant
 enum FXFontSlant {
   FONTSLANT_DONTCARE        = 0,    /// Don't care about slant
   FONTSLANT_REGULAR         = 1,    /// Regular straight up
@@ -61,7 +66,7 @@ enum FXFontEncoding {
   FONTENCODING_ISO_8859_2   = 2,
   FONTENCODING_ISO_8859_3   = 3,
   FONTENCODING_ISO_8859_4   = 4,
-  FONTENCODING_ISO_8859_5   = 5,                        /// Cyrillic (almost obsolete) 
+  FONTENCODING_ISO_8859_5   = 5,                        /// Cyrillic (almost obsolete)
   FONTENCODING_ISO_8859_6   = 6,
   FONTENCODING_ISO_8859_7   = 7,
   FONTENCODING_ISO_8859_8   = 8,
@@ -77,29 +82,29 @@ enum FXFontEncoding {
   FONTENCODING_KOI8_U       = 19,                       /// Ukrainian
   FONTENCODING_KOI8_UNIFIED = 20,
 
-  FONTENCODING_LATIN1      = FONTENCODING_ISO_8859_1,   /// Latin 1 (West European) 
-  FONTENCODING_LATIN2      = FONTENCODING_ISO_8859_2,   /// Latin 2 (East European) 
-  FONTENCODING_LATIN3      = FONTENCODING_ISO_8859_3,   /// Latin 3 (South European) 
-  FONTENCODING_LATIN4      = FONTENCODING_ISO_8859_4,   /// Latin 4 (North European) 
-  FONTENCODING_LATIN5      = FONTENCODING_ISO_8859_9,   /// Latin 5 (Turkish) 
-  FONTENCODING_LATIN6      = FONTENCODING_ISO_8859_10,  /// Latin 6 (Nordic) 
+  FONTENCODING_LATIN1      = FONTENCODING_ISO_8859_1,   /// Latin 1 (West European)
+  FONTENCODING_LATIN2      = FONTENCODING_ISO_8859_2,   /// Latin 2 (East European)
+  FONTENCODING_LATIN3      = FONTENCODING_ISO_8859_3,   /// Latin 3 (South European)
+  FONTENCODING_LATIN4      = FONTENCODING_ISO_8859_4,   /// Latin 4 (North European)
+  FONTENCODING_LATIN5      = FONTENCODING_ISO_8859_9,   /// Latin 5 (Turkish)
+  FONTENCODING_LATIN6      = FONTENCODING_ISO_8859_10,  /// Latin 6 (Nordic)
   FONTENCODING_LATIN7      = FONTENCODING_ISO_8859_13,  /// Latin 7 (Baltic Rim)
   FONTENCODING_LATIN8      = FONTENCODING_ISO_8859_14,  /// Latin 8 (Celtic)
   FONTENCODING_LATIN9      = FONTENCODING_ISO_8859_15,  /// Latin 9 AKA Latin 0
   FONTENCODING_LATIN10     = FONTENCODING_ISO_8859_16,  /// Latin 10
 
   FONTENCODING_USASCII     = FONTENCODING_ISO_8859_1,   /// Latin 1
-  FONTENCODING_WESTEUROPE  = FONTENCODING_ISO_8859_1,   /// Latin 1 (West European) 
-  FONTENCODING_EASTEUROPE  = FONTENCODING_ISO_8859_2,   /// Latin 2 (East European) 
-  FONTENCODING_SOUTHEUROPE = FONTENCODING_ISO_8859_3,   /// Latin 3 (South European) 
-  FONTENCODING_NORTHEUROPE = FONTENCODING_ISO_8859_4,   /// Latin 4 (North European) 
+  FONTENCODING_WESTEUROPE  = FONTENCODING_ISO_8859_1,   /// Latin 1 (West European)
+  FONTENCODING_EASTEUROPE  = FONTENCODING_ISO_8859_2,   /// Latin 2 (East European)
+  FONTENCODING_SOUTHEUROPE = FONTENCODING_ISO_8859_3,   /// Latin 3 (South European)
+  FONTENCODING_NORTHEUROPE = FONTENCODING_ISO_8859_4,   /// Latin 4 (North European)
   FONTENCODING_CYRILLIC    = FONTENCODING_ISO_8859_5,   /// Cyrillic
   FONTENCODING_RUSSIAN     = FONTENCODING_KOI8,         /// Cyrillic
   FONTENCODING_ARABIC      = FONTENCODING_ISO_8859_6,   /// Arabic
   FONTENCODING_GREEK       = FONTENCODING_ISO_8859_7,   /// Greek
   FONTENCODING_HEBREW      = FONTENCODING_ISO_8859_8,   /// Hebrew
-  FONTENCODING_TURKISH     = FONTENCODING_ISO_8859_9,   /// Latin 5 (Turkish) 
-  FONTENCODING_NORDIC      = FONTENCODING_ISO_8859_10,  /// Latin 6 (Nordic) 
+  FONTENCODING_TURKISH     = FONTENCODING_ISO_8859_9,   /// Latin 5 (Turkish)
+  FONTENCODING_NORDIC      = FONTENCODING_ISO_8859_10,  /// Latin 6 (Nordic)
   FONTENCODING_THAI        = FONTENCODING_ISO_8859_11,  /// Thai
   FONTENCODING_BALTIC      = FONTENCODING_ISO_8859_13,  /// Latin 7 (Baltic Rim)
   FONTENCODING_CELTIC      = FONTENCODING_ISO_8859_14   /// Latin 8 (Celtic)
@@ -224,58 +229,58 @@ public:
 
   /// Get font description
   void getFontDesc(FXFontDesc& fontdesc) const;
-  
+
   /// Change font description
   void setFontDesc(const FXFontDesc& fontdesc);
 
   /// Find out if the font is monotype or proportional
   FXbool isFontMono() const;
-  
+
   /// See if font has glyph for ch
   FXbool hasChar(FXint ch) const;
 
-  /// Get first character glyph in font  
+  /// Get first character glyph in font
   FXint getMinChar() const;
-  
+
   /// Get last character glyph in font
   FXint getMaxChar() const;
 
   /// Left bearing
   FXint leftBearing(FXchar ch) const;
-  
+
   /// Right bearing
   FXint rightBearing(FXchar ch) const;
-  
+
   /// Width of widest character in font
   FXint getFontWidth() const;
-  
+
   /// Height of highest character in font
   FXint getFontHeight() const;
-  
+
   /// Ascent from baseline
   FXint getFontAscent() const;
-  
+
   /// Descent from baseline
   FXint getFontDescent() const;
-  
+
   /// Get font leading [that is lead-ing as in Pb!]
   FXint getFontLeading() const;
-  
+
   /// Get font line spacing
   FXint getFontSpacing() const;
 
   /// Calculate width of given text in this font
   FXint getTextWidth(const FXchar *text,FXuint n) const;
-  
+
   /// Calculate height of given text in this font
   FXint getTextHeight(const FXchar *text,FXuint n) const;
-  
+
   /// List all fonts matching hints
   static FXbool listFonts(FXFontDesc*& fonts,FXuint& numfonts,const FXString& face,FXuint wt=FONTWEIGHT_DONTCARE,FXuint sl=FONTSLANT_DONTCARE,FXuint sw=FONTSETWIDTH_DONTCARE,FXuint en=FONTENCODING_DEFAULT,FXuint h=0);
 
   /// Save font data into stream
   virtual void save(FXStream& store) const;
-  
+
   /// Load font data from stream
   virtual void load(FXStream& store);
 
@@ -283,13 +288,13 @@ public:
   virtual ~FXFont();
   };
 
-  
-  
-/// Parse font description from a string DEPRECATED
+
+
+/// Parse font description from a string
 extern FXAPI FXbool fxparsefontdesc(FXFontDesc& fontdesc,const FXchar* string);
 
-/// Unparse font description into a string DEPRECATED
+/// Unparse font description into a string
 extern FXAPI FXbool fxunparsefontdesc(FXchar *string,const FXFontDesc& fontdesc);
 
-    
+
 #endif
