@@ -3,7 +3,7 @@
 *                        F o n t   S e l e c t i o n   B o x                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXFontSelector.h,v 1.9 2001/03/23 07:02:41 jeroen Exp $                  *
+* $Id: FXFontSelector.h,v 1.12 2002/01/18 22:42:53 jeroen Exp $                 *
 ********************************************************************************/
 #ifndef FXFONTSELECTOR_H
 #define FXFONTSELECTOR_H
 
+#ifndef FXPACKER_H
+#include "FXPacker.h"
+#endif
+
+
 
 class FXTextField;
 class FXList;
