@@ -3,7 +3,7 @@
 *                       F r a m e   W i n d o w   W i d g e t                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXFrame.h,v 1.9 2001/03/23 07:02:41 jeroen Exp $                         *
+* $Id: FXFrame.h,v 1.13 2002/01/18 22:42:53 jeroen Exp $                        *
 ********************************************************************************/
 #ifndef FXFRAME_H
 #define FXFRAME_H
 
+#ifndef FXWINDOW_H
+#include "FXWindow.h"
+#endif
+
+
 
 // Default padding
 #define DEFAULT_PAD   2
@@ -52,7 +57,6 @@ protected:
   void drawDoubleRaisedRectangle(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint h);
   void drawDoubleSunkenRectangle(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint h);
   void drawFrame(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint h);
-  void drawFocusRectangle(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint h);
 private:
   FXFrame(const FXFrame&);
   FXFrame &operator=(const FXFrame&);
