@@ -3,7 +3,7 @@
 *                G L  C a n v a s   W i n d o w   W i d g e t                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLCanvas.h,v 1.20 2001/06/20 16:24:57 jeroen Exp $                     *
+* $Id: FXGLCanvas.h,v 1.24 2002/01/18 22:42:53 jeroen Exp $                     *
 ********************************************************************************/
 #ifndef FXGLCANVAS_H
 #define FXGLCANVAS_H
 
+#ifndef FXCANVAS_H
+#include "FXCanvas.h"
+#endif
+
+
 
 /// GLCanvas, an area drawn by another object
 class FXAPI FXGLCanvas : public FXCanvas {
@@ -31,6 +36,7 @@ class FXAPI FXGLCanvas : public FXCanvas {
 private:
   FXGLCanvas  *sgnext;  // Share group next in share list
   FXGLCanvas  *sgprev;  // Share group previous in share list
+protected:
   void        *ctx;     // GL Context
 protected:
   FXGLCanvas();
@@ -75,7 +81,10 @@ public:
 
   /// Return TRUE if context is current
   virtual FXbool isCurrent() const;
-  
+
+  /// Get GL context handle
+  void* getContext() const { return ctx; }
+
   /// Swap front and back buffer
   virtual void swapBuffers();
 
