@@ -3,7 +3,7 @@
 *                        O p e n G L   C o n e    O b j e c t                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLCone.h,v 1.7 2001/04/25 05:47:37 jeroen Exp $                        *
+* $Id: FXGLCone.h,v 1.11 2002/01/18 22:42:53 jeroen Exp $                       *
 ********************************************************************************/
 #ifndef FXGLCONE_H
 #define FXGLCONE_H
 
+#ifndef FXGLSHAPE_H
+#include "FXGLShape.h"
+#endif
+
+
 
 /// OpenGL Cone Object
 class FXAPI FXGLCone : public FXGLShape {
@@ -37,7 +42,7 @@ protected:
 public:
 
   /// Construct with specified origin, height and radius
-  FXGLCone(FXfloat x,FXfloat y,FXfloat z,FXfloat h=1.0,FXfloat r=1.0);
+  FXGLCone(FXfloat x,FXfloat y,FXfloat z,FXfloat h=1.0f,FXfloat r=1.0f);
 
   /// Construct with specified origin, height, radius and material
   FXGLCone(FXfloat x,FXfloat y,FXfloat z,FXfloat h,FXfloat r,const FXMaterial& mtl);
@@ -48,12 +53,20 @@ public:
   /// Copy this object
   virtual FXGLObject* copy();
 
+  /// Change radius
+  void setRadius(FXfloat r){ radius=r; }
+  FXfloat getRadius() const { return radius; }
+
+  /// Change height
+  void setHeight(FXfloat h){ height=h; }
+  FXfloat getHeight() const { return height; }
+
   /// Save to a stream
   virtual void save(FXStream& store) const;
 
   /// Load from a stream
   virtual void load(FXStream& store);
-  
+
   /// Destroy
   virtual ~FXGLCone();
   };
