@@ -3,7 +3,7 @@
 *                        O p e n G L   C u b e    O b j e c t                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLCube.h,v 1.6 2001/04/25 05:47:37 jeroen Exp $                        *
+* $Id: FXGLCube.h,v 1.11 2002/01/18 22:46:41 jeroen Exp $                       *
 ********************************************************************************/
 #ifndef FXGLCUBE_H
 #define FXGLCUBE_H
-    
+
+#ifndef FXGLSHAPE_H
+#include "FXGLShape.h"
+#endif
+
+
 
 /// OpenGL Cube Object
 class FXAPI FXGLCube : public FXGLShape {
@@ -38,7 +43,7 @@ protected:
 public:
 
   /// Construct with specified origin, width, height and depth
-  FXGLCube(FXfloat x,FXfloat y,FXfloat z,FXfloat w=1.0,FXfloat h=1.0,FXfloat d=1.0);
+  FXGLCube(FXfloat x,FXfloat y,FXfloat z,FXfloat w=1.0f,FXfloat h=1.0f,FXfloat d=1.0f);
 
   /// Construct with specified origin, width, height, depth and material
   FXGLCube(FXfloat x,FXfloat y,FXfloat z,FXfloat w,FXfloat h,FXfloat d,const FXMaterial& mtl);
@@ -49,12 +54,24 @@ public:
   /// Copy this object
   virtual FXGLObject* copy();
 
+  /// Change width
+  void setWidth(FXfloat w){ width=w; }
+  FXfloat getWidth() const { return width; }
+
+  /// Change height
+  void setHeight(FXfloat h){ height=h; }
+  FXfloat getHeight() const { return height; }
+
+  /// Change depth
+  void setDepth(FXfloat d){ depth=d; }
+  FXfloat getDepth() const { return depth; }
+
   /// Save to a stream
   virtual void save(FXStream& store) const;
 
   /// Load from a stream
   virtual void load(FXStream& store);
-  
+
   /// Destroy
   virtual ~FXGLCube();
   };
