@@ -3,7 +3,7 @@
 *                G r o u p  B o x   W i n d o w   W i d g e t                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,15 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGroupBox.h,v 1.12 2001/04/30 17:16:24 jeroen Exp $                     *
+* $Id: FXGroupBox.h,v 1.14 2002/01/18 22:42:53 jeroen Exp $                     *
 ********************************************************************************/
 #ifndef FXGROUPBOX_H
 #define FXGROUPBOX_H
 
+#ifndef FXPACKER_H
+#include "FXPacker.h"
+#endif
+
 
 
 // Group box options
