@@ -3,7 +3,7 @@
 *                          H e a d e r   W i d g e t                            *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXHeader.h,v 1.25 2001/08/23 16:24:51 jeroen Exp $                       *
+* $Id: FXHeader.h,v 1.27 2002/01/18 22:42:53 jeroen Exp $                       *
 ********************************************************************************/
 #ifndef FXHEADER_H
 #define FXHEADER_H
 
+#ifndef FXFRAME_H
+#include "FXFrame.h"
+#endif
+
+
 
 struct FXTimer;
 class FXIcon;
@@ -58,7 +63,7 @@ public:
 
   /// Construct new item with given text, icon, size, and user-data
   FXHeaderItem(const FXString& text,FXIcon* ic=NULL,FXint s=0,void* ptr=NULL):label(text),icon(ic),size(s),data(ptr),arrow(MAYBE){}
-  
+
   /// Change item's text label
   virtual void setText(const FXString& txt){ label=txt; }
 
