@@ -3,7 +3,7 @@
 *                               I c o n - O b j e c t                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXIcon.h,v 1.14 2001/08/23 16:24:51 jeroen Exp $                         *
+* $Id: FXIcon.h,v 1.17 2002/02/20 07:02:12 fox Exp $                         *
 ********************************************************************************/
 #ifndef FXICON_H
 #define FXICON_H
 
+#ifndef FXIMAGE_H
+#include "FXImage.h"
+#endif
+
+
 
 class FXDC;
 class FXDCWindow;
@@ -71,6 +76,12 @@ public:
   /// Resize pixmap to the specified width and height
   virtual void resize(FXint w,FXint h);
 
+  /// Obtain transparency color
+  FXColor getTransparentColor() const { return transp; }
+  
+  /// Change transparency color
+  void setTransparentColor(FXColor color){ transp=color; }
+  
   /// Destructor
   virtual ~FXIcon();
   };
