@@ -3,7 +3,7 @@
 *                            L i s t   W i d g e t                              *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,15 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXList.h,v 1.44 2001/07/17 21:58:56 jeroen Exp $                         *
+* $Id: FXList.h,v 1.51 2002/01/18 22:42:53 jeroen Exp $                         *
 ********************************************************************************/
 #ifndef FXLIST_H
 #define FXLIST_H
 
+#ifndef FXSCROLLAREA_H
+#include "FXScrollArea.h"
+#endif
+
 
 
 /// List styles
@@ -52,10 +56,10 @@ protected:
   FXIcon   *icon;
   void     *data;
   FXuint    state;
+  FXint     x,y;
 protected:
-  FXListItem():icon(NULL),data(NULL),state(0){}
+  FXListItem():icon(NULL),data(NULL),state(0),x(0),y(0){}
   virtual void draw(const FXList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h);
-  void drawFocus(const FXList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
   virtual FXint hitItem(const FXList* list,FXint x,FXint y) const;
 protected:
   enum {
@@ -66,7 +70,7 @@ protected:
     ICONOWNED = 16
     };
 public:
-  FXListItem(const FXString& text,FXIcon* ic=NULL,void* ptr=NULL):label(text),icon(ic),data(ptr),state(0){}
+  FXListItem(const FXString& text,FXIcon* ic=NULL,void* ptr=NULL):label(text),icon(ic),data(ptr),state(0),x(0),y(0){}
   virtual void setText(const FXString& txt){ label=txt; }
   FXString getText() const { return label; }
   virtual void setIcon(FXIcon* icn){ icon=icn; }
@@ -112,8 +116,8 @@ protected:
   FXColor        textColor;         // Text color
   FXColor        selbackColor;      // Selected back color
   FXColor        seltextColor;      // Selected text color
-  FXint          itemWidth;         // Item width
-  FXint          itemHeight;        // Item height
+  FXint          listWidth;         // List width
+  FXint          listHeight;        // List height
   FXint          visible;           // Number of rows high
   FXString       help;              // Help text
   FXListSortFunc sortfunc;          // Item sort function
@@ -195,6 +199,12 @@ public:
   /// List widget can receive focus
   virtual FXbool canFocus() const;
 
+  /// Move the focus to this window
+  virtual void setFocus();
+
+  /// Remove the focus from this window
+  virtual void killFocus();
+
   /// Return the number of items in the list
   FXint getNumItems() const { return nitems; }
 
@@ -238,10 +248,10 @@ public:
   void clearItems(FXbool notify=FALSE);
 
   /// Return item width
-  FXint getItemWidth() const { return itemWidth; }
+  FXint getItemWidth(FXint index) const;
 
   /// Return item height
-  FXint getItemHeight() const { return itemHeight; }
+  FXint getItemHeight(FXint index) const;
 
   /// Return index of item at x,y, if any
   FXint getItemAt(FXint x,FXint y) const;
