@@ -3,7 +3,7 @@
 *          M u l t i p l e   D o c u m e n t   C h i l d   W i n d o w          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMDIChild.h,v 1.20 2001/07/02 20:25:51 jeroen Exp $                     *
+* $Id: FXMDIChild.h,v 1.22 2002/01/18 22:42:53 jeroen Exp $                     *
 ********************************************************************************/
 #ifndef FXMDICHILD_H
 #define FXMDICHILD_H
 
+#ifndef FXCOMPOSITE_H
+#include "FXComposite.h"
+#endif
+
+
 
 struct FXTimer;
 class FXMDIClient;
