@@ -3,7 +3,7 @@
 *                     M a i n   W i n d o w   W i d g e t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,15 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMainWindow.h,v 1.7 2001/03/23 07:02:42 jeroen Exp $                    *
+* $Id: FXMainWindow.h,v 1.9 2002/01/18 22:42:53 jeroen Exp $                    *
 ********************************************************************************/
 #ifndef FXMAINWINDOW_H
 #define FXMAINWINDOW_H
 
+#ifndef FXTOPWINDOW_H
+#include "FXTopWindow.h"
+#endif
+
 
 
 /// Main application window
