@@ -3,7 +3,7 @@
 *                   M a t r i x   C o n t a i n e r   W i d g e t               *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMatrix.h,v 1.10 2001/06/06 16:49:54 jeroen Exp $                        *
+* $Id: FXMatrix.h,v 1.12 2002/01/18 22:42:53 jeroen Exp $                       *
 ********************************************************************************/
 #ifndef FXMATRIX_H
 #define FXMATRIX_H
 
+#ifndef FXPACKER_H
+#include "FXPacker.h"
+#endif
+
+
 
 /// Matrix packing options
 enum {
