@@ -3,7 +3,7 @@
 *                      M e n u   C a s c a d e   W i d g e t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,17 +19,25 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMenuCascade.h,v 1.12 2001/07/31 05:34:48 jeroen Exp $                  *
+* $Id: FXMenuCascade.h,v 1.15 2002/01/18 22:42:53 jeroen Exp $                  *
 ********************************************************************************/
 #ifndef FXMENUCASCADE_H
 #define FXMENUCASCADE_H
 
+#ifndef FXMENUCAPTION_H
+#include "FXMenuCaption.h"
+#endif
+
+
 
 class FXPopup;
 struct FXTimer;
 
 
-/// Cascade menu item
+/**
+* The cascade menu widget is used to bring up a sub menu from a
+* pull down menu.
+*/
 class FXAPI FXMenuCascade : public FXMenuCaption {
   FXDECLARE(FXMenuCascade)
 protected:
@@ -60,7 +68,8 @@ public:
     ID_LAST
     };
 public:
-  /// Constructor
+
+  /// Construct a menu cascade responsible for the given popup menu
   FXMenuCascade(FXComposite* p,const FXString& text,FXIcon* ic=NULL,FXPopup* pup=NULL,FXuint opts=0);
 
   /// Create server-side resources
