@@ -3,7 +3,7 @@
 *                     M e n u   C o m m a n d   W i d g e t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,22 +19,31 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMenuCommand.h,v 1.15 2001/07/31 05:34:48 jeroen Exp $                  *
+* $Id: FXMenuCommand.h,v 1.19 2002/01/18 22:42:53 jeroen Exp $                  *
 ********************************************************************************/
 #ifndef FXMENUCOMMAND_H
 #define FXMENUCOMMAND_H
 
+#ifndef FXMENUCAPTION_H
+#include "FXMenuCaption.h"
+#endif
 
-// States the menu can be in
+
+
+/// States the menu command can be in
 enum {
-  MENUSTATE_NORMAL   = 0,           // Normal, unchecked state
-  MENUSTATE_CHECKED  = 1,           // Checked with a checkmark
-  MENUSTATE_RCHECKED = 2            // Checked with a bullet
+  MENUSTATE_NORMAL   = 0,           /// Normal, unchecked state
+  MENUSTATE_CHECKED  = 1,           /// Checked with a checkmark
+  MENUSTATE_RCHECKED = 2            /// Checked with a bullet
   };
-  
-  
- 
-/// Command menu item
+
+
+/**
+* The menu command widget is used to invoke a command in the
+* application from a menu.  Menu commands may reflect
+* the state of the application by graying out, becoming hidden,
+* or by a check mark or bullit.
+*/
 class FXAPI FXMenuCommand : public FXMenuCaption {
   FXDECLARE(FXMenuCommand)
 protected:
@@ -65,7 +74,8 @@ public:
   long onCmdGetIntValue(FXObject*,FXSelector,void*);
   long onCmdAccel(FXObject*,FXSelector,void*);
 public:
-  /// Constructor
+
+  /// Construct a menu command
   FXMenuCommand(FXComposite* p,const FXString& text,FXIcon* ic=NULL,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0);
 
   /// Return default width
@@ -73,46 +83,37 @@ public:
 
   /// Return default height
   virtual FXint getDefaultHeight();
-  
+
   /// Yes it can receive the focus
   virtual FXbool canFocus() const;
-  
+
   /// Move the focus to this window
   virtual void setFocus();
-  
+
   /// Remove the focus from this window
   virtual void killFocus();
-  
-  /// Make appear as default
-  void setDefault();
-  
-  /// Make appear as non-default
-  void setOther();
-  
-  /// True if appearing as default
-  FXint isDefault() const;
-  
+
   /// Place checkmark next to text
   void check();
-  
+
   /// Uncheck the item
   void uncheck();
-  
+
   /// Return TRUE if checked
   FXint isChecked() const;
-  
+
   /// Place radio bullit next to text
   void checkRadio();
-  
+
   /// Uncheck radio bullit
   void uncheckRadio();
-  
+
   /// Return TRUE if radio-checked
   FXint isRadioChecked() const;
-  
+
   /// Set accelerator text
   void setAccelText(const FXString& text);
-  
+
   /// Return accelarator text
   FXString getAccelText() const { return accel; }
 
