@@ -3,36 +3,43 @@
 *                      M e n u   T i t l e   W i d g e t                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997 by Jeroen van der Zijp.   All Rights Reserved.             *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Library General Public                   *
+* modify it under the terms of the GNU Lesser General Public                    *
 * License as published by the Free Software Foundation; either                  *
-* version 2 of the License, or (at your option) any later version.              *
+* version 2.1 of the License, or (at your option) any later version.            *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Library General Public License for more details.                              *
+* Lesser General Public License for more details.                               *
 *                                                                               *
-* You should have received a copy of the GNU Library General Public             *
-* License along with this library; if not, write to the Free                    *
-* Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.            *
+* You should have received a copy of the GNU Lesser General Public              *
+* License along with this library; if not, write to the Free Software           *
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMenuTitle.h,v 1.2 1999/09/20 22:12:56 jeroen Exp $                     *
+* $Id: FXMenuTitle.h,v 1.13 2002/01/18 22:42:54 jeroen Exp $                    *
 ********************************************************************************/
 #ifndef FXMENUTITLE_H
 #define FXMENUTITLE_H
 
-
-class FXMenuPane;
+#ifndef FXMENUCAPTION_H
+#include "FXMenuCaption.h"
+#endif
 
 
-// Menu title button
+class FXPopup;
+
+
+/**
+* A menu title is a child of a menu bar which is responsible
+* for popping up a pulldown menu.
+*/
 class FXAPI FXMenuTitle : public FXMenuCaption {
   FXDECLARE(FXMenuTitle)
 protected:
-  FXMenuPane *pane;
+  FXPopup *pane;
 protected:
   FXMenuTitle(){}
 private:
@@ -55,19 +62,47 @@ public:
   long onCmdPost(FXObject*,FXSelector,void*);
   long onCmdUnpost(FXObject*,FXSelector,void*);
 public:
-  FXMenuTitle(FXComposite* p,const FXString& text,FXIcon* ic=NULL,FXMenuPane* pup=NULL,FXuint opts=LAYOUT_LEFT);
+
+  /// Constructor
+  FXMenuTitle(FXComposite* p,const FXString& text,FXIcon* ic=NULL,FXPopup* pup=NULL,FXuint opts=0);
+
+  /// Create server-side resources
   virtual void create();
+
+  /// Detach server-side resources
   virtual void detach();
-  virtual FXbool canFocus() const;
-  virtual void setFocus();
-  virtual void killFocus();
-  void setPopup(FXMenuPane *pup){ pane = pup; }
-  FXMenuPane* getPopup() const { return pane; }
+
+  /// Return default width
   virtual FXint getDefaultWidth();
+
+  /// Return default height
   virtual FXint getDefaultHeight();
+
+  /// Yes it can receive the focus
+  virtual FXbool canFocus() const;
+
+  /// Move the focus to this window
+  virtual void setFocus();
+
+  /// Remove the focus from this window
+  virtual void killFocus();
+
+  /// Set popup menu to pop up
+  void setMenu(FXPopup *menu){ pane = menu; }
+
+  /// Return popup menu
+  FXPopup* getMenu() const { return pane; }
+
+  /// True if this menu or is popup logically contains the mouse
   virtual FXbool contains(FXint parentx,FXint parenty) const;
+
+  /// Save menu to a stream
   virtual void save(FXStream& store) const;
+
+  /// Load menu from a stream
   virtual void load(FXStream& store);
+
+  /// Destructor
   virtual ~FXMenuTitle();
   };
 
