@@ -3,7 +3,7 @@
 *                     P o p u p   W i n d o w   W i d g e t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXPopup.h,v 1.24 2001/08/29 04:12:44 jeroen Exp $                        *
+* $Id: FXPopup.h,v 1.26 2002/01/18 22:42:54 jeroen Exp $                        *
 ********************************************************************************/
 #ifndef FXPOPUP_H
 #define FXPOPUP_H
 
+#ifndef FXSHELL_H
+#include "FXShell.h"
+#endif
+
+
 
 /// Popup internal orientation
 enum {
@@ -32,7 +37,7 @@ enum {
   POPUP_SHRINKWRAP = 0x00040000       /// Shrinkwrap to content
   };
 
-  
+
 
 /// Popup window
 class FXAPI FXPopup : public FXShell {
@@ -87,16 +92,16 @@ public:
     ID_LAST=ID_CHOICE+1000
     };
 public:
-  
+
   /// Construct popup pane
   FXPopup(FXWindow* owner,FXuint opts=POPUP_VERTICAL|FRAME_RAISED|FRAME_THICK,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
 
   /// Return the default width of this window
   virtual FXint getDefaultWidth();
-  
-  /// Return the default height of this window 
+
+  /// Return the default height of this window
   virtual FXint getDefaultHeight();
-  
+
   /// Move the focus to this window
   virtual void setFocus();
 
@@ -105,61 +110,61 @@ public:
 
   /// Change frame style
   void setFrameStyle(FXuint style);
-  
+
   /// Return frame style
   FXuint getFrameStyle() const;
-  
+
   /// Return border width
   FXint getBorderWidth() const { return border; }
 
   /// Change highlight color
   void setHiliteColor(FXColor clr);
-  
+
   /// Return highlight color
   FXColor getHiliteColor() const { return hiliteColor; }
 
   /// Change shadow color
   void setShadowColor(FXColor clr);
-  
+
   /// Return shadow color
   FXColor getShadowColor() const { return shadowColor; }
 
   /// Change border color
   void setBorderColor(FXColor clr);
-  
+
   /// Return border color
   FXColor getBorderColor() const { return borderColor; }
-  
+
   /// Change base color
   void setBaseColor(FXColor clr);
-  
+
   /// Return base color
   FXColor getBaseColor() const { return baseColor; }
-  
+
   /// Popup the menu and grab to the given owner
   virtual void popup(FXWindow* grabto,FXint x,FXint y,FXint w=0,FXint h=0);
-  
+
   /// Pop down the menu
   virtual void popdown();
-  
+
   /// Return current grab owner
   FXWindow* getGrabOwner() const;
-  
+
 //   /// Popup the menu and grab to the given owner
 //   virtual FXint popup(FXint x,FXint y,FXint w=0,FXint h=0);
-// 
+//
 //   /// Pop down the menu
 //   virtual void popdown(FXint value);
 
   /// Return popup orientation
   FXuint getOrientation() const;
-  
+
   /// Change popup orientation
   void setOrientation(FXuint orient);
 
   /// Return shrinkwrap mode
   FXbool getShrinkWrap() const;
-  
+
   /// Change shrinkwrap mode
   void setShrinkWrap(FXbool sw);
 
