@@ -3,29 +3,42 @@
 *                        P r i n t   J o b   D i a l o g                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999 by Jeroen van der Zijp.   All Rights Reserved.             *
+* Copyright (C) 1999,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Library General Public                   *
+* modify it under the terms of the GNU Lesser General Public                    *
 * License as published by the Free Software Foundation; either                  *
-* version 2 of the License, or (at your option) any later version.              *
+* version 2.1 of the License, or (at your option) any later version.            *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Library General Public License for more details.                              *
+* Lesser General Public License for more details.                               *
 *                                                                               *
-* You should have received a copy of the GNU Library General Public             *
-* License along with this library; if not, write to the Free                    *
-* Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.            *
+* You should have received a copy of the GNU Lesser General Public              *
+* License along with this library; if not, write to the Free Software           *
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXPrintDialog.h,v 1.2 1999/09/20 22:12:56 jeroen Exp $                   *
+* $Id: FXPrintDialog.h,v 1.11 2002/01/18 22:55:03 jeroen Exp $                  *
 ********************************************************************************/
 #ifndef FXPRINTDIALOG_H
 #define FXPRINTDIALOG_H
 
+#ifndef FXDIALOGBOX_H
+#include "FXDialogBox.h"
+#endif
 
-// File selection dialog
+
+
+class FXRadioButton;
+class FXComboBox;
+class FXListBox;
+class FXTextField;
+class FXSpinner;
+class FXIcon;
+
+
+/// Printer selection dialog
 class FXAPI FXPrintDialog : public FXDialogBox {
   FXDECLARE(FXPrintDialog)
 protected:
@@ -43,18 +56,12 @@ protected:
   FXRadioButton *printinblacknwhite;
   FXRadioButton *orientportrait;
   FXRadioButton *orientlanscape;
-  FXRadioButton *sizeletter;
-  FXRadioButton *sizelegal;
-  FXRadioButton *sizeA4;
-  FXRadioButton *sizeenvelope;
-  FXRadioButton *sizecustom;
-  FXTextField   *sizewidth;
-  FXTextField   *sizeheight;
+  FXListBox     *media;
   FXSpinner     *firstpage;
   FXSpinner     *lastpage;
   FXSpinner     *numberofcopies;
-  FXGIFIcon     *landscapeIcon;
-  FXGIFIcon     *portraitIcon;
+  FXIcon        *landscapeIcon;
+  FXIcon        *portraitIcon;
   FXPrinter      printer;
 protected:
   FXPrintDialog(){}
@@ -90,16 +97,13 @@ public:
   long onUpdCollateNormal(FXObject*,FXSelector,void*);
   long onCmdCollateReversed(FXObject*,FXSelector,void*);
   long onUpdCollateReversed(FXObject*,FXSelector,void*);
-  long onCmdMedia(FXObject*,FXSelector,void*);
-  long onUpdMedia(FXObject*,FXSelector,void*);
-  long onCmdMediaWidth(FXObject*,FXSelector,void*);
-  long onUpdMediaWidth(FXObject*,FXSelector,void*);
-  long onCmdMediaHeight(FXObject*,FXSelector,void*);
-  long onUpdMediaHeight(FXObject*,FXSelector,void*);
   long onCmdFileName(FXObject*,FXSelector,void*);
   long onUpdFileName(FXObject*,FXSelector,void*);
   long onCmdPrinterName(FXObject*,FXSelector,void*);
   long onUpdPrinterName(FXObject*,FXSelector,void*);
+  long onCmdAccept(FXObject*,FXSelector,void*);
+  long onCmdMedia(FXObject*,FXSelector,void*);
+  long onUpdMedia(FXObject*,FXSelector,void*);
 public:
   enum{
     ID_TO_PRINTER=FXDialogBox::ID_LAST,
@@ -108,13 +112,7 @@ public:
     ID_FILE_NAME,
     ID_LANDSCAPE,
     ID_PORTRAIT,
-    ID_SIZE_CUSTOM,
-    ID_SIZE_LETTER,
-    ID_SIZE_LEGAL,
-    ID_SIZE_A4,
-    ID_SIZE_ENVELOPE,
-    ID_SIZE_WIDTH,
-    ID_SIZE_HEIGHT,
+    ID_MEDIA,
     ID_COLLATE_NORMAL,
     ID_COLLATE_REVERSED,
     ID_PAGES_ALL,
@@ -130,12 +128,26 @@ public:
     ID_NUM_COPIES
     };
 public:
+
+  /// Construct print dialog
   FXPrintDialog(FXWindow* owner,const FXString& name,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
+
+  /// Create dialog
   virtual void create();
+
+  /// Set printer info
   void setPrinter(const FXPrinter& pr);
+
+  /// Get printer info
   void getPrinter(FXPrinter& pr);
+
+  /// Save dialog to a stream
   virtual void save(FXStream& store) const;
+
+  /// Load dialog from a stream
   virtual void load(FXStream& store);
+
+  /// Destructor
   virtual ~FXPrintDialog();
   };
 
