@@ -3,7 +3,7 @@
 *                           R e g i s t r y   C l a s s                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,21 +19,27 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXRegistry.h,v 1.17 2001/07/05 15:43:48 jeroen Exp $                     *
+* $Id: FXRegistry.h,v 1.21 2002/01/23 18:53:57 jeroen Exp $                     *
 ********************************************************************************/
 #ifndef FXREGISTRY_H
 #define FXREGISTRY_H
 
+#ifndef FXSETTINGS_H
+#include "FXSettings.h"
+#endif
+
+
 
 /**
 * The registry maintains a database of persistent settings for an application,
 * or suite of applications.
 */
 class FXAPI FXRegistry : public FXSettings {
+  FXDECLARE(FXRegistry)
 protected:
-  FXString       applicationkey;  // Application key
-  FXString       vendorkey;       // Vendor key
-  FXbool	 ascii;		  // ASCII file-based registry
+  FXString applicationkey;  // Application key
+  FXString vendorkey;       // Vendor key
+  FXbool   ascii;           // ASCII file-based registry
 protected:
   FXbool readFromDir(const FXString& dirname,FXbool mark);
 #ifdef WIN32
@@ -42,8 +48,6 @@ protected:
   FXbool readFromRegistryGroup(void* org,const char* groupname,FXbool mark=FALSE);
   FXbool writeToRegistryGroup(void* org,const char* groupname);
 #endif
-protected:
-  FXRegistry(){}
 private:
   FXRegistry(const FXRegistry&);
   FXRegistry &operator=(const FXRegistry&);
@@ -53,7 +57,7 @@ public:
   * Construct registry object; akey and vkey must be string constants.
   * Regular applications SHOULD set a vendor key!
   */
-  FXRegistry(const FXString& akey,const FXString& vkey=FXString::null);
+  FXRegistry(const FXString& akey=FXString::null,const FXString& vkey=FXString::null);
 
   /// Read registry
   FXbool read();
