@@ -3,7 +3,7 @@
 *                      S e p a r a t o r   W i d g e t s                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXSeparator.h,v 1.7 2001/03/23 07:02:42 jeroen Exp $                     *
+* $Id: FXSeparator.h,v 1.9 2002/01/18 22:42:54 jeroen Exp $                     *
 ********************************************************************************/
 #ifndef FXSEPARATOR_H
 #define FXSEPARATOR_H
 
+#ifndef FXFRAME_H
+#include "FXFrame.h"
+#endif
+
+
 
 /// Separator Options
 enum {
