@@ -3,7 +3,7 @@
 *                     S h e l l   W i n d o w   W i d g e t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,15 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXShell.h,v 1.16 2001/04/16 21:13:58 jeroen Exp $                        *
+* $Id: FXShell.h,v 1.23 2002/01/18 22:42:54 jeroen Exp $                        *
 ********************************************************************************/
 #ifndef FXSHELL_H
 #define FXSHELL_H
 
+#ifndef FXCOMPOSITE_H
+#include "FXComposite.h"
+#endif
+
 
 
 /// A child of the Root window
@@ -38,6 +42,8 @@ private:
   FXShell &operator=(const FXShell&);
 public:
   long onConfigure(FXObject*,FXSelector,void*);
+  long onKeyPress(FXObject*,FXSelector,void*);
+  long onKeyRelease(FXObject*,FXSelector,void*);
   long onFocusNext(FXObject*,FXSelector,void*);
   long onFocusPrev(FXObject*,FXSelector,void*);
 public:
