@@ -3,7 +3,7 @@
 *                        S p i n   B u t t o n   W i d g e t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,15 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXSpinner.h,v 1.23 2001/06/27 16:10:22 jeroen Exp $                      *
+* $Id: FXSpinner.h,v 1.26 2002/01/18 22:42:54 jeroen Exp $                      *
 ********************************************************************************/
 #ifndef FXSPINNER_H
 #define FXSPINNER_H
 
+#ifndef FXPACKER_H
+#include "FXPacker.h"
+#endif
+
 
 
 // Spinner Options
@@ -116,7 +120,7 @@ public:
   void setTextVisible(FXbool shown);
 
   /// Change current value
-  void setValue(FXint value);
+  virtual void setValue(FXint value);
 
   /// Return current value
   FXint getValue() const { return pos; }
@@ -159,7 +163,7 @@ public:
 
   /// Allow editing of the text field
   void setEditable(FXbool edit=TRUE);
-  
+
   /// Return TRUE if text field is editable
   FXbool isEditable() const;
 
