@@ -3,7 +3,7 @@
 *                S p l i t t e r   W i n d o w   W i d g e t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,15 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXSplitter.h,v 1.17 2001/08/14 06:17:25 jeroen Exp $                     *
+* $Id: FXSplitter.h,v 1.19 2002/01/18 22:42:54 jeroen Exp $                     *
 ********************************************************************************/
 #ifndef FXSPLITTER_H
 #define FXSPLITTER_H
 
+#ifndef FXCOMPOSITE_H
+#include "FXComposite.h"
+#endif
+
 
 
 /// Splitter options
@@ -49,11 +53,11 @@ enum {
 * during the resizing of the panes; at the end of the resize interaction,
 * it sends a SEL_COMMAND to signify that the resize operation is complete.
 * Normally, children are resizable from 0 upwards; however, if the child
-* in a horizontally oriented splitter has LAYOUT_FILL_X in combination with 
+* in a horizontally oriented splitter has LAYOUT_FILL_X in combination with
 * LAYOUT_FIX_WIDTH, it will not be made smaller than its default width,
 * except when the child is the last visible widget (or first when the option
 * SPLITTER_REVERSED has been passed to the splitter).
-* In a vertically oriented splitter, children with LAYOUT_FILL_Y and 
+* In a vertically oriented splitter, children with LAYOUT_FILL_Y and
 * LAYOUT_FIX_HEIGHT behave analogously.
 * These options only affect interactive resizing.
 */
