@@ -3,7 +3,7 @@
 *                       S t a t u s b a r   W i d g e t                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXStatusbar.h,v 1.11 2001/03/23 07:02:42 jeroen Exp $                    *
+* $Id: FXStatusbar.h,v 1.13 2002/01/18 22:42:54 jeroen Exp $                    *
 ********************************************************************************/
 #ifndef FXSTATUSBAR_H
 #define FXSTATUSBAR_H
 
+#ifndef FXHORIZONTALFRAME_H
+#include "FXHorizontalFrame.h"
+#endif
+
+
 
 /// Statusbar options
 enum {
