@@ -3,7 +3,7 @@
 *                  S w i t c h   C o n t a i n e r   W i d g e t                *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,13 +19,23 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXSwitcher.h,v 1.8 2001/03/23 07:02:42 jeroen Exp $                      *
+* $Id: FXSwitcher.h,v 1.11 2002/01/24 19:00:59 jeroen Exp $                     *
 ********************************************************************************/
 #ifndef FXSWITCHER_H
 #define FXSWITCHER_H
 
+#ifndef FXPACKER_H
+#include "FXPacker.h"
+#endif
 
 
+/// Switcher options
+enum {
+  SWITCHER_HCOLLAPSE = 0x00020000,  /// Collapse horizontally to width of current child
+  SWITCHER_VCOLLAPSE = 0x00040000   /// Collapse vertically to height of current child
+  };
+
+  
 /**
 * The Switcher layout manager automatically arranges its child
 * windows such that one of them is placed on top; all other
@@ -36,6 +46,10 @@
 * Switcher ignores all layout hints from its children:- all
 * children are stretched according to the switcher layout
 * managers own size.
+* When the SWITCHER_HCOLLAPSE or SWITCHER_VCOLLAPSE options
+* are used, Switcher's default size is based on the width or
+* height of the current child, instead of the maximum width
+* or height of all of the children.
 */
 class FXAPI FXSwitcher : public FXPacker {
   FXDECLARE(FXSwitcher)
@@ -86,6 +100,12 @@ public:
   /// Return the index of the child window currently on top
   FXint getCurrent() const { return current; }
 
+  /// Set the switcher style flags
+  void setSwitcherStyle(FXuint style);
+
+  /// Get the switcher style flags
+  FXuint getSwitcherStyle() const;
+
   /// Save to stream
   virtual void save(FXStream& store) const;
 
