@@ -3,7 +3,7 @@
 *                            T a b l e   W i d g e t                            *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXTable.h,v 1.64 2001/06/18 21:15:44 jeroen Exp $                        *
+* $Id: FXTable.h,v 1.79 2002/01/18 22:42:55 jeroen Exp $                        *
 ********************************************************************************/
 #ifndef FXTABLE_H
 #define FXTABLE_H
 
+#ifndef FXSCROLLAREA_H
+#include "FXScrollArea.h"
+#endif
+
+
 
 //////////////////////////////  UNDER DEVELOPMENT  //////////////////////////////
 
@@ -40,8 +45,10 @@ class FXTable;
 
 /// Table options
 enum {
-  TABLE_COL_SIZABLE = 0x00100000,   /// Columns are resizable
-  TABLE_ROW_SIZABLE = 0x00200000    /// Rows are resizable
+  TABLE_COL_SIZABLE   = 0x00100000,   /// Columns are resizable
+  TABLE_ROW_SIZABLE   = 0x00200000,   /// Rows are resizable
+  TABLE_NO_COLSELECT  = 0x00400000,   /// Disallow column selections
+  TABLE_NO_ROWSELECT  = 0x00800000    /// Disallow row selections
   };
 
 
@@ -71,30 +78,36 @@ protected:
 protected:
   FXTableItem():icon(NULL),data(NULL),state(0){}
   virtual void draw(const FXTable* table,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
-  virtual void drawButtonDown(const FXTable* table,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
-  virtual void drawButtonUp(const FXTable* table,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
-  virtual void drawNormal(const FXTable* table,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
+  virtual void drawButton(const FXTable* table,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
+  virtual void drawBorders(const FXTable* table,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
+  virtual void drawContent(const FXTable* table,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
+  virtual void drawPattern(const FXTable* table,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
+  virtual void drawBackground(const FXTable* table,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
 protected:
   enum{
-    SELECTED   = 0x0001,
-    FOCUS      = 0x0002,
-    DISABLED   = 0x0004,
-    DRAGGABLE  = 0x0008,
-    BUTTON     = 0x0010,
-    PRESSED    = 0x0020
+    SELECTED   = 0x00000001,
+    FOCUS      = 0x00000002,
+    DISABLED   = 0x00000004,
+    DRAGGABLE  = 0x00000008,
+    BUTTON     = 0x00000010,
+    PRESSED    = 0x00000020,
+    ICONOWNED  = 0x00000040
     };
 public:
   enum{
-    RIGHT      = 0x0040,      /// Align on right 
-    LEFT       = 0x0080,      /// Align on left
-    TOP        = 0x0100,      /// Align on top
-    BOTTOM     = 0x0200,      /// Align on bottom
-    LBORDER    = 0x0400,      /// Draw left border
-    RBORDER    = 0x0800,      /// Draw right border
-    TBORDER    = 0x1000,      /// Draw top border
-    BBORDER    = 0x2000,      /// Draw bottom border
-    BACKGROUND = 0x4000       /// Draw background
-    }; 
+    RIGHT      = 0x00002000,      /// Align on right
+    LEFT       = 0x00004000,      /// Align on left
+    TOP        = 0x00008000,      /// Align on top
+    BOTTOM     = 0x00010000,      /// Align on bottom
+    BEFORE     = 0x00020000,      /// Icon before the text
+    AFTER      = 0x00040000,      /// Icon after the text
+    ABOVE      = 0x00080000,      /// Icon above the text
+    BELOW      = 0x00100000,      /// Icon below the text
+    LBORDER    = 0x00200000,      /// Draw left border
+    RBORDER    = 0x00400000,      /// Draw right border
+    TBORDER    = 0x00800000,      /// Draw top border
+    BBORDER    = 0x01000000       /// Draw bottom border
+    };
 public:
   FXTableItem(const FXString& text,FXIcon* ic=NULL,void* ptr=NULL):label(text),icon(ic),data(ptr),state(FXTableItem::RIGHT){}
   virtual void setText(const FXString& txt){ label=txt; }
@@ -113,10 +126,18 @@ public:
   FXbool isDraggable() const { return (state&DRAGGABLE)!=0; }
   void setJustify(FXuint justify);
   FXuint getJustify() const { return state&(RIGHT|LEFT|TOP|BOTTOM); }
+  void setIconPosition(FXuint mode);
+  FXuint getIconPosition() const { return state&(BEFORE|AFTER|ABOVE|BELOW); }
   void setBorders(FXuint borders);
   FXuint getBorders() const { return state&(LBORDER|RBORDER|TBORDER|BBORDER); }
-  void setOpaque(FXbool opaque);
-  FXbool getOpaque() const { return (state&BACKGROUND)!=0; }
+  void setStipple(FXStipplePattern pat);
+  FXStipplePattern getStipple() const;
+  void setButton(FXbool button);
+  FXbool isButton() const { return (state&BUTTON)!=0; }
+  void setPressed(FXbool pressed);
+  FXbool isPressed() const { return (state&PRESSED)!=0; }
+  virtual void setIconOwned(FXuint owned=ICONOWNED);
+  FXuint isIconOwned() const { return (state&ICONOWNED); }
   virtual FXint getWidth(const FXTable* table) const;
   virtual FXint getHeight(const FXTable* table) const;
   virtual void create();
@@ -124,7 +145,7 @@ public:
   virtual void destroy();
   virtual void save(FXStream& store) const;
   virtual void load(FXStream& store);
-  virtual ~FXTableItem(){}
+  virtual ~FXTableItem();
   };
 
 
@@ -153,6 +174,7 @@ protected:
   FXColor       selbackColor;           // Select background color
   FXColor       seltextColor;           // Select text color
   FXColor       gridColor;              // Grid line color
+  FXColor       stippleColor;           // Stipple color
   FXColor       cellBorderColor;        // Cell border color
   FXint         cellBorderWidth;        // Cell border width
   FXColor       cellBackColor[2][2];    // Row/Column even/odd background color
@@ -172,6 +194,7 @@ protected:
   FXint         table_right;            // Right edge of right side of table
   FXint         table_top;              // Top side of table
   FXint         table_bottom;           // Bottom side of bottom of table
+  FXTableRange  selection;              // Selected cell range
   FXTablePos    current;                // Current position
   FXTablePos    anchor;                 // Anchor position
   FXTablePos    extent;                 // Extent position
@@ -183,16 +206,17 @@ protected:
   FXuchar       mode;                   // Mode we're in
   FXint         grabx;                  // Grab point x
   FXint         graby;                  // Grab point y
+  FXint         rowcol;                 // Row or column being resized
   FXTimer      *blinker;                // Blink timer
   FXString      help;
+public:
+  static FXDragType csvType;
+  static const FXchar csvTypeName[];
 protected:
   FXTable();
   virtual void layout();
-  FXint yOfRow(FXint r) const;
-  FXint xOfCol(FXint c) const;
   void drawCursor(FXuint state);
   FXRectangle cellRect(FXint r,FXint c) const;
-  virtual void drawFocus(FXDC& dc,FXint x,FXint y,FXint w,FXint h);
   virtual void drawCell(FXDC& dc,FXint xlo,FXint xhi,FXint ylo,FXint yhi,FXint xoff,FXint yoff,FXint sr,FXint er,FXint sc,FXint ec);
   virtual void drawRange(FXDC& dc,FXint xlo,FXint xhi,FXint ylo,FXint yhi,FXint xoff,FXint yoff,FXint rlo,FXint rhi,FXint clo,FXint chi);
   virtual FXTableItem* createItem(const FXString& text,FXIcon* icon,void* ptr);
@@ -200,6 +224,8 @@ protected:
   FXint startCol(FXint row,FXint col) const;
   FXint endRow(FXint row,FXint col) const;
   FXint endCol(FXint row,FXint col) const;
+  FXint nearestCol(FXint col,FXint x) const;
+  FXint nearestRow(FXint row,FXint y) const;
 protected:
   enum {
     MOUSE_NONE,
@@ -301,6 +327,7 @@ public:
     ID_CUT_SEL,
     ID_COPY_SEL,
     ID_PASTE_SEL,
+    ID_BLINK,
     ID_LAST
     };
 
@@ -312,8 +339,16 @@ public:
   virtual void create();
   virtual void detach();
   virtual void recalc();
+
+  /// Table widget can receive focus
   virtual FXbool canFocus() const;
 
+  /// Move the focus to this window
+  virtual void setFocus();
+
+  /// Remove the focus from this window
+  virtual void killFocus();
+
   /// Change visible rows/columns
   void setVisibleRows(FXint nvrows);
   FXint getVisibleRows() const { return visiblerows; }
@@ -421,6 +456,14 @@ public:
   void setRowHeight(FXint row,FXint rheight);
   FXint getRowHeight(FXint row) const;
 
+  /// Change X coordinate of column c
+  void setColumnX(FXint col,FXint x);
+  FXint getColumnX(FXint col) const;
+
+  /// Change Y coordinate of row r
+  void setRowY(FXint row,FXint y);
+  FXint getRowY(FXint row) const;
+
   /// Change default column width
   void setDefColumnWidth(FXint cwidth);
   FXint getDefColumnWidth() const { return defColumnWidth; }
@@ -452,7 +495,7 @@ public:
 
   /// Repaint cell at r,c
   void updateItem(FXint r,FXint c);
-  
+
   /// Enable, disable, select, deselect, toggle cell
   FXbool enableItem(FXint r,FXint c);
   FXbool disableItem(FXint r,FXint c);
@@ -492,6 +535,7 @@ public:
   FXColor getSelBackColor() const { return selbackColor; }
   FXColor getSelTextColor() const { return seltextColor; }
   FXColor getGridColor() const { return gridColor; }
+  FXColor getStippleColor() const { return stippleColor; }
   FXColor getCellBorderColor() const { return cellBorderColor; }
 
   /// Change colors of various parts
@@ -503,6 +547,7 @@ public:
   void setSelBackColor(FXColor clr);
   void setSelTextColor(FXColor clr);
   void setGridColor(FXColor clr);
+  void setStippleColor(FXColor clr);
   void setCellBorderColor(FXColor clr);
 
   /// Change cell background color for even/odd rows/columns
