@@ -3,7 +3,7 @@
 *                         T e x t   F i e l d   W i d g e t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXTextField.h,v 1.28 2001/08/23 16:37:35 jeroen Exp $                    *
+* $Id: FXTextField.h,v 1.34 2002/01/18 22:42:55 jeroen Exp $                    *
 ********************************************************************************/
 #ifndef FXTEXTFIELD_H
 #define FXTEXTFIELD_H
 
+#ifndef FXFRAME_H
+#include "FXFrame.h"
+#endif
+
+
 
 struct FXTimer;
 
@@ -125,7 +130,7 @@ public:
   long onCmdCopySel(FXObject*,FXSelector,void*);
   long onCmdPasteSel(FXObject*,FXSelector,void*);
   long onCmdDeleteSel(FXObject*,FXSelector,void*);
-  long onCmdInsertChar(FXObject*,FXSelector,void*);
+  long onCmdOverstString(FXObject*,FXSelector,void*);
   long onCmdInsertString(FXObject*,FXSelector,void*);
   long onCmdBackspace(FXObject*,FXSelector,void*);
   long onCmdDelete(FXObject*,FXSelector,void*);
@@ -147,12 +152,13 @@ public:
     ID_COPY_SEL,
     ID_PASTE_SEL,
     ID_DELETE_SEL,
-    ID_INSERT_CHAR,
+    ID_OVERST_STRING,
     ID_INSERT_STRING,
     ID_BACKSPACE,
     ID_DELETE,
     ID_TOGGLE_EDITABLE,
     ID_TOGGLE_OVERSTRIKE,
+    ID_BLINK,
     ID_LAST
     };
 public:
