@@ -3,65 +3,78 @@
 *                   T o g g l e    B u t t o n    W i d g e t                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998 by Jeroen van der Zijp.   All Rights Reserved.             *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Library General Public                   *
+* modify it under the terms of the GNU Lesser General Public                    *
 * License as published by the Free Software Foundation; either                  *
-* version 2 of the License, or (at your option) any later version.              *
+* version 2.1 of the License, or (at your option) any later version.            *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Library General Public License for more details.                              *
+* Lesser General Public License for more details.                               *
 *                                                                               *
-* You should have received a copy of the GNU Library General Public             *
-* License along with this library; if not, write to the Free                    *
-* Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.            *
+* You should have received a copy of the GNU Lesser General Public              *
+* License along with this library; if not, write to the Free Software           *
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXToggleButton.h,v 1.2 1999/09/20 22:12:57 jeroen Exp $                  *
+* $Id: FXToggleButton.h,v 1.19 2002/01/18 22:42:55 jeroen Exp $                 *
 ********************************************************************************/
 #ifndef FXTOGGLEBUTTON_H
 #define FXTOGGLEBUTTON_H
 
+#ifndef FXLABEL_H
+#include "FXLabel.h"
+#endif
 
 
-// Button flags
-enum FXToggleButtonStyle {
-  TOGGLEBUTTON_AUTOGRAY = 0x00800000,
-  TOGGLEBUTTON_AUTOHIDE = 0x01000000,
-  TOGGLEBUTTON_TOOLBAR  = 0x02000000
+
+/// Toggle button flags
+enum {
+  TOGGLEBUTTON_AUTOGRAY = 0x00800000,       /// Automatically gray out when not updated
+  TOGGLEBUTTON_AUTOHIDE = 0x01000000,       /// Automatically hide toggle button when not updated
+  TOGGLEBUTTON_TOOLBAR  = 0x02000000,       /// Toolbar style toggle button [flat look]
+  TOGGLEBUTTON_NORMAL   = FRAME_RAISED|FRAME_THICK|JUSTIFY_NORMAL|ICON_BEFORE_TEXT
   };
 
 
-// Your basic button
+/**
+* The toggle button provides a two-state button, which toggles between the
+* on and the off state each time it is pressed.  For each state, the toggle
+* button has a unique icon and text label.
+* When pressed, the button widget sends a SEL_COMMAND to its target, with the
+* message data set to the current state of the toggle button, of the type FXbool.
+*/
 class FXAPI FXToggleButton : public FXLabel {
   FXDECLARE(FXToggleButton)
 protected:
-  FXString  altlabel; 
+  FXString  altlabel;
   FXIcon   *alticon;
   FXHotKey  althotkey;
   FXint     althotoff;
-  FXuchar   oldstate;
-  FXuchar   state;
-  FXString  tip;
-  FXString  help;
   FXString  alttip;
   FXString  althelp;
+  FXbool    state;
+  FXbool    down;
 protected:
   FXToggleButton();
+  void press(FXbool dn);
 private:
   FXToggleButton(const FXToggleButton&);
   FXToggleButton& operator=(const FXToggleButton&);
 public:
   long onPaint(FXObject*,FXSelector,void*);
   long onUpdate(FXObject*,FXSelector,void*);
-  long onFocusIn(FXObject*,FXSelector,void*);
-  long onFocusOut(FXObject*,FXSelector,void*);
-  long onActivate(FXObject*,FXSelector,void*);
-  long onDeactivate(FXObject*,FXSelector,void*);
   long onEnter(FXObject*,FXSelector,void*);
   long onLeave(FXObject*,FXSelector,void*);
+  long onFocusIn(FXObject*,FXSelector,void*);
+  long onFocusOut(FXObject*,FXSelector,void*);
+  long onUngrabbed(FXObject*,FXSelector,void*);
+  long onLeftBtnPress(FXObject*,FXSelector,void*);
+  long onLeftBtnRelease(FXObject*,FXSelector,void*);
+  long onKeyPress(FXObject*,FXSelector,void*);
+  long onKeyRelease(FXObject*,FXSelector,void*);
   long onHotKeyPress(FXObject*,FXSelector,void*);
   long onHotKeyRelease(FXObject*,FXSelector,void*);
   long onCheck(FXObject*,FXSelector,void*);
@@ -72,32 +85,70 @@ public:
   long onCmdSetIntValue(FXObject*,FXSelector,void*);
   long onCmdGetIntValue(FXObject*,FXSelector,void*);
 public:
-  FXToggleButton(FXComposite* p,const FXString& text1,const FXString& text2,FXIcon* icon1=NULL,FXIcon* icon2=NULL,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=FRAME_RAISED|FRAME_THICK|JUSTIFY_NORMAL|ICON_BEFORE_TEXT,FXint x=0,FXint y=0,FXint w=0,FXint h=0,FXint pl=DEFAULT_PAD,FXint pr=DEFAULT_PAD,FXint pt=DEFAULT_PAD,FXint pb=DEFAULT_PAD);
+
+  /// Construct toggle button with two text labels, and two icons, one for each state
+  FXToggleButton(FXComposite* p,const FXString& text1,const FXString& text2,FXIcon* icon1=NULL,FXIcon* icon2=NULL,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=TOGGLEBUTTON_NORMAL,FXint x=0,FXint y=0,FXint w=0,FXint h=0,FXint pl=DEFAULT_PAD,FXint pr=DEFAULT_PAD,FXint pt=DEFAULT_PAD,FXint pb=DEFAULT_PAD);
+
+  /// Create server-side resources
   virtual void create();
+
+  /// Detach server-side resources
   virtual void detach();
-  virtual void enable();
-  virtual void disable();
+
+  /// Returns true because a toggle button can receive focus
   virtual FXbool canFocus() const;
+
+  /// Get default width
   virtual FXint getDefaultWidth();
+
+  /// Get default height
   virtual FXint getDefaultHeight();
+
+  /// Change alternate text shown when toggled
   void setAltText(const FXString& text);
+
+  /// Return alternate text
   FXString getAltText() const { return altlabel; }
+
+  /// Change alternate icon shown when toggled
   void setAltIcon(FXIcon* ic);
+
+  /// Return alternate icon
   FXIcon* getAltIcon() const { return alticon; }
-  void setState(FXuint s=TRUE);
-  FXuint getState() const { return state; }
-  void setHelpText(const FXString& text);
-  FXString getHelpText() const { return help; }
+
+  /// Change toggled state
+  void setState(FXbool s=TRUE);
+
+  /// return toggled state
+  FXbool getState() const { return state; }
+
+  /// Change alternate help text shown when toggled
   void setAltHelpText(const FXString& text);
+
+  /// Return alternate help text
   FXString getAltHelpText() const { return althelp; }
-  void setTipText(const FXString& text);
-  FXString getTipText() const { return tip; }
+
+  /// Change alternate tip text shown when toggled
   void setAltTipText(const FXString& text);
+
+  /// Return alternate tip text
   FXString getAltTipText() const { return alttip; }
+
+  /// Set the toggle button style flags
+  void setToggleStyle(FXuint style);
+
+  /// Get the toggle button style flags
+  FXuint getToggleStyle() const;
+
+  /// Save toggle button to a stream
   virtual void save(FXStream& store) const;
+
+  /// Load toggle button from a stream
   virtual void load(FXStream& store);
+
+  /// Destructor
   virtual ~FXToggleButton();
   };
 
-  
+
 #endif
