@@ -3,7 +3,7 @@
 *                         T r e e   L i s t   W i d g e t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXTreeList.h,v 1.42 2001/08/23 16:24:51 jeroen Exp $                     *
+* $Id: FXTreeList.h,v 1.50 2002/01/18 22:42:55 jeroen Exp $                     *
 ********************************************************************************/
 #ifndef FXTREELIST_H
 #define FXTREELIST_H
 
+#ifndef FXSCROLLAREA_H
+#include "FXScrollArea.h"
+#endif
+
+
 
 struct FXTimer;
 class FXIcon;
@@ -66,7 +71,6 @@ protected:
 protected:
   FXTreeItem():prev(NULL),next(NULL),parent(NULL),first(NULL),last(NULL),openIcon(NULL),closedIcon(NULL),data(NULL),state(0),x(0),y(0){}
   virtual void draw(const FXTreeList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
-  void drawFocus(const FXTreeList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
   virtual FXint hitItem(const FXTreeList* list,FXint x,FXint y) const;
 protected:
   enum{
@@ -232,6 +236,12 @@ public:
   /// Tree list can receive focus
   virtual FXbool canFocus() const;
 
+  /// Move the focus to this window
+  virtual void setFocus();
+
+  /// Remove the focus from this window
+  virtual void killFocus();
+
   /// Return number of items
   FXint getNumItems() const;
 
@@ -280,14 +290,11 @@ public:
   /// Remove all items from list
   void clearItems(FXbool notify=FALSE);
 
-  // DEPRECATED same as above
-  void removeAllItems(FXbool notify=FALSE){ clearItems(notify); }
-
   /// Return item width
-  FXint getItemWidth(const FXTreeItem* item) const { return item->getWidth(this); }
+  FXint getItemWidth(const FXTreeItem* item) const;
 
   /// Return item height
-  FXint getItemHeight(const FXTreeItem* item) const { return item->getHeight(this); }
+  FXint getItemHeight(const FXTreeItem* item) const;
 
   /// Get item at x,y, if any
   virtual FXTreeItem* getItemAt(FXint x,FXint y) const;
