@@ -3,7 +3,7 @@
 *                  U n d o / R e d o - a b l e   C o m m a n d                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2000,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXUndoList.h,v 1.14 2001/08/23 16:37:35 jeroen Exp $                     *
+* $Id: FXUndoList.h,v 1.16 2002/01/18 22:42:55 jeroen Exp $                     *
 ********************************************************************************/
 #ifndef FXUNDOLIST_H
 #define FXUNDOLIST_H
 
+#ifndef FXOBJECT_H
+#include "FXObject.h"
+#endif
+
+
 
 class FXUndoList;
 
