@@ -3,7 +3,7 @@
 *                            V i s u a l   C l a s s                            *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXVisual.h,v 1.21 2001/08/23 16:24:51 jeroen Exp $                       *
+* $Id: FXVisual.h,v 1.23 2002/01/18 22:42:55 jeroen Exp $                       *
 ********************************************************************************/
 #ifndef FXVISUAL_H
 #define FXVISUAL_H
 
+#ifndef FXID_H
+#include "FXId.h"
+#endif
+
+
 
 /// Construction options for FXVisual class
 enum FXVisualOptions {
