@@ -3,7 +3,7 @@
 *                            X P M   I m a g e   O b j e c t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2000,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,14 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXXPMImage.h,v 1.4 2001/03/23 07:02:43 jeroen Exp $                      *
+* $Id: FXXPMImage.h,v 1.6 2002/01/18 22:42:55 jeroen Exp $                      *
 ********************************************************************************/
 #ifndef FXXPMIMAGE_H
 #define FXXPMIMAGE_H
 
+#ifndef FXIMAGE_H
+#include "FXImage.h"
+#endif
 
 
 /// X Pixmap image
