@@ -3,7 +3,7 @@
 *                   M a i n   F O X   I n c l u d e   F i l e                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: fx.h,v 1.44 2001/08/16 08:02:32 jeroen Exp $                             *
+* $Id: fx.h,v 1.49 2002/01/18 22:42:55 jeroen Exp $                             *
 ********************************************************************************/
 #ifndef FX_H
 #define FX_H
@@ -47,6 +47,7 @@
 #include "FXDict.h"
 #include "FXFile.h"
 #include "FXURL.h"
+#include "FXStringDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXObjectList.h"
@@ -66,11 +67,13 @@
 #include "FXBMPImage.h"
 #include "FXXPMImage.h"
 #include "FXPCXImage.h"
+#include "FXTGAImage.h"
 #include "FXIcon.h"
 #include "FXGIFIcon.h"
 #include "FXBMPIcon.h"
 #include "FXXPMIcon.h"
 #include "FXPCXIcon.h"
+#include "FXTGAIcon.h"
 #include "FXRegion.h"
 #include "FXDC.h"
 #include "FXDCWindow.h"
@@ -81,9 +84,12 @@
 #include "FXSeparator.h"
 #include "FXLabel.h"
 #include "FXDial.h"
+#include "FXColorBar.h"
 #include "FXColorWell.h"
+#include "FXColorWheel.h"
 #include "FXTextField.h"
 #include "FXButton.h"
+#include "FXPicker.h"
 #include "FXToggleButton.h"
 #include "FXCheckButton.h"
 #include "FXRadioButton.h"
@@ -114,7 +120,9 @@
 #include "FXMenubar.h"
 #include "FXOptionMenu.h"
 #include "FXSwitcher.h"
-#include "FXTab.h"
+#include "FXTabBar.h"
+#include "FXTabBook.h"
+#include "FXTabItem.h"
 #include "FXScrollbar.h"
 #include "FXScrollArea.h"
 #include "FXScrollWindow.h"
