@@ -3,7 +3,7 @@
 *      A d d i t i o n a l   F O X   I n c l u d e   F i l e   F o r   3 D      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: fx3d.h,v 1.4 2001/01/25 19:48:27 jeroen Exp $                            *
+* $Id: fx3d.h,v 1.5.4.1 2003/04/08 14:06:03 fox Exp $                            *
 ********************************************************************************/
 #ifndef FX3D_H
 #define FX3D_H
@@ -33,6 +33,12 @@
 #endif
 #ifdef HAVE_OPENGL
 #include <GL/gl.h>
+#ifndef GLAPIENTRY
+#define GLAPIENTRY
+#endif
+#ifndef GLAPI
+#define GLAPI
+#endif
 #include <GL/glu.h>
 #endif
 
