@@ -3,7 +3,7 @@
 *                     FOX Definitions, Types, and Macros                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: fxdefs.h,v 1.82 2001/08/02 06:09:42 jeroen Exp $                         *
+* $Id: fxdefs.h,v 1.95.4.3 2003/06/20 19:02:07 fox Exp $                            *
 ********************************************************************************/
 #ifndef FXDEFS_H
 #define FXDEFS_H
@@ -185,8 +185,6 @@ enum FXSelType {
   SEL_FOCUS_LEFT,
   SEL_FOCUS_DOWN,
   SEL_FOCUS_UP,
-  SEL_FOCUS_HOME,
-  SEL_FOCUS_END,
   SEL_FOCUS_NEXT,
   SEL_FOCUS_PREV,
   SEL_DND_ENTER,                      // Drag action entering potential drop target
@@ -194,8 +192,6 @@ enum FXSelType {
   SEL_DND_DROP,                       // Drop on drop target
   SEL_DND_MOTION,                     // Drag position changed over potential drop target
   SEL_DND_REQUEST,                    // Inquire drag and drop data
-  SEL_ACTIVATE,                       // Activate through mouse or keyboard
-  SEL_DEACTIVATE,                     // Deactivate through mouse or keyboard
   SEL_UNCHECK_OTHER,                  // Sent by child to parent to uncheck other children
   SEL_UNCHECK_RADIO,                  // Sent by parent to uncheck radio children
   SEL_IO_READ,                        // Read activity on a pipe
@@ -206,8 +202,8 @@ enum FXSelType {
   };
 
 
-/// FOX Keyboard/Button states
-enum FXModifierMasks {
+/// FOX Keyboard and Button states
+enum {
   SHIFTMASK        = 0x001,           /// Shift key is down
   CAPSLOCKMASK     = 0x002,           /// Caps Lock key is down
   CONTROLMASK      = 0x004,           /// Ctrl key is down
@@ -220,24 +216,24 @@ enum FXModifierMasks {
   };
 
 
-/// FOX Mouse Buttons
-enum FXMouseButton {
+/// FOX Mouse buttons
+enum {
   LEFTBUTTON       = 1,
   MIDDLEBUTTON     = 2,
   RIGHTBUTTON      = 3
   };
 
 
-/// FOX Crossing Modes
-enum FXCrossingMode {
+/// FOX window crossing modes
+enum {
   CROSSINGNORMAL,		     /// Normal crossing event
   CROSSINGGRAB,			     /// Crossing due to mouse grab
   CROSSINGUNGRAB		     /// Crossing due to mouse ungrab
   };
 
 
-/// FOX Visibility Modes
-enum FXVisibility {
+/// FOX window visibility modes
+enum {
   VISIBILITYTOTAL,
   VISIBILITYPARTIAL,
   VISIBILITYNONE
@@ -245,7 +241,7 @@ enum FXVisibility {
 
 
 /// Options for fxfilematch
-enum FXFileMatchOptions {
+enum {
   FILEMATCH_FILE_NAME   = 1,        /// No wildcard can ever match `/'
   FILEMATCH_NOESCAPE    = 2,        /// Backslashes don't quote special chars
   FILEMATCH_PERIOD      = 4,        /// Leading `.' is matched only explicitly
@@ -273,15 +269,6 @@ enum FXDNDOrigin {
   };
 
 
-/// File input modes for addInput
-enum FXInputMode {
-  INPUT_NONE   = 0,                 /// Inactive
-  INPUT_READ   = 1,                 /// Read input fd
-  INPUT_WRITE  = 2,                 /// Write input fd
-  INPUT_EXCEPT = 4                  /// Except input fd
-  };
-
-
 /// Exponent display
 enum FXExponent {
   EXP_NEVER=FALSE,                  /// Never use exponential notation
@@ -291,7 +278,7 @@ enum FXExponent {
 
 
 /// Search modes for search/replace dialogs
-enum FXSearchMode {
+enum {
   SEARCH_FORWARD      = 0,    /// Search forward (default)
   SEARCH_BACKWARD     = 1,    /// Search backward
   SEARCH_NOWRAP       = 0,    /// Don't wrap (default)
@@ -303,43 +290,6 @@ enum FXSearchMode {
   };
 
 
-/// All ways of being modal
-enum FXModality {
-  MODAL_FOR_NONE,                 /// Non modal event loop (dispatch normally)
-  MODAL_FOR_WINDOW,               /// Modal dialog (beep if outside of modal dialog)
-  MODAL_FOR_POPUP                 /// Modal for popup (always dispatch to popup)
-  };
-
-
-/// Default cursors provided by the application
-enum FXDefaultCursor {
-  DEF_ARROW_CURSOR,                     /// Arrow cursor
-  DEF_RARROW_CURSOR,                    /// Reverse arrow cursor
-  DEF_TEXT_CURSOR,                      /// Text cursor
-  DEF_HSPLIT_CURSOR,                    /// Horizontal split cursor
-  DEF_VSPLIT_CURSOR,                    /// Vertical split cursor
-  DEF_XSPLIT_CURSOR,                    /// Cross split cursor
-  DEF_SWATCH_CURSOR,                    /// Color swatch drag cursor
-  DEF_MOVE_CURSOR,                      /// Move cursor
-  DEF_DRAGH_CURSOR,                     /// Resize horizontal edge
-  DEF_DRAGV_CURSOR,                     /// Resize vertical edge
-  DEF_DRAGTL_CURSOR,                    /// Resize upper-leftcorner
-  DEF_DRAGBR_CURSOR=DEF_DRAGTL_CURSOR,  /// Resize bottom-right corner
-  DEF_DRAGTR_CURSOR,                    /// Resize upper-right corner
-  DEF_DRAGBL_CURSOR=DEF_DRAGTR_CURSOR,  /// Resize bottom-left corner
-  DEF_DNDSTOP_CURSOR,                   /// Drag and drop stop
-  DEF_DNDCOPY_CURSOR,                   /// Drag and drop copy
-  DEF_DNDMOVE_CURSOR,                   /// Drag and drop move
-  DEF_DNDLINK_CURSOR,                   /// Drag and drop link
-  DEF_CROSSHAIR_CURSOR,                 /// Cross hair cursor
-  DEF_CORNERNE_CURSOR,                  /// North-east cursor
-  DEF_CORNERNW_CURSOR,                  /// North-west cursor
-  DEF_CORNERSE_CURSOR,                  /// South-east cursor
-  DEF_CORNERSW_CURSOR,                  /// South-west cursor
-  DEF_ROTATE_CURSOR                     /// Rotate cursor
-  };
-
-
 /*********************************  Typedefs  **********************************/
 
 
@@ -361,16 +311,25 @@ typedef FXObject              *FXObjectPtr;
 #define FX_LONG
 typedef unsigned __int64       FXulong;
 typedef __int64                FXlong;
-#elif defined(__GNUG__) || defined(__GNUC__) || defined(__SUNPRO_CC)
+#elif defined(__GNUG__) || defined(__GNUC__) || defined(__SUNPRO_CC) || defined(__MWERKS__) || defined(__SC__)
 #define FX_LONG
 typedef unsigned long long int FXulong;
 typedef long long int          FXlong;
 #endif
 
 
+// Integral types large enough to hold value of a pointer
+#if defined(_MSC_VER) && defined(_WIN64)
+typedef __int64                FXival;
+typedef unsigned __int64       FXuval;
+#else
+typedef long                   FXival;
+typedef unsigned long          FXuval;
+#endif
+
 // Handle to something in server
 #ifndef WIN32
-typedef unsigned int           FXID;
+typedef unsigned long          FXID;
 #else
 typedef void*                  FXID;
 #endif
@@ -492,32 +451,37 @@ typedef void*                  FXInputHandle;
 // Definitions for little-endian machines
 #if FOX_BIGENDIAN == 0
 
-
-// Make RGBA color
+/// Make RGBA color
 #define FXRGBA(r,g,b,a)    (((FXuint)(FXuchar)(r)) | ((FXuint)(FXuchar)(g)<<8) | ((FXuint)(FXuchar)(b)<<16) | ((FXuint)(FXuchar)(a)<<24))
 
-// Make RGB color
+/// Make RGB color
 #define FXRGB(r,g,b)       (((FXuint)(FXuchar)(r)) | ((FXuint)(FXuchar)(g)<<8) | ((FXuint)(FXuchar)(b)<<16) | 0xff000000)
 
-// Get red value from RGBA color
+/// Get red value from RGBA color
 #define FXREDVAL(rgba)     ((FXuchar)((rgba)&0xff))
 
-// Get green value from RGBA color
+/// Get green value from RGBA color
 #define FXGREENVAL(rgba)   ((FXuchar)(((rgba)>>8)&0xff))
 
-// Get blue value from RGBA color
+/// Get blue value from RGBA color
 #define FXBLUEVAL(rgba)    ((FXuchar)(((rgba)>>16)&0xff))
 
-// Get alpha value from RGBA color
+/// Get alpha value from RGBA color
 #define FXALPHAVAL(rgba)   ((FXuchar)(((rgba)>>24)&0xff))
 
-// Get component value of RGBA color
+/// Get component value of RGBA color
 #define FXRGBACOMPVAL(rgba,comp) ((FXuchar)(((rgba)>>((comp)<<3))&0xff))
 
 #endif
 
 
-// Assertion
+/**
+* FXASSERT() prints out a message when the expression fails,
+* and nothing otherwise.  Unlike assert(), FXASSERT() will not
+* terminate the execution of the application.
+* When compiling your application for release, all assertions
+* are compiled out; thus there is no impact on execution speed.
+*/
 #ifndef NDEBUG
 #define FXASSERT(exp) ((exp)?((void)0):(void)fxassert(#exp,__FILE__,__LINE__))
 #else
@@ -525,11 +489,18 @@ typedef void*                  FXInputHandle;
 #endif
 
 
-// Tracing; use like: FXTRACE((10,"The value of x=%d\n",x)).
-// Setting fxTraceLevel to N will cause all trace statements with
-// trace levels greater than or equal to N to be blocked; trace
-// statements with levels below N will be printed.
-// Thus, fxTraceLevel equal to 0 will block all trace statements.
+/**
+* FXTRACE() allows you to trace the execution of your application
+* with increasing levels of detail the higher the trace level.
+* The trace level is determined by variable fxTraceLevel, which
+* may be set from the command line with "-tracelevel <level>".
+* When compiling your application for release, all trace statements
+* are compiled out, just like FXASSERT.
+* A statement like: FXTRACE((10,"The value of x=%d\n",x)) will
+* generate output only if fxTraceLevel is set to 11 or greater.
+* The default value fxTraceLevel=0 will block all trace outputs.
+* Note the double parentheses!
+*/
 #ifndef NDEBUG
 #define FXTRACE(arguments) fxtrace arguments
 #else
@@ -592,9 +563,6 @@ extern FXAPI void fxtrace(unsigned int level,const char* format,...) FX_PRINTF(2
 /// Sleep n microseconds
 extern FXAPI void fxsleep(unsigned int n);
 
-/// Key character value of keysym + modifier state
-extern FXAPI FXchar fxkeyval(FXuint code,FXuint state=0);
-
 /// Match a file name with a pattern
 extern FXAPI FXint fxfilematch(const char *pattern,const char *string,FXuint flags=(FILEMATCH_NOESCAPE|FILEMATCH_FILE_NAME));
 
@@ -622,123 +590,6 @@ extern FXAPI FXchar* fxgetgroupname(FXchar* result,FXuint gid);
 /// Get permissions string from mode.
 extern FXAPI FXchar* fxgetpermissions(FXchar* result,FXuint mode);
 
-/// Return TRUE iff s is a prefix of t
-extern FXAPI FXbool fxprefix(const FXchar* s,const FXchar* t);
-
-/// Return TRUE iff s is a suffix of t
-extern FXAPI FXbool fxsuffix(const FXchar* s, const FXchar* t);
-
-/**
- * Expand ~ in filenames using HOME environment variable.
- * This function is deprecated; use FXFile::expand() instead.
- */
-extern FXAPI FXchar* fxexpand(FXchar* result,const FXchar* name);
-
-/**
- * Construct a full pathname from the given directory and file name.
- * This function is deprecated; use FXFile::??? instead.
- */
-extern FXAPI FXchar* fxpathname(FXchar* result,const FXchar* dirname,const FXchar* filename);
-
-/**
- * Return the directory part of pathname.
- * This function is deprecated; use FXFile::directory() instead.
- */
-extern FXAPI FXchar* fxdirpart(FXchar* result,const FXchar* pathname);
-
-/**
- * Return the file title, i.e. filename less extension part of pathname.
- * This function is deprecated; use FXFile::title() instead.
- */
-extern FXAPI FXchar* fxfiletitle(FXchar* result,const FXchar* pathname);
-
-/**
- * Return the filename part of pathname.
- * This function is deprecated; use FXFile::name() instead.
- */
-extern FXAPI FXchar* fxfilepart(FXchar* result,const FXchar* pathname);
-
-/**
- * Return the file extension part of pathname.
- * This function is deprecated; use FXFile::extension() instead.
- */
-extern FXAPI FXchar* fxfileext(FXchar* result,const FXchar* pathname);
-
-/**
- * Check whether a file exists.
- * This function is deprecated; use FXFile::exists() instead.
- */
-extern FXAPI FXbool fxexists(const FXchar *name);
-
-/**
- * Check whether it's a directory.
- * This function is deprecated; use FXFile::isDirectory() instead.
- */
-extern FXAPI FXbool fxisdir(const FXchar *name);
-
-/**
- * Check whether it's a file.
- * This function is deprecated; use FXFile::isFile() instead.
- */
-extern FXAPI FXbool fxisfile(const FXchar *name);
-
-/// Create a unique numbered backup file name for the given pathname
-extern FXAPI FXchar* fxbakname(FXchar* result,const FXchar* pathname);
-
-/// Check whether two files are identical (refer to the same inode)
-extern FXAPI FXbool fxidentical(const FXchar *name1,const FXchar *name2);
-
-/// Split a string into substrings delimited by a given character
-extern FXAPI FXchar *fxsplit(FXchar*& s,FXchar c);
-
-/**
- * Return the shortest path equivalent to pathname (remove . and ..).
- * This function is deprecated; use FXFile::simplify() instead.
- */
-extern FXAPI FXchar *fxshortestpath(FXchar *result,const FXchar *pathname);
-
-/**
- * Return directory one level above given one.
- * This function is deprecated; use FXFile::upLevel() instead.
- */
-extern FXAPI FXchar* fxupdir(FXchar* result,const FXchar *dirname);
-
-/**
- * Translate filename to an absolute pathname; ~ in filename is expanded,
- * and if the resulting pathname is still relative, basename is prepended.
- * This function is deprecated; use FXFile::absolute() instead.
- */
-extern FXAPI FXchar *fxabspath(FXchar *result,const FXchar *basename,const FXchar *filename);
-
-/**
- * Test if path is the toplevel directory.
- * This function is deprecated; use FXFile::isTopDirectory() instead.
- */
-extern FXAPI FXbool fxistopdir(const FXchar* path);
-
-/**
- * Get current working directory.
- * This function is deprecated; use FXFile::getCurrentDirectory() instead.
- */
-extern FXAPI FXchar* fxgetcurrentdir(FXchar *result);
-
-/// Make a directory
-extern FXAPI FXint fxmkdir(const FXchar *pathname,FXuint mode);
-
-/**
- * Get home directory.
- * This function is deprecated; use FXFile::getHomeDirectory() instead.
- */
-extern FXAPI FXchar* fxgethomedir(FXchar *result);
-
-/**
- * Search path for file name. A ~ in path is expanded. If name is absolute
- * it is returned unchanged. Otherwise the absolute name is returned in
- * result. If name is not found on path, NULL is returned.
- * This function is deprecated; use FXFile::search() instead.
- */
-extern FXAPI FXchar *fxsearchpath(FXchar *result,const FXchar *path,const FXchar *name);
-
 /// Get process id
 extern FXAPI FXint fxgetpid();
 
@@ -764,7 +615,13 @@ extern FXAPI void fxhsv_to_rgb(FXfloat& r,FXfloat& g,FXfloat& b,FXfloat h,FXfloa
 extern FXAPI FXint fxieeefloatclass(FXfloat number);
 extern FXAPI FXint fxieeedoubleclass(FXdouble number);
 
+
+/// Version number that the library has been compiled with
+extern FXAPI const FXuchar fxversion[3];
+
+
 /// Controls tracing level
 extern FXAPI unsigned int fxTraceLevel;
 
+
 #endif
