@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: PathFinder.cpp,v 1.51 2001/08/08 17:27:59 jeroen Exp $                   *
+* $Id: PathFinder.cpp,v 1.57.4.2 2003/06/20 19:02:07 fox Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fx.h"
@@ -33,18 +33,18 @@
 
 /*
   Notes:
-  
+
   - Copy / Paste /Cut doesn't seem to work
-  - If you drag some files to a certain directory in the dir-list, hilight the directory so 
+  - If you drag some files to a certain directory in the dir-list, hilight the directory so
     we're sure we are dropping it in the right directory...
   - Settings dialog like the one in TextEdit....
   - Edit menu layout should change:
 
-      Undo 
+      Undo
       Redo
       separator
       Cut
-      Copy 
+      Copy
       Paste
       Delete
       separator
@@ -55,10 +55,10 @@
 
   - Mount/Unmount functionality....
   - A special bookmark button like home/work for /mnt/cdrom or/and just the /mnt directory
-  - Selecting multiple files and clicking Open With only displays the first file ... 
-    not the whole range you've selected.... mayby we should show the first and the last 
+  - Selecting multiple files and clicking Open With only displays the first file ...
+    not the whole range you've selected.... mayby we should show the first and the last
     file of the selection: (file1.htm ... file99.htm)
-  - Change 'Delete Files' dynamically  depending on the amount of files you've selected:  
+  - Change 'Delete Files' dynamically  depending on the amount of files you've selected:
     so 1 file shows only Delete File....  same thing for the dialog that shows up....
   - Time in statusbar as in TextEdit
 
@@ -142,10 +142,11 @@ PathFinderMain::PathFinderMain(FXApp* a):
   bigp=new FXBMPIcon(getApp(),bigpenguin,0,IMAGE_ALPHAGUESS);
   minip=new FXBMPIcon(getApp(),minipenguin,0,IMAGE_ALPHAGUESS);
   cuticon=new FXBMPIcon(getApp(),cut,0,IMAGE_ALPHAGUESS);
-  copyicon=new FXBMPIcon(getApp(),copy,0,IMAGE_ALPHAGUESS);
+  copyicon=new FXGIFIcon(getApp(),copyit,FXRGB(178,192,220),IMAGE_ALPHACOLOR);
+  moveicon=new FXGIFIcon(getApp(),moveit,FXRGB(178,192,220),IMAGE_ALPHACOLOR);
   pasteicon=new FXBMPIcon(getApp(),paste,0,IMAGE_ALPHAGUESS);
   upicon=new FXBMPIcon(getApp(),dirup,0,IMAGE_ALPHAGUESS);
-  homeicon=new FXBMPIcon(getApp(),home,0,IMAGE_ALPHAGUESS);
+  homeicon=new FXGIFIcon(getApp(),home);
   backicon=new FXBMPIcon(getApp(),goback,0,IMAGE_ALPHAGUESS);
   forwicon=new FXBMPIcon(getApp(),goforw,0,IMAGE_ALPHAGUESS);
   bigiconsicon=new FXBMPIcon(getApp(),bigicons,0,IMAGE_ALPHAGUESS);
@@ -167,27 +168,35 @@ PathFinderMain::PathFinderMain(FXApp* a):
   setTarget(this);
   setSelector(ID_MAINWINDOW);
 
-  // Menu bar
-  FXMenubar* menubar=new FXMenubar(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X,0,0,0,0, 4,4,4,4, 0,0);
+  // Make menu bar
+  FXMenubar *menubar=new FXMenubar(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X,0,0,0,0, 3,3,3,3, 0,0);
+
+  // Separator
+  new FXHorizontalSeparator(this,LAYOUT_SIDE_TOP|SEPARATOR_GROOVE|LAYOUT_FILL_X);
+
+  // Make Tool bar
+  FXToolbar *toolbar=new FXToolbar(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X,0,0,0,0, 3,3,3,3, 0,0);
 
   // Properties panel
   property=new PropertyDialog(this);
 
   // File menu pane
   filemenu=new FXMenuPane(this);
-  new FXMenuCommand(filemenu,"New &PathFinder...\tCtl-P\tStart another PathFinder.",minip,this,ID_NEW_PATHFINDER);
+  new FXMenuCommand(filemenu,"Open\t\tOpen selected file.",NULL,this,ID_OPEN);
+  new FXMenuCommand(filemenu,"Open with...\t\tOpen selected file using program.",NULL,this,ID_OPEN_WITH);
+  new FXMenuSeparator(filemenu);
+  new FXMenuCommand(filemenu,"&Run...\tCtl-R\tRun a command.",NULL,this,ID_RUN);
+  new FXMenuCommand(filemenu,"&Terminal...\tCtl-T\tOpen Terminal.",NULL,this,ID_TERMINAL);
+  new FXMenuSeparator(filemenu);
   new FXMenuCommand(filemenu,"&New Directory...",NULL,this,ID_NEW);
-  new FXMenuCommand(filemenu,"&Delete Files...",NULL,this,ID_DELETE);
+  new FXMenuCommand(filemenu,"Delete\tDel\tDelete the selection.",deleteicon,this,ID_DELETE);
+  new FXMenuSeparator(filemenu);
+  new FXMenuCommand(filemenu,"New &PathFinder...\tCtl-P\tStart another PathFinder.",minip,this,ID_NEW_PATHFINDER);
   new FXMenuCommand(filemenu,"&Quit\tCtl-Q\tQuit PathFinder",NULL,this,ID_QUIT);
+
+  // Command Menu Pane
   new FXMenuTitle(menubar,"&File",NULL,filemenu);
 
-  // Separator
-  new FXHorizontalSeparator(this,LAYOUT_SIDE_TOP|SEPARATOR_GROOVE|LAYOUT_FILL_X);
-
-  // Toolbar
-  FXToolbar* toolbar=new FXToolbar(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X,0,0,0,0, 4,4,4,4, 0,0);
-
-
   // Status bar
   FXStatusbar *status=new FXStatusbar(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|STATUSBAR_WITH_DRAGCORNER);
   FXStatusline *statusline=status->getStatusline();
@@ -207,11 +216,11 @@ PathFinderMain::PathFinderMain(FXApp* a):
 
 
   // Directories
-  new FXLabel(group1,"Directories",NULL,JUSTIFY_LEFT|LAYOUT_TOP|LAYOUT_FILL_X|FRAME_SUNKEN);
+  FXLabel* folders=new FXLabel(group1,"Folders",NULL,JUSTIFY_LEFT|LAYOUT_TOP|LAYOUT_FILL_X|FRAME_GROOVE);
   subgroup1=new FXVerticalFrame(group1,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y, 0,0,0,0, 0,0,0,0);
 
   // Files
-  FXLabel* files=new FXLabel(group2,"Files",NULL,JUSTIFY_LEFT|LAYOUT_TOP|LAYOUT_FILL_X|FRAME_SUNKEN);
+  FXLabel* files=new FXLabel(group2,"Files",NULL,JUSTIFY_LEFT|LAYOUT_TOP|LAYOUT_FILL_X|FRAME_GROOVE);
   files->setTarget(this);
   files->setSelector(ID_UPDATE_FILES);
   subgroup2=new FXVerticalFrame(group2,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y, 0,0,0,0, 0,0,0,0);
@@ -228,21 +237,15 @@ PathFinderMain::PathFinderMain(FXApp* a):
 
   // Edit Menu Pane
   editmenu=new FXMenuPane(this);
+  new FXMenuCommand(editmenu,"Cu&t\tCtl-X\tCut to clipboard.",cuticon,NULL,0);
+  new FXMenuCommand(editmenu,"&Copy\tCtl-C\tCopy to clipboard.",copyicon,NULL,0);
+  new FXMenuCommand(editmenu,"&Paste\tCtl-V\tPaste from clipboard.",pasteicon,NULL,0);
+  new FXMenuSeparator(editmenu);
   new FXMenuCommand(editmenu,"&Select All\tCtl-A\tSelect all icons",NULL,filelist,FXFileList::ID_SELECT_ALL);
   new FXMenuCommand(editmenu,"&Deselect All\t\tDeselect all icons",NULL,filelist,FXFileList::ID_DESELECT_ALL);
   new FXMenuCommand(editmenu,"&Invert Selection\t\tInvert selection",NULL,filelist,FXFileList::ID_SELECT_INVERSE);
-  new FXMenuCommand(editmenu,"Cu&t\tCtl-X\tCut to clipboard.",cuticon,NULL,0,FRAME_THICK|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
-  new FXMenuCommand(editmenu,"&Copy\tCtl-C\tCopy to clipboard.",copyicon,NULL,0,FRAME_THICK|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
-  new FXMenuCommand(editmenu,"&Paste\tCtl-V\tPaste from clipboard.",pasteicon,NULL,0,FRAME_THICK|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
   new FXMenuTitle(menubar,"&Edit",NULL,editmenu);
 
-  // Command Menu Pane
-  commandmenu=new FXMenuPane(this);
-  new FXMenuCommand(commandmenu,"Open...\t\tOpen selected file.",NULL,this,ID_OPEN);
-  new FXMenuCommand(commandmenu,"Open with...\t\tOpen selected file using program.",NULL,this,ID_OPEN_WITH);
-  new FXMenuCommand(commandmenu,"&Run command...\tCtl-R\tRun a command.",NULL,this,ID_RUN);
-  new FXMenuCommand(commandmenu,"&Terminal...\tCtl-T\tOpen Terminal.",NULL,this,ID_TERMINAL);
-  new FXMenuTitle(menubar,"&Command",NULL,commandmenu);
 
   // Pattern
   pattern=new FXComboBox(status,25,4,this,ID_FILEFILTER,COMBOBOX_STATIC|LAYOUT_RIGHT|LAYOUT_FIX_WIDTH|FRAME_SUNKEN|FRAME_THICK, 0,0,200,0, 0,0,1,1);
@@ -278,45 +281,56 @@ PathFinderMain::PathFinderMain(FXApp* a):
 
 
   // Add some toolbar buttons
-  new FXButton(toolbar,"\tUp\tChange up one level.",upicon,this,ID_UPDIRECTORY,FRAME_THICK|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
-  new FXButton(toolbar,"\tHome\tChange to home directory.",homeicon,this,ID_GO_HOME,FRAME_THICK|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
-  new FXButton(toolbar,"\tWork\tChange to current working directory.",workicon,this,ID_GO_WORK,FRAME_THICK|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
-  new FXMenuButton(toolbar,"\tBookmarks\tVisit bookmarked directories.",setbookicon,bookmarkmenu,MENUBUTTON_NOARROWS|MENUBUTTON_ATTACH_LEFT|FRAME_RAISED|FRAME_THICK);
-  new FXButton(toolbar,"\tBack\tChange to previous directory.",backicon,this,ID_GO_BACK,FRAME_THICK|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
-  new FXButton(toolbar,"\tForward\tChange to next directory.",forwicon,this,ID_GO_FORWARD,FRAME_THICK|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+  new FXButton(toolbar,"\tUp\tChange up one level.",upicon,this,ID_UPDIRECTORY,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+  new FXButton(toolbar,"\tHome\tChange to home directory.",homeicon,this,ID_GO_HOME,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+  new FXButton(toolbar,"\tWork\tChange to current working directory.",workicon,this,ID_GO_WORK,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+  new FXMenuButton(toolbar,"\tBookmarks\tVisit bookmarked directories.",setbookicon,bookmarkmenu,BUTTON_TOOLBAR|MENUBUTTON_NOARROWS|MENUBUTTON_ATTACH_LEFT|FRAME_RAISED);
+  new FXButton(toolbar,"\tBack\tChange to previous directory.",backicon,this,ID_GO_BACK,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+  new FXButton(toolbar,"\tForward\tChange to next directory.",forwicon,this,ID_GO_FORWARD,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
 
   // Spacer
-  new FXFrame(toolbar,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH,0,0,8,0);
+  new FXFrame(toolbar,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH,0,0,4,0);
+  new FXFrame(toolbar,FRAME_SUNKEN|LAYOUT_CENTER_Y|LAYOUT_FIX_HEIGHT|LAYOUT_FIX_WIDTH,0,0,2,22);
+  new FXFrame(toolbar,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH,0,0,4,0);
 
-  new FXButton(toolbar,"\tMount\tMount device.",mapicon,NULL,0,FRAME_THICK|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
-  new FXButton(toolbar,"\tUnmount\tUnmount device.",unmapicon,NULL,0,FRAME_THICK|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+
+  new FXButton(toolbar,"\tMount\tMount device.",mapicon,NULL,0,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+  new FXButton(toolbar,"\tUnmount\tUnmount device.",unmapicon,NULL,0,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+
+   // Spacer
+  new FXFrame(toolbar,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH,0,0,4,0);
+  new FXFrame(toolbar,FRAME_SUNKEN|LAYOUT_CENTER_Y|LAYOUT_FIX_HEIGHT|LAYOUT_FIX_WIDTH,0,0,2,22);
+  new FXFrame(toolbar,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH,0,0,4,0);
+
+  new FXButton(toolbar,"\tCut\tCut to clipboard.",cuticon,NULL,0,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+  new FXButton(toolbar,"\tCopy\tCopy to clipboard.",copyicon,NULL,0,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+  new FXButton(toolbar,"\tMove\tMove file.",moveicon,NULL,0,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+  new FXButton(toolbar,"\tPaste\tPaste from clipboard.",pasteicon,NULL,0,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
 
   // Spacer
-  new FXFrame(toolbar,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH,0,0,8,0);
+  new FXFrame(toolbar,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH,0,0,4,0);
+  new FXFrame(toolbar,FRAME_SUNKEN|LAYOUT_CENTER_Y|LAYOUT_FIX_HEIGHT|LAYOUT_FIX_WIDTH,0,0,2,22);
+  new FXFrame(toolbar,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH,0,0,4,0);
 
-  new FXButton(toolbar,"\tCut\tCut to clipboard.",cuticon,NULL,0,FRAME_THICK|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
-  new FXButton(toolbar,"\tCopy\tCopy to clipboard.",copyicon,NULL,0,FRAME_THICK|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
-  new FXButton(toolbar,"\tPaste\tPaste from clipboard.",pasteicon,NULL,0,FRAME_THICK|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
-
-  // Spacer
-  new FXFrame(toolbar,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH,0,0,8,0);
-
-  new FXButton(toolbar,"\tProperties\tDisplay file properties.",propicon,this,ID_PROPERTIES,FRAME_THICK|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
-
-  // Spacer
-  new FXFrame(toolbar,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH,0,0,8,0);
+  new FXButton(toolbar,"\tProperties\tDisplay file properties.",propicon,this,ID_PROPERTIES,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
 
+ // Spacer
+  new FXFrame(toolbar,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH,0,0,4,0);
+  new FXFrame(toolbar,FRAME_SUNKEN|LAYOUT_CENTER_Y|LAYOUT_FIX_HEIGHT|LAYOUT_FIX_WIDTH,0,0,2,22);
+  new FXFrame(toolbar,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH,0,0,4,0);
 
   // Switch display modes
-  new FXButton(toolbar,"\tBig Icons\tShow big icons.",bigiconsicon,filelist,FXFileList::ID_SHOW_BIG_ICONS,FRAME_THICK|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
-  new FXButton(toolbar,"\tSmall Icons\tShow small icons.",miniiconsicon,filelist,FXFileList::ID_SHOW_MINI_ICONS,FRAME_THICK|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
-  new FXButton(toolbar,"\tDetails\tShow detail view.",detailsicon,filelist,FXFileList::ID_SHOW_DETAILS,FRAME_THICK|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+  new FXButton(toolbar,"\tBig Icons\tShow big icons.",bigiconsicon,filelist,FXFileList::ID_SHOW_BIG_ICONS,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+  new FXButton(toolbar,"\tSmall Icons\tShow small icons.",miniiconsicon,filelist,FXFileList::ID_SHOW_MINI_ICONS,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+  new FXButton(toolbar,"\tDetails\tShow detail view.",detailsicon,filelist,FXFileList::ID_SHOW_DETAILS,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
 
-  // Spacer
-  new FXFrame(toolbar,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH,0,0,16,0);
+ // Spacer
+  new FXFrame(toolbar,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH,0,0,4,0);
+  new FXFrame(toolbar,FRAME_SUNKEN|LAYOUT_CENTER_Y|LAYOUT_FIX_HEIGHT|LAYOUT_FIX_WIDTH,0,0,2,22);
+  new FXFrame(toolbar,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH,0,0,4,0);
 
   // Delete button far away
-  new FXButton(toolbar,"\tDelete\tDelete file.",deleteicon,this,ID_DELETE,FRAME_THICK|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
+  new FXButton(toolbar,"\tDelete\tDelete file.",deleteicon,this,ID_DELETE,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
 
   // Go Menu Pane
   gomenu=new FXMenuPane(this);
@@ -411,7 +425,6 @@ PathFinderMain::~PathFinderMain(){
   delete associations;
   delete filemenu;
   delete editmenu;
-  delete commandmenu;
   delete viewmenu;
   delete gomenu;
   delete arrangemenu;
@@ -423,6 +436,7 @@ PathFinderMain::~PathFinderMain(){
   delete minip;
   delete cuticon;
   delete copyicon;
+  delete moveicon;
   delete pasteicon;
   delete upicon;
   delete homeicon;
@@ -501,7 +515,7 @@ long PathFinderMain::onUpdOpen(FXObject* sender,FXSelector,void*){
 
 // File Item was double-clicked
 long PathFinderMain::onCmdFileDblClicked(FXObject*,FXSelector,void* ptr){
-  FXint index=(FXint)(long)ptr;
+  FXint index=(FXint)(FXival)ptr;
   if(0<=index){
 
     // If directory, open the directory
@@ -585,7 +599,7 @@ long PathFinderMain::onFileListPopup(FXObject*,FXSelector,void* ptr){
     new FXMenuCommand(&pane,"Open...",NULL,this,ID_OPEN);
     new FXMenuCommand(&pane,"Open with...",NULL,this,ID_OPEN_WITH);
     new FXMenuSeparator(&pane);
-    new FXMenuCommand(&pane,"Copy",NULL,NULL,0);
+    new FXMenuCommand(&pane,"Copy",copyicon,NULL,0);
     new FXMenuCommand(&pane,"Rename",NULL,NULL,0);
     new FXMenuCommand(&pane,"Delete",deleteicon,this,ID_DELETE);
     new FXMenuSeparator(&pane);
@@ -615,8 +629,8 @@ long PathFinderMain::onCmdSetSearchPath(FXObject*,FXSelector,void*){
   FXTextField *text=new FXTextField(content,30,&dialog,FXDialogBox::ID_ACCEPT,TEXTFIELD_ENTER_ONLY|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X);
   new FXHorizontalSeparator(content,SEPARATOR_GROOVE|LAYOUT_FILL_X);
   FXHorizontalFrame* buttons=new FXHorizontalFrame(content,LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0,0,0,0,0);
-  new FXButton(buttons,"&OK",NULL,&dialog,FXDialogBox::ID_ACCEPT,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT);
-  new FXButton(buttons,"&Cancel",NULL,&dialog,FXDialogBox::ID_CANCEL,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
+  new FXButton(buttons,"&OK",NULL,&dialog,FXDialogBox::ID_ACCEPT,BUTTON_INITIAL|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT);
+  new FXButton(buttons,"&Cancel",NULL,&dialog,FXDialogBox::ID_CANCEL,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
   path=getApp()->reg().readStringEntry("SETTINGS","iconpath","~/.foxicons");
   text->setText(path);
   dialog.create();
@@ -825,12 +839,14 @@ long PathFinderMain::onCmdDelete(FXObject*,FXSelector,void*){
         file=filelist->getItemFilename(i);
         if(file=="..") continue;
         filetoremove=FXFile::absolute(filelist->getDirectory(),file);
+        FXTRACE((100,"filetoremove=%s\n",filetoremove.text()));
         if(!FXFile::remove(filetoremove)){
           if(MBOX_CLICKED_NO==FXMessageBox::error(this,MBOX_YES_NO,"Error Deleting File","Unable to delete file: %s\nContinue with operation?",filetoremove.text())){
             break;
             }
           }
         }
+
       }
     }
   return 1;
@@ -857,8 +873,8 @@ long PathFinderMain::onCmdNew(FXObject*,FXSelector,void*){
   FXTextField *text=new FXTextField(content,40,&dialog,FXDialogBox::ID_ACCEPT,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X);
   new FXHorizontalSeparator(content,SEPARATOR_GROOVE|LAYOUT_FILL_X);
   FXHorizontalFrame* buttons=new FXHorizontalFrame(content,LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0,0,0,0,0);
-  new FXButton(buttons,"&OK",NULL,&dialog,FXDialogBox::ID_ACCEPT,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT);
-  new FXButton(buttons,"&Cancel",NULL,&dialog,FXDialogBox::ID_CANCEL,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
+  new FXButton(buttons,"&OK",NULL,&dialog,FXDialogBox::ID_ACCEPT,BUTTON_INITIAL|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT);
+  new FXButton(buttons,"&Cancel",NULL,&dialog,FXDialogBox::ID_CANCEL,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
   dialog.create();
   text->setText(suggestedname);
   text->setFocus();
@@ -1196,7 +1212,7 @@ long PathFinderMain::onCmdOpenWith(FXObject*,FXSelector,void*){
       //fcntl(fd,F_SETFD,TRUE);
       // Start command and pass it the filename
       execlp(cmd.text(),cmd.text(),filename.text(),NULL);
-      
+
       // Just in case we failed to execute the command
       ::exit(0);
       }
@@ -1231,8 +1247,13 @@ long PathFinderMain::onCmdRun(FXObject*,FXSelector,void*){
 // Run terminal
 long PathFinderMain::onCmdTerminal(FXObject*,FXSelector,void*){
   FXString prg=getApp()->reg().readStringEntry("SETTINGS","terminal","xterm");
-  prg+=" &";
-  system(prg.text());
+  if(!prg.empty()){
+    prg+=" &";
+    system(prg.text());
+    }
+  else{
+    FXMessageBox::information(this,MBOX_OK,"Cannot run terminal!","Terminal Application is not specified.\n");
+    }
   return 1;
   }
 
@@ -1405,33 +1426,33 @@ long PathFinderMain::onSigHarvest(FXObject*,FXSelector,void*){
 
 // Start the whole thing
 int main(int argc,char *argv[]){
-  
+
   // Create application
   FXApp application("PathFinder","FoxTest");
-  
+
   // Keep original launch name
   PathFinderMain::pathfindercommand=argv[0];
-  
+
   // Initialize application
   application.init(argc,argv);
-  
+
   // Build GUI
   PathFinderMain* window=new PathFinderMain(&application);
-  
+
   // On unix, we need to catch SIGCHLD to harvest zombie child processes.
 #ifndef WIN32
   application.addSignal(SIGCHLD,window,PathFinderMain::ID_HARVEST,TRUE);
 #endif
-  
+
   // Also catch interrupt so we can gracefully terminate
   application.addSignal(SIGINT,window,PathFinderMain::ID_QUIT);
-  
+
   // Create window
   application.create();
-  
+
   // If given, start in indicated directory
   if(argc==2) window->setDirectory(argv[1]);
-  
+
   // Run the app now...
   return application.run();
   }
