@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: PathFinder.h,v 1.18 2001/06/21 06:27:06 jeroen Exp $                     *
+* $Id: PathFinder.h,v 1.20.4.1 2002/04/17 18:45:00 fox Exp $                     *
 ********************************************************************************/
 #ifndef PATHFINDER_H
 #define PATHFINDER_H
@@ -35,7 +35,6 @@ protected:
   PropertyDialog    *property;
   FXMenuPane        *filemenu;
   FXMenuPane        *editmenu;
-  FXMenuPane        *commandmenu;
   FXMenuPane        *viewmenu;
   FXMenuPane        *gomenu;
   FXMenuPane        *arrangemenu;
@@ -57,6 +56,7 @@ protected:
   FXIcon            *minip;
   FXIcon            *cuticon;
   FXIcon            *copyicon;
+  FXIcon            *moveicon;
   FXIcon            *pasteicon;
   FXIcon            *upicon;
   FXIcon            *homeicon;
