@@ -3,7 +3,7 @@
 *                   A c c e l e r a t o r   T a b l e   C l a s s               *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXAccelTable.cpp,v 1.8 2001/04/27 14:30:30 jeroen Exp $                  *
+* $Id: FXAccelTable.cpp,v 1.11 2002/01/18 22:42:57 jeroen Exp $                 *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,7 +30,6 @@
 #include "FXPoint.h"
 #include "FXRectangle.h"
 #include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
@@ -186,6 +185,25 @@ FXbool FXAccelTable::hasAccel(FXHotKey hotkey) const {
   }
 
 
+// Return target object of the given accelerator
+FXObject* FXAccelTable::targetOfAccel(FXHotKey hotkey) const {
+  if(hotkey){
+    register FXuint p,x,c;
+    FXASSERT(hotkey!=UNUSEDSLOT);
+    FXASSERT(hotkey!=EMPTYSLOT);
+    p=HASH1(hotkey,nkey);
+    FXASSERT(p<nkey);
+    x=HASH2(hotkey,nkey);
+    FXASSERT(1<=x && x<nkey);
+    while((c=key[p].code)!=UNUSEDSLOT){
+      if(c==hotkey) return key[p].target;
+      p=(p+x)%nkey;
+      }
+    }
+  return NULL;
+  }
+
+
 // Keyboard press; forward to focus child
 long FXAccelTable::onKeyPress(FXObject* sender,FXSelector,void* ptr){
   FXEvent* event=(FXEvent*)ptr;
