@@ -3,7 +3,7 @@
 *                     A r r o w   B u t t o n    O b j e c t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXArrowButton.cpp,v 1.22 2001/08/23 04:53:16 jeroen Exp $                *
+* $Id: FXArrowButton.cpp,v 1.26 2002/01/18 22:42:58 jeroen Exp $                *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,17 +30,10 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
 #include "FXLabel.h"
 #include "FXArrowButton.h"
 
@@ -69,6 +62,8 @@ FXDEFMAP(FXArrowButton) FXArrowButtonMap[]={
   FXMAPFUNC(SEL_KEYRELEASE,0,FXArrowButton::onKeyRelease),
   FXMAPFUNC(SEL_KEYPRESS,FXWindow::ID_HOTKEY,FXArrowButton::onHotKeyPress),
   FXMAPFUNC(SEL_KEYRELEASE,FXWindow::ID_HOTKEY,FXArrowButton::onHotKeyRelease),
+  FXMAPFUNC(SEL_UPDATE,FXWindow::ID_QUERY_TIP,FXArrowButton::onQueryTip),
+  FXMAPFUNC(SEL_UPDATE,FXWindow::ID_QUERY_HELP,FXArrowButton::onQueryHelp),
   };
 
 
@@ -301,6 +296,26 @@ long FXArrowButton::onHotKeyRelease(FXObject*,FXSelector,void*){
   }
 
 
+// We were asked about status text
+long FXArrowButton::onQueryHelp(FXObject* sender,FXSelector,void*){
+  if(!help.empty() && (flags&FLAG_HELP)){
+    sender->handle(this,MKUINT(ID_SETSTRINGVALUE,SEL_COMMAND),(void*)&help);
+    return 1;
+    }
+  return 0;
+  }
+
+
+// We were asked about tip text
+long FXArrowButton::onQueryTip(FXObject* sender,FXSelector,void*){
+  if(!tip.empty() && (flags&FLAG_TIP)){
+    sender->handle(this,MKUINT(ID_SETSTRINGVALUE,SEL_COMMAND),(void*)&tip);
+    return 1;
+    }
+  return 0;
+  }
+
+
 // Handle repaint
 long FXArrowButton::onPaint(FXObject*,FXSelector,void* ptr){
   FXEvent   *ev=(FXEvent*)ptr;
