@@ -3,7 +3,7 @@
 *                             B i t m a p    O b j e c t                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXBitmap.cpp,v 1.30 2001/08/21 22:37:55 jeroen Exp $                     *
+* $Id: FXBitmap.cpp,v 1.35 2002/01/18 22:42:58 jeroen Exp $                     *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -29,17 +29,12 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
 #include "FXVisual.h"
-#include "FXDrawable.h"
 #include "FXBitmap.h"
 #include "FXVisual.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
 
 /*
@@ -94,10 +89,10 @@ FXBitmap::FXBitmap(FXApp* a,const void *pix,FXuint opts,FXint w,FXint h):FXDrawa
 // Create bitmap
 void FXBitmap::create(){
   if(!xid){
-    if(getApp()->initialized){ 
+    if(getApp()->initialized){
       FXTRACE((100,"%s::create %p\n",getClassName(),this));
 #ifndef WIN32
-      
+
       // Initialize visual
       visual->create();
 
@@ -105,7 +100,7 @@ void FXBitmap::create(){
       xid=XCreatePixmap(DISPLAY(getApp()),XDefaultRootWindow(DISPLAY(getApp())),width,height,1);
       if(!xid){ fxerror("%s::create: unable to create bitmap.\n",getClassName()); }
 #else
-    
+
       // Initialize visual
       visual->create();
 
@@ -142,11 +137,11 @@ void FXBitmap::destroy(){
     if(getApp()->initialized){
       FXTRACE((100,"%s::destroy %p\n",getClassName(),this));
 #ifndef WIN32
-      
+
       // Delete pixmap
       XFreePixmap(DISPLAY(getApp()),xid);
 #else
-      
+
       // Delete bitmap
       DeleteObject(xid);
 #endif
@@ -158,145 +153,154 @@ void FXBitmap::destroy(){
 
 // Render into pixmap
 void FXBitmap::render(){
+  if(xid){
 
-  FXTRACE((100,"%s::render bitmap %p\n",getClassName(),this));
+    FXTRACE((100,"%s::render bitmap %p\n",getClassName(),this));
 
-  // Do it for X-Windows
+    // Do it for X-Windows
 #ifndef WIN32
 
-  // XImage xim;
-  register XImage *xim=NULL;
-  register Visual *vis;
-  register int size;
-  register FXuchar *pix;
-  register int i;
-  XGCValues values;
-  GC gc;
+    // XImage xim;
+    register XImage *xim=NULL;
+    register Visual *vis;
+    register int size;
+    register FXuchar *pix;
+    register int i;
+    XGCValues values;
+    GC gc;
 
-  // Can not render before creation
-  if(!xid){ fxerror("%s::render: trying to render bitmap before it has been created.\n",getClassName()); }
+    // Check for legal size
+    if(width<1 || height<1){ fxerror("%s::render: illegal bitmap size.\n",getClassName()); }
 
-  // Check for legal size
-  if(width<1 || height<1){ fxerror("%s::render: illegal bitmap size.\n",getClassName()); }
+    // Make GC
+    values.foreground=0xffffffff;
+    values.background=0;
+    gc=XCreateGC(DISPLAY(getApp()),xid,GCForeground|GCBackground,&values);
 
-  // Make GC
-  values.foreground=0xffffffff;
-  values.background=0;
-  gc=XCreateGC(DISPLAY(getApp()),xid,GCForeground|GCBackground,&values);
+    // Just leave if black if no data
+    if(data){
 
-  // Just leave if black if no data
-  if(data){
+      // Get Visual
+      vis=(Visual*)visual->visual;
 
-    // Get Visual
-    vis=(Visual*)visual->visual;
+      xim=XCreateImage(DISPLAY(getApp()),vis,1,XYBitmap,0,NULL,width,height,8,(width+7)>>3);
+      if(!xim){ fxerror("%s::render: unable to render image.\n",getClassName()); }
 
-    xim=XCreateImage(DISPLAY(getApp()),vis,1,XYBitmap,0,NULL,width,height,8,(width+7)>>3);
-    if(!xim){ fxerror("%s::render: unable to render image.\n",getClassName()); }
+      // Try create temp pixel store
+      if(!FXMALLOC(&xim->data,char,xim->bytes_per_line*height)){ fxerror("%s::render: unable to allocate memory.\n",getClassName()); }
 
-    // Try create temp pixel store
-    if(!FXMALLOC(&xim->data,char,xim->bytes_per_line*height)){ fxerror("%s::render: unable to allocate memory.\n",getClassName()); }
+      // Render bits into server-formatted bitmap
+      size=xim->bytes_per_line*height;
+      pix=(FXuchar*)xim->data;
 
-    // Render bits into server-formatted bitmap
-    size=xim->bytes_per_line*height;
-    pix=(FXuchar*)xim->data;
+      // Most significant bit first
+      if(xim->bitmap_bit_order==MSBFirst){
+        for(i=0; i<size; i++) pix[i]=FXBITREVERSE(data[i]);
+        }
 
-    // Most significant bit first
-    if(xim->bitmap_bit_order==MSBFirst){
-      for(i=0; i<size; i++) pix[i]=FXBITREVERSE(data[i]);
+      // Least significant bit first
+      else{
+        memcpy(pix,data,size);
+        }
+
+      // Blast the image
+      XPutImage(DISPLAY(getApp()),xid,gc,xim,0,0,0,0,width,height);
+      FXFREE(&xim->data);
+      XDestroyImage(xim);
       }
 
-    // Least significant bit first
+    // No data, fill with black
     else{
-      memcpy(pix,data,size);
+      XFillRectangle(DISPLAY(getApp()),xid,gc,0,0,width,height);
       }
 
-    // Blast the image
-    XPutImage(DISPLAY(getApp()),xid,gc,xim,0,0,0,0,width,height);
-    FXFREE(&xim->data);
-    XDestroyImage(xim);
-    }
-
-  // No data, fill with black
-  else{
-    XFillRectangle(DISPLAY(getApp()),xid,gc,0,0,width,height);
-    }
-
-  // We're done
-  XFreeGC(DISPLAY(getApp()),gc);
+    // We're done
+    XFreeGC(DISPLAY(getApp()),gc);
 
 #else
 
-  register FXuchar *p,*q,bits;
-  register FXint nb,i,j,bytes_per_line;
-  FXuchar *widedata;
+    register FXuchar *p,*q,bits;
+    register FXint nb,i,j,bytes_per_line;
+    FXuchar *widedata;
 
-  // Can not render before creation
-  if(!xid){ fxerror("%s::render: trying to render bitmap before it has been created.\n",getClassName()); }
+    // Check for legal size
+    if(width<1 || height<1){ fxerror("%s::render: illegal bitmap size.\n",getClassName()); }
 
-  // Check for legal size
-  if(width<1 || height<1){ fxerror("%s::render: illegal bitmap size.\n",getClassName()); }
+    HDC hdcmem=::CreateCompatibleDC(NULL);
 
-  HDC hdcmem=::CreateCompatibleDC(NULL);
+    // Fill with data
+    if(data){
 
-  // Fill with data
-  if(data){
+      // Now make the device dependent bitmap
+      struct BITMAPINFO2 {
+        BITMAPINFOHEADER bmiHeader;
+        RGBQUAD          bmiColors[2];
+        };
 
-    // Now make the device dependent bitmap
-    struct BITMAPINFO2 {
-      BITMAPINFOHEADER bmiHeader;
-      RGBQUAD          bmiColors[2];
-      };
+      // Set up the bitmap info
+      BITMAPINFO2 bmi;
+      bmi.bmiHeader.biSize=sizeof(BITMAPINFOHEADER);
+      bmi.bmiHeader.biWidth=width;
+      bmi.bmiHeader.biHeight=height;
+      bmi.bmiHeader.biPlanes=1;
+      bmi.bmiHeader.biBitCount=1;
+      bmi.bmiHeader.biCompression=0;
+      bmi.bmiHeader.biSizeImage=0;
+      bmi.bmiHeader.biXPelsPerMeter=0;
+      bmi.bmiHeader.biYPelsPerMeter=0;
+      bmi.bmiHeader.biClrUsed=0;
+      bmi.bmiHeader.biClrImportant=0;
+      bmi.bmiColors[0].rgbBlue=0;
+      bmi.bmiColors[0].rgbGreen=0;
+      bmi.bmiColors[0].rgbRed=0;
+      bmi.bmiColors[0].rgbReserved=0;
+      bmi.bmiColors[1].rgbBlue=255;
+      bmi.bmiColors[1].rgbGreen=255;
+      bmi.bmiColors[1].rgbRed=255;
+      bmi.bmiColors[1].rgbReserved=0;
 
-    // Set up the bitmap info
-    BITMAPINFO2 bmi;
-    bmi.bmiHeader.biSize=sizeof(BITMAPINFOHEADER);
-    bmi.bmiHeader.biWidth=width;
-    bmi.bmiHeader.biHeight=height;
-    bmi.bmiHeader.biPlanes=1;
-    bmi.bmiHeader.biBitCount=1;
-    bmi.bmiHeader.biCompression=0;
-    bmi.bmiHeader.biSizeImage=0;
-    bmi.bmiHeader.biXPelsPerMeter=0;
-    bmi.bmiHeader.biYPelsPerMeter=0;
-    bmi.bmiHeader.biClrUsed=0;
-    bmi.bmiHeader.biClrImportant=0;
-    bmi.bmiColors[0].rgbBlue=0;
-    bmi.bmiColors[0].rgbGreen=0;
-    bmi.bmiColors[0].rgbRed=0;
-    bmi.bmiColors[0].rgbReserved=0;
-    bmi.bmiColors[1].rgbBlue=255;
-    bmi.bmiColors[1].rgbGreen=255;
-    bmi.bmiColors[1].rgbRed=255;
-    bmi.bmiColors[1].rgbReserved=0;
-
-    nb=(width+7)>>3;
-    bytes_per_line=((width+31)&~31)>>3;
-    FXCALLOC(&widedata,FXuchar,height*bytes_per_line);
-    p=widedata+(height-1)*bytes_per_line;
-    q=data;
-    for(i=0; i<height; i++){
-      for(j=0; j<nb; j++){
-        bits=~q[j];
-        p[j]=FXBITREVERSE(bits);
+      nb=(width+7)>>3;
+      bytes_per_line=((width+31)&~31)>>3;
+      FXCALLOC(&widedata,FXuchar,height*bytes_per_line);
+      p=widedata+(height-1)*bytes_per_line;
+      q=data;
+      for(i=0; i<height; i++){
+        for(j=0; j<nb; j++){
+          bits=~q[j];
+          p[j]=FXBITREVERSE(bits);
+          }
+        q+=nb;
+        p-=bytes_per_line;
         }
-      q+=nb;
-      p-=bytes_per_line;
+      if(!SetDIBits(hdcmem,(HBITMAP)xid,0,height,widedata,(BITMAPINFO*)&bmi,DIB_RGB_COLORS)){
+        fxerror("%s::render: unable to render pixels\n",getClassName());
+        }
+      FXFREE(&widedata);
+      GdiFlush();
       }
-    if(!SetDIBits(hdcmem,(HBITMAP)xid,0,height,widedata,(BITMAPINFO*)&bmi,DIB_RGB_COLORS)){
-      fxerror("%s::render: unable to render pixels\n",getClassName());
+
+    // No data, fill with black
+    else{
+      SelectObject(hdcmem,(HBITMAP)xid);
+      BitBlt(hdcmem,0,0,width,height,hdcmem,0,0,BLACKNESS);
       }
-    FXFREE(&widedata);
-    GdiFlush();
-    }
-
-  // No data, fill with black
-  else{
-    SelectObject(hdcmem,(HBITMAP)xid);
-    BitBlt(hdcmem,0,0,width,height,hdcmem,0,0,BLACKNESS);
-    }
-  ::DeleteDC(hdcmem);
-
+    ::DeleteDC(hdcmem);
 #endif
+    }
+  }
+
+
+// Get pixel at x,y
+FXbool FXBitmap::getPixel(FXint x,FXint y) const {
+  register FXint nb=(width+7)>>3;
+  return (data[y*nb+(x>>3)] & (1<<(x&7)))!=0;
+  }
+
+
+// Change pixel at x,y
+void FXBitmap::setPixel(FXint x,FXint y,FXbool color){
+  register FXint nb=(width+7)>>3;
+  if(color) data[y*nb+(x>>3)]|=(1<<(x&7)); else data[y*nb+(x>>3)]&=~(1<<(x&7));
   }
 
 
