@@ -3,7 +3,7 @@
 *                           B u t t o n    O b j e c t s                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXButton.cpp,v 1.26 2001/05/24 18:58:53 jeroen Exp $                     *
+* $Id: FXButton.cpp,v 1.41.4.3 2003/06/20 19:02:07 fox Exp $                     *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,20 +30,12 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
-#include "FXDrawable.h"
-#include "FXImage.h"
 #include "FXIcon.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
-#include "FXLabel.h"
+#include "FXShell.h"
 #include "FXButton.h"
 
 
@@ -63,7 +55,7 @@
 */
 
 // Button styles
-#define BUTTON_MASK        (BUTTON_AUTOGRAY|BUTTON_AUTOHIDE|BUTTON_TOOLBAR)
+#define BUTTON_MASK (BUTTON_AUTOGRAY|BUTTON_AUTOHIDE|BUTTON_TOOLBAR|BUTTON_DEFAULT)
 
 /*******************************************************************************/
 
@@ -106,7 +98,37 @@ FXButton::FXButton(FXComposite* p,const FXString& text,FXIcon* ic,FXObject* tgt,
   target=tgt;
   message=sel;
   state=STATE_UP;
-  if(options&BUTTON_DEFAULT) addHotKey(MKUINT(KEY_Return,0));
+  if(options&BUTTON_INITIAL){
+    setInitial(TRUE);
+    setDefault(TRUE);
+    }
+  }
+
+
+// If window can have focus
+FXbool FXButton::canFocus() const { return 1; }
+
+
+// Set focus to this widget
+void FXButton::setFocus(){
+  FXLabel::setFocus();
+  if(options&BUTTON_DEFAULT) setDefault(TRUE);
+  update();
+  }
+
+
+// Kill focus to this widget
+void FXButton::killFocus(){
+  FXLabel::killFocus();
+  if(options&BUTTON_DEFAULT) setDefault(MAYBE);
+  update();
+  }
+
+
+// Make widget drawn as default
+void FXButton::setDefault(FXbool enable){
+  FXLabel::setDefault(enable);
+  update();
   }
 
 
@@ -119,13 +141,9 @@ void FXButton::setState(FXuint s){
   }
 
 
-// If window can have focus
-FXbool FXButton::canFocus() const { return 1; }
-
-
 // Update value from a message
 long FXButton::onCmdSetValue(FXObject*,FXSelector,void* ptr){
-  setState((FXint)(long)ptr);
+  setState((FXuint)(FXuval)ptr);
   return 1;
   }
 
@@ -171,7 +189,7 @@ long FXButton::onUpdate(FXObject* sender,FXSelector sel,void* ptr){
 // Gained focus
 long FXButton::onFocusIn(FXObject* sender,FXSelector sel,void* ptr){
   FXLabel::onFocusIn(sender,sel,ptr);
-  update(border,border,width-(border<<1),height-(border<<1));
+  update();
   return 1;
   }
 
@@ -179,7 +197,7 @@ long FXButton::onFocusIn(FXObject* sender,FXSelector sel,void* ptr){
 // Lost focus
 long FXButton::onFocusOut(FXObject* sender,FXSelector sel,void* ptr){
   FXLabel::onFocusOut(sender,sel,ptr);
-  update(border,border,width-(border<<1),height-(border<<1));
+  update();
   return 1;
   }
 
@@ -254,7 +272,7 @@ long FXButton::onKeyPress(FXObject*,FXSelector,void* ptr){
   flags&=~FLAG_TIP;
   if(isEnabled() && !(flags&FLAG_PRESSED)){
     if(target && target->handle(this,MKUINT(message,SEL_KEYPRESS),ptr)) return 1;
-    if(event->code==KEY_space || event->code==KEY_KP_Space){
+    if((event->code==KEY_space || event->code==KEY_KP_Space) || (isDefault() && (event->code==KEY_Return || event->code==KEY_KP_Enter))){
       if(state!=STATE_ENGAGED) setState(STATE_DOWN);
       flags|=FLAG_PRESSED;
       flags&=~FLAG_UPDATE;
@@ -271,7 +289,7 @@ long FXButton::onKeyRelease(FXObject*,FXSelector,void* ptr){
   FXbool click=(state==STATE_DOWN);
   if(isEnabled() && (flags&FLAG_PRESSED)){
     if(target && target->handle(this,MKUINT(message,SEL_KEYRELEASE),ptr)) return 1;
-    if(event->code==KEY_space || event->code==KEY_KP_Space){
+    if((event->code==KEY_space || event->code==KEY_KP_Space) || (isDefault() && (event->code==KEY_Return || event->code==KEY_KP_Enter))){
       if(state!=STATE_ENGAGED) setState(STATE_UP);
       flags|=FLAG_UPDATE;
       flags&=~FLAG_PRESSED;
@@ -444,7 +462,7 @@ long FXButton::onPaint(FXObject*,FXSelector,void* ptr){
       dc.setForeground(textColor);
       drawLabel(dc,label,hotoff,tx,ty,tw,th);
       if(hasFocus()){
-        drawFocusRectangle(dc,border+2,border+2,width-2*border-4,height-2*border-4);
+        dc.drawFocusRectangle(border+1,border+1,width-2*border-2,height-2*border-2);
         }
       }
     else{
@@ -458,7 +476,7 @@ long FXButton::onPaint(FXObject*,FXSelector,void* ptr){
   }
 
 
-// Set icon positioning
+// Set button style
 void FXButton::setButtonStyle(FXuint style){
   FXuint opts=(options&~BUTTON_MASK) | (style&BUTTON_MASK);
   if(options!=opts){
@@ -468,34 +486,8 @@ void FXButton::setButtonStyle(FXuint style){
   }
 
 
-// Get icon positioning
+// Get button style
 FXuint FXButton::getButtonStyle() const {
   return (options&BUTTON_MASK);
   }
 
-
-// Test if default
-FXbool FXButton::isDefault() const {
-  return (options&BUTTON_DEFAULT)!=0;
-  }
-
-
-// Set as default widget
-void FXButton::setDefault(FXbool def){
-  if((options&BUTTON_DEFAULT) && !def){
-    options&=~BUTTON_DEFAULT;
-    remHotKey(MKUINT(KEY_Return,0));
-    update();
-    }
-  else if(!(options&BUTTON_DEFAULT) && def){
-    options|=BUTTON_DEFAULT;
-    addHotKey(MKUINT(KEY_Return,0));
-    update();
-    }
-  }
-
-
-// Destroy
-FXButton::~FXButton(){
-  if(options&BUTTON_DEFAULT) remHotKey(MKUINT(KEY_Return,0));
-  }
