@@ -3,7 +3,7 @@
 *                    C h e c k   B u t t o n    O b j e c t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXCheckButton.cpp,v 1.31 2001/05/24 13:16:23 jeroen Exp $                *
+* $Id: FXCheckButton.cpp,v 1.36.4.1 2003/06/20 19:02:07 fox Exp $                *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,18 +30,10 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
-#include "FXLabel.h"
 #include "FXCheckButton.h"
 
 /*
@@ -161,14 +153,14 @@ long FXCheckButton::onUnknown(FXObject*,FXSelector,void*){
 
 // Update value from a message
 long FXCheckButton::onCmdSetValue(FXObject*,FXSelector,void* ptr){
-  setCheck((FXint)(long)ptr);
+  setCheck((FXbool)(FXuval)ptr);
   return 1;
   }
 
 
 // Update value from a message
 long FXCheckButton::onCmdSetIntValue(FXObject*,FXSelector,void* ptr){
-  setCheck(*((FXint*)ptr));
+  setCheck((FXbool)*((FXint*)ptr));
   return 1;
   }
 
@@ -246,7 +238,7 @@ long FXCheckButton::onLeftBtnRelease(FXObject*,FXSelector,void* ptr){
     if(target && target->handle(this,MKUINT(message,SEL_LEFTBUTTONRELEASE),ptr)) return 1;
     flags|=FLAG_UPDATE;
     flags&=~FLAG_PRESSED;
-    if(check!=oldcheck && target){ target->handle(this,MKUINT(message,SEL_COMMAND),(void*)check); }
+    if(check!=oldcheck && target){ target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(long)check); }
     return 1;
     }
   return 0;
@@ -289,7 +281,7 @@ long FXCheckButton::onKeyRelease(FXObject*,FXSelector,void* ptr){
     if(event->code==KEY_space || event->code==KEY_KP_Space){
       flags|=FLAG_UPDATE;
       flags&=~FLAG_PRESSED;
-      if(check!=oldcheck && target){ target->handle(this,MKUINT(message,SEL_COMMAND),(void*)check); }
+      if(check!=oldcheck && target){ target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(long)check); }
       return 1;
       }
     }
@@ -317,7 +309,7 @@ long FXCheckButton::onHotKeyRelease(FXObject*,FXSelector,void*){
     flags|=FLAG_UPDATE;
     flags&=~FLAG_PRESSED;
     if(check!=oldcheck){
-      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)check);
+      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(long)check);
       }
     }
   return 1;
@@ -398,7 +390,7 @@ long FXCheckButton::onPaint(FXObject*,FXSelector,void* ptr){
       dc.setForeground(textColor);
       drawLabel(dc,label,hotoff,tx,ty,tw,th);
       if(hasFocus()){
-        drawFocusRectangle(dc,tx-1,ty-1,tw+2,th+2);
+        dc.drawFocusRectangle(tx-1,ty-1,tw+2,th+2);
         }
       }
     else{
