@@ -3,7 +3,7 @@
 *                         C o l o r W e l l   C l a s s                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXColorWell.cpp,v 1.31 2001/04/27 14:30:31 jeroen Exp $                  *
+* $Id: FXColorWell.cpp,v 1.40.4.1 2003/06/20 19:02:07 fox Exp $                  *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -31,22 +31,12 @@
 #include "FXPoint.h"
 #include "FXRectangle.h"
 #include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
-#include "FXComposite.h"
 #include "FXLabel.h"
 #include "FXColorWell.h"
-#include "FXShell.h"
-#include "FXTopWindow.h"
-#include "FXDialogBox.h"
 #include "FXColorDialog.h"
 
 /*
@@ -118,7 +108,7 @@ FXIMPLEMENT(FXColorWell,FXFrame,FXColorWellMap,ARRAYNUMBER(FXColorWellMap))
 
 // Init
 FXColorWell::FXColorWell(){
-  flags|=FLAG_ENABLED|FLAG_SHOWN;
+  flags|=FLAG_ENABLED|FLAG_DROPTARGET;
   rgba=0;
   oldrgba=0;
   wellColor[0]=0;
@@ -129,7 +119,7 @@ FXColorWell::FXColorWell(){
 // Make a color well
 FXColorWell::FXColorWell(FXComposite* p,FXColor clr,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h,FXint pl,FXint pr,FXint pt,FXint pb):
   FXFrame(p,opts,x,y,w,h,pl,pr,pt,pb){
-  flags|=FLAG_ENABLED|FLAG_SHOWN;
+  flags|=FLAG_ENABLED|FLAG_DROPTARGET;
   target=tgt;
   message=sel;
   rgba=clr;
@@ -144,7 +134,6 @@ void FXColorWell::create(){
   FXFrame::create();
   if(!colorType){colorType=getApp()->registerDragType(colorTypeName);}
   if(!textType){textType=getApp()->registerDragType(textTypeName);}
-  dropEnable();
   }
 
 
@@ -160,6 +149,20 @@ void FXColorWell::detach(){
 FXbool FXColorWell::canFocus() const { return 1; }
 
 
+// Into focus chain
+void FXColorWell::setFocus(){
+  FXFrame::setFocus();
+  setDefault(TRUE);
+  }
+
+
+// Out of focus chain
+void FXColorWell::killFocus(){
+  FXFrame::killFocus();
+  setDefault(MAYBE);
+  }
+
+
 // Compute color over black
 FXColor FXColorWell::rgbaoverblack(FXColor clr){
   FXint r,g,b,mul=FXALPHAVAL(clr);
@@ -219,7 +222,7 @@ long FXColorWell::onPaint(FXObject*,FXSelector,void* ptr){
   dc.fillPolygon(points,3);
   drawDoubleSunkenRectangle(dc,padleft+FOCUSBORDER,padtop+FOCUSBORDER,width-padright-padleft-(FOCUSBORDER<<1),height-padbottom-padtop-(FOCUSBORDER<<1));
   if(hasFocus()){
-    drawFocusRectangle(dc,padleft,padtop,width-padright-padleft,height-padbottom-padtop);
+    dc.drawFocusRectangle(padleft,padtop,width-padright-padleft,height-padbottom-padtop);
     }
   return 1;
   }
@@ -255,7 +258,7 @@ long FXColorWell::onDNDLeave(FXObject* sender,FXSelector sel,void* ptr){
   if(FXFrame::onDNDLeave(sender,sel,ptr)) return 1;
   flags|=FLAG_UPDATE;
   if(oldrgba!=rgba){
-    handle(this,MKUINT(0,SEL_CHANGED),(void*)oldrgba);
+    handle(this,MKUINT(0,SEL_CHANGED),(void*)(FXuval)oldrgba);
     }
   return 1;
   }
@@ -275,7 +278,7 @@ long FXColorWell::onDNDMotion(FXObject* sender,FXSelector sel,void* ptr){
   if(getDNDData(FROM_DRAGNDROP,colorType,(FXuchar*&)clr,len)){
     color=FXRGBA((clr[0]+128)/257,(clr[1]+128)/257,(clr[2]+128)/257,(clr[3]+128)/257);
     FXFREE(&clr);
-    handle(this,MKUINT(0,SEL_CHANGED),(void*)color);
+    handle(this,MKUINT(0,SEL_CHANGED),(void*)(FXuval)color);
     acceptDrop(DRAG_COPY);
     return 1;
     }
@@ -288,7 +291,7 @@ long FXColorWell::onDNDMotion(FXObject* sender,FXSelector sel,void* ptr){
 
     // Accept the drop only if it was a valid color name
     if(color!=FXRGBA(0,0,0,0)){
-      handle(this,MKUINT(0,SEL_CHANGED),(void*)color);
+      handle(this,MKUINT(0,SEL_CHANGED),(void*)(FXuval)color);
       acceptDrop(DRAG_COPY);
       return 1;
       }
@@ -307,7 +310,7 @@ long FXColorWell::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr){
 
   // Now send the command because the drop was finalized
   if(oldrgba!=rgba){
-    handle(this,MKUINT(0,SEL_COMMAND),(void*)rgba);
+    handle(this,MKUINT(0,SEL_COMMAND),(void*)(FXuval)rgba);
     oldrgba=rgba;
     return 1;
     }
@@ -472,14 +475,14 @@ long FXColorWell::onLeftBtnRelease(FXObject*,FXSelector,void* ptr){
     if(target && target->handle(this,MKUINT(message,SEL_LEFTBUTTONRELEASE),ptr)) return 1;
     if(flgs&FLAG_DODRAG){handle(this,MKUINT(0,SEL_ENDDRAG),ptr);}
     if(event->click_count==1){
-      handle(this,MKUINT(0,SEL_CLICKED),(void*)rgba);
-      if(!event->moved){handle(this,MKUINT(0,SEL_COMMAND),(void*)rgba);}
+      handle(this,MKUINT(0,SEL_CLICKED),(void*)(FXuval)rgba);
+      if(!event->moved){handle(this,MKUINT(0,SEL_COMMAND),(void*)(FXuval)rgba);}
       }
     else if(event->click_count==2){
-      handle(this,MKUINT(0,SEL_DOUBLECLICKED),(void*)rgba);
+      handle(this,MKUINT(0,SEL_DOUBLECLICKED),(void*)(FXuval)rgba);
       }
     else if(event->click_count==3){
-      handle(this,MKUINT(0,SEL_TRIPLECLICKED),(void*)rgba);
+      handle(this,MKUINT(0,SEL_TRIPLECLICKED),(void*)(FXuval)rgba);
       }
     return 1;
     }
@@ -511,8 +514,8 @@ long FXColorWell::onMiddleBtnRelease(FXObject*,FXSelector,void* ptr){
     if(getDNDData(FROM_SELECTION,colorType,(FXuchar*&)clr,len)){
       color=FXRGBA((clr[0]+128)/257,(clr[1]+128)/257,(clr[2]+128)/257,(clr[3]+128)/257);
       FXFREE(&clr);
-      handle(this,MKUINT(0,SEL_CHANGED),(void*)color);
-      handle(this,MKUINT(0,SEL_COMMAND),(void*)color);
+      handle(this,MKUINT(0,SEL_CHANGED),(void*)(FXuval)color);
+      handle(this,MKUINT(0,SEL_COMMAND),(void*)(FXuval)color);
       return 1;
       }
 
@@ -521,8 +524,8 @@ long FXColorWell::onMiddleBtnRelease(FXObject*,FXSelector,void* ptr){
       FXRESIZE(&str,FXchar,len+1); str[len]='\0';
       color=fxcolorfromname(str);
       FXFREE(&str);
-      handle(this,MKUINT(0,SEL_CHANGED),(void*)color);
-      handle(this,MKUINT(0,SEL_COMMAND),(void*)color);
+      handle(this,MKUINT(0,SEL_CHANGED),(void*)(FXuval)color);
+      handle(this,MKUINT(0,SEL_COMMAND),(void*)(FXuval)color);
       return 1;
       }
     }
@@ -539,11 +542,8 @@ long FXColorWell::onKeyPress(FXObject*,FXSelector,void* ptr){
     switch(event->code){
       case KEY_space:
       case KEY_KP_Enter:
-        flags&=~FLAG_UPDATE;
-        flags|=FLAG_KEY;
       case KEY_Return:
         flags&=~FLAG_UPDATE;
-        flags|=FLAG_KEY;
         return 1;
       }
     }
@@ -556,16 +556,15 @@ long FXColorWell::onKeyRelease(FXObject*,FXSelector,void* ptr){
   FXEvent* event=(FXEvent*)ptr;
   if(isEnabled()){
     flags|=FLAG_UPDATE;
-    flags&=~FLAG_KEY;
     if(target && target->handle(this,MKUINT(message,SEL_KEYRELEASE),ptr)) return 1;
     switch(event->code){
       case KEY_space:
-        handle(this,MKUINT(0,SEL_CLICKED),(void*)rgba);
-        handle(this,MKUINT(0,SEL_COMMAND),(void*)rgba);
+        handle(this,MKUINT(0,SEL_CLICKED),(void*)(FXuval)rgba);
+        handle(this,MKUINT(0,SEL_COMMAND),(void*)(FXuval)rgba);
         return 1;
       case KEY_KP_Enter:
       case KEY_Return:
-        handle(this,MKUINT(0,SEL_DOUBLECLICKED),(void*)rgba);
+        handle(this,MKUINT(0,SEL_DOUBLECLICKED),(void*)(FXuval)rgba);
         return 1;
       }
     }
@@ -575,10 +574,10 @@ long FXColorWell::onKeyRelease(FXObject*,FXSelector,void* ptr){
 
 // Change color value
 long FXColorWell::onChanged(FXObject*,FXSelector,void* ptr){
-  FXColor clr=(FXColor)(long)ptr;
+  FXColor clr=(FXColor)(FXuval)ptr;
   if(clr!=rgba){
     setRGBA(clr);
-    if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)rgba);
+    if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXuval)rgba);
     }
   return 1;
   }
@@ -586,7 +585,7 @@ long FXColorWell::onChanged(FXObject*,FXSelector,void* ptr){
 
 // Command from cell
 long FXColorWell::onCommand(FXObject*,FXSelector,void*){
-  return target && target->handle(this,MKUINT(message,SEL_COMMAND),(void*)rgba);
+  return target && target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(FXuval)rgba);
   }
 
 
@@ -594,7 +593,7 @@ long FXColorWell::onCommand(FXObject*,FXSelector,void*){
 long FXColorWell::onClicked(FXObject*,FXSelector,void*){
   FXDragType types[2];
 
-  if(target && target->handle(this,MKUINT(message,SEL_CLICKED),(void*)rgba)) return 1;
+  if(target && target->handle(this,MKUINT(message,SEL_CLICKED),(void*)(FXuval)rgba)) return 1;
 
   // Double click means claim selection
   if(!hasSelection()){
@@ -610,7 +609,7 @@ long FXColorWell::onClicked(FXObject*,FXSelector,void*){
 long FXColorWell::onDoubleClicked(FXObject*,FXSelector,void*){
 
   // Double click
-  if(target && target->handle(this,MKUINT(message,SEL_DOUBLECLICKED),(void*)rgba)) return 1;
+  if(target && target->handle(this,MKUINT(message,SEL_DOUBLECLICKED),(void*)(FXuval)rgba)) return 1;
 
   // Can not be edited
   if(options&COLORWELL_SOURCEONLY) return 1;
@@ -625,8 +624,8 @@ long FXColorWell::onDoubleClicked(FXObject*,FXSelector,void*){
 
   // We canceled, so restore the old color
   if(!colordialog.execute()){
-    handle(this,MKUINT(0,SEL_CHANGED),(void*)oldcolor);
-    handle(this,MKUINT(0,SEL_COMMAND),(void*)oldcolor);
+    handle(this,MKUINT(0,SEL_CHANGED),(void*)(FXuval)oldcolor);
+    handle(this,MKUINT(0,SEL_COMMAND),(void*)(FXuval)oldcolor);
     }
   return 1;
   }
@@ -634,7 +633,7 @@ long FXColorWell::onDoubleClicked(FXObject*,FXSelector,void*){
 
 // Triple clicked in well, to edit its color; only if not a source-only well
 long FXColorWell::onTripleClicked(FXObject*,FXSelector,void*){
-  return target && target->handle(this,MKUINT(message,SEL_TRIPLECLICKED),(void*)rgba);
+  return target && target->handle(this,MKUINT(message,SEL_TRIPLECLICKED),(void*)(FXuval)rgba);
   }
 
 
@@ -651,7 +650,7 @@ long FXColorWell::onUngrabbed(FXObject* sender,FXSelector sel,void* ptr){
 // Change from another Color Well
 long FXColorWell::onChgColorWell(FXObject*,FXSelector,void* ptr){
   flags&=~FLAG_UPDATE;
-  setRGBA((FXColor)(long)ptr);
+  setRGBA((FXColor)(FXuval)ptr);
   if(target) target->handle(this,MKUINT(message,SEL_CHANGED),ptr);
   return 1;
   }
@@ -659,7 +658,7 @@ long FXColorWell::onChgColorWell(FXObject*,FXSelector,void* ptr){
 
 // Command from another Color Well
 long FXColorWell::onCmdColorWell(FXObject*,FXSelector,void* ptr){
-  setRGBA((FXColor)(long)ptr);
+  setRGBA((FXColor)(FXuval)ptr);
   if(target) target->handle(this,MKUINT(message,SEL_COMMAND),ptr);
   flags|=FLAG_UPDATE;
   return 1;
@@ -686,18 +685,6 @@ long FXColorWell::onQueryTip(FXObject* sender,FXSelector,void*){
   }
 
 
-// Change help text
-void FXColorWell::setHelpText(const FXString& text){
-  help=text;
-  }
-
-
-// Change tip text
-void FXColorWell::setTipText(const FXString& text){
-  tip=text;
-  }
-
-
 // Change RGBA color
 void FXColorWell::setRGBA(FXColor clr){
   if(options&COLORWELL_OPAQUEONLY) clr|=FXRGBA(0,0,0,255);
@@ -710,27 +697,21 @@ void FXColorWell::setRGBA(FXColor clr){
   }
 
 
-// Get RGBA color
-FXColor FXColorWell::getRGBA() const {
-  return rgba;
-  }
-
-
 // Set color
 long FXColorWell::onCmdSetValue(FXObject*,FXSelector,void* ptr){
-  setRGBA((FXColor)(long)ptr);
+  setRGBA((FXColor)(FXuval)ptr);
   return 1;
   }
 
 
-// Update value from a message
+// Update well from a message
 long FXColorWell::onCmdSetIntValue(FXObject*,FXSelector,void* ptr){
   setRGBA(*((FXColor*)ptr));
   return 1;
   }
 
 
-// Obtain value from text field
+// Obtain value from well
 long FXColorWell::onCmdGetIntValue(FXObject*,FXSelector,void* ptr){
   *((FXColor*)ptr)=getRGBA();
   return 1;
