@@ -3,7 +3,7 @@
 *                       C o m b o   B o x   O b j e c t                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXComboBox.cpp,v 1.15 2001/04/27 14:30:31 jeroen Exp $                   *
+* $Id: FXComboBox.cpp,v 1.21.4.1 2003/06/20 19:02:07 fox Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,8 +30,6 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
@@ -64,8 +62,8 @@
   - FXComboBox is a text field which in turn may fill an FXList also.
   - In most other respects, it behaves like a FXTextField.
   - Need to catch up/down arrow keys.
-  - Need to have mode to pass item* instead of char*.
   - Combobox turns OFF GUI Updating while being manipulated.
+  - Need some way to size the FXList automatically to the number of items.
 */
 
 #define COMBOBOX_INS_MASK   (COMBOBOX_REPLACE|COMBOBOX_INSERT_BEFORE|COMBOBOX_INSERT_AFTER|COMBOBOX_INSERT_FIRST|COMBOBOX_INSERT_LAST)
@@ -79,8 +77,6 @@
 FXDEFMAP(FXComboBox) FXComboBoxMap[]={
   FXMAPFUNC(SEL_FOCUS_UP,0,FXComboBox::onFocusUp),
   FXMAPFUNC(SEL_FOCUS_DOWN,0,FXComboBox::onFocusDown),
-  FXMAPFUNC(SEL_CHANGED,0,FXComboBox::onChanged),
-  FXMAPFUNC(SEL_COMMAND,0,FXComboBox::onCommand),
   FXMAPFUNC(SEL_UPDATE,FXComboBox::ID_TEXT,FXComboBox::onUpdFmText),
   FXMAPFUNC(SEL_CLICKED,FXComboBox::ID_LIST,FXComboBox::onListClicked),
   FXMAPFUNC(SEL_LEFTBUTTONPRESS,FXComboBox::ID_TEXT,FXComboBox::onTextButton),
@@ -106,8 +102,8 @@ FXComboBox::FXComboBox(FXComposite *p,FXint cols,FXint nvis,FXObject* tgt,FXSele
   flags|=FLAG_ENABLED;
   target=tgt;
   message=sel;
-  text=new FXTextField(this,cols,this,FXComboBox::ID_TEXT,0, 0,0,0,0, pl,pr,pt,pb);
-  if(options&COMBOBOX_STATIC) text->setEditable(FALSE);
+  field=new FXTextField(this,cols,this,FXComboBox::ID_TEXT,0, 0,0,0,0, pl,pr,pt,pb);
+  if(options&COMBOBOX_STATIC) field->setEditable(FALSE);
   pane=new FXPopup(this,FRAME_LINE);
   list=new FXList(pane,nvis,this,FXComboBox::ID_LIST,LIST_BROWSESELECT|LIST_AUTOSELECT|LAYOUT_FILL_X|LAYOUT_FILL_Y|SCROLLERS_TRACK|HSCROLLER_NEVER);
   if(options&COMBOBOX_STATIC) list->setScrollStyle(SCROLLERS_TRACK|HSCROLLING_OFF);
@@ -143,7 +139,7 @@ void FXComboBox::destroy(){
 void FXComboBox::enable(){
   if(!(flags&FLAG_ENABLED)){
     FXPacker::enable();
-    text->enable();
+    field->enable();
     button->enable();
     }
   }
@@ -153,7 +149,7 @@ void FXComboBox::enable(){
 void FXComboBox::disable(){
   if(flags&FLAG_ENABLED){
     FXPacker::disable();
-    text->disable();
+    field->disable();
     button->disable();
     }
   }
@@ -162,7 +158,7 @@ void FXComboBox::disable(){
 // Get default width
 FXint FXComboBox::getDefaultWidth(){
   FXint ww,pw;
-  ww=text->getDefaultWidth()+button->getDefaultWidth()+(border<<1);
+  ww=field->getDefaultWidth()+button->getDefaultWidth()+(border<<1);
   pw=pane->getDefaultWidth();
   return FXMAX(ww,pw);
   }
@@ -171,7 +167,7 @@ FXint FXComboBox::getDefaultWidth(){
 // Get default height
 FXint FXComboBox::getDefaultHeight(){
   FXint th,bh;
-  th=text->getDefaultHeight();
+  th=field->getDefaultHeight();
   bh=button->getDefaultHeight();
   return FXMAX(th,bh)+(border<<1);
   }
@@ -183,7 +179,7 @@ void FXComboBox::layout(){
   itemHeight=height-(border<<1);
   buttonWidth=button->getDefaultWidth();
   textWidth=width-buttonWidth-(border<<1);
-  text->position(border,border,textWidth,itemHeight);
+  field->position(border,border,textWidth,itemHeight);
   button->position(border+textWidth,border,buttonWidth,itemHeight);
   pane->resize(width,pane->getDefaultHeight());
   flags&=~FLAG_DIRTY;
@@ -192,37 +188,22 @@ void FXComboBox::layout(){
 
 // Forward GUI update of text field to target; but only if pane is not popped
 long FXComboBox::onUpdFmText(FXObject*,FXSelector,void*){
-  return target && !pane->shown() && target->handle(this,MKUINT(message,SEL_UPDATE),NULL);
+  return target && !isPaneShown() && target->handle(this,MKUINT(message,SEL_UPDATE),NULL);
   }
 
 
 // Command handled in the text field
 long FXComboBox::onFwdToText(FXObject* sender,FXSelector sel,void* ptr){
-  return text->handle(sender,sel,ptr);
-  }
-
-
-// Changed
-long FXComboBox::onChanged(FXObject*,FXSelector,void* ptr){
-  if(target) target->handle(this,MKUINT(message,SEL_CHANGED),ptr);
-  return 1;
-  }
-
-
-// Command
-long FXComboBox::onCommand(FXObject*,FXSelector,void* ptr){
-  if(target) target->handle(this,MKUINT(message,SEL_COMMAND),ptr);
-  return 1;
+  return field->handle(sender,sel,ptr);
   }
 
 
 // Forward clicked message from list to target
 long FXComboBox::onListClicked(FXObject*,FXSelector,void* ptr){
   button->handle(this,MKUINT(ID_UNPOST,SEL_COMMAND),NULL);    // Unpost the list
-  if(0<=((FXint)(long)ptr)){
-    FXString string=list->getItemText((FXint)(long)ptr);
-    text->setText(string);
-    handle(this,MKUINT(0,SEL_COMMAND),(void*)string.text());
+  if(0<=((FXint)(FXival)ptr)){
+    field->setText(list->getItemText((FXint)(FXival)ptr));
+    if(target){target->handle(this,MKUINT(message,SEL_COMMAND),(void*)getText().text());}
     }
   return 1;
   }
@@ -240,8 +221,7 @@ long FXComboBox::onTextButton(FXObject*,FXSelector,void*){
 
 // Text has changed
 long FXComboBox::onTextChanged(FXObject*,FXSelector,void* ptr){
-  handle(this,MKUINT(0,SEL_CHANGED),ptr);
-  return 1;
+  return target && target->handle(this,MKUINT(message,SEL_CHANGED),ptr);
   }
 
 
@@ -267,8 +247,7 @@ long FXComboBox::onTextCommand(FXObject*,FXSelector,void* ptr){
         break;
       }
     }
-  handle(this,MKUINT(0,SEL_COMMAND),ptr);
-  return 1;
+  return target && target->handle(this,MKUINT(message,SEL_COMMAND),ptr);
   }
 
 
@@ -279,7 +258,7 @@ long FXComboBox::onFocusUp(FXObject*,FXSelector,void*){
   else if(0<index) index--;
   if(0<=index && index<getNumItems()){
     setCurrentItem(index);
-    handle(this,MKUINT(0,SEL_COMMAND),(void*)list->getItemText(index).text());
+    if(target){target->handle(this,MKUINT(message,SEL_COMMAND),(void*)getText().text());}
     }
   return 1;
   }
@@ -292,7 +271,7 @@ long FXComboBox::onFocusDown(FXObject*,FXSelector,void*){
   else if(index<getNumItems()-1) index++;
   if(0<=index && index<getNumItems()){
     setCurrentItem(index);
-    handle(this,MKUINT(0,SEL_COMMAND),(void*)list->getItemText(index).text());
+    if(target){target->handle(this,MKUINT(message,SEL_COMMAND),(void*)getText().text());}
     }
   return 1;
   }
@@ -300,37 +279,37 @@ long FXComboBox::onFocusDown(FXObject*,FXSelector,void*){
 
 // Return true if editable
 FXbool FXComboBox::isEditable() const {
-  return text->isEditable();
+  return field->isEditable();
   }
 
 
 // Set widget is editable or not
 void FXComboBox::setEditable(FXbool edit){
-  text->setEditable(edit);
+  field->setEditable(edit);
   }
 
 
 // Set text
-void FXComboBox::setText(const FXString& txt){
-  text->setText(txt);
+void FXComboBox::setText(const FXString& text){
+  field->setText(text);
   }
 
 
 // Obtain text
 FXString FXComboBox::getText() const {
-  return text->getText();
+  return field->getText();
   }
 
 
 // Set number of text columns
 void FXComboBox::setNumColumns(FXint cols){
-  text->setNumColumns(cols);
+  field->setNumColumns(cols);
   }
 
 
 // Get number of text columns
 FXint FXComboBox::getNumColumns() const {
-  return text->getNumColumns();
+  return field->getNumColumns();
   }
 
 
@@ -365,7 +344,7 @@ void FXComboBox::setCurrentItem(FXint index){
     setText(list->getItemText(index));
     }
   else{
-    setText("");
+    setText(FXString::null);
     }
   }
 
@@ -385,6 +364,9 @@ FXString FXComboBox::retrieveItem(FXint index) const {
 // Replace text of item at index
 void FXComboBox::replaceItem(FXint index,const FXString& text,void* ptr){
   list->replaceItem(index,text,NULL,ptr);
+  if(isItemCurrent(index)){
+    field->setText(text);
+    }
   recalc();
   }
 
@@ -392,6 +374,9 @@ void FXComboBox::replaceItem(FXint index,const FXString& text,void* ptr){
 // Insert item at index
 void FXComboBox::insertItem(FXint index,const FXString& text,void* ptr){
   list->insertItem(index,text,NULL,ptr);
+  if(isItemCurrent(index)){
+    field->setText(text);
+    }
   recalc();
   }
 
@@ -399,6 +384,9 @@ void FXComboBox::insertItem(FXint index,const FXString& text,void* ptr){
 // Append item
 void FXComboBox::appendItem(const FXString& text,void* ptr){
   list->appendItem(text,NULL,ptr);
+  if(isItemCurrent(getNumItems()-1)){
+    field->setText(text);
+    }
   recalc();
   }
 
@@ -406,20 +394,25 @@ void FXComboBox::appendItem(const FXString& text,void* ptr){
 // Prepend item
 void FXComboBox::prependItem(const FXString& text,void* ptr){
   list->prependItem(text,NULL,ptr);
+  if(isItemCurrent(0)){
+    field->setText(text);
+    }
   recalc();
   }
 
 
 // Remove given item
 void FXComboBox::removeItem(FXint index){
-  FXint current;
+  FXint current=list->getCurrentItem();
   list->removeItem(index);
-  current=list->getCurrentItem();
-  if(0<=current){
-    setText(list->getItemText(current));
-    }
-  else{
-    setText("");
+  if(index==current){
+    current=list->getCurrentItem();
+    if(0<=current){
+      field->setText(list->getItemText(current));
+      }
+    else{
+      field->setText(FXString::null);
+      }
     }
   recalc();
   }
@@ -427,8 +420,8 @@ void FXComboBox::removeItem(FXint index){
 
 // Remove all items
 void FXComboBox::clearItems(){
+  field->setText(FXString::null);
   list->clearItems();
-  setText("");
   recalc();
   }
 
@@ -459,10 +452,16 @@ void* FXComboBox::getItemData(FXint index) const {
   }
 
 
+// Is the pane shown
+FXbool FXComboBox::isPaneShown() const {
+  return pane->shown();
+  }
+
+
 // Set font
 void FXComboBox::setFont(FXFont* fnt){
   if(!fnt){ fxerror("%s::setFont: NULL font specified.\n",getClassName()); }
-  text->setFont(fnt);
+  field->setFont(fnt);
   list->setFont(fnt);
   recalc();
   }
@@ -470,7 +469,7 @@ void FXComboBox::setFont(FXFont* fnt){
 
 // Obtain font
 FXFont* FXComboBox::getFont() const {
-  return text->getFont();
+  return field->getFont();
   }
 
 
@@ -480,11 +479,11 @@ void FXComboBox::setComboStyle(FXuint mode){
   if(opts!=options){
     options=opts;
     if(options&COMBOBOX_STATIC){
-      text->setEditable(FALSE);                                 // Non-editable
+      field->setEditable(FALSE);                                // Non-editable
       list->setScrollStyle(SCROLLERS_TRACK|HSCROLLING_OFF);     // No scrolling
       }
     else{
-      text->setEditable(TRUE);                                  // Editable
+      field->setEditable(TRUE);                                 // Editable
       list->setScrollStyle(SCROLLERS_TRACK|HSCROLLER_NEVER);    // Scrollable, but no scrollbar
       }
     recalc();
@@ -500,83 +499,101 @@ FXuint FXComboBox::getComboStyle() const {
 
 // Set window background color
 void FXComboBox::setBackColor(FXColor clr){
-  text->setBackColor(clr);
+  field->setBackColor(clr);
   list->setBackColor(clr);
   }
 
 
 // Get background color
 FXColor FXComboBox::getBackColor() const {
-  return text->getBackColor();
+  return field->getBackColor();
   }
 
 
 // Set text color
 void FXComboBox::setTextColor(FXColor clr){
-  text->setTextColor(clr);
+  field->setTextColor(clr);
   list->setTextColor(clr);
   }
 
 
 // Return text color
 FXColor FXComboBox::getTextColor() const {
-  return text->getTextColor();
+  return field->getTextColor();
   }
 
 
 // Set select background color
 void FXComboBox::setSelBackColor(FXColor clr){
-  text->setSelBackColor(clr);
+  field->setSelBackColor(clr);
   list->setSelBackColor(clr);
   }
 
 
 // Return selected background color
 FXColor FXComboBox::getSelBackColor() const {
-  return text->getSelBackColor();
+  return field->getSelBackColor();
   }
 
 
 // Set selected text color
 void FXComboBox::setSelTextColor(FXColor clr){
-  text->setSelTextColor(clr);
+  field->setSelTextColor(clr);
   list->setSelTextColor(clr);
   }
 
 
 // Return selected text color
 FXColor FXComboBox::getSelTextColor() const {
-  return text->getSelTextColor();
+  return field->getSelTextColor();
+  }
+
+
+// Sort items using current sort function
+void FXComboBox::sortItems(){
+  list->sortItems();
+  }
+
+
+// Return sort function
+FXListSortFunc FXComboBox::getSortFunc() const {
+  return list->getSortFunc();
+  }
+
+
+// Change sort function
+void FXComboBox::setSortFunc(FXListSortFunc func){
+  list->setSortFunc(func);
   }
 
 
 // Set help text
 void FXComboBox::setHelpText(const FXString& txt){
-  text->setHelpText(txt);
+  field->setHelpText(txt);
   }
 
 // Get help text
 FXString FXComboBox::getHelpText() const {
-  return text->getHelpText();
+  return field->getHelpText();
   }
 
 
 // Set tip text
 void FXComboBox::setTipText(const FXString& txt){
-  text->setTipText(txt);
+  field->setTipText(txt);
   }
 
 
 // Get tip text
 FXString FXComboBox::getTipText() const {
-  return text->getTipText();
+  return field->getTipText();
   }
 
 
 // Save object to stream
 void FXComboBox::save(FXStream& store) const {
   FXPacker::save(store);
-  store << text;
+  store << field;
   store << button;
   store << list;
   store << pane;
@@ -586,7 +603,7 @@ void FXComboBox::save(FXStream& store) const {
 // Load object from stream
 void FXComboBox::load(FXStream& store){
   FXPacker::load(store);
-  store >> text;
+  store >> field;
   store >> button;
   store >> list;
   store >> pane;
@@ -597,7 +614,7 @@ void FXComboBox::load(FXStream& store){
 FXComboBox::~FXComboBox(){
   delete pane;
   pane=(FXPopup*)-1;
-  text=(FXTextField*)-1;
+  field=(FXTextField*)-1;
   button=(FXMenuButton*)-1;
   list=(FXList*)-1;
   }
