@@ -3,7 +3,7 @@
 *                C o m p o s i t e   W i n d o w   O b j e c t                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXComposite.cpp,v 1.17 2001/08/29 04:12:48 jeroen Exp $                  *
+* $Id: FXComposite.cpp,v 1.30 2002/01/18 22:42:59 jeroen Exp $                  *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,15 +30,10 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
 #include "FXComposite.h"
 
 
@@ -85,8 +80,8 @@ FXComposite::FXComposite(FXComposite* p,FXuint opts,FXint x,FXint y,FXint w,FXin
 
 
 // Is widget a composite
-FXbool FXComposite::isComposite() const { 
-  return 1; 
+FXbool FXComposite::isComposite() const {
+  return 1;
   }
 
 
@@ -240,24 +235,20 @@ long FXComposite::onFocusPrev(FXObject*,FXSelector sel,void* ptr){
 
 // Keyboard press
 long FXComposite::onKeyPress(FXObject* sender,FXSelector sel,void* ptr){
-  FXEvent* event=(FXEvent*)ptr;
-
-  // Trace message
-  FXTRACE((200,"%s::onKeyPress %p keysym=0x%04x state=%04x\n",getClassName(),this,event->code,event->state));
 
   // Bounce to focus widget
   if(getFocus() && getFocus()->handle(sender,sel,ptr)) return 1;
 
-  // Try bounce to the target first
-  if(target && target->handle(this,MKUINT(message,SEL_KEYPRESS),ptr)) return 1;
-  
-  // Next, check the accelerators...
+  // Try target first
+  if(isEnabled() && target && target->handle(this,MKUINT(message,SEL_KEYPRESS),ptr)) return 1;
+
+  // Check the accelerators
   if(getAccelTable() && getAccelTable()->handle(this,sel,ptr)) return 1;
 
   // Otherwise, perform the default keyboard processing
-  switch(event->code){
+  switch(((FXEvent*)ptr)->code){
     case KEY_Tab:
-      if(event->state&SHIFTMASK) goto prv;
+      if(((FXEvent*)ptr)->state&SHIFTMASK) goto prv;
     case KEY_Next:
       return handle(this,MKUINT(0,SEL_FOCUS_NEXT),ptr);
     case KEY_Prior:
@@ -275,12 +266,6 @@ prv:  return handle(this,MKUINT(0,SEL_FOCUS_PREV),ptr);
     case KEY_Right:
     case KEY_KP_Right:
       return handle(this,MKUINT(0,SEL_FOCUS_RIGHT),ptr);
-    case KEY_Home:
-    case KEY_KP_Home:
-      return handle(this,MKUINT(0,SEL_FOCUS_HOME),ptr);
-    case KEY_End:
-    case KEY_KP_End:
-      return handle(this,MKUINT(0,SEL_FOCUS_END),ptr);
     }
   return 0;
   }
@@ -288,20 +273,16 @@ prv:  return handle(this,MKUINT(0,SEL_FOCUS_PREV),ptr);
 
 // Keyboard release
 long FXComposite::onKeyRelease(FXObject* sender,FXSelector sel,void* ptr){
-  FXEvent* event=(FXEvent*)ptr;
-
-  // Trace message
-  FXTRACE((200,"%s::onKeyRelease %p keysym=0x%04x state=%04x\n",getClassName(),this,event->code,event->state));
 
   // Bounce to focus widget
   if(getFocus() && getFocus()->handle(sender,sel,ptr)) return 1;
 
-  // Try bounce to the target first
-  if(target && target->handle(this,MKUINT(message,SEL_KEYRELEASE),ptr)) return 1;
-  
-  // Next, check the accelerators...
+  // Try target first
+  if(isEnabled() && target && target->handle(this,MKUINT(message,SEL_KEYRELEASE),ptr)) return 1;
+
+  // Check the accelerators
   if(getAccelTable() && getAccelTable()->handle(this,sel,ptr)) return 1;
-  
+
   return 0;
   }
 
