@@ -3,7 +3,7 @@
 *                         C u r s o r - O b j e c t                             *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXCursor.cpp,v 1.19 2001/08/21 22:37:55 jeroen Exp $                     *
+* $Id: FXCursor.cpp,v 1.22.4.1 2003/06/20 19:02:07 fox Exp $                     *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -29,8 +29,6 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
@@ -43,6 +41,7 @@
   - Add subclass to read in .CUR file (similar to FXGIFIcon reading
     e.g. a GIF icon) from an FXStream.
   - Cursor size should be less than or equal to 32x32; this is necessary for Windows!
+  - Need standard glyph for "invisible" cursor.
 */
 
 #define DISPLAY(app) ((Display*)((app)->display))
@@ -99,9 +98,9 @@ void FXCursor::create(){
   if(!xid){
     if(getApp()->initialized){
       FXTRACE((100,"%s::create %p\n",getClassName(),this));
-      
+
 #ifndef WIN32
-      
+
       // Stock cursor glyphs
       const FXuint stock[]={XC_top_left_arrow,XC_arrow,XC_xterm,XC_watch,XC_crosshair,XC_sb_h_double_arrow,XC_sb_v_double_arrow,XC_fleur};
       Pixmap srcpix,mskpix;
@@ -133,15 +132,15 @@ void FXCursor::create(){
 
       // Building stock cursor
       else{
-        FXASSERT(glyph-1<ARRAYNUMBER(stock));
+        FXASSERT(glyph<=ARRAYNUMBER(stock));
         xid=XCreateFontCursor(DISPLAY(getApp()),stock[glyph-1]);
         }
-      
+
       // Were we successful?
       if(!xid){ fxerror("%s::create: unable to create cursor.\n",getClassName()); }
-    
+
 #else
-    
+
       // Stock cursor glyphs
       const LPCTSTR stock[]={IDC_ARROW,IDC_ARROW,IDC_IBEAM,IDC_WAIT,IDC_CROSS,IDC_SIZENS,IDC_SIZEWE,IDC_SIZEALL};
 
@@ -185,10 +184,10 @@ void FXCursor::create(){
         FXASSERT(glyph-1<ARRAYNUMBER(stock));
         xid=LoadCursor(NULL,stock[glyph-1]);
         }
-      
+
       // Were we successful?
       if(!xid){ fxerror("%s::create: unable to create cursor.\n",getClassName()); }
-    
+
 #endif
       }
     }
@@ -210,12 +209,12 @@ void FXCursor::destroy(){
     if(getApp()->initialized){
       FXTRACE((100,"%s::destroy %p\n",getClassName(),this));
 #ifndef WIN32
-      
-      // Delete cursor 
+
+      // Delete cursor
       XFreeCursor(DISPLAY(getApp()),xid);
 #else
-      
-      // Delete cursor 
+
+      // Delete cursor
       DestroyCursor((HCURSOR)xid);
 #endif
       }
