@@ -3,7 +3,7 @@
 *               D e v i c e   C o n t e x t   B a s e   C l a s s               *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * Major Contributions for Windows NT by Lyle Johnson                            *
 *********************************************************************************
@@ -21,7 +21,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDC.cpp,v 1.15 2001/07/06 19:33:07 jeroen Exp $                         *
+* $Id: FXDC.cpp,v 1.18 2002/01/18 22:42:59 jeroen Exp $                         *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -31,8 +31,6 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
@@ -267,6 +265,10 @@ void FXDC::drawIconSunken(const FXIcon*,FXint,FXint){ }
 void FXDC::drawHashBox(FXint,FXint,FXint,FXint,FXint){ }
 
 
+// Draw focus rectangle
+void FXDC::drawFocusRectangle(FXint,FXint,FXint,FXint){ }
+
+
 // Set foreground drawing color (brush)
 void FXDC::setForeground(FXColor clr){
   fg=clr;
