@@ -3,7 +3,7 @@
 *  D e v i c e   C o n t e x t   F o r   W i n d o w s   a n d   I m a g e s    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDCWindow.cpp,v 1.74 2001/08/23 16:24:53 jeroen Exp $                   *
+* $Id: FXDCWindow.cpp,v 1.86 2002/01/18 22:42:59 jeroen Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -31,7 +31,6 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
@@ -52,7 +51,6 @@
 #include "FXRegion.h"
 #include "FXDC.h"
 #include "FXDCWindow.h"
-#include "FXProfiler.h"
 
 /*
   Notes:
@@ -134,6 +132,8 @@
     behavior.  I've unfortunately been away from FOX work for a few months
     or I'd try it myself.
 
+  - Device caps for DirectX:
+    http://www.molybdenium.de/devicecaps/e_index.html
 */
 
 #define DISPLAY(app) ((Display*)((app)->display))
@@ -396,18 +396,21 @@ void FXDCWindow::drawBitmap(const FXBitmap* bitmap,FXint dx,FXint dy) {
 void FXDCWindow::drawIcon(const FXIcon* icon,FXint dx,FXint dy){
   if(!surface){ fxerror("FXDCWindow::drawIcon: DC not connected to drawable.\n"); }
   if(!icon || !icon->id() || !icon->shape){ fxerror("FXDCWindow::drawIcon: illegal icon specified.\n"); }
-  XGCValues gcv;
-  if(icon->getOptions()&IMAGE_OPAQUE){
-    XCopyArea(DISPLAY(getApp()),icon->id(),surface->id(),(GC)gc,0,0,icon->width,icon->height,dx,dy);
-    }
-  else{
-    gcv.clip_mask=icon->shape;
-    gcv.clip_x_origin=dx;
-    gcv.clip_y_origin=dy;
-    XChangeGC(DISPLAY(getApp()),(GC)gc,GCClipMask|GCClipXOrigin|GCClipYOrigin,&gcv);
-    XCopyArea(DISPLAY(getApp()),icon->id(),surface->id(),(GC)gc,0,0,icon->width,icon->height,dx,dy);
-    XSetClipRectangles(DISPLAY(getApp()),(GC)gc,0,0,(XRectangle*)&clip,1,Unsorted); // Restore old clip rectangle
-    flags|=GCClipMask;
+  FXRectangle d=clip*FXRectangle(dx,dy,icon->width,icon->height);
+  if(d.w>0 && d.h>0){
+    if(icon->getOptions()&IMAGE_OPAQUE){
+      XCopyArea(DISPLAY(getApp()),icon->id(),surface->id(),(GC)gc,d.x-dx,d.y-dy,d.w,d.h,d.x,d.y);
+      }
+    else{
+      XGCValues gcv;
+      gcv.clip_mask=icon->shape;
+      gcv.clip_x_origin=dx;
+      gcv.clip_y_origin=dy;
+      XChangeGC(DISPLAY(getApp()),(GC)gc,GCClipMask|GCClipXOrigin|GCClipYOrigin,&gcv);
+      XCopyArea(DISPLAY(getApp()),icon->id(),surface->id(),(GC)gc,d.x-dx,d.y-dy,d.w,d.h,d.x,d.y);
+      XSetClipRectangles(DISPLAY(getApp()),(GC)gc,0,0,(XRectangle*)&clip,1,Unsorted); // Restore old clip rectangle
+      flags|=GCClipMask;
+      }
     }
   }
 
@@ -416,27 +419,30 @@ void FXDCWindow::drawIcon(const FXIcon* icon,FXint dx,FXint dy){
 void FXDCWindow::drawIconShaded(const FXIcon* icon,FXint dx,FXint dy){
   if(!surface){ fxerror("FXDCWindow::drawIconShaded: DC not connected to drawable.\n"); }
   if(!icon || !icon->id() || !icon->shape){ fxerror("FXDCWindow::drawIconShaded: illegal icon specified.\n"); }
-  XGCValues gcv;
-  gcv.clip_mask=icon->shape;
-  gcv.clip_x_origin=dx;
-  gcv.clip_y_origin=dy;
-  XChangeGC(DISPLAY(getApp()),(GC)gc,GCClipMask|GCClipXOrigin|GCClipYOrigin,&gcv);
-  XCopyArea(DISPLAY(getApp()),icon->id(),surface->id(),(GC)gc,0,0,icon->width,icon->height,dx,dy);
-  gcv.function=BLT_SRC;
-  gcv.stipple=getApp()->stipples[STIPPLE_GRAY];
-  gcv.fill_style=FILL_STIPPLED;
-  gcv.ts_x_origin=dx;
-  gcv.ts_y_origin=dy;
-  gcv.foreground=visual->getPixel(getApp()->getSelbackColor());
-  XChangeGC(DISPLAY(getApp()),(GC)gc,GCForeground|GCFunction|GCTileStipXOrigin|GCTileStipYOrigin|GCStipple|GCFillStyle,&gcv);
-  XFillRectangle(DISPLAY(getApp()),surface->id(),(GC)gc,dx,dy,icon->width,icon->height);
-  gcv.function=rop;
-  gcv.fill_style=fill;
-  gcv.ts_x_origin=tx;
-  gcv.ts_y_origin=ty;
-  XChangeGC(DISPLAY(getApp()),(GC)gc,GCTileStipXOrigin|GCTileStipYOrigin|GCFunction|GCFillStyle,&gcv);                // Restore old raster op function and fill style
-  XSetClipRectangles(DISPLAY(getApp()),(GC)gc,0,0,(XRectangle*)&clip,1,Unsorted); // Restore old clip rectangle
-  flags|=GCClipMask;
+  FXRectangle d=clip*FXRectangle(dx,dy,icon->width,icon->height);
+  if(d.w>0 && d.h>0){
+    XGCValues gcv;
+    gcv.clip_mask=icon->shape;
+    gcv.clip_x_origin=dx;
+    gcv.clip_y_origin=dy;
+    XChangeGC(DISPLAY(getApp()),(GC)gc,GCClipMask|GCClipXOrigin|GCClipYOrigin,&gcv);
+    XCopyArea(DISPLAY(getApp()),icon->id(),surface->id(),(GC)gc,d.x-dx,d.y-dy,d.w,d.h,d.x,d.y);
+    gcv.function=BLT_SRC;
+    gcv.stipple=getApp()->stipples[STIPPLE_GRAY];
+    gcv.fill_style=FILL_STIPPLED;
+    gcv.ts_x_origin=dx;
+    gcv.ts_y_origin=dy;
+    gcv.foreground=visual->getPixel(getApp()->getSelbackColor());
+    XChangeGC(DISPLAY(getApp()),(GC)gc,GCForeground|GCFunction|GCTileStipXOrigin|GCTileStipYOrigin|GCStipple|GCFillStyle,&gcv);
+    XFillRectangle(DISPLAY(getApp()),surface->id(),(GC)gc,d.x,d.y,d.w,d.h);
+    gcv.function=rop;
+    gcv.fill_style=fill;
+    gcv.ts_x_origin=tx;
+    gcv.ts_y_origin=ty;
+    XChangeGC(DISPLAY(getApp()),(GC)gc,GCTileStipXOrigin|GCTileStipYOrigin|GCFunction|GCFillStyle,&gcv);  // Restore old raster op function and fill style
+    XSetClipRectangles(DISPLAY(getApp()),(GC)gc,0,0,(XRectangle*)&clip,1,Unsorted); // Restore old clip rectangle
+    flags|=GCClipMask;
+    }
   }
 
 
@@ -444,30 +450,40 @@ void FXDCWindow::drawIconShaded(const FXIcon* icon,FXint dx,FXint dy){
 void FXDCWindow::drawIconSunken(const FXIcon* icon,FXint dx,FXint dy){
   if(!surface){ fxerror("FXDCWindow::drawIconSunken: DC not connected to drawable.\n"); }
   if(!icon || !icon->id() || !icon->etch){ fxerror("FXDCWindow::drawIconSunken: illegal icon specified.\n"); }
-  FXColor base=getApp()->getBaseColor();
-  FXuint r=FXREDVAL(base);
-  FXuint g=FXGREENVAL(base);
-  FXuint b=FXBLUEVAL(base);
-  FXColor clr=FXRGB((85*r)/100,(85*g)/100,(85*b)/100);
   XGCValues gcv;
-  gcv.clip_mask=icon->etch;
-  gcv.clip_x_origin=dx+1;
-  gcv.clip_y_origin=dy+1;
-  gcv.foreground=visual->getPixel(getApp()->getHiliteColor());
-  gcv.function=BLT_SRC;
-  XChangeGC(DISPLAY(getApp()),(GC)gc,GCForeground|GCClipMask|GCClipXOrigin|GCClipYOrigin|GCFunction,&gcv);
+  FXColor base=getApp()->getBaseColor();
+  FXColor clr=FXRGB((85*FXREDVAL(base))/100,(85*FXGREENVAL(base))/100,(85*FXBLUEVAL(base))/100);
+
+  // Erase to black
+  gcv.background=0;
+  gcv.foreground=0xffffffff;
+  gcv.function=BLT_NOT_SRC_AND_DST;
+  XChangeGC(DISPLAY(getApp()),(GC)gc,GCForeground|GCBackground|GCFunction,&gcv);
   XCopyPlane(DISPLAY(getApp()),icon->etch,surface->id(),(GC)gc,0,0,icon->width,icon->height,dx+1,dy+1,1);
-  gcv.clip_mask=icon->etch;
-  gcv.clip_x_origin=dx;
-  gcv.clip_y_origin=dy;
-  gcv.foreground=visual->getPixel(clr);
-  XChangeGC(DISPLAY(getApp()),(GC)gc,GCForeground|GCClipMask|GCClipXOrigin|GCClipYOrigin,&gcv);
+
+  // Paint highlight part
+  gcv.function=BLT_SRC_OR_DST;
+  gcv.foreground=visual->getPixel(getApp()->getHiliteColor());
+  XChangeGC(DISPLAY(getApp()),(GC)gc,GCForeground|GCFunction,&gcv);
+  XCopyPlane(DISPLAY(getApp()),icon->etch,surface->id(),(GC)gc,0,0,icon->width,icon->height,dx+1,dy+1,1);
+
+  // Erase to black
+  gcv.foreground=0xffffffff;
+  gcv.function=BLT_NOT_SRC_AND_DST;
+  XChangeGC(DISPLAY(getApp()),(GC)gc,GCForeground|GCFunction,&gcv);
   XCopyPlane(DISPLAY(getApp()),icon->etch,surface->id(),(GC)gc,0,0,icon->width,icon->height,dx,dy,1);
+
+  // Paint shadow part
+  gcv.function=BLT_SRC_OR_DST;
+  gcv.foreground=visual->getPixel(clr);
+  XChangeGC(DISPLAY(getApp()),(GC)gc,GCForeground|GCFunction,&gcv);
+  XCopyPlane(DISPLAY(getApp()),icon->etch,surface->id(),(GC)gc,0,0,icon->width,icon->height,dx,dy,1);
+
+  // Restore stuff
   gcv.foreground=devfg;
+  gcv.background=devbg;
   gcv.function=rop;
-  XChangeGC(DISPLAY(getApp()),(GC)gc,GCForeground|GCFunction,&gcv);               // Restore old raster op function and color
-  XSetClipRectangles(DISPLAY(getApp()),(GC)gc,0,0,(XRectangle*)&clip,1,Unsorted); // Restore old clip rectangle
-  flags|=GCClipMask;
+  XChangeGC(DISPLAY(getApp()),(GC)gc,GCForeground|GCBackground|GCFunction,&gcv);
   }
 
 
@@ -482,11 +498,37 @@ void FXDCWindow::drawHashBox(FXint x,FXint y,FXint w,FXint h,FXint b){
   XFillRectangle(DISPLAY(getApp()),surface->id(),(GC)gc,x+b,y+h-b,w-b,b);
   XFillRectangle(DISPLAY(getApp()),surface->id(),(GC)gc,x,y+b,b,h-b);
   gcv.stipple=getApp()->stipples[STIPPLE_WHITE];    // Needed for IRIX6.4 bug workaround!
-  gcv.fill_style=fill;    // Restore old fill style
+  gcv.fill_style=fill;
   XChangeGC(DISPLAY(getApp()),(GC)gc,GCStipple|GCFillStyle,&gcv);
   }
 
 
+void FXDCWindow::drawFocusRectangle(FXint x,FXint y,FXint w,FXint h){
+  XGCValues gcv;
+  if(!surface){ fxerror("FXDCWindow::drawFocusRectangle: DC not connected to drawable.\n"); }
+  gcv.stipple=getApp()->stipples[STIPPLE_GRAY];
+  gcv.fill_style=FILL_STIPPLED;
+  gcv.background=0;
+  gcv.foreground=0xffffffff;    // Maybe should use FILL_OPAQUESTIPPLED and current fg/bg color and BLT_SRC
+  gcv.function=BLT_SRC_XOR_DST; // This would be more flexible
+  gcv.ts_x_origin=x;
+  gcv.ts_y_origin=y;
+  XChangeGC(DISPLAY(getApp()),(GC)gc,GCTileStipXOrigin|GCTileStipYOrigin|GCForeground|GCBackground|GCFunction|GCStipple|GCFillStyle,&gcv);
+  XFillRectangle(DISPLAY(getApp()),surface->id(),(GC)gc,x,y,w-1,1);
+  XFillRectangle(DISPLAY(getApp()),surface->id(),(GC)gc,x+w-1,y,1,h-1);
+  XFillRectangle(DISPLAY(getApp()),surface->id(),(GC)gc,x+1,y+h-1,w-1,1);
+  XFillRectangle(DISPLAY(getApp()),surface->id(),(GC)gc,x,y+1,1,h-1);
+  gcv.stipple=getApp()->stipples[STIPPLE_WHITE];    // Needed for IRIX6.4 bug workaround!
+  gcv.fill_style=fill;
+  gcv.background=devbg;
+  gcv.foreground=devfg;
+  gcv.function=rop;
+  gcv.ts_x_origin=tx;
+  gcv.ts_y_origin=ty;
+  XChangeGC(DISPLAY(getApp()),(GC)gc,GCTileStipXOrigin|GCTileStipYOrigin|GCForeground|GCBackground|GCFunction|GCStipple|GCFillStyle,&gcv);
+  }
+
+
 void FXDCWindow::setForeground(FXColor clr){
   if(!surface){ fxerror("FXDCWindow::setForeground: DC not connected to drawable.\n"); }
   devfg=visual->getPixel(clr);
@@ -1016,6 +1058,8 @@ void FXDCWindow::drawArc(FXint x,FXint y,FXint w,FXint h,FXint ang1,FXint ang2){
   if(ang2==0) return;
   if(needsNewPen) updatePen();
   ang2+=ang1;
+  w+=1;
+  h+=1;
   int xStart=int(x+0.5*w+w*cos(ang1*PI/(180.0*64.0)));
   int yStart=int(y+0.5*h-h*sin(ang1*PI/(180.0*64.0)));
   int xEnd=int(x+0.5*w+w*cos(ang2*PI/(180.0*64.0)));
@@ -1075,6 +1119,8 @@ void FXDCWindow::fillArc(FXint x,FXint y,FXint w,FXint h,FXint ang1,FXint ang2){
   if(ang2==0) return;
   if(needsNewBrush) updateBrush();
   ang2+=ang1;
+  w+=1;
+  h+=1;
   int xStart=int(x+0.5*w+w*cos(ang1*PI/(180.0*64.0)));
   int yStart=int(y+0.5*h-h*sin(ang1*PI/(180.0*64.0)));
   int xEnd=int(x+0.5*w+w*cos(ang2*PI/(180.0*64.0)));
@@ -1427,6 +1473,7 @@ void FXDCWindow::drawIconShaded(const FXIcon* icon,FXint dx,FXint dy){
 
   HBRUSH hBrush=CreatePatternBrush((HBITMAP)getApp()->stipples[STIPPLE_GRAY]);
   HBRUSH hOldBrush=(HBRUSH)SelectObject((HDC)dc,hBrush);
+  SetBrushOrgEx((HDC)dc,dx,dy,NULL);
 
   // Make black where pattern is 0 and shape is 0 [DPSoa]
   BitBlt((HDC)dc,dx,dy,icon->getWidth(),icon->getHeight(),hdcMsk,0,0,0x00A803A9);
@@ -1442,6 +1489,7 @@ void FXDCWindow::drawIconShaded(const FXIcon* icon,FXint dx,FXint dy){
   DeleteDC(hdcMsk);
   SetBkColor((HDC)dc,crOldBack);
   SetTextColor((HDC)dc,crOldText);
+  SetBrushOrgEx((HDC)dc,tx,ty,NULL);
   icon->ReleaseDC(hdcSrc);
   }
 
@@ -1486,16 +1534,35 @@ void FXDCWindow::drawIconSunken(const FXIcon* icon,FXint dx,FXint dy){
   }
 
 
-void FXDCWindow::drawHashBox(FXint x,FXint y,FXint w,FXint h,FXint b){    // FIXME
+void FXDCWindow::drawHashBox(FXint x,FXint y,FXint w,FXint h,FXint b){
   if(!surface){ fxerror("FXDCWindow::drawHashBox: DC not connected to drawable.\n"); }
   HBRUSH hBrush=(HBRUSH)SelectObject((HDC)dc,CreatePatternBrush((HBITMAP)getApp()->stipples[STIPPLE_GRAY]));
   COLORREF crOldBack=SetBkColor((HDC)dc,RGB(255,255,255));
+  COLORREF crOldText=SetTextColor((HDC)dc,RGB(0,0,0));
   PatBlt((HDC)dc,x,y,w-b,b,PATINVERT);
   PatBlt((HDC)dc,x+w-b,y,b,h-b,PATINVERT);
   PatBlt((HDC)dc,x+b,y+h-b,w-b,b,PATINVERT);
   PatBlt((HDC)dc,x,y+b,b,h-b,PATINVERT);
   DeleteObject(SelectObject((HDC)dc,hBrush));
   SetBkColor((HDC)dc,crOldBack);
+  SetTextColor((HDC)dc,crOldText);
+  }
+
+
+void FXDCWindow::drawFocusRectangle(FXint x,FXint y,FXint w,FXint h){
+  if(!surface){ fxerror("FXDCWindow::drawFocusRectangle: DC not connected to drawable.\n"); }
+  HBRUSH hBrush=(HBRUSH)SelectObject((HDC)dc,CreatePatternBrush((HBITMAP)getApp()->stipples[STIPPLE_GRAY]));
+  COLORREF crOldBack=SetBkColor((HDC)dc,RGB(255,255,255));
+  COLORREF crOldText=SetTextColor((HDC)dc,RGB(0,0,0));
+  SetBrushOrgEx((HDC)dc,x,y,NULL);
+  PatBlt((HDC)dc,x,y,w-1,1,PATINVERT);
+  PatBlt((HDC)dc,x+w-1,y,1,h-1,PATINVERT);
+  PatBlt((HDC)dc,x+1,y+h-1,w-1,1,PATINVERT);
+  PatBlt((HDC)dc,x,y+1,1,h-1,PATINVERT);
+  DeleteObject(SelectObject((HDC)dc,hBrush));
+  SetBkColor((HDC)dc,crOldBack);
+  SetTextColor((HDC)dc,crOldText);
+  SetBrushOrgEx((HDC)dc,tx,ty,NULL);
   }
 
 
