@@ -3,7 +3,7 @@
 *                              D a t a   T a r g e t                            *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDataTarget.cpp,v 1.17 2001/08/28 22:52:27 jeroen Exp $                 *
+* $Id: FXDataTarget.cpp,v 1.20 2002/01/18 22:42:59 jeroen Exp $                 *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,16 +30,9 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
-#include "FXAccelTable.h"
-#include "FXObjectList.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXCursor.h"
-#include "FXDrawable.h"
 #include "FXWindow.h"
 #include "FXDataTarget.h"
 
@@ -118,7 +111,7 @@ long FXDataTarget::onCmdValue(FXObject* sender,FXSelector sel,void*){
       break;
     }
   if(target){
-    target->handle(this,MKUINT(message,SELTYPE(sel)),data); 
+    target->handle(this,MKUINT(message,SELTYPE(sel)),data);
     }
   return 1;
   }
@@ -196,7 +189,7 @@ long FXDataTarget::onCmdOption(FXObject*,FXSelector sel,void*){
       break;
     }
   if(target){
-    target->handle(this,MKUINT(message,SELTYPE(sel)),data); 
+    target->handle(this,MKUINT(message,SELTYPE(sel)),data);
     }
   return 1;
   }
