@@ -3,7 +3,7 @@
 *                      D e b u g - T a r g e t   O b j e c t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,13 +19,12 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDebugTarget.cpp,v 1.13 2001/03/06 19:17:21 jeroen Exp $                *
+* $Id: FXDebugTarget.cpp,v 1.16 2002/01/18 22:42:59 jeroen Exp $                *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
 #include "FXStream.h"
-#include "FXObject.h"
 #include "FXDebugTarget.h"
 
 /*
@@ -43,89 +42,85 @@
 // Table of message type names
 const char *const FXDebugTarget::messageTypeName[]={
   "SEL_NONE",
-  "SEL_KEYPRESS",           
-  "SEL_KEYRELEASE",         
-  "SEL_LEFTBUTTONPRESS",    
-  "SEL_LEFTBUTTONRELEASE",  
-  "SEL_MIDDLEBUTTONPRESS",  
+  "SEL_KEYPRESS",
+  "SEL_KEYRELEASE",
+  "SEL_LEFTBUTTONPRESS",
+  "SEL_LEFTBUTTONRELEASE",
+  "SEL_MIDDLEBUTTONPRESS",
   "SEL_MIDDLEBUTTONRELEASE",
-  "SEL_RIGHTBUTTONPRESS",   
-  "SEL_RIGHTBUTTONRELEASE", 
-  "SEL_MOTION",             
+  "SEL_RIGHTBUTTONPRESS",
+  "SEL_RIGHTBUTTONRELEASE",
+  "SEL_MOTION",
   "SEL_ENTER",
   "SEL_LEAVE",
   "SEL_FOCUSIN",
   "SEL_FOCUSOUT",
   "SEL_KEYMAP",
   "SEL_UNGRABBED",
-  "SEL_PAINT",              
+  "SEL_PAINT",
   "SEL_CREATE",
   "SEL_DESTROY",
   "SEL_UNMAP",
   "SEL_MAP",
-  "SEL_CONFIGURE",          
-  "SEL_SELECTION_LOST",     
-  "SEL_SELECTION_GAINED",   
-  "SEL_SELECTION_REQUEST",  
+  "SEL_CONFIGURE",
+  "SEL_SELECTION_LOST",
+  "SEL_SELECTION_GAINED",
+  "SEL_SELECTION_REQUEST",
   "SEL_RAISED",
   "SEL_LOWERED",
-  "SEL_CLOSE",              
+  "SEL_CLOSE",
   "SEL_CLOSEALL",
-  "SEL_DELETE",              
+  "SEL_DELETE",
   "SEL_MINIMIZE",
   "SEL_RESTORE",
   "SEL_MAXIMIZE",
-  "SEL_UPDATE",             
-  "SEL_COMMAND",            
-  "SEL_CLICKED",            
-  "SEL_DOUBLECLICKED",      
-  "SEL_TRIPLECLICKED",      
+  "SEL_UPDATE",
+  "SEL_COMMAND",
+  "SEL_CLICKED",
+  "SEL_DOUBLECLICKED",
+  "SEL_TRIPLECLICKED",
   "SEL_MOUSEWHEEL",
-  "SEL_CHANGED",            
-  "SEL_VERIFY",            
-  "SEL_DESELECTED",         
-  "SEL_SELECTED",           
-  "SEL_INSERTED",           
+  "SEL_CHANGED",
+  "SEL_VERIFY",
+  "SEL_DESELECTED",
+  "SEL_SELECTED",
+  "SEL_INSERTED",
   "SEL_REPLACED",
-  "SEL_DELETED",           
-  "SEL_OPENED",             
-  "SEL_CLOSED",             
-  "SEL_EXPANDED",           
-  "SEL_COLLAPSED",          
-  "SEL_BEGINDRAG",            
-  "SEL_ENDDRAG",            
-  "SEL_DRAGGED",            
-  "SEL_LASSOED",            
-  "SEL_TIMEOUT",            
+  "SEL_DELETED",
+  "SEL_OPENED",
+  "SEL_CLOSED",
+  "SEL_EXPANDED",
+  "SEL_COLLAPSED",
+  "SEL_BEGINDRAG",
+  "SEL_ENDDRAG",
+  "SEL_DRAGGED",
+  "SEL_LASSOED",
+  "SEL_TIMEOUT",
   "SEL_SIGNAL",
   "SEL_CLIPBOARD_LOST",
   "SEL_CLIPBOARD_GAINED",
   "SEL_CLIPBOARD_REQUEST",
-  "SEL_CHORE",              
-  "SEL_FOCUS_SELF",        
-  "SEL_FOCUS_RIGHT",        
+  "SEL_CHORE",
+  "SEL_FOCUS_SELF",
+  "SEL_FOCUS_RIGHT",
   "SEL_FOCUS_LEFT",
   "SEL_FOCUS_DOWN",
   "SEL_FOCUS_UP",
-  "SEL_FOCUS_HOME",
-  "SEL_FOCUS_END",
   "SEL_FOCUS_NEXT",
   "SEL_FOCUS_PREV",
-  "SEL_DND_ENTER",          
-  "SEL_DND_LEAVE",          
-  "SEL_DND_DROP",           
-  "SEL_DND_MOTION",         
-  "SEL_DND_REQUEST",         
-  "SEL_ACTIVATE",           
-  "SEL_DEACTIVATE",
-  "SEL_UNCHECK_OTHER",      
-  "SEL_UNCHECK_RADIO",      
+  "SEL_DND_ENTER",
+  "SEL_DND_LEAVE",
+  "SEL_DND_DROP",
+  "SEL_DND_MOTION",
+  "SEL_DND_REQUEST",
+  "SEL_UNCHECK_OTHER",
+  "SEL_UNCHECK_RADIO",
   "SEL_IO_READ",
   "SEL_IO_WRITE",
   "SEL_IO_EXCEPT",
   "SEL_PICKED"
   };
-  
+
 
 // Map
 FXDEFMAP(FXDebugTarget) FXDebugTargetMap[]={
