@@ -3,7 +3,7 @@
 *                     D i a l o g   B o x    O b j e c t                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDialogBox.cpp,v 1.16 2001/04/27 14:30:31 jeroen Exp $                  *
+* $Id: FXDialogBox.cpp,v 1.19 2002/01/18 22:42:59 jeroen Exp $                  *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,19 +30,10 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
 #include "FXCursor.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
-#include "FXComposite.h"
-#include "FXShell.h"
-#include "FXTopWindow.h"
 #include "FXDialogBox.h"
 
 /*
@@ -113,9 +104,8 @@ long FXDialogBox::onCmdCancel(FXObject*,FXSelector,void*){
 
 // Keyboard press; handle escape to close the dialog
 long FXDialogBox::onKeyPress(FXObject* sender,FXSelector sel,void* ptr){
-  FXEvent* event=(FXEvent*)ptr;
   if(FXTopWindow::onKeyPress(sender,sel,ptr)) return 1;
-  if(event->code==KEY_Escape){
+  if(((FXEvent*)ptr)->code==KEY_Escape){
     handle(this,MKUINT(ID_CANCEL,SEL_COMMAND),NULL);
     return 1;
     }
@@ -125,9 +115,8 @@ long FXDialogBox::onKeyPress(FXObject* sender,FXSelector sel,void* ptr){
 
 // Keyboard release; handle escape to close the dialog
 long FXDialogBox::onKeyRelease(FXObject* sender,FXSelector sel,void* ptr){
-  FXEvent* event=(FXEvent*)ptr;
   if(FXTopWindow::onKeyRelease(sender,sel,ptr)) return 1;
-  if(event->code==KEY_Escape){
+  if(((FXEvent*)ptr)->code==KEY_Escape){
     return 1;
     }
   return 0;
