@@ -3,7 +3,7 @@
 *                          D i c t i o n a r y    C l a s s                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,13 +19,12 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDict.cpp,v 1.11 2001/08/16 22:01:29 jeroen Exp $                       *
+* $Id: FXDict.cpp,v 1.17.4.1 2002/03/19 14:11:00 fox Exp $                       *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
 #include "FXStream.h"
-#include "FXObject.h"
 #include "FXDict.h"
 
 
@@ -144,7 +143,7 @@ void* FXDict::insert(const FXchar* ky,const void* pdata,FXbool mrk){
   ptr=createData(pdata);
   dict[i].hash=h;
   dict[i].mark=mrk;
-  dict[i].key=fxstrdup(ky);
+  dict[i].key=strdup(ky);
   dict[i].data=ptr;
   number++;
   if((100*number)>=(MAX_LOAD*total)) size(number);
@@ -188,7 +187,7 @@ void* FXDict::replace(const FXchar* ky,const void* pdata,FXbool mrk){
   ptr=createData(pdata);
   dict[i].hash=h;
   dict[i].mark=mrk;
-  dict[i].key=fxstrdup(ky);
+  dict[i].key=strdup(ky);
   dict[i].data=ptr;
   number++;
   if((100*number)>=(MAX_LOAD*total)) size(number);
@@ -215,7 +214,7 @@ void* FXDict::remove(const FXchar* ky){
         FXTRACE((120,"FXDict::remove: %p removing: \"%s\"\n",this,ky));
         dict[p].hash=-2;
         dict[p].mark=FALSE;
-        FXFREE(&dict[p].key);
+        free(dict[p].key);
         deleteData(dict[p].data);
         dict[p].key=NULL;
         dict[p].data=NULL;
@@ -233,7 +232,7 @@ void* FXDict::remove(const FXchar* ky){
 
 
 // Find entry
-void* FXDict::find(const FXchar* ky){
+void* FXDict::find(const FXchar* ky) const {
   register FXint p,x,h,n;
   if(!ky){ fxerror("FXDict::find: NULL key argument.\n"); }
   if(0<number){
@@ -298,141 +297,21 @@ void FXDict::clear(){
   register FXint i;
   for(i=0; i<total; i++){
     if(dict[i].hash>=0){
-      FXFREE(&dict[i].key);
+      dict[i].hash=-1;
+      free(dict[i].key);
       deleteData(dict[i].data);
       }
     }
-  FXFREE(&dict);
-  total=0;
   number=0;
   }
 
 
-// Save data
-void FXDict::save(FXStream& store) const {
-  FXint len,i;
-  FXObject::save(store);
-  store << total;
-  store << number;
-  for(i=0; i<total; i++){
-    store << dict[i].hash;
-    if(dict[i].hash>=0){
-      len=strlen(dict[i].key)+1;
-      store << len;
-      store << dict[i].mark;
-      store.save(dict[i].key,len);
-      }
-    }
-  }
-
-
-// Load data
-void FXDict::load(FXStream& store){
-  FXint len,i;
-  FXObject::load(store);
-  store >> total;
-  store >> number;
-  FXCALLOC(&dict,FXDictEntry,total);
-  for(i=0; i<total; i++){
-    store >> dict[i].hash;
-    if(dict[i].hash>=0){
-      store >> len;
-      store >> dict[i].mark;
-      FXMALLOC(&dict[i].key,FXchar,len);
-      store.load(dict[i].key,len);
-      }
-    }
-  }
-
-
 // Destroy table
 FXDict::~FXDict(){
   clear();
+  FXFREE(&dict);
   dict=(FXDictEntry*)-1;
   }
 
 
-/*******************************************************************************/
 
-// Object implementation
-FXIMPLEMENT(FXStringDict,FXDict,NULL,0)
-
-
-// Construct string dict
-FXStringDict::FXStringDict(){
-  FXTRACE((100,"FXStringDict::FXStringDict %p\n",this));
-  }
-
-
-// Create string
-void *FXStringDict::createData(const void* ptr){
-  return strdup((const char*)ptr);
-  }
-
-
-// Delete string
-void FXStringDict::deleteData(void* ptr){
-  free(ptr);
-  }
-
-
-// Save data
-void FXStringDict::save(FXStream& store) const {
-  FXDict::save(store);
-  }
-
-
-// Load data
-void FXStringDict::load(FXStream& store){
-  FXDict::load(store);
-  }
-
-
-// Destructor
-FXStringDict::~FXStringDict(){
-  FXTRACE((100,"FXStringDict::~FXStringDict %p\n",this));
-  clear();
-  }
-
-
-/*******************************************************************************/
-
-// Object implementation
-FXIMPLEMENT(FXSectionDict,FXDict,NULL,0)
-
-
-// Construct string dict
-FXSectionDict::FXSectionDict(){
-  FXTRACE((100,"FXSectionDict::FXSectionDict %p\n",this));
-  }
-
-
-// Create data
-void *FXSectionDict::createData(const void*){
-  return new FXStringDict;
-  }
-
-
-// Delete data
-void FXSectionDict::deleteData(void* ptr){
-  delete ((FXStringDict*)ptr);
-  }
-
-
-// Save data
-void FXSectionDict::save(FXStream& store) const {
-  FXDict::save(store);
-  }
-
-
-// Load data
-void FXSectionDict::load(FXStream& store){
-  FXDict::load(store);
-  }
-
-
-// Destructor
-FXSectionDict::~FXSectionDict(){
-  FXTRACE((100,"FXSectionDict::~FXSectionDict %p\n",this));
-  clear();
-  }
