@@ -3,7 +3,7 @@
 *                         D o c u m e n t   O b j e c t                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDocument.cpp,v 1.8 2001/04/27 14:30:31 jeroen Exp $                    *
+* $Id: FXDocument.cpp,v 1.10 2002/01/18 22:42:59 jeroen Exp $                    *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -31,19 +31,13 @@
 #include "FXPoint.h"
 #include "FXRectangle.h"
 #include "FXFile.h"
-#include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXObjectList.h"
 #include "FXApp.h"
-#include "FXId.h"
 #include "FXCursor.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
 #include "FXFrame.h"
-#include "FXComposite.h"
 #include "FXRootWindow.h"
 #include "FXShell.h"
 #include "FXDocument.h"
