@@ -3,7 +3,7 @@
 *                         D r i v e   B o x   O b j e c t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDriveBox.cpp,v 1.6 2001/04/27 14:30:31 jeroen Exp $                    *
+* $Id: FXDriveBox.cpp,v 1.10.4.2 2003/06/20 19:02:07 fox Exp $                    *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,8 +30,6 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
@@ -252,8 +250,8 @@ const unsigned char folder[]={
 
 // Map
 FXDEFMAP(FXDriveBox) FXDriveBoxMap[]={
-  FXMAPFUNC(SEL_CHANGED,0,FXDriveBox::onChanged),
-  FXMAPFUNC(SEL_COMMAND,0,FXDriveBox::onCommand),
+  FXMAPFUNC(SEL_CHANGED,FXDriveBox::ID_LIST,FXDriveBox::onListChanged),
+  FXMAPFUNC(SEL_CLICKED,FXDriveBox::ID_LIST,FXDriveBox::onListClicked),
   FXMAPFUNC(SEL_COMMAND,FXWindow::ID_SETVALUE,FXDriveBox::onCmdSetValue),
   FXMAPFUNC(SEL_COMMAND,FXWindow::ID_SETSTRINGVALUE,FXDriveBox::onCmdSetStringValue),
   FXMAPFUNC(SEL_COMMAND,FXWindow::ID_GETSTRINGVALUE,FXDriveBox::onCmdGetStringValue),
@@ -276,15 +274,7 @@ FXDriveBox::FXDriveBox(FXComposite *p,FXint nvis,FXObject* tgt,FXSelector sel,FX
   computericon=new FXBMPIcon(getApp(),mycomputer,0,IMAGE_ALPHAGUESS);
   nethoodicon=new FXBMPIcon(getApp(),nethood,0,IMAGE_ALPHAGUESS);
   zipdiskicon=new FXBMPIcon(getApp(),zipdisk,0,IMAGE_ALPHAGUESS);
-
-  loaddrives();  // Fill our list with available drives
-
-#ifndef WIN32
-  setCurrentItem(0);
-  currentdrive = getItemText(0);
-#else
   setDrive(FXFile::getCurrentDrive());
-#endif
   }
 
 
@@ -342,7 +332,6 @@ long FXDriveBox::onCmdSetValue(FXObject*,FXSelector,void* ptr){
 
 // Change value
 long FXDriveBox::onCmdSetStringValue(FXObject*,FXSelector,void* ptr){
-  if(ptr==NULL){ fxerror("%s::onCmdSetStringValue: NULL pointer.\n",getClassName()); }
   setDrive(*((FXString*)ptr));
   return 1;
   }
@@ -350,17 +339,15 @@ long FXDriveBox::onCmdSetStringValue(FXObject*,FXSelector,void* ptr){
 
 // Obtain value
 long FXDriveBox::onCmdGetStringValue(FXObject*,FXSelector,void* ptr){
-  if(ptr==NULL){ fxerror("%s::onCmdGetStringValue: NULL pointer.\n",getClassName()); }
-  *((FXString*)ptr)=currentdrive;
+  *((FXString*)ptr)=getDrive();
   return 1;
   }
 
 
 // Fill list with names of available drives
-void FXDriveBox::loaddrives(){
-  clearItems();
+void FXDriveBox::listDrives(){
 #ifndef WIN32
-  appendItem(PATHSEPSTRING,foldericon);
+  appendItem("",foldericon);
 #else
   LPTSTR lpDriveStrings=0;
   DWORD dwCount=GetLogicalDriveStrings(0,lpDriveStrings); // Get required size
@@ -418,75 +405,42 @@ void FXDriveBox::loaddrives(){
   }
 
 
-// Changed current item in list; pass path to current item
-long FXDriveBox::onChanged(FXObject*,FXSelector,void*){
-  FXString string=getItemText(getCurrentItem());
-  if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)string.text());
+// Forward clicked message from list to target
+long FXDriveBox::onListClicked(FXObject*,FXSelector,void* ptr){
+  button->handle(this,MKUINT(ID_UNPOST,SEL_COMMAND),NULL);    // Unpost the list
+  if(0<=((FXint)(FXival)ptr)){
+    field->setText(getItemText((FXint)(FXival)ptr));
+    field->setIcon(getItemIcon((FXint)(FXival)ptr));
+    if(target){target->handle(this,MKUINT(message,SEL_COMMAND),(void*)getItemText((FXint)(FXival)ptr).text());}
+    }
   return 1;
   }
 
 
-// Switch current item
-long FXDriveBox::onCommand(FXObject*,FXSelector,void* ptr){
-  if(setDrive(getItemText((FXint)(long)ptr))){
-    if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)currentdrive.text());
-    }
-  return 1;
+// List has changed
+long FXDriveBox::onListChanged(FXObject*,FXSelector,void* ptr){
+  return target && target->handle(this,MKUINT(message,SEL_CHANGED),(void*)getItemText((FXint)(FXival)ptr).text());
   }
 
 
 // Set directory
 FXbool FXDriveBox::setDrive(const FXString& drive){
-#ifndef WIN32
-  //Widget is not too useful for non WIN32.
-  //The only drive is "/".
-  //Maybe this box could list mount points?
+  clearItems();
+  listDrives();
+  setCurrentItem(findItem(FXFile::drive(FXFile::absolute(drive))));
   return TRUE;
-#else
-  if(drive.empty()||(drive[1]!=':')) return FALSE;
-
-  //Drive letters are a lower case letter with a colon
-  FXString newdrive((FXchar)tolower(drive[0]),1);
-  newdrive.append(':');
-
-  // Exactly equal already
-  if(newdrive!=currentdrive){
-    // Switch
-    FXint n = getNumItems();
-    while(n){
-      n--;
-      if(getItemText(n)==newdrive){
-        //Make sure the drive is accessible
-//        if(_chdrive(newdrive[0]-'a'+1)==0){
-        if(FXFile::setCurrentDrive(newdrive)){
-          currentdrive = newdrive;     //If we are here we can assume the given drive is valid
-          setCurrentItem(n);
-          return TRUE;
-          }
-        else{
-          //Drive is inaccessible.  Set it back to the previous drive.
-          if(options&DRIVEBOX_REPORT_ERRORS) FXMessageBox::error(this,MBOX_OK,"Drive Error","%s is not accessible.\n\nThe device is not ready.",newdrive.text());
-          setCurrentItem(list->findItem(currentdrive));
-          return FALSE;
-          }
-        }
-      }
-    }
-  return FALSE;
-#endif
   }
 
 
-// Set widget is editable or not
-void FXDriveBox::reportErrors(FXbool errors){
-  if(errors) options&=~DRIVEBOX_REPORT_ERRORS; else options|=DRIVEBOX_REPORT_ERRORS;
+// Return current drive
+FXString FXDriveBox::getDrive() const {
+  return getItemText(getCurrentItem());
   }
 
 
 // Save object to stream
 void FXDriveBox::save(FXStream& store) const {
   FXListBox::save(store);
-  store << currentdrive;
   store << foldericon;
   store << cdromicon;
   store << desktopicon;
@@ -502,7 +456,6 @@ void FXDriveBox::save(FXStream& store) const {
 // Load object from stream
 void FXDriveBox::load(FXStream& store){
   FXListBox::load(store);
-  store >> currentdrive;
   store >> foldericon;
   store >> cdromicon;
   store >> desktopicon;
@@ -517,6 +470,7 @@ void FXDriveBox::load(FXStream& store){
 
 // Delete it
 FXDriveBox::~FXDriveBox(){
+  clearItems();
   delete foldericon;
   delete cdromicon;
   delete desktopicon;
