@@ -3,7 +3,7 @@
 *                    F i l e   S e l e c t i o n   D i a l o g                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXFileDialog.cpp,v 1.21 2001/04/27 14:30:31 jeroen Exp $                 *
+* $Id: FXFileDialog.cpp,v 1.23.4.3 2003/03/27 20:34:43 fox Exp $                 *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -31,9 +31,6 @@
 #include "FXPoint.h"
 #include "FXRectangle.h"
 #include "FXFile.h"
-#include "FXObject.h"
-#include "FXObjectList.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
@@ -243,9 +240,9 @@ FXString FXFileDialog::getOpenFilename(FXWindow* owner,const FXString& caption,c
   FXFileDialog opendialog(owner,caption);
   FXString filename;
   opendialog.setSelectMode(SELECTFILE_EXISTING);
+  opendialog.setFilename(path);
   opendialog.setPatternList(patterns);
   opendialog.setCurrentPattern(initial);
-  opendialog.setFilename(path);
   if(opendialog.execute()){
     filename=opendialog.getFilename();
     if(FXFile::isFile(filename)) return filename;
@@ -258,9 +255,9 @@ FXString FXFileDialog::getOpenFilename(FXWindow* owner,const FXString& caption,c
 FXString FXFileDialog::getSaveFilename(FXWindow* owner,const FXString& caption,const FXString& path,const FXString& patterns,FXint initial){
   FXFileDialog savedialog(owner,caption);
   savedialog.setSelectMode(SELECTFILE_ANY);
+  savedialog.setFilename(path);
   savedialog.setPatternList(patterns);
   savedialog.setCurrentPattern(initial);
-  savedialog.setFilename(path);
   if(savedialog.execute()){
     return savedialog.getFilename();
     }
@@ -272,9 +269,9 @@ FXString FXFileDialog::getSaveFilename(FXWindow* owner,const FXString& caption,c
 FXString* FXFileDialog::getOpenFilenames(FXWindow* owner,const FXString& caption,const FXString& path,const FXString& patterns,FXint initial){
   FXFileDialog opendialog(owner,caption);
   opendialog.setSelectMode(SELECTFILE_MULTIPLE);
+  opendialog.setFilename(path);
   opendialog.setPatternList(patterns);
   opendialog.setCurrentPattern(initial);
-  opendialog.setDirectory(path);
   if(opendialog.execute()){
     return opendialog.getFilenames();
     }
