@@ -3,7 +3,7 @@
 *                  F i l e   S e l e c t i o n   W i d g e t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXFileSelector.cpp,v 1.72 2001/07/05 22:34:29 jeroen Exp $               *
+* $Id: FXFileSelector.cpp,v 1.101.4.9 2003/06/20 19:02:07 fox Exp $                  *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,21 +30,14 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXObjectList.h"
-#include "FXDict.h"
 #include "FXFile.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXApp.h"
-#include "FXId.h"
 #include "FXFont.h"
-#include "FXDrawable.h"
-#include "FXImage.h"
-#include "FXIcon.h"
 #include "FXGIFIcon.h"
-#include "FXWindow.h"
+#include "FXBMPIcon.h"
 #include "FXRecentFiles.h"
 #include "FXFrame.h"
 #include "FXLabel.h"
@@ -54,7 +47,6 @@
 #include "FXToggleButton.h"
 #include "FXCheckButton.h"
 #include "FXMenuButton.h"
-#include "FXComposite.h"
 #include "FXPacker.h"
 #include "FXHorizontalFrame.h"
 #include "FXVerticalFrame.h"
@@ -75,6 +67,7 @@
 #include "FXFileList.h"
 #include "FXFileSelector.h"
 #include "FXMenuCaption.h"
+#include "FXMenuCascade.h"
 #include "FXMenuCommand.h"
 #include "FXMenuSeparator.h"
 #include "FXTopWindow.h"
@@ -124,6 +117,8 @@
 
   - When changing filter, maybe update the extension (if not more than
     one extension given).
+
+  - Perhaps ".." should be excluded from SELECTFILE_MULTIPLE_ALL selections.
 */
 
 
@@ -175,13 +170,13 @@ const unsigned char tblist[]={
   };
 
 const unsigned char home[]={
-  0x47,0x49,0x46,0x38,0x37,0x61,0x10,0x00,0x10,0x00,0xf1,0x00,0x00,0xb2,0xc0,0xdc,
-  0x00,0x00,0x00,0xff,0xa5,0x00,0xff,0xff,0x00,0x2c,0x00,0x00,0x00,0x00,0x10,0x00,
-  0x10,0x00,0x00,0x02,0x3b,0x84,0x0f,0x11,0xc8,0x6a,0x21,0xc4,0x62,0x6f,0xc1,0x28,
-  0x69,0x52,0x18,0x4f,0xc4,0x75,0x5e,0x23,0x8a,0x9f,0x82,0xa6,0xea,0x16,0x0c,0xee,
-  0x0b,0xa3,0x0f,0x4c,0x0f,0x5f,0xe2,0xa2,0xb6,0x62,0x83,0x39,0x6e,0xe9,0x1d,0x5a,
-  0xbd,0x96,0xee,0x46,0x0c,0xc6,0x7c,0x45,0x1a,0x52,0xa6,0x72,0x68,0xa6,0x86,0x02,
-  0x00,0x3b
+  0x47,0x49,0x46,0x38,0x37,0x61,0x10,0x00,0x10,0x00,0xc2,0x00,0x00,0xb2,0xc0,0xdc,
+  0x00,0x00,0x00,0x84,0x00,0x00,0xff,0xff,0x00,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
+  0x00,0x00,0x00,0x00,0x00,0x2c,0x00,0x00,0x00,0x00,0x10,0x00,0x10,0x00,0x00,0x03,
+  0x3b,0x08,0xba,0xdc,0xae,0x21,0x28,0x21,0x1f,0x08,0x63,0x48,0x6a,0x71,0xd4,0x9c,
+  0xe3,0x11,0x84,0x57,0x31,0x23,0x59,0x6a,0x4d,0xaa,0xae,0xa7,0xfb,0xc2,0x4b,0x30,
+  0xcf,0xe7,0xa5,0x46,0xd1,0x8e,0xee,0x19,0x1b,0x29,0x27,0x5c,0x69,0x7c,0x35,0xe0,
+  0x71,0xf8,0x1b,0x06,0x91,0x10,0x9e,0x54,0x6a,0xa9,0x02,0x12,0x00,0x3b
   };
 
 const unsigned char fileshown[]={
@@ -249,6 +244,48 @@ const unsigned char dlgnewfolder[]={
   0xa1,0xa2,0x13,0x09,0x00,0x3b
   };
 
+const unsigned char deletefile[]={
+  0x42,0x4d,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x00,0x00,0x00,0x28,0x00,
+  0x00,0x00,0x10,0x00,0x00,0x00,0x10,0x00,0x00,0x00,0x01,0x00,0x01,0x00,0x00,0x00,
+  0x00,0x00,0x40,0x00,0x00,0x00,0x6d,0x0b,0x00,0x00,0x6d,0x0b,0x00,0x00,0x02,0x00,
+  0x00,0x00,0x02,0x00,0x00,0x00,0xdc,0xc0,0xb2,0x00,0x00,0x00,0x84,0x00,0x00,0x00,
+  0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x04,0x00,0x00,0x70,0x00,0x00,0x00,0x78,0x08,
+  0x00,0x00,0x38,0x10,0x00,0x00,0x1c,0x30,0x00,0x00,0x0e,0x60,0x00,0x00,0x07,0xc0,
+  0x00,0x00,0x03,0x80,0x00,0x00,0x07,0xc0,0x00,0x00,0x0e,0x60,0x00,0x00,0x3c,0x30,
+  0x00,0x00,0x78,0x18,0x00,0x00,0x70,0x04,0x00,0x00,0x00,0x00,0x00,0x00
+  };
+
+
+const unsigned char copyfile[]={
+  0x47,0x49,0x46,0x38,0x37,0x61,0x10,0x00,0x10,0x00,0xa1,0x00,0x00,0xb2,0xc0,0xdc,
+  0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xcb,0x2c,0x00,0x00,0x00,0x00,0x10,0x00,
+  0x10,0x00,0x00,0x02,0x3c,0x84,0x8f,0x09,0xc1,0xad,0x18,0x84,0x14,0xec,0x99,0x38,
+  0x63,0xb0,0xba,0x57,0x85,0x4d,0xd2,0x06,0x52,0x8c,0xd9,0x90,0x97,0x48,0x0d,0xee,
+  0xf0,0x2d,0x68,0xfb,0x06,0xf0,0x2a,0xda,0x0c,0xec,0xa4,0xcd,0x0b,0x54,0x41,0x78,
+  0x3f,0xe1,0xc1,0x06,0x74,0x19,0x2f,0xc4,0xdd,0x72,0x91,0x54,0x3e,0x7c,0x29,0x40,
+  0x01,0x00,0x3b
+  };
+
+
+const unsigned char movefile[]={
+  0x47,0x49,0x46,0x38,0x37,0x61,0x10,0x00,0x10,0x00,0xc2,0x00,0x00,0xb2,0xc0,0xdc,
+  0x7f,0x7f,0x65,0xb3,0xb3,0x8e,0x00,0x00,0x00,0xff,0xff,0xcb,0x00,0x00,0x00,0x00,
+  0x00,0x00,0x00,0x00,0x00,0x2c,0x00,0x00,0x00,0x00,0x10,0x00,0x10,0x00,0x00,0x03,
+  0x3e,0x08,0xba,0xdc,0x10,0x30,0x3a,0x16,0x84,0x15,0x70,0xaa,0x7a,0x6b,0xd0,0x5e,
+  0x98,0x39,0xdc,0x65,0x7d,0x24,0x06,0x09,0x43,0xeb,0x52,0x26,0x4b,0xcc,0x44,0xbb,
+  0x88,0x32,0x3d,0xd4,0x5b,0xbc,0xb7,0xb5,0x57,0x24,0xb2,0xa3,0xe9,0x26,0x3f,0xd7,
+  0x0f,0x69,0x3c,0x3a,0x92,0x2e,0xde,0xb3,0x39,0x1b,0x20,0x95,0x4a,0x40,0x02,0x00,
+  0x3b
+  };
+
+const unsigned char linkfile[]={
+  0x47,0x49,0x46,0x38,0x37,0x61,0x10,0x00,0x10,0x00,0xa1,0x00,0x00,0xb2,0xc0,0xdc,
+  0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x2c,0x00,0x00,0x00,0x00,0x10,0x00,
+  0x10,0x00,0x00,0x02,0x20,0x84,0x8f,0xa9,0xcb,0xed,0x0f,0x4f,0x98,0x33,0xd1,0x00,
+  0x82,0xd8,0xfb,0x6a,0x3e,0x09,0x1e,0x48,0x89,0x1f,0x59,0x82,0xd9,0x65,0x51,0xd1,
+  0x0b,0xc7,0xf2,0x8c,0x14,0x00,0x3b
+  };
+
 /*******************************************************************************/
 
 
@@ -259,6 +296,7 @@ FXDEFMAP(FXFileSelector) FXFileSelectorMap[]={
   FXMAPFUNC(SEL_DOUBLECLICKED,FXFileSelector::ID_FILELIST,FXFileSelector::onCmdItemDblClicked),
   FXMAPFUNC(SEL_SELECTED,FXFileSelector::ID_FILELIST,FXFileSelector::onCmdItemSelected),
   FXMAPFUNC(SEL_DESELECTED,FXFileSelector::ID_FILELIST,FXFileSelector::onCmdItemDeselected),
+  FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,FXFileSelector::ID_FILELIST,FXFileSelector::onPopupMenu),
   FXMAPFUNC(SEL_COMMAND,FXFileSelector::ID_DIRECTORY_UP,FXFileSelector::onCmdDirectoryUp),
   FXMAPFUNC(SEL_UPDATE,FXFileSelector::ID_DIRECTORY_UP,FXFileSelector::onUpdDirectoryUp),
   FXMAPFUNC(SEL_COMMAND,FXFileSelector::ID_DIRTREE,FXFileSelector::onCmdDirTree),
@@ -269,7 +307,13 @@ FXDEFMAP(FXFileSelector) FXFileSelectorMap[]={
   FXMAPFUNC(SEL_COMMAND,FXFileSelector::ID_NEW,FXFileSelector::onCmdNew),
   FXMAPFUNC(SEL_UPDATE,FXFileSelector::ID_NEW,FXFileSelector::onUpdNew),
   FXMAPFUNC(SEL_COMMAND,FXFileSelector::ID_DELETE,FXFileSelector::onCmdDelete),
-  FXMAPFUNC(SEL_UPDATE,FXFileSelector::ID_DELETE,FXFileSelector::onUpdDelete),
+  FXMAPFUNC(SEL_COMMAND,FXFileSelector::ID_MOVE,FXFileSelector::onCmdMove),
+  FXMAPFUNC(SEL_COMMAND,FXFileSelector::ID_COPY,FXFileSelector::onCmdCopy),
+  FXMAPFUNC(SEL_COMMAND,FXFileSelector::ID_LINK,FXFileSelector::onCmdLink),
+  FXMAPFUNC(SEL_UPDATE,FXFileSelector::ID_COPY,FXFileSelector::onUpdSelected),
+  FXMAPFUNC(SEL_UPDATE,FXFileSelector::ID_MOVE,FXFileSelector::onUpdSelected),
+  FXMAPFUNC(SEL_UPDATE,FXFileSelector::ID_LINK,FXFileSelector::onUpdSelected),
+  FXMAPFUNC(SEL_UPDATE,FXFileSelector::ID_DELETE,FXFileSelector::onUpdSelected),
   };
 
 
@@ -290,17 +334,17 @@ FXFileSelector::FXFileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuin
   FXAccelTable *table;
   target=tgt;
   message=sel;
-  FXHorizontalFrame *buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
+  FXHorizontalFrame *buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X,0,0,0,0, DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING, 0,0);
   FXMatrix *fields=new FXMatrix(this,3,MATRIX_BY_COLUMNS|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
   new FXLabel(fields,"&File Name:",NULL,JUSTIFY_LEFT|LAYOUT_CENTER_Y);
   filename=new FXTextField(fields,25,this,ID_ACCEPT,TEXTFIELD_ENTER_ONLY|LAYOUT_FILL_COLUMN|LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK);
-  new FXButton(fields,"&OK",NULL,this,ID_ACCEPT,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_X,0,0,0,0,20,20);
+  new FXButton(fields,"&OK",NULL,this,ID_ACCEPT,BUTTON_INITIAL|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_X,0,0,0,0,20,20);
   accept=new FXButton(buttons,NULL,NULL,NULL,0,LAYOUT_FIX_X|LAYOUT_FIX_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,0,0, 0,0,0,0);
   new FXLabel(fields,"File F&ilter:",NULL,JUSTIFY_LEFT|LAYOUT_CENTER_Y);
   FXHorizontalFrame *filterframe=new FXHorizontalFrame(fields,LAYOUT_FILL_COLUMN|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0);
   filefilter=new FXComboBox(filterframe,10,4,this,ID_FILEFILTER,COMBOBOX_STATIC|LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK);
   readonly=new FXCheckButton(filterframe,"Read Only",NULL,0,ICON_BEFORE_TEXT|JUSTIFY_LEFT|LAYOUT_CENTER_Y);
-  cancel=new FXButton(fields,"&Cancel",NULL,NULL,0,FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_X,0,0,0,0,20,20);
+  cancel=new FXButton(fields,"&Cancel",NULL,NULL,0,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_X,0,0,0,0,20,20);
   FXHorizontalFrame *frame=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN|FRAME_THICK,0,0,0,0,0,0,0,0);
   filebox=new FXFileList(frame,this,ID_FILELIST,ICONLIST_MINI_ICONS|ICONLIST_BROWSESELECT|ICONLIST_AUTOSIZE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
   new FXLabel(buttons,"Directory:",NULL,LAYOUT_CENTER_Y);
@@ -315,9 +359,13 @@ FXFileSelector::FXFileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuin
   hiddenicon=new FXGIFIcon(getApp(),filehidden);
   markicon=new FXGIFIcon(getApp(),mark);
   clearicon=new FXGIFIcon(getApp(),clear);
+  deleteicon=new FXBMPIcon(getApp(),deletefile,0,IMAGE_ALPHAGUESS);
+  moveicon=new FXGIFIcon(getApp(),movefile);
+  copyicon=new FXGIFIcon(getApp(),copyfile);
+  linkicon=new FXGIFIcon(getApp(),linkfile);
   dirbox=new FXDirBox(buttons,5,this,ID_DIRTREE,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FIX_WIDTH|LAYOUT_CENTER_Y,0,0,160,0);
   bookmarks=new FXMenuPane(this,POPUP_SHRINKWRAP);
-  new FXMenuCommand(bookmarks,"&Set Bookmark\t\tBookmark current directory.",markicon,this,ID_BOOKMARK);
+  new FXMenuCommand(bookmarks,"&Set bookmark\t\tBookmark current directory.",markicon,this,ID_BOOKMARK);
   new FXMenuCommand(bookmarks,"&Clear bookmarks\t\tClear bookmarks.",clearicon,&mrufiles,FXRecentFiles::ID_CLEAR);
   FXMenuSeparator* sep1=new FXMenuSeparator(bookmarks);
   sep1->setTarget(&mrufiles);
@@ -332,25 +380,27 @@ FXFileSelector::FXFileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuin
   new FXMenuCommand(bookmarks,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_8);
   new FXMenuCommand(bookmarks,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_9);
   new FXMenuCommand(bookmarks,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_10);
-  new FXButton(buttons,"\tGo Up One Directory\tMove up to higher directory.",updiricon,this,ID_DIRECTORY_UP,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
-  new FXButton(buttons,"\tGo To Home Directory\tBack to home directory.",homeicon,this,ID_HOME,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
-  new FXButton(buttons,"\tGo To Work Directory\tBack to working directory.",workicon,this,ID_WORK,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+  new FXFrame(buttons,LAYOUT_FIX_WIDTH,0,0,4,1);
+  new FXButton(buttons,"\tGo up one directory\tMove up to higher directory.",updiricon,this,ID_DIRECTORY_UP,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+  new FXButton(buttons,"\tGo to home directory\tBack to home directory.",homeicon,this,ID_HOME,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+  new FXButton(buttons,"\tGo to work directory\tBack to working directory.",workicon,this,ID_WORK,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
   new FXMenuButton(buttons,"\tBookmarks\tVisit bookmarked directories.",markicon,bookmarks,MENUBUTTON_NOARROWS|MENUBUTTON_ATTACH_LEFT|MENUBUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
-  new FXButton(buttons,"\tCreate New Directory\tCreate new directory.",newdiricon,this,ID_NEW,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
-  new FXButton(buttons,"\tShow List\tDisplay directory with small icons.",listicon,filebox,FXFileList::ID_SHOW_MINI_ICONS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
-  new FXButton(buttons,"\tShow Icons\tDisplay directory with big icons.",iconsicon,filebox,FXFileList::ID_SHOW_BIG_ICONS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
-  new FXButton(buttons,"\tShow Details\tDisplay detailed directory listing.",detailicon,filebox,FXFileList::ID_SHOW_DETAILS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
-  new FXToggleButton(buttons,"\tShow Hidden Files\tShow hidden files and directories.","\tHide Hidden Files\tHide hidden files and directories.",hiddenicon,shownicon,filebox,FXFileList::ID_TOGGLE_HIDDEN,TOGGLEBUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+  new FXButton(buttons,"\tCreate new directory\tCreate new directory.",newdiricon,this,ID_NEW,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+  new FXButton(buttons,"\tShow list\tDisplay directory with small icons.",listicon,filebox,FXFileList::ID_SHOW_MINI_ICONS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+  new FXButton(buttons,"\tShow icons\tDisplay directory with big icons.",iconsicon,filebox,FXFileList::ID_SHOW_BIG_ICONS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+  new FXButton(buttons,"\tShow details\tDisplay detailed directory listing.",detailicon,filebox,FXFileList::ID_SHOW_DETAILS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+  new FXToggleButton(buttons,"\tShow hidden files\tShow hidden files and directories.","\tHide Hidden Files\tHide hidden files and directories.",hiddenicon,shownicon,filebox,FXFileList::ID_TOGGLE_HIDDEN,TOGGLEBUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
   mrufiles.setTarget(this);
   mrufiles.setSelector(ID_VISIT);
   table=getShell()->getAccelTable();
   readonly->hide();
   if(table){
-    table->addAccel(MKUINT(KEY_Delete,0),this,MKUINT(ID_DELETE,SEL_COMMAND));
     table->addAccel(MKUINT(KEY_BackSpace,0),this,MKUINT(ID_DIRECTORY_UP,SEL_COMMAND));
+    table->addAccel(MKUINT(KEY_Delete,0),this,MKUINT(ID_DELETE,SEL_COMMAND));
     table->addAccel(MKUINT(KEY_h,CONTROLMASK),this,MKUINT(ID_HOME,SEL_COMMAND));
     table->addAccel(MKUINT(KEY_w,CONTROLMASK),this,MKUINT(ID_WORK,SEL_COMMAND));
     table->addAccel(MKUINT(KEY_n,CONTROLMASK),this,MKUINT(ID_NEW,SEL_COMMAND));
+    table->addAccel(MKUINT(KEY_a,CONTROLMASK),filebox,MKUINT(FXFileList::ID_SELECT_ALL,SEL_COMMAND));
     table->addAccel(MKUINT(KEY_b,CONTROLMASK),filebox,MKUINT(FXFileList::ID_SHOW_BIG_ICONS,SEL_COMMAND));
     table->addAccel(MKUINT(KEY_s,CONTROLMASK),filebox,MKUINT(FXFileList::ID_SHOW_MINI_ICONS,SEL_COMMAND));
     table->addAccel(MKUINT(KEY_l,CONTROLMASK),filebox,MKUINT(FXFileList::ID_SHOW_DETAILS,SEL_COMMAND));
@@ -359,39 +409,27 @@ FXFileSelector::FXFileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuin
   setPatternList(allfiles);
   setDirectory(FXFile::getCurrentDirectory());
   filebox->setFocus();
-  }
-
-
-// Double-clicked item in file list
-long FXFileSelector::onCmdItemDblClicked(FXObject*,FXSelector,void* ptr){
-  FXint index=(FXint)(long)ptr;
-  if(index<0) return 1;
-
-  // If directory, open the directory
-  if(filebox->isItemDirectory(index)){
-    setDirectory(filebox->getItemPathname(index));
-    return 1;
-    }
-
-  // Only return if we wanted a file
-  if(selectmode!=SELECTFILE_DIRECTORY){
-    if(filebox->isItemFile(index)){
-      FXObject *tgt=accept->getTarget();
-      FXSelector sel=accept->getSelector();
-      if(tgt) tgt->handle(accept,MKUINT(sel,SEL_COMMAND),(void*)1);
-      }
-    }
-  return 1;
+  accept->hide();
   }
 
 
 // Change in items which are selected
 long FXFileSelector::onCmdItemSelected(FXObject*,FXSelector,void* ptr){
-  FXint index=(FXint)(long)ptr;
+  register FXint index=(FXint)(FXival)ptr;
+  register FXint i;
   FXString text,file;
   if(selectmode==SELECTFILE_MULTIPLE){
-    for(FXint i=0; i<filebox->getNumItems(); i++){
-      if(filebox->isItemFile(i) && filebox->isItemSelected(i)){
+    for(i=0; i<filebox->getNumItems(); i++){
+      if(filebox->isItemSelected(i) && !filebox->isItemDirectory(i)){
+        if(!text.empty()) text+=' ';
+        text+="\""+filebox->getItemFilename(i)+"\"";
+        }
+      }
+    filename->setText(text);
+    }
+  else if(selectmode==SELECTFILE_MULTIPLE_ALL){
+    for(i=0; i<filebox->getNumItems(); i++){
+      if(filebox->isItemSelected(i) && filebox->getItemFilename(i)!=".."){
         if(!text.empty()) text+=' ';
         text+="\""+filebox->getItemFilename(i)+"\"";
         }
@@ -405,7 +443,7 @@ long FXFileSelector::onCmdItemSelected(FXObject*,FXSelector,void* ptr){
       }
     }
   else{
-    if(filebox->isItemFile(index)){
+    if(!filebox->isItemDirectory(index)){
       text=filebox->getItemFilename(index);
       filename->setText(text);
       }
@@ -419,13 +457,44 @@ long FXFileSelector::onCmdItemDeselected(FXObject*,FXSelector,void*){
   FXString text,file;
   if(selectmode==SELECTFILE_MULTIPLE){
     for(FXint i=0; i<filebox->getNumItems(); i++){
-      if(filebox->isItemFile(i) && filebox->isItemSelected(i)){
+      if(filebox->isItemSelected(i) && !filebox->isItemDirectory(i)){
         if(!text.empty()) text+=' ';
         text+="\""+filebox->getItemFilename(i)+"\"";
         }
       }
     filename->setText(text);
     }
+  else if(selectmode==SELECTFILE_MULTIPLE_ALL){
+    for(FXint i=0; i<filebox->getNumItems(); i++){
+      if(filebox->isItemSelected(i) && filebox->getItemFilename(i)!=".."){
+        if(!text.empty()) text+=' ';
+        text+="\""+filebox->getItemFilename(i)+"\"";
+        }
+      }
+    filename->setText(text);
+    }
+  return 1;
+  }
+
+
+// Double-clicked item in file list
+long FXFileSelector::onCmdItemDblClicked(FXObject*,FXSelector,void* ptr){
+  FXSelector sel=accept->getSelector();
+  FXObject *tgt=accept->getTarget();
+  FXint index=(FXint)(FXival)ptr;
+  if(0<=index){
+
+    // If directory, open the directory
+    if(filebox->isItemDirectory(index)){
+      setDirectory(filebox->getItemPathname(index));
+      return 1;
+      }
+
+    // Only return if we wanted a file
+    if(selectmode!=SELECTFILE_DIRECTORY){
+      if(tgt) tgt->handle(accept,MKUINT(sel,SEL_COMMAND),(void*)(FXuval)1);
+      }
+    }
   return 1;
   }
 
@@ -437,89 +506,66 @@ long FXFileSelector::onCmdAccept(FXObject*,FXSelector,void*){
 
   // Get (first) filename
   FXString path=getFilename();
-  
-/*
-path=filename->getText();
-  FXString *list;
-  FXint     count;
-  count=FXFile::listFiles(list,path,"*",FILEMATCH_NOESCAPE|FILEMATCH_FILE_NAME);
-  FXTRACE((1,"listFiles(%s) count=%d\n",path.text(),count));
-  if(count){
-    for(int i=0; i<count; i++){
-      FXTRACE((1,"list[%d]=%s\n",i,list[i].text()));
-      }
-    delete [] list;
-    }
-return 1;
-*/
-  
-  // Is directory?
-  if(FXFile::isDirectory(path)){
 
-    // In directory mode:- we got our answer!
-    if(selectmode==SELECTFILE_DIRECTORY){
-      if(tgt) tgt->handle(accept,MKUINT(sel,SEL_COMMAND),(void*)1);
+  // Only do something if a selection was made
+  if(!path.empty()){
+
+    // Is directory?
+    if(FXFile::isDirectory(path)){
+
+      // In directory mode:- we got our answer!
+      if(selectmode==SELECTFILE_DIRECTORY || selectmode==SELECTFILE_MULTIPLE_ALL){
+        if(tgt) tgt->handle(accept,MKUINT(sel,SEL_COMMAND),(void*)(FXuval)1);
+        return 1;
+        }
+
+      // Hop over to that directory
+      dirbox->setDirectory(path);
+      filebox->setDirectory(path);
+      filename->setText(FXString::null);
       return 1;
       }
 
-    // Hop over to that directory
-    dirbox->setDirectory(path);
-    filebox->setDirectory(path);
-    filename->setText(FXString::null);
-    return 1;
-    }
+    // Get directory part of path
+    FXString dir=FXFile::directory(path);
 
-  // Get directory part of path
-  FXString dir=FXFile::directory(path);
+    // In file mode, directory part of path should exist
+    if(FXFile::isDirectory(dir)){
 
-  // In file mode, directory part of path should exist
-  if(FXFile::isDirectory(dir)){
+      // In any mode, existing directory part is good enough
+      if(selectmode==SELECTFILE_ANY){
+        if(tgt) tgt->handle(accept,MKUINT(sel,SEL_COMMAND),(void*)(FXuval)1);
+        return 1;
+        }
 
-    // In any mode, existing directory part is good enough
-    if(selectmode==SELECTFILE_ANY){
-      if(tgt) tgt->handle(accept,MKUINT(sel,SEL_COMMAND),(void*)1);
-      return 1;
-      }
-
-    // In existing mode, the whole filename must exist and be a file
-    else if(selectmode==SELECTFILE_EXISTING){
-      if(FXFile::isFile(path)){
-        if(tgt) tgt->handle(accept,MKUINT(sel,SEL_COMMAND),(void*)1);
+      // Otherwise, the whole filename must exist and be a file
+      else if(FXFile::exists(path)){
+        if(tgt) tgt->handle(accept,MKUINT(sel,SEL_COMMAND),(void*)(FXuval)1);
         return 1;
         }
       }
 
-    // In multiple mode, return if all selected files exist
-    else{
-      for(FXint i=0; i<filebox->getNumItems(); i++){
-        if(filebox->isItemFile(i) && filebox->isItemSelected(i)){
-          if(tgt) tgt->handle(accept,MKUINT(sel,SEL_COMMAND),(void*)1);
-          return 1;
-          }
-        }
+    // Go up to the lowest directory which still exists
+    while(!FXFile::isTopDirectory(dir) && !FXFile::isDirectory(dir)){
+      dir=FXFile::upLevel(dir);
       }
+
+    // Switch as far as we could go
+    dirbox->setDirectory(dir);
+    filebox->setDirectory(dir);
+
+    // Put the tail end back for further editing
+    FXASSERT(dir.length()<=path.length());
+    if(ISPATHSEP(path[dir.length()]))
+      path.remove(0,dir.length()+1);
+    else
+      path.remove(0,dir.length());
+
+    // Replace text box with new stuff
+    filename->setText(path);
+    filename->selectAll();
     }
 
-  // Go up to the lowest directory which still exists
-  while(!FXFile::isTopDirectory(dir) && !FXFile::isDirectory(dir)){
-    dir=FXFile::upLevel(dir);
-    }
-
-  // Switch as far as we could go
-  dirbox->setDirectory(dir);
-  filebox->setDirectory(dir);
-
-  // Put the tail end back for further editing
-  FXASSERT(dir.length()<=path.length());
-  if(ISPATHSEP(path[dir.length()]))
-    path.remove(0,dir.length()+1);
-  else
-    path.remove(0,dir.length());
-
-  // Replace text box with new stuff
-  filename->setText(path);
-  filename->selectAll();
-
   // Beep
   getApp()->beep();
   return 1;
@@ -585,10 +631,11 @@ long FXFileSelector::onCmdDirTree(FXObject*,FXSelector,void* ptr){
 
 // Create new directory
 long FXFileSelector::onCmdNew(FXObject*,FXSelector,void*){
+  FXString dir=filebox->getDirectory();
   FXString name="DirectoryName";
   FXGIFIcon newdiricon(getApp(),dlgnewfolder);
-  if(FXInputDialog::getString(name,this,"Create New Directory","Create new directory in: "+filebox->getDirectory(),&newdiricon)){
-    FXString dirname=FXFile::absolute(filebox->getDirectory(),name);
+  if(FXInputDialog::getString(name,this,"Create New Directory","Create new directory in: "+dir,&newdiricon)){
+    FXString dirname=FXFile::absolute(dir,name);
     if(FXFile::exists(dirname)){
       FXMessageBox::error(this,MBOX_OK,"Already Exists","File or directory %s already exists.\n",dirname.text());
       }
@@ -602,8 +649,8 @@ long FXFileSelector::onCmdNew(FXObject*,FXSelector,void*){
 
 // Update create new directory
 long FXFileSelector::onUpdNew(FXObject* sender,FXSelector,void*){
-  FXString path=filebox->getDirectory();
-  if(FXFile::isWritable(path))
+  FXString dir=filebox->getDirectory();
+  if(FXFile::isWritable(dir))
     sender->handle(this,MKUINT(ID_ENABLE,SEL_COMMAND),NULL);
   else
     sender->handle(this,MKUINT(ID_DISABLE,SEL_COMMAND),NULL);
@@ -611,18 +658,24 @@ long FXFileSelector::onUpdNew(FXObject* sender,FXSelector,void*){
   }
 
 
-// Delete file or directory
-long FXFileSelector::onCmdDelete(FXObject*,FXSelector,void*){
-  FXuint answer=FXMessageBox::warning(this,MBOX_YES_NO,"Deleting files","Are you sure you want to delete these files?");
-  if(answer==MBOX_CLICKED_YES){
-    FXString filetoremove,file;
-    for(FXint i=0; i<filebox->getNumItems(); i++){
-      if(filebox->isItemSelected(i)){
-        file=filebox->getItemFilename(i);
-        if(file=="..") continue;
-        filetoremove=FXFile::absolute(filebox->getDirectory(),file);
-        if(!FXFile::remove(filetoremove)){
-          if(MBOX_CLICKED_NO==FXMessageBox::error(this,MBOX_YES_NO,"Error Deleting File","Unable to delete file: %s\nContinue with operation?",filetoremove.text())){
+// Copy file or directory
+long FXFileSelector::onCmdCopy(FXObject*,FXSelector,void*){
+  FXString dir=filebox->getDirectory();
+  FXString newname,oldname,name;
+  for(FXint i=0; i<filebox->getNumItems(); i++){
+    if(filebox->isItemSelected(i)){
+      name=filebox->getItemFilename(i);
+      if(name=="..") continue;
+      oldname=FXFile::absolute(dir,name);
+      newname=FXFile::absolute(dir,"CopyOf"+name);
+      //FXGIFIcon copybigicon(getApp(),copyfilebig);
+      FXInputDialog inputdialog(this,"Copy File","Copy file from location:\n\n"+oldname+"\n\nto location:",NULL,INPUTDIALOG_STRING,0,0,0,0);
+      inputdialog.setText(newname);
+      inputdialog.setNumColumns(60);
+      if(inputdialog.execute()){
+        newname=inputdialog.getText();
+        if(!FXFile::copy(oldname,newname,FALSE)){
+          if(MBOX_CLICKED_NO==FXMessageBox::error(this,MBOX_YES_NO,"Error Copying File","Unable to copy file:\n\n%s  to:  %s\n\nContinue with operation?",oldname.text(),newname.text())){
             break;
             }
           }
@@ -633,8 +686,158 @@ long FXFileSelector::onCmdDelete(FXObject*,FXSelector,void*){
   }
 
 
-// Update delete button
-long FXFileSelector::onUpdDelete(FXObject*,FXSelector,void*){
+// Move file or directory
+long FXFileSelector::onCmdMove(FXObject*,FXSelector,void*){
+  FXString dir=filebox->getDirectory();
+  FXString newname,oldname,name;
+  for(FXint i=0; i<filebox->getNumItems(); i++){
+    if(filebox->isItemSelected(i)){
+      name=filebox->getItemFilename(i);
+      if(name=="..") continue;
+      oldname=FXFile::absolute(dir,name);
+      newname=FXFile::absolute(dir,name);
+      //FXGIFIcon movebigicon(getApp(),movefilebig);
+      FXInputDialog inputdialog(this,"Move File","Move file from location:\n\n"+oldname+"\n\nto location:",NULL,INPUTDIALOG_STRING,0,0,0,0);
+      inputdialog.setText(newname);
+      inputdialog.setNumColumns(60);
+      if(inputdialog.execute()){
+        newname=inputdialog.getText();
+        if(!FXFile::move(oldname,newname,FALSE)){
+          if(MBOX_CLICKED_NO==FXMessageBox::error(this,MBOX_YES_NO,"Error Moving File","Unable to move file:\n\n%s  to:  %s\n\nContinue with operation?",oldname.text(),newname.text())){
+            break;
+            }
+          }
+        }
+      }
+    }
+  return 1;
+  }
+
+
+// Link file or directory
+long FXFileSelector::onCmdLink(FXObject*,FXSelector,void*){
+  FXString dir=filebox->getDirectory();
+  FXString newname,oldname,name;
+  for(FXint i=0; i<filebox->getNumItems(); i++){
+    if(filebox->isItemSelected(i)){
+      name=filebox->getItemFilename(i);
+      if(name=="..") continue;
+      oldname=FXFile::absolute(dir,name);
+      newname=FXFile::absolute(dir,"LinkTo"+name);
+      //FXGIFIcon copybigicon(getApp(),linkfilebig);
+      FXInputDialog inputdialog(this,"Link File","Link file from location:\n\n"+oldname+"\n\nto location:",NULL,INPUTDIALOG_STRING,0,0,0,0);
+      inputdialog.setText(newname);
+      inputdialog.setNumColumns(60);
+      if(inputdialog.execute()){
+        newname=inputdialog.getText();
+        if(!FXFile::link(oldname,newname,FALSE)){
+          if(MBOX_CLICKED_NO==FXMessageBox::error(this,MBOX_YES_NO,"Error Linking File","Unable to link file:\n\n%s  to:  %s\n\nContinue with operation?",oldname.text(),newname.text())){
+            break;
+            }
+          }
+        }
+      }
+    }
+  return 1;
+  }
+
+
+// Delete file or directory
+long FXFileSelector::onCmdDelete(FXObject*,FXSelector,void*){
+  FXString dir=filebox->getDirectory();
+  FXString fullname,name;
+  FXuint answer;
+  for(FXint i=0; i<filebox->getNumItems(); i++){
+    if(filebox->isItemSelected(i)){
+      name=filebox->getItemFilename(i);
+      if(name=="..") continue;
+      fullname=FXFile::absolute(dir,name);
+      answer=FXMessageBox::warning(this,MBOX_YES_NO_CANCEL,"Deleting files","Are you sure you want to delete the file:\n\n%s",fullname.text());
+      if(answer==MBOX_CLICKED_CANCEL) break;
+      if(answer==MBOX_CLICKED_NO) continue;
+      if(!FXFile::remove(fullname)){
+        if(MBOX_CLICKED_NO==FXMessageBox::error(this,MBOX_YES_NO,"Error Deleting File","Unable to delete file:\n\n%s\n\nContinue with operation?",fullname.text())){
+          break;
+          }
+        }
+      }
+    }
+  return 1;
+  }
+
+
+// Sensitize when files are selected
+long FXFileSelector::onUpdSelected(FXObject* sender,FXSelector,void*){
+  for(FXint i=0; i<filebox->getNumItems(); i++){
+    if(filebox->isItemSelected(i)){
+      sender->handle(this,MKUINT(ID_ENABLE,SEL_COMMAND),NULL);
+      return 1;
+      }
+    }
+  sender->handle(this,MKUINT(ID_DISABLE,SEL_COMMAND),NULL);
+  return 1;
+  }
+
+
+// Popup menu for item in file list
+long FXFileSelector::onPopupMenu(FXObject*,FXSelector,void* ptr){
+  FXEvent *event=(FXEvent*)ptr;
+  if(event->moved) return 1;
+
+  FXMenuPane filemenu(this);
+  new FXMenuCommand(&filemenu,"Up one level",updiricon,this,ID_DIRECTORY_UP);
+  new FXMenuCommand(&filemenu,"Home directory",homeicon,this,ID_HOME);
+  new FXMenuCommand(&filemenu,"Work directory",workicon,this,ID_WORK);
+  new FXMenuCommand(&filemenu,"Select all",NULL,filebox,FXFileList::ID_SELECT_ALL);
+  new FXMenuSeparator(&filemenu);
+
+  FXMenuPane sortmenu(this);
+  new FXMenuCascade(&filemenu,"Sort by",NULL,&sortmenu);
+  new FXMenuCommand(&sortmenu,"Name",NULL,filebox,FXFileList::ID_SORT_BY_NAME);
+  new FXMenuCommand(&sortmenu,"Type",NULL,filebox,FXFileList::ID_SORT_BY_TYPE);
+  new FXMenuCommand(&sortmenu,"Size",NULL,filebox,FXFileList::ID_SORT_BY_SIZE);
+  new FXMenuCommand(&sortmenu,"Time",NULL,filebox,FXFileList::ID_SORT_BY_TIME);
+  new FXMenuCommand(&sortmenu,"User",NULL,filebox,FXFileList::ID_SORT_BY_USER);
+  new FXMenuCommand(&sortmenu,"Group",NULL,filebox,FXFileList::ID_SORT_BY_GROUP);
+  new FXMenuCommand(&sortmenu,"Reverse",NULL,filebox,FXFileList::ID_SORT_REVERSE);
+
+  FXMenuPane viewmenu(this);
+  new FXMenuCascade(&filemenu,"View",NULL,&viewmenu);
+  new FXMenuCommand(&viewmenu,"Small icons",NULL,filebox,FXFileList::ID_SHOW_MINI_ICONS);
+  new FXMenuCommand(&viewmenu,"Big icons",NULL,filebox,FXFileList::ID_SHOW_BIG_ICONS);
+  new FXMenuCommand(&viewmenu,"Details",NULL,filebox,FXFileList::ID_SHOW_DETAILS);
+  new FXMenuCommand(&viewmenu,"Rows",NULL,filebox,FXFileList::ID_ARRANGE_BY_ROWS);
+  new FXMenuCommand(&viewmenu,"Columns",NULL,filebox,FXFileList::ID_ARRANGE_BY_COLUMNS);
+  new FXMenuCommand(&viewmenu,"Hidden files",NULL,filebox,FXFileList::ID_TOGGLE_HIDDEN);
+
+  FXMenuPane bookmarks(this);
+  new FXMenuCascade(&filemenu,"Bookmarks",NULL,&bookmarks);
+  new FXMenuCommand(&bookmarks,"Set bookmark",markicon,this,ID_BOOKMARK);
+  new FXMenuCommand(&bookmarks,"Clear bookmarks",clearicon,&mrufiles,FXRecentFiles::ID_CLEAR);
+  FXMenuSeparator* sep1=new FXMenuSeparator(&bookmarks);
+  sep1->setTarget(&mrufiles);
+  sep1->setSelector(FXRecentFiles::ID_ANYFILES);
+  new FXMenuCommand(&bookmarks,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_1);
+  new FXMenuCommand(&bookmarks,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_2);
+  new FXMenuCommand(&bookmarks,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_3);
+  new FXMenuCommand(&bookmarks,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_4);
+  new FXMenuCommand(&bookmarks,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_5);
+  new FXMenuCommand(&bookmarks,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_6);
+  new FXMenuCommand(&bookmarks,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_7);
+  new FXMenuCommand(&bookmarks,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_8);
+  new FXMenuCommand(&bookmarks,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_9);
+  new FXMenuCommand(&bookmarks,NULL,NULL,&mrufiles,FXRecentFiles::ID_FILE_10);
+
+  new FXMenuSeparator(&filemenu);
+  new FXMenuCommand(&filemenu,"New directory...",newdiricon,this,ID_NEW);
+  new FXMenuCommand(&filemenu,"Copy...",copyicon,this,ID_COPY);
+  new FXMenuCommand(&filemenu,"Move...",moveicon,this,ID_MOVE);
+  new FXMenuCommand(&filemenu,"Link...",linkicon,this,ID_LINK);
+  new FXMenuCommand(&filemenu,"Delete...",deleteicon,this,ID_DELETE);
+
+  filemenu.create();
+  filemenu.popup(NULL,event->root_x,event->root_y);
+  getApp()->runModalWhileShown(&filemenu);
   return 1;
   }
 
@@ -706,6 +909,10 @@ FXString FXFileSelector::getDirectory() const {
 // Set file name
 void FXFileSelector::setFilename(const FXString& path){
   FXString abspath=FXFile::absolute(path);
+  filebox->setCurrentFile(abspath);
+  dirbox->setDirectory(FXFile::directory(abspath));
+  filename->setText(FXFile::name(abspath));
+  /*
   if(selectmode==SELECTFILE_DIRECTORY){
     filebox->setDirectory(abspath);
     dirbox->setDirectory(abspath);
@@ -716,38 +923,79 @@ void FXFileSelector::setFilename(const FXString& path){
     dirbox->setDirectory(FXFile::directory(abspath));
     filename->setText(FXFile::name(abspath));
     }
+    */
   }
 
 
 // Get complete path + filename
 FXString FXFileSelector::getFilename() const {
-  return FXFile::absolute(filebox->getDirectory(),filename->getText());
+  register FXint i;
+  if(selectmode==SELECTFILE_MULTIPLE_ALL){
+    for(i=0; i<filebox->getNumItems(); i++){
+      if(filebox->isItemSelected(i) && filebox->getItemFilename(i)!=".."){
+        return FXFile::absolute(filebox->getDirectory(),filebox->getItemFilename(i));
+        }
+      }
+    }
+  else if(selectmode==SELECTFILE_MULTIPLE){
+    for(i=0; i<filebox->getNumItems(); i++){
+      if(filebox->isItemSelected(i) && !filebox->isItemDirectory(i)){
+        return FXFile::absolute(filebox->getDirectory(),filebox->getItemFilename(i));
+        }
+      }
+    }
+  else{
+    if(!filename->getText().empty()){
+      return FXFile::absolute(filebox->getDirectory(),filename->getText());
+      }
+    }
+  return FXString::null;
   }
 
 
 // Return empty-string terminated list of selected file names, or NULL
 FXString* FXFileSelector::getFilenames() const {
   register FXString *files=NULL;
+  register FXint i,n;
   if(filebox->getNumItems()){
-    register FXint i,n;
-    for(i=n=0; i<filebox->getNumItems(); i++){
-      if(filebox->isItemFile(i) && filebox->isItemSelected(i)) n++;
-      }
-    if(n){
-      files=new FXString [n+1];
+    if(selectmode==SELECTFILE_MULTIPLE_ALL){
       for(i=n=0; i<filebox->getNumItems(); i++){
-        if(filebox->isItemFile(i) && filebox->isItemSelected(i)){
-          files[n++]=filebox->getItemPathname(i);
+        if(filebox->isItemSelected(i) && filebox->getItemFilename(i)!=".."){
+          n++;
           }
         }
-      files[n]=FXString::null;
+      if(n){
+        files=new FXString [n+1];
+        for(i=n=0; i<filebox->getNumItems(); i++){
+          if(filebox->isItemSelected(i) && filebox->getItemFilename(i)!=".."){
+            files[n++]=filebox->getItemPathname(i);
+            }
+          }
+        files[n]=FXString::null;
+        }
+      }
+    else{
+      for(i=n=0; i<filebox->getNumItems(); i++){
+        if(filebox->isItemSelected(i) && !filebox->isItemDirectory(i)){
+          n++;
+          }
+        }
+      if(n){
+        files=new FXString [n+1];
+        for(i=n=0; i<filebox->getNumItems(); i++){
+          if(filebox->isItemSelected(i) && !filebox->isItemDirectory(i)){
+            files[n++]=filebox->getItemPathname(i);
+            }
+          }
+        files[n]=FXString::null;
+        }
       }
     }
   return files;
   }
 
 
-// Set bunch of patterns (DEPRECATED)
+// Set bunch of patterns
 void FXFileSelector::setPatternList(const FXchar **ptrns){
   filefilter->clearItems();
   if(ptrns){
@@ -763,9 +1011,9 @@ void FXFileSelector::setPatternList(const FXchar **ptrns){
 
 // Change patterns, each pattern separated by newline
 void FXFileSelector::setPatternList(const FXString& patterns){
-  FXString pat; FXint i;
+  FXString pat;
   filefilter->clearItems();
-  for(i=0; !(pat=patterns.extract(i,'\n')).empty(); i++){
+  for(FXint i=0; !(pat=patterns.extract(i,'\n')).empty(); i++){
     filefilter->appendItem(pat);
     }
   if(!filefilter->getNumItems()) filefilter->appendItem(allfiles);
@@ -775,8 +1023,8 @@ void FXFileSelector::setPatternList(const FXString& patterns){
 
 // Return list of patterns
 FXString FXFileSelector::getPatternList() const {
-  FXString pat; FXint i;
-  for(i=0; i<filefilter->getNumItems(); i++){
+  FXString pat;
+  for(FXint i=0; i<filefilter->getNumItems(); i++){
     if(!pat.empty()) pat+='\n';
     pat+=filefilter->getItemText(i);
     }
@@ -860,6 +1108,8 @@ void FXFileSelector::setSelectMode(FXuint mode){
       filebox->setListStyle((filebox->getListStyle()&~FILELISTMASK)|ICONLIST_BROWSESELECT);
       break;
     case SELECTFILE_MULTIPLE:
+    case SELECTFILE_MULTIPLE_ALL:
+      filebox->showOnlyDirectories(FALSE);
       filebox->setListStyle((filebox->getListStyle()&~FILELISTMASK)|ICONLIST_EXTENDEDSELECT);
       break;
     case SELECTFILE_DIRECTORY:
@@ -917,10 +1167,13 @@ void FXFileSelector::save(FXStream& store) const {
   store << detailicon;
   store << iconsicon;
   store << homeicon;
+  store << workicon;
   store << shownicon;
   store << hiddenicon;
   store << markicon;
   store << clearicon;
+  store << moveicon;
+  store << copyicon;
   store << selectmode;
   }
 
@@ -942,10 +1195,13 @@ void FXFileSelector::load(FXStream& store){
   store >> detailicon;
   store >> iconsicon;
   store >> homeicon;
+  store >> workicon;
   store >> shownicon;
   store >> hiddenicon;
   store >> markicon;
   store >> clearicon;
+  store >> moveicon;
+  store >> copyicon;
   store >> selectmode;
   }
 
@@ -954,11 +1210,12 @@ void FXFileSelector::load(FXStream& store){
 FXFileSelector::~FXFileSelector(){
   FXAccelTable *table=getShell()->getAccelTable();
   if(table){
-    table->removeAccel(MKUINT(KEY_Delete,0));
     table->removeAccel(MKUINT(KEY_BackSpace,0));
+    table->removeAccel(MKUINT(KEY_Delete,0));
     table->removeAccel(MKUINT(KEY_h,CONTROLMASK));
     table->removeAccel(MKUINT(KEY_w,CONTROLMASK));
     table->removeAccel(MKUINT(KEY_n,CONTROLMASK));
+    table->removeAccel(MKUINT(KEY_a,CONTROLMASK));
     table->removeAccel(MKUINT(KEY_b,CONTROLMASK));
     table->removeAccel(MKUINT(KEY_s,CONTROLMASK));
     table->removeAccel(MKUINT(KEY_l,CONTROLMASK));
@@ -975,6 +1232,10 @@ FXFileSelector::~FXFileSelector(){
   delete hiddenicon;
   delete markicon;
   delete clearicon;
+  delete deleteicon;
+  delete moveicon;
+  delete copyicon;
+  delete linkicon;
   filebox=(FXFileList*)-1;
   filename=(FXTextField*)-1;
   filefilter=(FXComboBox*)-1;
@@ -994,6 +1255,10 @@ FXFileSelector::~FXFileSelector(){
   hiddenicon=(FXIcon*)-1;
   markicon=(FXIcon*)-1;
   clearicon=(FXIcon*)-1;
+  deleteicon=(FXIcon*)-1;
+  moveicon=(FXIcon*)-1;
+  copyicon=(FXIcon*)-1;
+  linkicon=(FXIcon*)-1;
   }
 
 
