@@ -3,7 +3,7 @@
 *                               F o n t   O b j e c t                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXFont.cpp,v 1.48 2001/08/21 22:37:55 jeroen Exp $                       *
+* $Id: FXFont.cpp,v 1.52 2002/02/12 00:58:29 fox Exp $                          *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,8 +30,6 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
@@ -1133,11 +1131,11 @@ void FXFont::detach(){
   if(xid){
     FXTRACE((100,"%s::detach %p\n",getClassName(),this));
 #ifndef WIN32
-    
+
     // Free font struct w/o doing anything else...
     XFreeFont(DISPLAY(getApp()),(XFontStruct*)font);
 #else
-    
+
     // Free font metrics
     FXFREE(&font);
 #endif
@@ -1153,17 +1151,20 @@ void FXFont::destroy(){
     if(getApp()->initialized){
       FXTRACE((100,"%s::destroy %p\n",getClassName(),this));
 #ifndef WIN32
-      
+
       // Delete font & metrics
       XFreeFont(DISPLAY(getApp()),(XFontStruct*)font);
 #else
-      
+
+      // Necessary to prevent resource leak
+      SelectObject((HDC)dc,GetStockObject(SYSTEM_FONT));
+
       // Delete font
       DeleteObject((HFONT)xid);
-      
+
       // Delete dummy DC
       DeleteDC((HDC)dc);
-      
+
       // Free font metrics
       FXFREE(&font);
 #endif
