@@ -3,7 +3,7 @@
 *                        F o n t   S e l e c t i o n   B o x                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXFontSelector.cpp,v 1.23 2001/06/20 16:24:59 jeroen Exp $               *
+* $Id: FXFontSelector.cpp,v 1.28.4.1 2003/06/20 19:02:07 fox Exp $               *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -29,9 +29,6 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXObjectList.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
@@ -107,8 +104,8 @@ FXFontSelector::FXFontSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuin
 
   // Bottom side
   FXHorizontalFrame *buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
-  accept=new FXButton(buttons,"&Accept",NULL,NULL,0,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
-  cancel=new FXButton(buttons,"&Cancel",NULL,NULL,0,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
+  accept=new FXButton(buttons,"&Accept",NULL,NULL,0,BUTTON_INITIAL|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
+  cancel=new FXButton(buttons,"&Cancel",NULL,NULL,0,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
 
   // Left side
   FXMatrix *controls=new FXMatrix(this,3,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FIX_HEIGHT,0,0,0,160, DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING, DEFAULT_SPACING,0);
@@ -119,6 +116,9 @@ FXFontSelector::FXFontSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuin
   FXHorizontalFrame *familyframe=new FXHorizontalFrame(controls,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_Y|LAYOUT_FILL_X|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW,0,0,0,0, 0,0,0,0);
   familylist=new FXList(familyframe,0,this,ID_FAMILY,LIST_BROWSESELECT|LAYOUT_FILL_Y|LAYOUT_FILL_X|HSCROLLER_NEVER|VSCROLLER_ALWAYS);
 
+  // Initial focus on list
+  familylist->setFocus();
+
   // Font weights
   new FXLabel(controls,"&Weight:",NULL,JUSTIFY_LEFT|LAYOUT_FILL_X|LAYOUT_FILL_COLUMN);
   weight=new FXTextField(controls,4,NULL,0,TEXTFIELD_READONLY|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_COLUMN);
@@ -233,7 +233,7 @@ void FXFontSelector::listFontFaces(){
   if(FXFont::listFonts(fonts,numfonts,"",FONTWEIGHT_DONTCARE,FONTSLANT_DONTCARE,selected.setwidth,selected.encoding,selected.flags)){
     FXASSERT(0<numfonts);
     for(f=0; f<numfonts; f++){
-      familylist->appendItem(fonts[f].face,NULL,(void*)fonts[f].flags);
+      familylist->appendItem(fonts[f].face,NULL,(void*)(FXuval)fonts[f].flags);
       if(strcmp(selected.face,fonts[f].face)==0) selindex=f;
       }
     if(selindex==-1) selindex=0;
@@ -277,7 +277,7 @@ void FXFontSelector::listWeights(){
           }
 
         // Add it
-        weightlist->appendItem(wgt,NULL,(void*)ww);
+        weightlist->appendItem(wgt,NULL,(void*)(FXuval)ww);
 
         // Remember if this was the current selection
         if(selected.weight==ww) selindex=weightlist->getNumItems()-1;
@@ -288,7 +288,7 @@ void FXFontSelector::listWeights(){
     if(0<weightlist->getNumItems()){
       weightlist->setCurrentItem(selindex);
       weight->setText(weightlist->getItemText(selindex));
-      selected.weight=(FXuint)(long)weightlist->getItemData(selindex);
+      selected.weight=(FXuint)(FXuval)weightlist->getItemData(selindex);
       }
     FXFREE(&fonts);
     }
@@ -321,7 +321,7 @@ void FXFontSelector::listSlants(){
           }
 
         // Add it
-        stylelist->appendItem(slt,NULL,(void*)s);
+        stylelist->appendItem(slt,NULL,(void*)(FXuval)s);
 
         // Remember if this was the current selection
         if(selected.slant == s) selindex=stylelist->getNumItems()-1;
@@ -332,7 +332,7 @@ void FXFontSelector::listSlants(){
     if(0<stylelist->getNumItems()){
       stylelist->setCurrentItem(selindex);
       style->setText(stylelist->getItemText(selindex));
-      selected.slant=(FXuint)(long)stylelist->getItemData(selindex);
+      selected.slant=(FXuint)(FXuval)stylelist->getItemData(selindex);
       }
     FXFREE(&fonts);
     }
@@ -347,13 +347,17 @@ void FXFontSelector::listFontSizes(){
   FXint selindex=-1;
   sizelist->clearItems();
   size->setText("");
+  FXString string;
   if(FXFont::listFonts(fonts,numfonts,selected.face,selected.weight,selected.slant,selected.setwidth,selected.encoding,selected.flags)){
     FXASSERT(0<numfonts);
     lasts=0;
     if(fonts[0].flags&FONTHINT_SCALABLE){
       for(f=0; f<ARRAYNUMBER(sizeint); f++){
         s=sizeint[f];
-        sizelist->appendItem(FXStringVal(0.1*sizeint[f],6,MAYBE),NULL,(void*)s);
+        string.format("%.1f",0.1*s);
+        sizelist->appendItem(string,NULL,(void*)(FXuval)s);
+//        sizelist->appendItem(FXStringVal(0.1*sizeint[f],6,MAYBE),NULL,(void*)s);
+//        sizelist->appendItem(FXStringVal(s/10),NULL,(void*)s);
         if(selected.size == s) selindex=sizelist->getNumItems()-1;
         lasts=s;
         }
@@ -362,7 +366,10 @@ void FXFontSelector::listFontSizes(){
       for(f=0; f<numfonts; f++){
         s=fonts[f].size;
         if(s!=lasts){
-          sizelist->appendItem(FXStringVal(0.1*s,6,MAYBE),NULL,(void*)s);
+          string.format("%.1f",0.1*s);
+          sizelist->appendItem(string,NULL,(void*)(FXuval)s);
+//          sizelist->appendItem(FXStringVal(0.1*s,6,MAYBE),NULL,(void*)s);
+//          sizelist->appendItem(FXStringVal(s/10),NULL,(void*)s);
           if(selected.size == s) selindex=sizelist->getNumItems()-1;
           lasts=s;
           }
@@ -372,7 +379,7 @@ void FXFontSelector::listFontSizes(){
     if(0<sizelist->getNumItems()){
       sizelist->setCurrentItem(selindex);
       size->setText(sizelist->getItemText(selindex));
-      selected.size=(FXuint)(long)sizelist->getItemData(selindex);
+      selected.size=(FXuint)(FXuval)sizelist->getItemData(selindex);
       }
     FXFREE(&fonts);
     }
@@ -416,7 +423,7 @@ void FXFontSelector::previewFont(){
 
 // Selected font family
 long FXFontSelector::onCmdFamily(FXObject*,FXSelector,void* ptr){
-  strncpy(selected.face,familylist->getItemText((FXint)(long)ptr).text(),sizeof(selected.face));
+  strncpy(selected.face,familylist->getItemText((FXint)(FXival)ptr).text(),sizeof(selected.face));
   family->setText(selected.face);
   listWeights();
   listSlants();
@@ -428,8 +435,8 @@ long FXFontSelector::onCmdFamily(FXObject*,FXSelector,void* ptr){
 
 // Changed weight setting
 long FXFontSelector::onCmdWeight(FXObject*,FXSelector,void* ptr){
-  selected.weight=(FXuint)(long)weightlist->getItemData((FXint)(long)ptr);
-  weight->setText(weightlist->getItemText((FXint)(long)ptr));
+  selected.weight=(FXuint)(FXuval)weightlist->getItemData((FXint)(FXival)ptr);
+  weight->setText(weightlist->getItemText((FXint)(FXival)ptr));
   listSlants();
   listFontSizes();
   previewFont();
@@ -439,8 +446,8 @@ long FXFontSelector::onCmdWeight(FXObject*,FXSelector,void* ptr){
 
 // User clicked up directory button
 long FXFontSelector::onCmdSize(FXObject*,FXSelector,void* ptr){
-  selected.size=(FXuint)(long)sizelist->getItemData((FXint)(long)ptr);
-  size->setText(sizelist->getItemText((FXint)(long)ptr));
+  selected.size=(FXuint)(FXuval)sizelist->getItemData((FXint)(FXival)ptr);
+  size->setText(sizelist->getItemText((FXint)(FXival)ptr));
   previewFont();
   return 1;
   }
@@ -458,8 +465,8 @@ long FXFontSelector::onCmdSizeText(FXObject*,FXSelector,void*){
 
 // User clicked up directory button
 long FXFontSelector::onCmdStyle(FXObject*,FXSelector,void* ptr){
-  selected.slant=(FXuint)(long)stylelist->getItemData((FXint)(long)ptr);
-  style->setText(stylelist->getItemText((FXint)(long)ptr));
+  selected.slant=(FXuint)(FXuval)stylelist->getItemData((FXint)(FXival)ptr);
+  style->setText(stylelist->getItemText((FXint)(FXival)ptr));
   listFontSizes();
   previewFont();
   return 1;
@@ -475,7 +482,7 @@ long FXFontSelector::onCmdStyleText(FXObject*,FXSelector,void*){
 // Character set
 long FXFontSelector::onCmdCharset(FXObject*,FXSelector,void*){
   FXint index=charset->getCurrentItem();
-  FXuint enc=(FXuint)(long)charset->getItemData(index);
+  FXuint enc=(FXuint)(FXuval)charset->getItemData(index);
   selected.encoding=(FXFontEncoding)enc;
   listFontFaces();
   listWeights();
@@ -489,7 +496,7 @@ long FXFontSelector::onCmdCharset(FXObject*,FXSelector,void*){
 // Update character set
 long FXFontSelector::onUpdCharset(FXObject*,FXSelector,void*){
   for(int i=0; i<charset->getNumItems(); i++){
-    if(selected.encoding == (FXuint)(long)charset->getItemData(i)){
+    if(selected.encoding == (FXuint)(FXuval)charset->getItemData(i)){
       charset->setCurrentItem(i);
       break;
       }
@@ -501,7 +508,7 @@ long FXFontSelector::onUpdCharset(FXObject*,FXSelector,void*){
 // Changed set width
 long FXFontSelector::onCmdSetWidth(FXObject*,FXSelector,void*){
   FXint index=setwidth->getCurrentItem();
-  selected.setwidth=(FXuint)(long)setwidth->getItemData(index);
+  selected.setwidth=(FXuint)(FXuval)setwidth->getItemData(index);
   listFontFaces();
   listWeights();
   listSlants();
@@ -522,7 +529,7 @@ long FXFontSelector::onUpdSetWidth(FXObject*,FXSelector,void*){
 long FXFontSelector::onCmdPitch(FXObject*,FXSelector,void*){
   FXint index=pitch->getCurrentItem();
   selected.flags&=~(FONTPITCH_FIXED|FONTPITCH_VARIABLE);
-  selected.flags|=(FXuint)(long)pitch->getItemData(index);
+  selected.flags|=(FXuint)(FXuval)pitch->getItemData(index);
   listFontFaces();
   listWeights();
   listSlants();
