@@ -3,7 +3,7 @@
 *                        F r a m e   W i n d o w   O b j e c t                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXFrame.cpp,v 1.15 2001/08/28 22:52:27 jeroen Exp $                      *
+* $Id: FXFrame.cpp,v 1.23 2002/02/02 03:58:46 fox Exp $                         *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -29,16 +29,10 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDrawable.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
-#include "FXWindow.h"
 #include "FXFrame.h"
 
 /*
@@ -151,10 +145,10 @@ void FXFrame::drawGrooveRectangle(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint h
   dc.fillRectangle(x+1,y+h-2,w-2,1);
   dc.fillRectangle(x+w-2,y+1,1,h-2);
   dc.setForeground(hiliteColor);
-  dc.fillRectangle(x+1,y+1,w-2,1);
-  dc.fillRectangle(x+1,y+1,1,h-2);
-  dc.fillRectangle(x+1,y+h-1,w,1);
-  dc.fillRectangle(x+w-1,y+1,1,h);
+  dc.fillRectangle(x+1,y+1,w-3,1);
+  dc.fillRectangle(x+1,y+1,1,h-3);
+  dc.fillRectangle(x,y+h-1,w,1);
+  dc.fillRectangle(x+w-1,y,1,h);
   }
 
 
@@ -189,18 +183,6 @@ void FXFrame::drawDoubleSunkenRectangle(FXDCWindow& dc,FXint x,FXint y,FXint w,F
   }
 
 
-// Draw dashed focus rectangle
-void FXFrame::drawFocusRectangle(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint h){
-  dc.setFillStyle(FILL_STIPPLED);
-  dc.setStipple(STIPPLE_GRAY);
-  dc.setForeground(borderColor);
-  dc.drawRectangle(x,y,w-1,h-1);
-  dc.setFillStyle(FILL_SOLID);
-  dc.setStipple(STIPPLE_NONE);
-  }
-
-
-
 // Draw border
 void FXFrame::drawFrame(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint h){
   switch(options&FRAME_MASK){
