@@ -3,7 +3,7 @@
 *                    O p e n G L   C a n v a s   O b j e c t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLCanvas.cpp,v 1.37 2001/08/23 16:24:54 jeroen Exp $                   *
+* $Id: FXGLCanvas.cpp,v 1.41 2002/01/18 22:43:00 jeroen Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -29,19 +29,13 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXApp.h"
-#include "FXId.h"
 #include "FXVisual.h"
 #include "FXGLVisual.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
 #include "FXCursor.h"
-#include "FXCanvas.h"
 #include "FXGLContext.h"
 #include "FXGLCanvas.h"
 
@@ -234,9 +228,11 @@ FXbool FXGLCanvas::makeNonCurrent(){
 #ifndef WIN32
     return glXMakeCurrent((Display*)getApp()->getDisplay(),None,(GLXContext)NULL);
 #else
-    HDC hdc=wglGetCurrentDC();
+    // According to "Steve Granja" <sjgranja@hks.com>,
+    // ::ReleaseDC is still necessary even for owned DC's.
+    // So release it here to prevent resource leak.
+    ::ReleaseDC((HWND)xid,wglGetCurrentDC());
     BOOL bStatus=wglMakeCurrent(NULL,NULL);
-//    ::ReleaseDC((HWND)xid,hdc);
     return bStatus;
 #endif
     }
@@ -266,10 +262,12 @@ void FXGLCanvas::swapBuffers(){
 #ifndef WIN32
   glXSwapBuffers((Display*)getApp()->getDisplay(),xid);
 #else
-  //SwapBuffers(wglGetCurrentDC());
-  // Suggested by Daniel Gehriger <gehriger@linkcad.com>
-  // for Windows 2000 OpenGL bug workaround with SwapBuffers()
-  wglSwapLayerBuffers(wglGetCurrentDC(),WGL_SWAP_MAIN_PLANE);
+  // SwapBuffers(wglGetCurrentDC());
+  // wglSwapLayerBuffers(wglGetCurrentDC(),WGL_SWAP_MAIN_PLANE);
+  HDC hdc=wglGetCurrentDC();
+  if(wglSwapLayerBuffers(hdc,WGL_SWAP_MAIN_PLANE)==FALSE){
+    SwapBuffers(hdc);
+    }
 #endif
 #endif
   }
