@@ -3,7 +3,7 @@
 *                      O p e n G L   C y l i n d e r   O b j e c t              *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * Contributed by: Angel-Ventura Mendo Gomez <ventura@labri.u-bordeaux.fr>       *
 *********************************************************************************
@@ -21,7 +21,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLCylinder.cpp,v 1.8 2001/04/27 14:30:32 jeroen Exp $                  *
+* $Id: FXGLCylinder.cpp,v 1.11 2002/01/18 22:43:00 jeroen Exp $                 *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -36,27 +36,11 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXObjectList.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXCursor.h"
-#include "FXCanvas.h"
-#include "FXGLCanvas.h"
-#include "FXDC.h"
-#include "FXDCPrint.h"
 #include "FXGLViewer.h"
-#include "FXGLObject.h"
-#include "FXComposite.h"
-#include "FXShell.h"
-#include "FXTooltip.h"
-#include "FXGLShape.h"
 #include "FXGLCylinder.h"
 
 
