@@ -3,7 +3,7 @@
 *                           O p e n G L   O b j e c t                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLObject.cpp,v 1.15 2001/07/20 22:18:02 jeroen Exp $                   *
+* $Id: FXGLObject.cpp,v 1.18 2002/01/18 22:43:00 jeroen Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -34,26 +34,12 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXObjectList.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXCursor.h"
-#include "FXCanvas.h"
-#include "FXGLCanvas.h"
-#include "FXDC.h"
-#include "FXDCPrint.h"
 #include "FXGLViewer.h"
 #include "FXGLObject.h"
-#include "FXComposite.h"
-#include "FXShell.h"
-#include "FXTooltip.h"
 
 
 // GLU versions prior to 1.1 have GLUquadric
