@@ -3,7 +3,7 @@
 *                      O p e n G L   S p h e r e   O b j e c t                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * Contributed by: Angel-Ventura Mendo Gomez <ventura@labri.u-bordeaux.fr>       *
 *********************************************************************************
@@ -21,7 +21,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLSphere.cpp,v 1.8 2001/04/27 14:30:32 jeroen Exp $                    *
+* $Id: FXGLSphere.cpp,v 1.11 2002/01/18 22:43:00 jeroen Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -36,27 +36,11 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXObjectList.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXCursor.h"
-#include "FXCanvas.h"
-#include "FXGLCanvas.h"
-#include "FXDC.h"
-#include "FXDCPrint.h"
 #include "FXGLViewer.h"
-#include "FXGLObject.h"
-#include "FXComposite.h"
-#include "FXShell.h"
-#include "FXTooltip.h"
-#include "FXGLShape.h"
 #include "FXGLSphere.h"
 
 
@@ -65,17 +49,20 @@
 #define GLUquadricObj GLUquadric
 #endif
 
-// Sphere fidelity
-#define FXGLSPHERE_SLICES_NUMBER                20
-#define FXGLSPHERE_STACKS_NUMBER                20
 
+// Sphere fidelity
+#define SPHERE_SLICES  20
+#define SPHERE_STACKS  20
+
+
+/*******************************************************************************/
 
 // Object implementation
 FXIMPLEMENT(FXGLSphere,FXGLShape,NULL,0)
 
 
 // Create sphere
-FXGLSphere::FXGLSphere(void):radius(0.5f){
+FXGLSphere::FXGLSphere(void):radius(0.5f),slices(SPHERE_SLICES),stacks(SPHERE_STACKS){
   FXTRACE((100,"FXGLSphere::FXGLSphere\n"));
   range[0][0]=-radius; range[0][1]=radius;
   range[1][0]=-radius; range[1][1]=radius;
@@ -85,7 +72,7 @@ FXGLSphere::FXGLSphere(void):radius(0.5f){
 
 // Create initialized sphere
 FXGLSphere::FXGLSphere(FXfloat x,FXfloat y,FXfloat z,FXfloat r):
-  FXGLShape(x,y,z,SHADING_SMOOTH|STYLE_SURFACE),radius(r){
+  FXGLShape(x,y,z,SHADING_SMOOTH|STYLE_SURFACE),radius(r),slices(SPHERE_SLICES),stacks(SPHERE_STACKS){
   FXTRACE((100,"FXGLSphere::FXGLSphere\n"));
   range[0][0]=-radius; range[0][1]=radius;
   range[1][0]=-radius; range[1][1]=radius;
@@ -95,7 +82,7 @@ FXGLSphere::FXGLSphere(FXfloat x,FXfloat y,FXfloat z,FXfloat r):
 
 // Create initialized sphere
 FXGLSphere::FXGLSphere(FXfloat x,FXfloat y,FXfloat z,FXfloat r,const FXMaterial& mtl):
-  FXGLShape(x,y,z,SHADING_SMOOTH|STYLE_SURFACE,mtl,mtl),radius(r){
+  FXGLShape(x,y,z,SHADING_SMOOTH|STYLE_SURFACE,mtl,mtl),radius(r),slices(SPHERE_SLICES),stacks(SPHERE_STACKS){
   FXTRACE((100,"FXGLSphere::FXGLSphere\n"));
   range[0][0]=-radius; range[0][1]=radius;
   range[1][0]=-radius; range[1][1]=radius;
@@ -107,6 +94,8 @@ FXGLSphere::FXGLSphere(FXfloat x,FXfloat y,FXfloat z,FXfloat r,const FXMaterial&
 FXGLSphere::FXGLSphere(const FXGLSphere& orig):FXGLShape(orig){
   FXTRACE((100,"FXGLSphere::FXGLSphere\n"));
   radius=orig.radius;
+  slices=orig.slices;
+  stacks=orig.stacks;
   }
 
 
@@ -121,7 +110,7 @@ void FXGLSphere::drawshape(FXGLViewer*){
     gluQuadricOrientation(quad,(GLenum)GLU_OUTSIDE);
     }
   */
-  gluSphere(quad,radius,FXGLSPHERE_SLICES_NUMBER,FXGLSPHERE_STACKS_NUMBER);
+  gluSphere(quad,radius,slices,stacks);
   gluDeleteQuadric(quad);
 #endif
   }
@@ -137,6 +126,8 @@ FXGLObject* FXGLSphere::copy(){
 void FXGLSphere::save(FXStream& store) const {
   FXGLShape::save(store);
   store << radius;
+  store << slices;
+  store << stacks;
   }
 
 
@@ -144,6 +135,8 @@ void FXGLSphere::save(FXStream& store) const {
 void FXGLSphere::load(FXStream& store){
   FXGLShape::load(store);
   store >> radius;
+  store >> slices;
+  store >> stacks;
   }
 
 
