@@ -3,7 +3,7 @@
 *                           O p e n G L   V i e w e r                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLViewer.cpp,v 1.98 2001/07/17 07:25:01 jeroen Exp $                   *
+* $Id: FXGLViewer.cpp,v 1.104.4.3 2003/06/20 19:02:07 fox Exp $                  *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -35,33 +35,20 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXObjectList.h"
 #include "FXApp.h"
-#include "FXId.h"
 #include "FXVisual.h"
 #include "FXGLVisual.h"
 #include "FXDC.h"
 #include "FXDCWindow.h"
 #include "FXDCPrint.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
-#include "FXComposite.h"
-#include "FXPacker.h"
-#include "FXShell.h"
-#include "FXTopWindow.h"
-#include "FXDialogBox.h"
 #include "FXMessageBox.h"
 #include "FXTooltip.h"
 #include "FXCursor.h"
-#include "FXCanvas.h"
 #include "FXGLContext.h"
-#include "FXGLCanvas.h"
 #include "FXGLViewer.h"
 #include "FXGLObject.h"
 #include "FXPrintDialog.h"
@@ -266,6 +253,7 @@ FXDragType FXGLViewer::objectType=0;
 
 // For deserialization
 FXGLViewer::FXGLViewer(){
+  flags|=FLAG_ENABLED|FLAG_DROPTARGET;
   dial[0]=0;
   dial[1]=0;
   dial[2]=0;
@@ -294,6 +282,7 @@ FXGLViewer::FXGLViewer(FXComposite* p,FXGLVisual *vis,FXGLViewer* sharegroup,FXO
 
 // Common initialization for constructor
 void FXGLViewer::initialize(){
+  flags|=FLAG_ENABLED|FLAG_DROPTARGET;
   defaultCursor=getApp()->getDefaultCursor(DEF_CROSSHAIR_CURSOR);
   dragCursor=getApp()->getDefaultCursor(DEF_CROSSHAIR_CURSOR);
   projection=PERSPECTIVE;                       // Projection
@@ -370,9 +359,6 @@ void FXGLViewer::create(){
   if(!colorType){colorType=getApp()->registerDragType(colorTypeName);}
   if(!objectType){objectType=getApp()->registerDragType(objectTypeName);}
 
-  // Viewer accepts any drop type
-  dropEnable();
-
   // If have scene already, get correct bounds
   if(scene) scene->bounds(r);
 
@@ -485,14 +471,14 @@ void FXGLViewer::drawWorld(FXViewport& wv){
 
   // Clear background
   glClearDepth(1.0);
-  glClearColor(background[0],background[1],background[2],1.0);
+  glClearColor(background[0],background[1],background[2],1.0f);
   glClear(GL_COLOR_BUFFER_BIT|GL_DEPTH_BUFFER_BIT);
 
   // Set OFFSET Projection Matrix
   glNewList(FXGLViewer::OFFSETPROJECTION,GL_COMPILE);
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
-  glTranslatef(0.0,0.0,(GLfloat)(-offset/zoom));    // FIXME when fov becomes very small this needs to be corrected!!!
+  glTranslatef(0.0f,0.0f,(GLfloat)(-offset/zoom));    // FIXME when fov becomes very small this needs to be corrected!!!
   switch(projection){
     case PARALLEL: glOrtho(wv.left,wv.right,wv.bottom,wv.top,wv.hither,wv.yon); break;
     case PERSPECTIVE: glFrustum(wv.left,wv.right,wv.bottom,wv.top,wv.hither,wv.yon); break;
@@ -560,7 +546,7 @@ void FXGLViewer::drawWorld(FXViewport& wv){
   if(options&VIEWER_FOG){
     glEnable(GL_FOG);
     glFogfv(GL_FOG_COLOR,background);         // Disappear into the background
-    //glFogf(GL_FOG_DENSITY,1.0);
+    //glFogf(GL_FOG_DENSITY,1.0f);
     glFogf(GL_FOG_START,(GLfloat)(distance-diameter));   // Range tight around model position
     glFogf(GL_FOG_END,(GLfloat)(distance+diameter));     // Far place same as clip plane:- clipped stuff is in the mist!
     glFogi(GL_FOG_MODE,GL_LINEAR);	// Simple linear depth cueing
@@ -576,7 +562,6 @@ void FXGLViewer::drawWorld(FXViewport& wv){
     glDisable(GL_DITHER);
 
   // Shade model
-  //glShadeModel(GL_FLAT);
   glShadeModel(GL_SMOOTH);
 
   // Draw what's visible
@@ -591,7 +576,7 @@ void FXGLViewer::drawAnti(FXViewport& wv){
   FXViewport jt=wv;
   FXdouble d=0.5*worldpx;
   register FXuint i;
-  glClearAccum(0.0,0.0,0.0,0.0);
+  glClearAccum(0.0f,0.0f,0.0f,0.0f);
   glClear(GL_ACCUM_BUFFER_BIT);
   for(i=0; i<ARRAYNUMBER(jitter); i++){
     jt.left = wv.left+jitter[i][0]*d;
@@ -653,7 +638,7 @@ FXint FXGLViewer::selectHits(FXuint*& hits,FXint& nhits,FXint x,FXint y,FXint w,
     // Model Matrix
     glMatrixMode(GL_MODELVIEW);
     glLoadMatrixf(transform);
-    
+
     // Loop until room enough to fit
     do{
       nhits=0;
@@ -1279,8 +1264,6 @@ void FXGLViewer::drawLasso(FXint x0,FXint y0,FXint x1,FXint y1){
     // You have OpenGL 1.1 or better, but chances are it
     // still doesn't work, because you may have an incomplete
     // implementation [DEC], or perhaps broken hardware.
-    //glBlendFunc(GL_ONE_MINUS_DST_COLOR,GL_ZERO);
-    //glEnable(GL_BLEND);
 
     // If it works for you, uncomment the lines below,
     // and comment the ones above...
@@ -2236,7 +2219,7 @@ long FXGLViewer::onCmdFov(FXObject* sender,FXSelector sel,void*){
 
 
 // Scale model
-long FXGLViewer::onCmdXYZScale(FXObject* sender,FXSelector sel,void* ptr){
+long FXGLViewer::onCmdXYZScale(FXObject* sender,FXSelector sel,void*){
   FXVec s=scale;
   FXdouble value;
   sender->handle(this,MKUINT(FXWindow::ID_GETREALVALUE,SEL_COMMAND),&value);
@@ -2260,7 +2243,7 @@ long FXGLViewer::onCmdXYZDial(FXObject*,FXSelector sel,void* ptr){
   const FXVec xaxis(1.0f,0.0f,0.0f);
   const FXVec yaxis(0.0f,1.0f,0.0f);
   const FXVec zaxis(0.0f,0.0f,1.0f);
-  FXint dialnew=(FXint)(long)ptr;
+  FXint dialnew=(FXint)(FXival)ptr;
   FXfloat ang;
   FXQuat q;
   if(SELTYPE(sel)==SEL_CHANGED){
@@ -2401,8 +2384,10 @@ long FXGLViewer::onCmdPrintImage(FXObject*,FXSelector,void*){
       return 1;
       }
 
-    // Repaint quickly
-    update();
+    // Repaint now
+    repaint();
+
+    // Flush commands
     getApp()->flush(TRUE);
 
     // Page header
@@ -2588,8 +2573,10 @@ long FXGLViewer::onCmdPrintVector(FXObject*,FXSelector,void*){
       return 1;
       }
 
-    // Repaint quickly
-    update();
+    // Repaint now
+    repaint();
+
+    // Flush commands
     getApp()->flush(TRUE);
 
     // Page header
@@ -2727,7 +2714,7 @@ long FXGLViewer::onUpdCurrent(FXObject* sender,FXSelector,void*){
 
 // Set background color
 long FXGLViewer::onCmdBackColor(FXObject*,FXSelector sel,void* ptr){
-  FXColor color=(FXColor)(long)ptr;
+  FXColor color=(FXColor)(FXuval)ptr;
   background=color;
   if(SELTYPE(sel)==SEL_COMMAND || !turbomode){
     update();
@@ -2739,14 +2726,14 @@ long FXGLViewer::onCmdBackColor(FXObject*,FXSelector sel,void* ptr){
 // Update background color
 long FXGLViewer::onUpdBackColor(FXObject* sender,FXSelector,void*){
   FXColor clr=background;
-  sender->handle(this,MKUINT(FXWindow::ID_SETVALUE,SEL_COMMAND),(void*)clr);
+  sender->handle(this,MKUINT(FXWindow::ID_SETVALUE,SEL_COMMAND),(void*)(FXuval)clr);
   return 1;
   }
 
 
 // Set ambient light color
 long FXGLViewer::onCmdAmbientColor(FXObject*,FXSelector sel,void* ptr){
-  FXColor color=(FXColor)(long)ptr;
+  FXColor color=(FXColor)(FXuval)ptr;
   ambient=color;
   if(SELTYPE(sel)==SEL_COMMAND || !turbomode){
     update();
@@ -2758,14 +2745,14 @@ long FXGLViewer::onCmdAmbientColor(FXObject*,FXSelector sel,void* ptr){
 // Update ambient light color
 long FXGLViewer::onUpdAmbientColor(FXObject* sender,FXSelector,void*){
   FXColor clr=ambient;
-  sender->handle(this,MKUINT(FXWindow::ID_SETVALUE,SEL_COMMAND),(void*)clr);
+  sender->handle(this,MKUINT(FXWindow::ID_SETVALUE,SEL_COMMAND),(void*)(FXuval)clr);
   return 1;
   }
 
 
 // Set ambient light color
 long FXGLViewer::onCmdLightAmbient(FXObject*,FXSelector sel,void* ptr){
-  FXColor color=(FXColor)(long)ptr;
+  FXColor color=(FXColor)(FXuval)ptr;
   light.ambient=color;
   if(SELTYPE(sel)==SEL_COMMAND || !turbomode){
     update();
@@ -2777,14 +2764,14 @@ long FXGLViewer::onCmdLightAmbient(FXObject*,FXSelector sel,void* ptr){
 // Update ambient light color
 long FXGLViewer::onUpdLightAmbient(FXObject* sender,FXSelector,void*){
   FXColor clr=light.ambient;
-  sender->handle(this,MKUINT(FXWindow::ID_SETVALUE,SEL_COMMAND),(void*)clr);
+  sender->handle(this,MKUINT(FXWindow::ID_SETVALUE,SEL_COMMAND),(void*)(FXuval)clr);
   return 1;
   }
 
 
 // Set diffuse light color
 long FXGLViewer::onCmdLightDiffuse(FXObject*,FXSelector sel,void* ptr){
-  FXColor color=(FXColor)(long)ptr;
+  FXColor color=(FXColor)(FXuval)ptr;
   light.diffuse=color;
   if(SELTYPE(sel)==SEL_COMMAND || !turbomode){
     update();
@@ -2796,14 +2783,14 @@ long FXGLViewer::onCmdLightDiffuse(FXObject*,FXSelector sel,void* ptr){
 // Update diffuse light color
 long FXGLViewer::onUpdLightDiffuse(FXObject* sender,FXSelector,void*){
   FXColor clr=light.diffuse;
-  sender->handle(this,MKUINT(FXWindow::ID_SETVALUE,SEL_COMMAND),(void*)clr);
+  sender->handle(this,MKUINT(FXWindow::ID_SETVALUE,SEL_COMMAND),(void*)(FXuval)clr);
   return 1;
   }
 
 
 // Set specular light color
 long FXGLViewer::onCmdLightSpecular(FXObject*,FXSelector sel,void* ptr){
-  FXColor color=(FXColor)(long)ptr;
+  FXColor color=(FXColor)(FXuval)ptr;
   light.specular=color;
   if(SELTYPE(sel)==SEL_COMMAND || !turbomode){
     update();
@@ -2815,7 +2802,7 @@ long FXGLViewer::onCmdLightSpecular(FXObject*,FXSelector sel,void* ptr){
 // Update specular light color
 long FXGLViewer::onUpdLightSpecular(FXObject* sender,FXSelector,void*){
   FXColor clr=light.specular;
-  sender->handle(this,MKUINT(FXWindow::ID_SETVALUE,SEL_COMMAND),(void*)clr);
+  sender->handle(this,MKUINT(FXWindow::ID_SETVALUE,SEL_COMMAND),(void*)(FXuval)clr);
   return 1;
   }
 
