@@ -3,7 +3,7 @@
 *                            V i s u a l   C l a s s                            *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLVisual.cpp,v 1.32 2001/08/23 18:56:57 jeroen Exp $                   *
+* $Id: FXGLVisual.cpp,v 1.34.4.1 2003/02/28 22:46:02 fox Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,16 +30,11 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
-#include "FXObjectList.h"
 #include "FXApp.h"
-#include "FXId.h"
 #include "FXFont.h"
-#include "FXVisual.h"
 #include "FXGLVisual.h"
 
 
@@ -342,13 +337,10 @@ void FXGLVisual::create(){
           // Accumulation buffers
           dmatch+=daccred+daccgreen+daccblue+daccalpha;
 
-          // Want alpha
+          // Extra penalty for no alpha if we asked for alpha, but no
+          // penalty at all if there is alpha and we didn't ask for it.
           if(alphaSize>0){
             if(glalpha<1) dmatch+=100000;
-            else dmatch+=dalpha;
-            }
-          else{
-            if(glalpha>0) dmatch+=100000;
             }
 
           // Wanted Z-buffer
@@ -508,9 +500,6 @@ void FXGLVisual::create(){
           // Prefer better Z than asked, but colors more important
           ddepth = gldepth-depthSize; if(ddepth<0) ddepth *= -10;
 
-          // Want the best colors, of course
-          dmatch=dred+dgreen+dblue;
-
           // We care about colors and Z depth more than stencil depth
           dstencil = glstencil-stencilSize; if(dstencil<0) dstencil *= -1;
 
@@ -531,13 +520,10 @@ void FXGLVisual::create(){
             dmatch+=10000;
             }
 
-          // Want alpha
+          // Extra penalty for no alpha if we asked for alpha, but no
+          // penalty at all if there is alpha and we didn't ask for it.
           if(alphaSize>0){
-            if(glalpha<1) dmatch+=1000000;
-            else dmatch+=dalpha;
-            }
-          else{
-            if(glalpha>0) dmatch+=1000000;
+            if(glalpha<1) dmatch+=100000;
             }
 
           // Wanted Z-buffer
