@@ -3,7 +3,7 @@
 *                               I c o n - O b j e c t                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXIcon.cpp,v 1.44 2001/08/29 04:12:48 jeroen Exp $                       *
+* $Id: FXIcon.cpp,v 1.47 2002/01/18 22:43:00 jeroen Exp $                       *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -29,15 +29,9 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
 #include "FXVisual.h"
-#include "FXDrawable.h"
-#include "FXImage.h"
 #include "FXIcon.h"
 
 
@@ -174,16 +168,16 @@ void FXIcon::detach(){
 // Destroy icon
 void FXIcon::destroy(){
   if(xid){
-    if(getApp()->initialized){ 
+    if(getApp()->initialized){
       FXTRACE((100,"%s::destroy %p\n",getClassName(),this));
 #ifndef WIN32
-      
+
       // Delete shape, etch, and image pixmaps
       XFreePixmap(DISPLAY(getApp()),shape);
       XFreePixmap(DISPLAY(getApp()),etch);
       XFreePixmap(DISPLAY(getApp()),xid);
 #else
-      
+
       // Delete shape, etch, and image bitmaps
       DeleteObject(shape);
       DeleteObject(etch);
@@ -202,185 +196,184 @@ void FXIcon::destroy(){
 
 // Render icon X Windows
 void FXIcon::render(){
+  if(xid){
+    register Visual *vis;
+    register XImage *xim=NULL;
+    register FXbool shmi=FALSE;
+    register FXuchar *img;
+    register FXint x,y;
+    register FXuchar tr,tg,tb;
+    XGCValues values;
+    GC gc;
 #ifdef HAVE_XSHM
-  XShmSegmentInfo shminfo;
-#endif
-  register Visual *vis;
-  register XImage *xim=NULL;
-  register FXbool shmi=FALSE;
-  register FXuchar *img;
-  register FXint x,y;
-  register FXuchar tr,tg,tb;
-  XGCValues values;
-  GC gc;
-
-  FXTRACE((100,"%s::render shape %p\n",getClassName(),this));
-
-  // Can not render before creation
-  if(!xid || !shape || !etch){ fxerror("%s::render: trying to render icon before it has been created.\n",getClassName()); }
-
-  // Check for legal size
-  if(width<1 || height<1){ fxerror("%s::render: illegal icon size %dx%d.\n",getClassName(),width,height); }
-
-  // Render the image pixels
-  FXImage::render();
-
-  // Just leave if black if no data
-  if(data){
-
-    // Get Visual
-    vis=(Visual*)visual->visual;
-
-    // Turn it on iff both supported and desired
-#ifdef HAVE_XSHM
-    if(options&IMAGE_SHMI) shmi=getApp()->shmi;
+    XShmSegmentInfo shminfo;
 #endif
 
-    // First try XShm
+    FXTRACE((100,"%s::render shape %p\n",getClassName(),this));
+
+    // Check for legal size
+    if(width<1 || height<1){ fxerror("%s::render: illegal icon size %dx%d.\n",getClassName(),width,height); }
+
+    // Render the image pixels
+    FXImage::render();
+
+    // Just leave if black if no data
+    if(data){
+
+      // Get Visual
+      vis=(Visual*)visual->visual;
+
+      // Turn it on iff both supported and desired
+#ifdef HAVE_XSHM
+      if(options&IMAGE_SHMI) shmi=getApp()->shmi;
+#endif
+
+      // First try XShm
 #ifdef HAVE_XSHM
-    if(shmi){
-      xim=XShmCreateImage(DISPLAY(getApp()),vis,1,ZPixmap,NULL,&shminfo,width,height);
-      if(!xim){ shmi=0; }
       if(shmi){
-        shminfo.shmid=shmget(IPC_PRIVATE,xim->bytes_per_line*xim->height,IPC_CREAT|0777);
-        if(shminfo.shmid==-1){ xim->data=NULL; XDestroyImage(xim); xim=NULL; shmi=0; }
+        xim=XShmCreateImage(DISPLAY(getApp()),vis,1,ZPixmap,NULL,&shminfo,width,height);
+        if(!xim){ shmi=0; }
         if(shmi){
-          shminfo.shmaddr=xim->data=(char*)shmat(shminfo.shmid,0,0);
-          shminfo.readOnly=FALSE;
-          XShmAttach(DISPLAY(getApp()),&shminfo);
-          FXTRACE((150,"Bitmap XSHM attached at memory=%p (%d bytes)\n",xim->data,xim->bytes_per_line*xim->height));
+          shminfo.shmid=shmget(IPC_PRIVATE,xim->bytes_per_line*xim->height,IPC_CREAT|0777);
+          if(shminfo.shmid==-1){ xim->data=NULL; XDestroyImage(xim); xim=NULL; shmi=0; }
+          if(shmi){
+            shminfo.shmaddr=xim->data=(char*)shmat(shminfo.shmid,0,0);
+            shminfo.readOnly=FALSE;
+            XShmAttach(DISPLAY(getApp()),&shminfo);
+            FXTRACE((150,"Bitmap XSHM attached at memory=%p (%d bytes)\n",xim->data,xim->bytes_per_line*xim->height));
+            }
           }
         }
-      }
 #endif
 
-    // Try the old fashioned way
-    if(!shmi){
+      // Try the old fashioned way
+      if(!shmi){
 
-      // Try create image
-      xim=XCreateImage(DISPLAY(getApp()),vis,1,ZPixmap,0,NULL,width,height,32,0);
-      if(!xim){ fxerror("%s::render: unable to render icon.\n",getClassName()); }
+        // Try create image
+        xim=XCreateImage(DISPLAY(getApp()),vis,1,ZPixmap,0,NULL,width,height,32,0);
+        if(!xim){ fxerror("%s::render: unable to render icon.\n",getClassName()); }
 
-      // Try create temp pixel store
-      if(!FXMALLOC(&xim->data,char,xim->bytes_per_line*height)){ fxerror("%s::render: unable to allocate memory.\n",getClassName()); }
-      }
+        // Try create temp pixel store
+        if(!FXMALLOC(&xim->data,char,xim->bytes_per_line*height)){ fxerror("%s::render: unable to allocate memory.\n",getClassName()); }
+        }
 
-    // Make GC
-    values.foreground=0xffffffff;
-    values.background=0xffffffff;
-    gc=XCreateGC(DISPLAY(getApp()),shape,GCForeground|GCBackground,&values);
+      // Make GC
+      values.foreground=0xffffffff;
+      values.background=0xffffffff;
+      gc=XCreateGC(DISPLAY(getApp()),shape,GCForeground|GCBackground,&values);
 
-    // Should have succeeded
-    FXASSERT(xim);
+      // Should have succeeded
+      FXASSERT(xim);
 
-    FXTRACE((150,"bm width = %d\n",xim->width));
-    FXTRACE((150,"bm height = %d\n",xim->height));
-    FXTRACE((150,"bm format = %s\n",xim->format==XYBitmap?"XYBitmap":xim->format==XYPixmap?"XYPixmap":"ZPixmap"));
-    FXTRACE((150,"bm byte_order = %s\n",(xim->byte_order==MSBFirst)?"MSBFirst":"LSBFirst"));
-    FXTRACE((150,"bm bitmap_unit = %d\n",xim->bitmap_unit));
-    FXTRACE((150,"bm bitmap_bit_order = %s\n",(xim->bitmap_bit_order==MSBFirst)?"MSBFirst":"LSBFirst"));
-    FXTRACE((150,"bm bitmap_pad = %d\n",xim->bitmap_pad));
-    FXTRACE((150,"bm bitmap_unit = %d\n",xim->bitmap_unit));
-    FXTRACE((150,"bm depth = %d\n",xim->depth));
-    FXTRACE((150,"bm bytes_per_line = %d\n",xim->bytes_per_line));
-    FXTRACE((150,"bm bits_per_pixel = %d\n",xim->bits_per_pixel));
+      FXTRACE((150,"bm width = %d\n",xim->width));
+      FXTRACE((150,"bm height = %d\n",xim->height));
+      FXTRACE((150,"bm format = %s\n",xim->format==XYBitmap?"XYBitmap":xim->format==XYPixmap?"XYPixmap":"ZPixmap"));
+      FXTRACE((150,"bm byte_order = %s\n",(xim->byte_order==MSBFirst)?"MSBFirst":"LSBFirst"));
+      FXTRACE((150,"bm bitmap_unit = %d\n",xim->bitmap_unit));
+      FXTRACE((150,"bm bitmap_bit_order = %s\n",(xim->bitmap_bit_order==MSBFirst)?"MSBFirst":"LSBFirst"));
+      FXTRACE((150,"bm bitmap_pad = %d\n",xim->bitmap_pad));
+      FXTRACE((150,"bm bitmap_unit = %d\n",xim->bitmap_unit));
+      FXTRACE((150,"bm depth = %d\n",xim->depth));
+      FXTRACE((150,"bm bytes_per_line = %d\n",xim->bytes_per_line));
+      FXTRACE((150,"bm bits_per_pixel = %d\n",xim->bits_per_pixel));
 
-    // Fill shape mask
-    img=data;
-    if(options&IMAGE_OPAQUE){           // Opaque image
-      FXTRACE((150,"Shape rectangle\n"));
-      memset(xim->data,0xff,xim->bytes_per_line*height);
-      }
-    else if(options&IMAGE_ALPHA){       // Transparency channel
-      FXTRACE((150,"Shape from alpha-channel\n"));
-      for(y=0; y<height; y++){
-        for(x=0; x<width; x++){
-          XPutPixel(xim,x,y,(img[3]!=0));
-          img+=4;
+      // Fill shape mask
+      img=data;
+      if(options&IMAGE_OPAQUE){           // Opaque image
+        FXTRACE((150,"Shape rectangle\n"));
+        memset(xim->data,0xff,xim->bytes_per_line*height);
+        }
+      else if(options&IMAGE_ALPHA){       // Transparency channel
+        FXTRACE((150,"Shape from alpha-channel\n"));
+        for(y=0; y<height; y++){
+          for(x=0; x<width; x++){
+            XPutPixel(xim,x,y,(img[3]!=0));
+            img+=4;
+            }
           }
         }
-      }
-    else{                               // Transparent color
-      tr=FXREDVAL(transp);
-      tg=FXGREENVAL(transp);
-      tb=FXBLUEVAL(transp);
-      FXTRACE((150,"Shape from alpha-color\n"));
-      for(y=0; y<height; y++){
-        for(x=0; x<width; x++){
-          XPutPixel(xim,x,y,!(img[0]==tr && img[1]==tg && img[2]==tb));
-          img+=3;
+      else{                               // Transparent color
+        tr=FXREDVAL(transp);
+        tg=FXGREENVAL(transp);
+        tb=FXBLUEVAL(transp);
+        FXTRACE((150,"Shape from alpha-color\n"));
+        for(y=0; y<height; y++){
+          for(x=0; x<width; x++){
+            XPutPixel(xim,x,y,!(img[0]==tr && img[1]==tg && img[2]==tb));
+            img+=3;
+            }
           }
         }
-      }
 
-    // Transfer image
+      // Transfer image
 #ifdef HAVE_XSHM
-    if(shmi){
-      XShmPutImage(DISPLAY(getApp()),shape,gc,xim,0,0,0,0,width,height,False);
-      XSync(DISPLAY(getApp()),False);
-      }
+      if(shmi){
+        XShmPutImage(DISPLAY(getApp()),shape,gc,xim,0,0,0,0,width,height,False);
+        XSync(DISPLAY(getApp()),False);
+        }
 #endif
-    if(!shmi){
-      XPutImage(DISPLAY(getApp()),shape,gc,xim,0,0,0,0,width,height);
-      }
+      if(!shmi){
+        XPutImage(DISPLAY(getApp()),shape,gc,xim,0,0,0,0,width,height);
+        }
 
-    // Fill etch image
-    img=data;
-    if(options&IMAGE_OPAQUE){           // Opaque image
-      for(y=0; y<height; y++){
-        for(x=0; x<width; x++){
-          XPutPixel(xim,x,y,DARKCOLOR(img[0],img[1],img[2]));
-          img+=channels;
+      // Fill etch image
+      img=data;
+      if(options&IMAGE_OPAQUE){           // Opaque image
+        for(y=0; y<height; y++){
+          for(x=0; x<width; x++){
+            XPutPixel(xim,x,y,DARKCOLOR(img[0],img[1],img[2]));
+            img+=channels;
+            }
           }
         }
-      }
-    else if(options&IMAGE_ALPHA){       // Transparency channel
-      for(y=0; y<height; y++){
-        for(x=0; x<width; x++){
-          XPutPixel(xim,x,y,(img[3]!=0) && DARKCOLOR(img[0],img[1],img[2]));
-          img+=4;
+      else if(options&IMAGE_ALPHA){       // Transparency channel
+        for(y=0; y<height; y++){
+          for(x=0; x<width; x++){
+            XPutPixel(xim,x,y,(img[3]!=0) && DARKCOLOR(img[0],img[1],img[2]));
+            img+=4;
+            }
           }
         }
-      }
-    else{                               // Transparent color
-      tr=FXREDVAL(transp);
-      tg=FXGREENVAL(transp);
-      tb=FXBLUEVAL(transp);
-      for(y=0; y<height; y++){
-        for(x=0; x<width; x++){
-          XPutPixel(xim,x,y,!(img[0]==tr && img[1]==tg && img[2]==tb) && DARKCOLOR(img[0],img[1],img[2]));
-          img+=3;
+      else{                               // Transparent color
+        tr=FXREDVAL(transp);
+        tg=FXGREENVAL(transp);
+        tb=FXBLUEVAL(transp);
+        for(y=0; y<height; y++){
+          for(x=0; x<width; x++){
+            XPutPixel(xim,x,y,!(img[0]==tr && img[1]==tg && img[2]==tb) && DARKCOLOR(img[0],img[1],img[2]));
+            img+=3;
+            }
           }
         }
-      }
 
-    // Transfer image
+      // Transfer image
 #ifdef HAVE_XSHM
-    if(shmi){
-      XShmPutImage(DISPLAY(getApp()),etch,gc,xim,0,0,0,0,width,height,False);
-      XSync(DISPLAY(getApp()),False);
-      }
+      if(shmi){
+        XShmPutImage(DISPLAY(getApp()),etch,gc,xim,0,0,0,0,width,height,False);
+        XSync(DISPLAY(getApp()),False);
+        }
 #endif
-    if(!shmi){
-      XPutImage(DISPLAY(getApp()),etch,gc,xim,0,0,0,0,width,height);
-      }
+      if(!shmi){
+        XPutImage(DISPLAY(getApp()),etch,gc,xim,0,0,0,0,width,height);
+        }
 
-    // Clean up
+      // Clean up
 #ifdef HAVE_XSHM
-    if(shmi){
-      FXTRACE((150,"Bitmap XSHM detached at memory=%p (%d bytes)\n",xim->data,xim->bytes_per_line*xim->height));
-      XShmDetach(DISPLAY(getApp()),&shminfo);
-      xim->data=NULL;
-      XDestroyImage(xim);
-      shmdt(shminfo.shmaddr);
-      shmctl(shminfo.shmid,IPC_RMID,0);
-      }
+      if(shmi){
+        FXTRACE((150,"Bitmap XSHM detached at memory=%p (%d bytes)\n",xim->data,xim->bytes_per_line*xim->height));
+        XShmDetach(DISPLAY(getApp()),&shminfo);
+        xim->data=NULL;
+        XDestroyImage(xim);
+        shmdt(shminfo.shmaddr);
+        shmctl(shminfo.shmid,IPC_RMID,0);
+        }
 #endif
-    if(!shmi){
-      FXFREE(&xim->data);
-      XDestroyImage(xim);
+      if(!shmi){
+        FXFREE(&xim->data);
+        XDestroyImage(xim);
+        }
+      XFreeGC(DISPLAY(getApp()),gc);
       }
-    XFreeGC(DISPLAY(getApp()),gc);
     }
   }
 
@@ -396,121 +389,121 @@ struct BITMAPINFO2 {
 
 // Render Icon MS-Windows
 void FXIcon::render(){
-  register FXuchar *maskdata,*etchdata,*msk,*ets,*img;
-  register FXint x,y;
-  register FXuchar tr,tg,tb;
-  register FXuint bytes_per_line;
-  BITMAPINFO2 bmi;
-  HDC hdcmsk;
-  FXTRACE((100,"%s::render %p\n",getClassName(),this));
+  if(xid){
+    register FXuchar *maskdata,*etchdata,*msk,*ets,*img;
+    register FXint x,y;
+    register FXuchar tr,tg,tb;
+    register FXuint bytes_per_line;
+    BITMAPINFO2 bmi;
+    HDC hdcmsk;
 
-  // Can not render before creation
-  if(!xid || !shape || !etch){ fxerror("%s::render: trying to render icon before it has been created.\n",getClassName()); }
+    FXTRACE((100,"%s::render %p\n",getClassName(),this));
 
-  // Check for legal size
-  if(width<1 || height<1){ fxerror("%s::render: illegal icon size %dx%d.\n",getClassName(),width,height); }
+    // Check for legal size
+    if(width<1 || height<1){ fxerror("%s::render: illegal icon size %dx%d.\n",getClassName(),width,height); }
 
-  // Render the image (color) pixels as usual
-  FXImage::render();
+    // Render the image (color) pixels as usual
+    FXImage::render();
 
-  // Just leave if black if no data
-  if(data){
+    // Just leave if black if no data
+    if(data){
 
-    // Set up the bitmap info
-    bmi.bmiHeader.biSize=sizeof(BITMAPINFOHEADER);
-    bmi.bmiHeader.biWidth=width;
-    bmi.bmiHeader.biHeight=height;
-    bmi.bmiHeader.biPlanes=1;
-    bmi.bmiHeader.biBitCount=1;
-    bmi.bmiHeader.biCompression=BI_RGB;
-    bmi.bmiHeader.biSizeImage=0;
-    bmi.bmiHeader.biXPelsPerMeter=0;
-    bmi.bmiHeader.biYPelsPerMeter=0;
-    bmi.bmiHeader.biClrUsed=0;
-    bmi.bmiHeader.biClrImportant=0;
-    bmi.bmiColors[0].rgbBlue=0;
-    bmi.bmiColors[0].rgbGreen=0;
-    bmi.bmiColors[0].rgbRed=0;
-    bmi.bmiColors[0].rgbReserved=0;
-    bmi.bmiColors[1].rgbBlue=255;
-    bmi.bmiColors[1].rgbGreen=255;
-    bmi.bmiColors[1].rgbRed=255;
-    bmi.bmiColors[1].rgbReserved=0;
+      // Set up the bitmap info
+      bmi.bmiHeader.biSize=sizeof(BITMAPINFOHEADER);
+      bmi.bmiHeader.biWidth=width;
+      bmi.bmiHeader.biHeight=height;
+      bmi.bmiHeader.biPlanes=1;
+      bmi.bmiHeader.biBitCount=1;
+      bmi.bmiHeader.biCompression=BI_RGB;
+      bmi.bmiHeader.biSizeImage=0;
+      bmi.bmiHeader.biXPelsPerMeter=0;
+      bmi.bmiHeader.biYPelsPerMeter=0;
+      bmi.bmiHeader.biClrUsed=0;
+      bmi.bmiHeader.biClrImportant=0;
+      bmi.bmiColors[0].rgbBlue=0;
+      bmi.bmiColors[0].rgbGreen=0;
+      bmi.bmiColors[0].rgbRed=0;
+      bmi.bmiColors[0].rgbReserved=0;
+      bmi.bmiColors[1].rgbBlue=255;
+      bmi.bmiColors[1].rgbGreen=255;
+      bmi.bmiColors[1].rgbRed=255;
+      bmi.bmiColors[1].rgbReserved=0;
 
-    // Allocate temp bit buffer
-    bytes_per_line=((width+31)&~31)>>3;
-    FXCALLOC(&maskdata,FXuchar,height*bytes_per_line);
-    FXCALLOC(&etchdata,FXuchar,height*bytes_per_line);
+      // Allocate temp bit buffer
+      bytes_per_line=((width+31)&~31)>>3;
+      FXCALLOC(&maskdata,FXuchar,height*bytes_per_line);
+      FXCALLOC(&etchdata,FXuchar,height*bytes_per_line);
 
-    img=data;
-    msk=maskdata+(height-1)*bytes_per_line;
-    ets=etchdata+(height-1)*bytes_per_line;
-    if(options&IMAGE_OPAQUE){
-      for(y=0; y<height; y++){
-        for(x=0; x<width; x++){
-          if(!DARKCOLOR(img[0],img[1],img[2])){ ets[x>>3]|=0x80>>(x&7); }
-          img+=channels;
+      img=data;
+      msk=maskdata+(height-1)*bytes_per_line;
+      ets=etchdata+(height-1)*bytes_per_line;
+      if(options&IMAGE_OPAQUE){
+        for(y=0; y<height; y++){
+          for(x=0; x<width; x++){
+            if(!DARKCOLOR(img[0],img[1],img[2])){ ets[x>>3]|=0x80>>(x&7); }
+            img+=channels;
+            }
+          ets-=bytes_per_line;
           }
-        ets-=bytes_per_line;
         }
-      }
-    else if(options&IMAGE_ALPHA){
-      for(y=0; y<height; y++){
-        for(x=0; x<width; x++){
-          if(!DARKCOLOR(img[0],img[1],img[2])){ ets[x>>3]|=0x80>>(x&7); }
-          if(img[3]==0){ msk[x>>3]|=0x80>>(x&7); ets[x>>3]|=0x80>>(x&7); }
-          img+=4;
+      else if(options&IMAGE_ALPHA){
+        for(y=0; y<height; y++){
+          for(x=0; x<width; x++){
+            if(!DARKCOLOR(img[0],img[1],img[2])){ ets[x>>3]|=0x80>>(x&7); }
+            if(img[3]==0){ msk[x>>3]|=0x80>>(x&7); ets[x>>3]|=0x80>>(x&7); }
+            img+=4;
+            }
+          msk-=bytes_per_line;
+          ets-=bytes_per_line;
           }
-        msk-=bytes_per_line;
-        ets-=bytes_per_line;
         }
-      }
-    else{
-      tr=FXREDVAL(transp);
-      tg=FXGREENVAL(transp);
-      tb=FXBLUEVAL(transp);
-      for(y=0; y<height; y++){
-        for(x=0; x<width; x++){
-          if(!DARKCOLOR(img[0],img[1],img[2])){ ets[x>>3]|=0x80>>(x&7); }
-          if((img[0]==tr) && (img[1]==tg) && (img[2]==tb)){ msk[x>>3]|=0x80>>(x&7); ets[x>>3]|=0x80>>(x&7); }
-          img+=3;
+      else{
+        tr=FXREDVAL(transp);
+        tg=FXGREENVAL(transp);
+        tb=FXBLUEVAL(transp);
+        for(y=0; y<height; y++){
+          for(x=0; x<width; x++){
+            if(!DARKCOLOR(img[0],img[1],img[2])){ ets[x>>3]|=0x80>>(x&7); }
+            if((img[0]==tr) && (img[1]==tg) && (img[2]==tb)){ msk[x>>3]|=0x80>>(x&7); ets[x>>3]|=0x80>>(x&7); }
+            img+=3;
+            }
+          msk-=bytes_per_line;
+          ets-=bytes_per_line;
           }
-        msk-=bytes_per_line;
-        ets-=bytes_per_line;
         }
+
+      // The MSDN documentation for SetDIBits() states that "the device context
+      // identified by the (first) parameter is used only if the DIB_PAL_COLORS
+      // constant is set for the (last) parameter". This may be true, but under
+      // Win95 you must pass in a non-NULL hdc for the first parameter; otherwise
+      // this call to SetDIBits() will fail (in contrast, it works fine under
+      // Windows NT if you pass in a NULL hdc).
+      hdcmsk=::CreateCompatibleDC(NULL);
+
+      // Set mask data
+      if(!SetDIBits(hdcmsk,(HBITMAP)shape,0,height,maskdata,(BITMAPINFO*)&bmi,DIB_RGB_COLORS)){
+        fxerror("%s::render: unable to render pixels\n",getClassName());
+        }
+
+      // Set etch data
+      if(!SetDIBits(hdcmsk,(HBITMAP)etch,0,height,etchdata,(BITMAPINFO*)&bmi,DIB_RGB_COLORS)){
+        fxerror("%s::render: unable to render pixels\n",getClassName());
+        }
+      FXFREE(&maskdata);
+      FXFREE(&etchdata);
+      GdiFlush();
+
+      // We AND the image with the mask, then we can do faster and more
+      // flicker-free icon painting later using the `black source' method
+      SelectObject(hdcmsk,(HBITMAP)shape);
+      HDC hdcmem=::CreateCompatibleDC(NULL);
+      SelectObject(hdcmem,(HBITMAP)xid);
+      SetBkColor(hdcmem,RGB(0,0,0));                // 1 -> black
+      SetTextColor(hdcmem,RGB(255,255,255));        // 0 -> white
+      BitBlt(hdcmem,0,0,width,height,hdcmsk,0,0,SRCAND);
+      ::DeleteDC(hdcmem);
+      ::DeleteDC(hdcmsk);
       }
-
-    // The MSDN documentation for SetDIBits() states that "the device context
-    // identified by the (first) parameter is used only if the DIB_PAL_COLORS
-    // constant is set for the (last) parameter". This may be true, but under
-    // Win95 you must pass in a non-NULL hdc for the first parameter; otherwise
-    // this call to SetDIBits() will fail (in contrast, it works fine under
-    // Windows NT if you pass in a NULL hdc).
-    hdcmsk=::CreateCompatibleDC(NULL);
-
-    // Set mask data
-    if(!SetDIBits(hdcmsk,(HBITMAP)shape,0,height,maskdata,(BITMAPINFO*)&bmi,DIB_RGB_COLORS)){
-      fxerror("%s::render: unable to render pixels\n",getClassName());
-      }
-
-    // Set etch data
-    if(!SetDIBits(hdcmsk,(HBITMAP)etch,0,height,etchdata,(BITMAPINFO*)&bmi,DIB_RGB_COLORS)){
-      fxerror("%s::render: unable to render pixels\n",getClassName());
-      }
-    FXFREE(&maskdata);
-    FXFREE(&etchdata);
-    GdiFlush();
-
-    // We AND the image with the mask, then we can do faster and more
-    // flicker-free icon painting later using the `black source' method
-    SelectObject(hdcmsk,(HBITMAP)shape);
-    HDC hdcmem=::CreateCompatibleDC(NULL);
-    SelectObject(hdcmem,(HBITMAP)xid);
-    SetBkColor(hdcmem,RGB(0,0,0));                // 1 -> black
-    SetTextColor(hdcmem,RGB(255,255,255));        // 0 -> white
-    BitBlt(hdcmem,0,0,width,height,hdcmsk,0,0,SRCAND);
-    ::DeleteDC(hdcmem);
-    ::DeleteDC(hdcmsk);
     }
   }
 
