@@ -3,7 +3,7 @@
 *                          I c o n L i s t   O b j e c t                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXIconList.cpp,v 1.86 2001/07/23 12:58:02 jeroen Exp $                   *
+* $Id: FXIconList.cpp,v 1.105.4.5 2003/06/20 19:02:07 fox Exp $                  *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,24 +30,14 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
 #include "FXFont.h"
-#include "FXDrawable.h"
 #include "FXImage.h"
 #include "FXIcon.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
-#include "FXLabel.h"
 #include "FXButton.h"
-#include "FXComposite.h"
 #include "FXScrollbar.h"
 #include "FXScrollArea.h"
 #include "FXHeader.h"
@@ -76,6 +66,7 @@
   - It may be convenient to have ways to move items around.
   - Need insertSorted() API to add item in the right place based on current
     sort function.
+  - Changing icon should NOT cause recalc() when size does not change.
 */
 
 
@@ -116,18 +107,6 @@ void FXIconItem::draw(const FXIconList* list,FXDC& dc,FXint x,FXint y,FXint w,FX
   }
 
 
-// Draw dotted rectangle for focus
-void FXIconItem::drawFocus(const FXIconList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const {
-  dc.setFillStyle(FILL_OPAQUESTIPPLED);
-  dc.setStipple(STIPPLE_GRAY,x,y);
-  dc.setForeground(list->getTextColor());
-  dc.setBackground(list->getBackColor());
-  dc.drawRectangle(x+1,y+1,w-3,h-3);
-  dc.setFillStyle(FILL_SOLID);
-  dc.setStipple(STIPPLE_NONE);
-  }
-
-
 // Draw big icon
 void FXIconItem::drawBigIcon(const FXIconList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const {
   register FXFont *font=list->getFont();
@@ -160,7 +139,7 @@ void FXIconItem::drawBigIcon(const FXIconList* list,FXDC& dc,FXint x,FXint y,FXi
       dc.drawText(xt+2,yt+font->getFontAscent()+2,label.text(),tdrw);
       if(dw) dc.drawText(xt+tw-2,yt+font->getFontAscent()+2,"...",3);
       if(hasFocus()){
-        drawFocus(list,dc,xt,yt,tw+dw,th);
+        dc.drawFocusRectangle(xt+1,yt+1,tw+dw-2,th-2);
         }
       }
     ss=BIG_TEXT_SPACING;    // Space between text and icon only added if we have both icon and text
@@ -224,7 +203,7 @@ void FXIconItem::drawMiniIcon(const FXIconList* list,FXDC& dc,FXint x,FXint y,FX
       dc.drawText(x+2,y+font->getFontAscent()+2,label.text(),tdrw);
       if(dw) dc.drawText(x+tw-2,y+font->getFontAscent()+2,"...",3);
       if(hasFocus()){
-        drawFocus(list,dc,x,y,tw+dw,th);
+        dc.drawFocusRectangle(x+1,y+1,tw+dw-2,th-2);
         }
       }
     }
@@ -244,7 +223,7 @@ void FXIconItem::drawDetails(const FXIconList* list,FXDC& dc,FXint x,FXint y,FXi
     dc.fillRectangle(x,y,header->getWidth(),h);
     }
   if(hasFocus()){
-    drawFocus(list,dc,x,y,header->getWidth(),h);
+    dc.drawFocusRectangle(x+1,y+1,header->getWidth()-2,h-2);
     }
   x+=SIDE_SPACING/2;
   if(miniIcon){
@@ -624,6 +603,21 @@ void FXIconList::detach(){
 FXbool FXIconList::canFocus() const { return 1; }
 
 
+// Into focus chain
+void FXIconList::setFocus(){
+  FXScrollArea::setFocus();
+  setDefault(TRUE);
+  }
+
+
+// Out of focus chain
+void FXIconList::killFocus(){
+  FXScrollArea::killFocus();
+  setDefault(MAYBE);
+  }
+
+
+
 // Move content
 void FXIconList::moveContents(FXint x,FXint y){
   FXint dx=x-pos_x;
@@ -973,6 +967,7 @@ FXbool FXIconList::isItemVisible(FXint index) const {
 void FXIconList::makeItemVisible(FXint index){
   register FXint x,y,hh,px,py;
   if(xid==0) return;
+  // FIXME maybe force layout first???
   if(0<=index && index<nitems){
     px=pos_x;
     py=pos_y;
@@ -1186,7 +1181,7 @@ FXbool FXIconList::selectItem(FXint index,FXbool notify){
       case ICONLIST_MULTIPLESELECT:
         items[index]->setSelected(TRUE);
         updateItem(index);
-        if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)index);}
+        if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)(FXival)index);}
         break;
       }
     return TRUE;
@@ -1205,7 +1200,7 @@ FXbool FXIconList::deselectItem(FXint index,FXbool notify){
       case ICONLIST_SINGLESELECT:
         items[index]->setSelected(FALSE);
         updateItem(index);
-        if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)index);}
+        if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)(FXival)index);}
         break;
       }
     return TRUE;
@@ -1223,7 +1218,7 @@ FXbool FXIconList::toggleItem(FXint index,FXbool notify){
         killSelection(notify);
         items[index]->setSelected(TRUE);
         updateItem(index);
-        if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)index);}
+        if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)(FXival)index);}
         }
       break;
     case ICONLIST_SINGLESELECT:
@@ -1231,12 +1226,12 @@ FXbool FXIconList::toggleItem(FXint index,FXbool notify){
         killSelection(notify);
         items[index]->setSelected(TRUE);
         updateItem(index);
-        if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)index);}
+        if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)(FXival)index);}
         }
       else{
         items[index]->setSelected(FALSE);
         updateItem(index);
-        if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)index);}
+        if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)(FXival)index);}
         }
       break;
     case ICONLIST_EXTENDEDSELECT:
@@ -1244,12 +1239,12 @@ FXbool FXIconList::toggleItem(FXint index,FXbool notify){
       if(!items[index]->isSelected()){
         items[index]->setSelected(TRUE);
         updateItem(index);
-        if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)index);}
+        if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)(FXival)index);}
         }
       else{
         items[index]->setSelected(FALSE);
         updateItem(index);
-        if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)index);}
+        if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)(FXival)index);}
         }
       break;
     }
@@ -1282,7 +1277,7 @@ FXbool FXIconList::extendSelection(FXint index,FXbool notify){
           items[i]->setSelected(TRUE);
           updateItem(i);
           changes=TRUE;
-          if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)i);}
+          if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)(FXival)i);}
           }
         }
 
@@ -1293,7 +1288,7 @@ FXbool FXIconList::extendSelection(FXint index,FXbool notify){
           items[i]->setSelected(FALSE);
           updateItem(i);
           changes=TRUE;
-          if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)i);}
+          if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)(FXival)i);}
           }
         }
       }
@@ -1308,7 +1303,7 @@ FXbool FXIconList::extendSelection(FXint index,FXbool notify){
           items[i]->setSelected(TRUE);
           updateItem(i);
           changes=TRUE;
-          if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)i);}
+          if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)(FXival)i);}
           }
         }
 
@@ -1319,7 +1314,7 @@ FXbool FXIconList::extendSelection(FXint index,FXbool notify){
           items[i]->setSelected(FALSE);
           updateItem(i);
           changes=TRUE;
-          if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)i);}
+          if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)(FXival)i);}
           }
         }
       }
@@ -1338,7 +1333,7 @@ FXbool FXIconList::killSelection(FXbool notify){
       items[i]->setSelected(FALSE);
       updateItem(i);
       changes=TRUE;
-      if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)i);}
+      if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)(FXival)i);}
       }
     }
   return changes;
@@ -1410,7 +1405,7 @@ FXbool FXIconList::selectInRectangle(FXint x,FXint y,FXint w,FXint h,FXbool noti
 
 // Update value from a message
 long FXIconList::onCmdSetValue(FXObject*,FXSelector,void* ptr){
-  setCurrentItem((FXint)(long)ptr);
+  setCurrentItem((FXint)(FXival)ptr);
   return 1;
   }
 
@@ -1441,7 +1436,7 @@ long FXIconList::onEnter(FXObject* sender,FXSelector sel,void* ptr){
 // Stop motion timer when leaving window
 long FXIconList::onLeave(FXObject* sender,FXSelector sel,void* ptr){
   FXScrollArea::onLeave(sender,sel,ptr);
-  if(timer){getApp()->removeTimeout(timer);timer=NULL;}
+  if(timer){timer=getApp()->removeTimeout(timer);}
   cursor=-1;
   return 1;
   }
@@ -1564,7 +1559,7 @@ long FXIconList::onPaint(FXObject*,FXSelector,void* ptr){
       dc.fillRectangle(event->rect.x,y,event->rect.w,event->rect.y+event->rect.h-y);
       }
     }
-  
+
   return 1;
   }
 
@@ -1735,26 +1730,30 @@ FXint FXIconList::descending(const FXIconItem* a,const FXIconItem* b){
 
 // Sort the items based on the sort function
 void FXIconList::sortItems(){
-  register FXIconItem *v;
+  register FXIconItem *v,*c;
   register FXint i,j,h;
-  register FXbool exch=FALSE;
   if(sortfunc){
+    if(0<=current){
+      c=items[current];
+      }
     for(h=1; h<=nitems/9; h=3*h+1);
-    if(hasFocus() && 0<=current) items[current]->setFocus(FALSE);
     for(; h>0; h/=3){
       for(i=h+1;i<=nitems;i++){
         v=items[i-1];
         j=i;
         while(j>h && sortfunc(items[j-h-1],v)>0){
           items[j-1]=items[j-h-1];
-          exch=TRUE;
           j-=h;
           }
         items[j-1]=v;
         }
       }
-    if(hasFocus() && 0<=current) items[current]->setFocus(TRUE);
-    if(exch) update();
+    if(0<=current){
+      for(i=0; i<nitems; i++){
+        if(items[i]==c){ current=i; break; }
+        }
+      }
+    recalc();
     }
   }
 
@@ -1787,10 +1786,10 @@ void FXIconList::setCurrentItem(FXint index,FXbool notify){
       }
 
     // Notify item change
-    if(notify && target){target->handle(this,MKUINT(message,SEL_CHANGED),(void*)current);}
+    if(notify && target){target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)current);}
     }
 
-  // In browse selection mode, deselect item
+  // In browse selection mode, select item
   if((options&SELECT_MASK)==ICONLIST_BROWSESELECT && 0<=current && items[current]->isEnabled()){
     selectItem(current,notify);
     }
@@ -1817,145 +1816,153 @@ long FXIconList::onLookupTimer(FXObject*,FXSelector,void*){
 long FXIconList::onKeyPress(FXObject*,FXSelector,void* ptr){
   FXEvent* event=(FXEvent*)ptr;
   FXint index=current;
-  char entry;
   flags&=~FLAG_TIP;
-  if(isEnabled()){
-    flags&=~FLAG_UPDATE;
-    if(target && target->handle(this,MKUINT(message,SEL_KEYPRESS),ptr)) return 1;
-    if(index<0) index=0;
-    switch(event->code){
-      case KEY_Page_Up:
-      case KEY_KP_Page_Up:
-        lookup=FXString::null;
-        setPosition(pos_x,pos_y+verticalScrollbar()->getPage());
+  if(!isEnabled()) return 0;
+  if(target && target->handle(this,MKUINT(message,SEL_KEYPRESS),ptr)) return 1;
+  if(index<0) index=0;
+  switch(event->code){
+    case KEY_Control_L:
+    case KEY_Control_R:
+    case KEY_Shift_L:
+    case KEY_Shift_R:
+    case KEY_Alt_L:
+    case KEY_Alt_R:
+      if(flags&FLAG_DODRAG){handle(this,MKUINT(0,SEL_DRAGGED),ptr);}
+      return 1;
+    case KEY_Page_Up:
+    case KEY_KP_Page_Up:
+      lookup=FXString::null;
+      setPosition(pos_x,pos_y+verticalScrollbar()->getPage());
+      return 1;
+    case KEY_Page_Down:
+    case KEY_KP_Page_Down:
+      lookup=FXString::null;
+      setPosition(pos_x,pos_y-verticalScrollbar()->getPage());
+      return 1;
+    case KEY_Right:
+    case KEY_KP_Right:
+      if(!(options&(ICONLIST_BIG_ICONS|ICONLIST_MINI_ICONS))){
+        setPosition(pos_x-10,pos_y);
         return 1;
-      case KEY_Page_Down:
-      case KEY_KP_Page_Down:
-        lookup=FXString::null;
-        setPosition(pos_x,pos_y-verticalScrollbar()->getPage());
+        }
+      if(options&ICONLIST_COLUMNS) index+=1; else index+=nrows;
+      goto hop;
+    case KEY_Left:
+    case KEY_KP_Left:
+      if(!(options&(ICONLIST_BIG_ICONS|ICONLIST_MINI_ICONS))){
+        setPosition(pos_x+10,pos_y);
         return 1;
-      case KEY_Right:
-      case KEY_KP_Right:
-        if(!(options&(ICONLIST_BIG_ICONS|ICONLIST_MINI_ICONS))){
-          setPosition(pos_x-10,pos_y);
-          return 1;
-          }
-        if(options&ICONLIST_COLUMNS) index+=1; else index+=nrows;
-        goto hop;
-      case KEY_Left:
-      case KEY_KP_Left:
-        if(!(options&(ICONLIST_BIG_ICONS|ICONLIST_MINI_ICONS))){
-          setPosition(pos_x+10,pos_y);
-          return 1;
-          }
-        if(options&ICONLIST_COLUMNS) index-=1; else index-=nrows;
-        goto hop;
-      case KEY_Up:
-      case KEY_KP_Up:
-        if(options&ICONLIST_COLUMNS) index-=ncols; else index-=1;
-        goto hop;
-      case KEY_Down:
-      case KEY_KP_Down:
-        if(options&ICONLIST_COLUMNS) index+=ncols; else index+=1;
-        goto hop;
-      case KEY_Home:
-      case KEY_KP_Home:
-        index=0;
-        goto hop;
-      case KEY_End:
-      case KEY_KP_End:
-        index=nitems-1;
-hop:    lookup=FXString::null;
-        if(0<=index && index<nitems){
-          setCurrentItem(index,TRUE);
-          makeItemVisible(index);
+        }
+      if(options&ICONLIST_COLUMNS) index-=1; else index-=nrows;
+      goto hop;
+    case KEY_Up:
+    case KEY_KP_Up:
+      if(options&ICONLIST_COLUMNS) index-=ncols; else index-=1;
+      goto hop;
+    case KEY_Down:
+    case KEY_KP_Down:
+      if(options&ICONLIST_COLUMNS) index+=ncols; else index+=1;
+      goto hop;
+    case KEY_Home:
+    case KEY_KP_Home:
+      index=0;
+      goto hop;
+    case KEY_End:
+    case KEY_KP_End:
+      index=nitems-1;
+hop:  lookup=FXString::null;
+      if(0<=index && index<nitems){
+        setCurrentItem(index,TRUE);
+        makeItemVisible(index);
+        if(items[index]->isEnabled()){
           if((options&SELECT_MASK)==ICONLIST_EXTENDEDSELECT){
-            if(items[index]->isEnabled()){
-              if(event->state&SHIFTMASK){
-                if(0<=anchor){
-                  selectItem(anchor,TRUE);
-                  extendSelection(index,TRUE);
-                  }
-                else{
-                  selectItem(index,TRUE);
-                  }
-                }
-              else if(!(event->state&CONTROLMASK)){
-                killSelection(TRUE);
-                selectItem(index,TRUE);
-                setAnchorItem(index);
-                }
-              }
-            }
-          }
-        return 1;
-      case KEY_space:
-      case KEY_KP_Space:
-        lookup=FXString::null;
-        if(0<=index && items[index]->isEnabled()){
-          switch(options&SELECT_MASK){
-            case ICONLIST_EXTENDEDSELECT:
-              if(event->state&SHIFTMASK){
-                if(0<=anchor){
-                  selectItem(anchor,TRUE);
-                  extendSelection(index,TRUE);
-                  }
-                else{
-                  selectItem(index,TRUE);
-                  }
-                }
-              else if(event->state&CONTROLMASK){
-                toggleItem(index,TRUE);
+            if(event->state&SHIFTMASK){
+              if(0<=anchor){
+                selectItem(anchor,TRUE);
+                extendSelection(index,TRUE);
                 }
               else{
-                killSelection(TRUE);
                 selectItem(index,TRUE);
                 }
-              break;
-            case ICONLIST_MULTIPLESELECT:
-            case ICONLIST_SINGLESELECT:
-              toggleItem(index,TRUE);
-              break;
-            }
-          setAnchorItem(index);
-          }
-        return 1;
-      case KEY_Return:
-      case KEY_KP_Enter:
-        lookup=FXString::null;
-        return 1;
-      case KEY_Control_L:
-      case KEY_Control_R:
-      case KEY_Shift_L:
-      case KEY_Shift_R:
-      case KEY_Alt_L:
-      case KEY_Alt_R:
-        if(flags&FLAG_DODRAG){handle(this,MKUINT(0,SEL_DRAGGED),ptr);}
-        return 1;
-      default:
-        if(!(event->state&(CONTROLMASK|ALTMASK))){
-          entry=fxkeyval(event->code,event->state);
-          if(' '<=(FXuchar)entry){
-            lookup.append(entry);
-            if(lookuptimer) getApp()->removeTimeout(lookuptimer);
-            lookuptimer=getApp()->addTimeout(getApp()->getTypingSpeed(),this,ID_LOOKUPTIMER);
-            index=findItem(lookup,current,SEARCH_FORWARD|SEARCH_WRAP|SEARCH_PREFIX);
-            if(0<=index){
-              setCurrentItem(index,TRUE);
-              makeItemVisible(index);
-              if((options&SELECT_MASK)==ICONLIST_EXTENDEDSELECT){
-                if(items[index]->isEnabled()){
-                  killSelection(TRUE);
-                  selectItem(index,TRUE);
-                  }
-                }
+              }
+            else if(!(event->state&CONTROLMASK)){
+              killSelection(TRUE);
+              selectItem(index,TRUE);
               setAnchorItem(index);
               }
-            return 1;
             }
           }
-        break;
-      }
+        }
+      handle(this,MKUINT(0,SEL_CLICKED),(void*)(FXival)current);
+      if(0<=current && items[current]->isEnabled()){
+        handle(this,MKUINT(0,SEL_COMMAND),(void*)(FXival)current);
+        }
+      return 1;
+    case KEY_space:
+    case KEY_KP_Space:
+      lookup=FXString::null;
+      if(0<=current && items[current]->isEnabled()){
+        switch(options&SELECT_MASK){
+          case ICONLIST_EXTENDEDSELECT:
+            if(event->state&SHIFTMASK){
+              if(0<=anchor){
+                selectItem(anchor,TRUE);
+                extendSelection(current,TRUE);
+                }
+              else{
+                selectItem(current,TRUE);
+                }
+              }
+            else if(event->state&CONTROLMASK){
+              toggleItem(current,TRUE);
+              }
+            else{
+              killSelection(TRUE);
+              selectItem(current,TRUE);
+              }
+            break;
+          case ICONLIST_MULTIPLESELECT:
+          case ICONLIST_SINGLESELECT:
+            toggleItem(current,TRUE);
+            break;
+          }
+        setAnchorItem(current);
+        }
+      handle(this,MKUINT(0,SEL_CLICKED),(void*)(FXival)current);
+      if(0<=current && items[current]->isEnabled()){
+        handle(this,MKUINT(0,SEL_COMMAND),(void*)(FXival)current);
+        }
+      return 1;
+    case KEY_Return:
+    case KEY_KP_Enter:
+      lookup=FXString::null;
+      handle(this,MKUINT(0,SEL_DOUBLECLICKED),(void*)(FXival)current);
+      if(0<=current && items[current]->isEnabled()){
+        handle(this,MKUINT(0,SEL_COMMAND),(void*)(FXival)current);
+        }
+      return 1;
+    default:
+      if((event->state&(CONTROLMASK|ALTMASK)) || !isprint((FXuchar)event->text[0])) return 0;
+      lookup.append(event->text);
+      if(lookuptimer) getApp()->removeTimeout(lookuptimer);
+      lookuptimer=getApp()->addTimeout(getApp()->getTypingSpeed(),this,ID_LOOKUPTIMER);
+      index=findItem(lookup,current,SEARCH_FORWARD|SEARCH_WRAP|SEARCH_PREFIX);
+      if(0<=index){
+	setCurrentItem(index,TRUE);
+	makeItemVisible(index);
+	if(items[index]->isEnabled()){
+	  if((options&SELECT_MASK)==ICONLIST_EXTENDEDSELECT){
+	    killSelection(TRUE);
+	    selectItem(index,TRUE);
+	    }
+	  setAnchorItem(index);
+	  }
+        }
+      handle(this,MKUINT(0,SEL_CLICKED),(void*)(FXival)current);
+      if(0<=current && items[current]->isEnabled()){
+        handle(this,MKUINT(0,SEL_COMMAND),(void*)(FXival)current);
+        }
+      return 1;
     }
   return 0;
   }
@@ -1964,75 +1971,17 @@ hop:    lookup=FXString::null;
 // Key Release
 long FXIconList::onKeyRelease(FXObject*,FXSelector,void* ptr){
   FXEvent* event=(FXEvent*)ptr;
-  char entry;
-  if(isEnabled()){
-    flags|=FLAG_UPDATE;
-    if(target && target->handle(this,MKUINT(message,SEL_KEYRELEASE),ptr)) return 1;
-    switch(event->code){
-      case KEY_Page_Up:
-      case KEY_KP_Page_Up:
-      case KEY_Page_Down:
-      case KEY_KP_Page_Down:
-        return 1;
-      case KEY_Right:
-      case KEY_KP_Right:
-      case KEY_Left:
-      case KEY_KP_Left:
-        if(!(options&(ICONLIST_BIG_ICONS|ICONLIST_MINI_ICONS))) return 1;
-      case KEY_Up:
-      case KEY_KP_Up:
-      case KEY_Down:
-      case KEY_KP_Down:
-      case KEY_Home:
-      case KEY_KP_Home:
-      case KEY_End:
-      case KEY_KP_End:
-        if((options&SELECT_MASK)==ICONLIST_BROWSESELECT){
-          handle(this,MKUINT(0,SEL_CLICKED),(void*)current);
-          if(0<=current && items[current]->isEnabled()){
-            handle(this,MKUINT(0,SEL_COMMAND),(void*)current);
-            }
-          }
-        return 1;
-      case KEY_space:
-      case KEY_KP_Space:
-        if((options&SELECT_MASK)!=ICONLIST_BROWSESELECT){
-          handle(this,MKUINT(0,SEL_CLICKED),(void*)current);
-          if(0<=current && items[current]->isEnabled()){
-            handle(this,MKUINT(0,SEL_COMMAND),(void*)current);
-            }
-          }
-        return 1;
-      case KEY_Return:
-      case KEY_KP_Enter:
-        handle(this,MKUINT(0,SEL_DOUBLECLICKED),(void*)current);
-        if(0<=current && items[current]->isEnabled()){
-          handle(this,MKUINT(0,SEL_COMMAND),(void*)current);
-          }
-        return 1;
-      case KEY_Shift_L:
-      case KEY_Shift_R:
-      case KEY_Control_L:
-      case KEY_Control_R:
-      case KEY_Alt_L:
-      case KEY_Alt_R:
-        if(flags&FLAG_DODRAG){handle(this,MKUINT(0,SEL_DRAGGED),ptr);}
-        return 1;
-      default:
-        if(!(event->state&(CONTROLMASK|ALTMASK))){
-          entry=fxkeyval(event->code,event->state);
-          if(' '<=(FXuchar)entry){
-            if((options&SELECT_MASK)==ICONLIST_BROWSESELECT){
-              handle(this,MKUINT(0,SEL_CLICKED),(void*)current);
-              if(0<=current && items[current]->isEnabled()){
-                handle(this,MKUINT(0,SEL_COMMAND),(void*)current);
-                }
-              }
-            return 1;
-            }
-          }
-        break;
-      }
+  if(!isEnabled()) return 0;
+  if(target && target->handle(this,MKUINT(message,SEL_KEYRELEASE),ptr)) return 1;
+  switch(event->code){
+    case KEY_Shift_L:
+    case KEY_Shift_R:
+    case KEY_Control_L:
+    case KEY_Control_R:
+    case KEY_Alt_L:
+    case KEY_Alt_R:
+      if(flags&FLAG_DODRAG){handle(this,MKUINT(0,SEL_DRAGGED),ptr);}
+      return 1;
     }
   return 0;
   }
@@ -2069,7 +2018,7 @@ long FXIconList::onAutoScroll(FXObject* sender,FXSelector sel,void* ptr){
     FXMINMAX(nlx,nrx,anchorx,currentx);
     FXMINMAX(nty,nby,anchory,currenty);
     lassoChanged(pos_x+olx,pos_y+oty,orx-olx+1,oby-oty+1,pos_x+nlx,pos_y+nty,nrx-nlx+1,nby-nty+1,TRUE);
-    
+
     // Force repaint on this window
     repaint();
 
@@ -2125,7 +2074,7 @@ long FXIconList::onMotion(FXObject*,FXSelector,void* ptr){
     FXMINMAX(nlx,nrx,anchorx,currentx);
     FXMINMAX(nty,nby,anchory,currenty);
     lassoChanged(pos_x+olx,pos_y+oty,orx-olx+1,oby-oty+1,pos_x+nlx,pos_y+nty,nrx-nlx+1,nby-nty+1,TRUE);
-    
+
     // Force repaint on this window
     repaint();
 
@@ -2301,18 +2250,18 @@ long FXIconList::onLeftBtnRelease(FXObject*,FXSelector,void* ptr){
 
       // Generate clicked callbacks
       if(event->click_count==1){
-        handle(this,MKUINT(0,SEL_CLICKED),(void*)current);
+        handle(this,MKUINT(0,SEL_CLICKED),(void*)(FXival)current);
         }
       else if(event->click_count==2){
-        handle(this,MKUINT(0,SEL_DOUBLECLICKED),(void*)current);
+        handle(this,MKUINT(0,SEL_DOUBLECLICKED),(void*)(FXival)current);
         }
       else if(event->click_count==3){
-        handle(this,MKUINT(0,SEL_TRIPLECLICKED),(void*)current);
+        handle(this,MKUINT(0,SEL_TRIPLECLICKED),(void*)(FXival)current);
         }
 
       // Command callback only when clicked on item
       if(0<=current && items[current]->isEnabled()){
-        handle(this,MKUINT(0,SEL_COMMAND),(void*)current);
+        handle(this,MKUINT(0,SEL_COMMAND),(void*)(FXival)current);
         }
       }
     return 1;
@@ -2409,7 +2358,7 @@ FXint FXIconList::replaceItem(FXint index,FXIconItem* item,FXbool notify){
   if(index<0 || nitems<=index){ fxerror("%s::replaceItem: index out of range.\n",getClassName()); }
 
   // Notify item will be replaced
-  if(notify && target){target->handle(this,MKUINT(message,SEL_REPLACED),(void*)index);}
+  if(notify && target){target->handle(this,MKUINT(message,SEL_REPLACED),(void*)(FXival)index);}
 
   // Copy the state over
   item->state=items[index]->state;
@@ -2455,11 +2404,11 @@ FXint FXIconList::insertItem(FXint index,FXIconItem* item,FXbool notify){
   if(current<0 && nitems==1) current=0;
 
   // Notify item has been inserted
-  if(notify && target){target->handle(this,MKUINT(message,SEL_INSERTED),(void*)index);}
+  if(notify && target){target->handle(this,MKUINT(message,SEL_INSERTED),(void*)(FXival)index);}
 
   // Current item may have changed
   if(old!=current){
-    if(notify && target){target->handle(this,MKUINT(message,SEL_CHANGED),(void*)current);}
+    if(notify && target){target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)current);}
     }
 
   // Was new item
@@ -2516,7 +2465,7 @@ void FXIconList::removeItem(FXint index,FXbool notify){
   if(index<0 || nitems<=index){ fxerror("%s::removeItem: index out of range.\n",getClassName()); }
 
   // Notify item will be deleted
-  if(notify && target){target->handle(this,MKUINT(message,SEL_DELETED),(void*)index);}
+  if(notify && target){target->handle(this,MKUINT(message,SEL_DELETED),(void*)(FXival)index);}
 
   nitems--;
   delete items[index];
@@ -2528,8 +2477,8 @@ void FXIconList::removeItem(FXint index,FXbool notify){
   if(current>index || current>=nitems) current--;
 
   // Current item has changed
-  if(old!=current){
-    if(notify && target){target->handle(this,MKUINT(message,SEL_CHANGED),(void*)current);}
+  if(index<=old){
+    if(notify && target){target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)current);}
     }
 
   // Deleted current item
@@ -2549,12 +2498,15 @@ void FXIconList::removeItem(FXint index,FXbool notify){
 
 // Remove all items
 void FXIconList::clearItems(FXbool notify){
+  register FXint old=current;
 
   // Delete items
-  for(FXint index=0; index<nitems; index++){
-    if(notify && target){target->handle(this,MKUINT(message,SEL_DELETED),(void*)index);}
+  for(FXint index=nitems-1; 0<=index; index--){
+    if(notify && target){target->handle(this,MKUINT(message,SEL_DELETED),(void*)(FXival)index);}
     delete items[index];
     }
+
+  // Free array
   FXFREE(&items);
   nitems=0;
 
@@ -2564,7 +2516,9 @@ void FXIconList::clearItems(FXbool notify){
   extent=-1;
 
   // Current item has changed
-  if(notify && target){target->handle(this,MKUINT(message,SEL_CHANGED),(void*)-1);}
+  if(old!=current){
+    if(notify && target){target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)-1);}
+    }
 
   // Redo layout
   recalc();
