@@ -3,7 +3,7 @@
 *                            L a b e l   W i d g e t                            *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXLabel.cpp,v 1.23 2001/04/27 14:30:33 jeroen Exp $                      *
+* $Id: FXLabel.cpp,v 1.28 2002/01/18 22:43:01 jeroen Exp $                      *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -29,20 +29,11 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
 #include "FXFont.h"
-#include "FXDrawable.h"
-#include "FXImage.h"
 #include "FXIcon.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
 #include "FXLabel.h"
 
 
@@ -338,9 +329,14 @@ long FXLabel::onPaint(FXObject*,FXSelector,void* ptr){
 long FXLabel::onHotKeyPress(FXObject*,FXSelector,void* ptr){
   FXWindow *window=getNext();
   while(window){
-    if(window->isEnabled() && window->canFocus()){
-      window->handle(this,MKUINT(0,SEL_FOCUS_SELF),ptr);
-      break;
+    if(window->shown()){
+      if(window->isEnabled() && window->canFocus()){
+        window->handle(this,MKUINT(0,SEL_FOCUS_SELF),ptr);
+        return 1;
+        }
+      if(window->isComposite() && window->handle(this,MKUINT(0,SEL_FOCUS_NEXT),ptr)){
+        return 1;
+        }
       }
     window=window->getNext();
     }
@@ -437,8 +433,8 @@ FXuint FXLabel::getJustify() const {
 
 
 // Set icon positioning
-void FXLabel::setIconPosition(FXuint style){
-  FXuint opts=(options&~ICON_TEXT_MASK) | (style&ICON_TEXT_MASK);
+void FXLabel::setIconPosition(FXuint mode){
+  FXuint opts=(options&~ICON_TEXT_MASK) | (mode&ICON_TEXT_MASK);
   if(options!=opts){
     options=opts;
     recalc();
