@@ -3,7 +3,7 @@
 *                            L i s t   O b j e c t                              *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXList.cpp,v 1.67 2001/07/17 21:58:58 jeroen Exp $                       *
+* $Id: FXList.cpp,v 1.85.4.8 2003/06/20 19:02:07 fox Exp $                       *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,23 +30,12 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXObjectList.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
 #include "FXFont.h"
-#include "FXDrawable.h"
-#include "FXImage.h"
 #include "FXIcon.h"
-#include "FXWindow.h"
-#include "FXComposite.h"
 #include "FXScrollbar.h"
-#include "FXScrollArea.h"
 #include "FXList.h"
 
 
@@ -54,8 +43,8 @@
 /*
 
   Notes:
-  - Draw stuff differently when disabled.
   - Move active item by means of focus navigation, or first letters typed.
+  - Draw stuff differently when disabled.
   - PageUp/PageDn should also change currentitem.
   - Should support borders in ScrollWindow & derivatives.
   - Should issue callbacks from keyboard also.
@@ -72,13 +61,16 @@
     do this when FXScrollArea gets derived from FXFrame, so we'll have internal
     padding, and inter-item padding.
   - When in single/browse mode, current item always the one that's selected
-  - Get rid of marking stuff.
-  - Generate callbacks when selected, deselected, etc.
-  - Add flag (default=false) to issue callback for setCurrentItem() etc.
   - It may be convenient to have ways to move items around.
-  - Need to add support for arbitrary icon sizes same as FXTreeList already has.
   - Need insertSorted() API to add item in the right place based on current
     sort function.
+  - Need to add support for justification (similar to FXTableItem).  Perhaps
+    multi-line labels too while we're at it.
+  - Sort API should change; it should become:
+
+        sortItems(FXListSortFunc func=FXList::ascending)
+
+    this way we will not need to keep track of sort func!
 */
 
 
@@ -109,7 +101,7 @@ void FXListItem::draw(const FXList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint
     dc.setForeground(list->getBackColor());
   dc.fillRectangle(x,y,w,h);
   if(hasFocus()){
-    drawFocus(list,dc,x,y,w,h);
+    dc.drawFocusRectangle(x+1,y+1,w-2,h-2);
     }
   x+=SIDE_SPACING/2;
   if(icon){
@@ -129,18 +121,6 @@ void FXListItem::draw(const FXList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint
   }
 
 
-// Draw dotted rectangle for focus
-void FXListItem::drawFocus(const FXList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const {
-  dc.setFillStyle(FILL_OPAQUESTIPPLED);
-  dc.setStipple(STIPPLE_GRAY,x,y);
-  dc.setForeground(list->getTextColor());
-  dc.setBackground(list->getBackColor());
-  dc.drawRectangle(x+1,y+1,w-3,h-3);
-  dc.setFillStyle(FILL_SOLID);
-  dc.setStipple(STIPPLE_NONE);
-  }
-
-
 // See if item got hit, and where: 0 is outside, 1 is icon, 2 is text
 FXint FXListItem::hitItem(const FXList* list,FXint x,FXint y) const {
   register FXint iw=0,ih=0,tw=0,th=0,ix,iy,tx,ty,h;
@@ -201,36 +181,38 @@ void FXListItem::setIconOwned(FXuint owned){
 
 
 // Create icon
-void FXListItem::create(){ 
-  if(icon) icon->create(); 
+void FXListItem::create(){
+  if(icon) icon->create();
   }
 
 
 // Destroy icon
-void FXListItem::destroy(){ 
-  if((state&ICONOWNED) && icon) icon->destroy(); 
+void FXListItem::destroy(){
+  if((state&ICONOWNED) && icon) icon->destroy();
   }
 
 
 // Detach from icon resource
-void FXListItem::detach(){ 
-  if(icon) icon->detach(); 
+void FXListItem::detach(){
+  if(icon) icon->detach();
   }
 
 
 // Get width of item
 FXint FXListItem::getWidth(const FXList* list) const {
-  FXint w=0;
+  register FXint w=0;
   if(icon) w=icon->getWidth();
-  if(!label.empty()){ w+=list->getFont()->getTextWidth(label.text(),label.length()); if(icon) w+=ICON_SPACING; }
+  if(!label.empty()){
+    if(w) w+=ICON_SPACING;
+    w+=list->getFont()->getTextWidth(label.text(),label.length());
+    }
   return SIDE_SPACING+w;
   }
 
 
 // Get height of item
 FXint FXListItem::getHeight(const FXList* list) const {
-  FXint th,ih;
-  th=ih=0;
+  register FXint th=0,ih=0;
   if(!label.empty()) th=list->getFont()->getFontHeight();
   if(icon) ih=icon->getHeight();
   return LINE_SPACING+FXMAX(th,ih);
@@ -311,8 +293,8 @@ FXList::FXList(){
   textColor=0;
   selbackColor=0;
   seltextColor=0;
-  itemWidth=1;
-  itemHeight=1;
+  listWidth=0;
+  listHeight=0;
   visible=0;
   sortfunc=NULL;
   grabx=0;
@@ -339,8 +321,8 @@ FXList::FXList(FXComposite *p,FXint nvis,FXObject* tgt,FXSelector sel,FXuint opt
   textColor=getApp()->getForeColor();
   selbackColor=getApp()->getSelbackColor();
   seltextColor=getApp()->getSelforeColor();
-  itemWidth=1;
-  itemHeight=1;
+  listWidth=0;
+  listHeight=0;
   visible=FXMAX(nvis,0);
   sortfunc=NULL;
   grabx=0;
@@ -373,6 +355,20 @@ void FXList::detach(){
 FXbool FXList::canFocus() const { return TRUE; }
 
 
+// Into focus chain
+void FXList::setFocus(){
+  FXScrollArea::setFocus();
+  setDefault(TRUE);
+  }
+
+
+// Out of focus chain
+void FXList::killFocus(){
+  FXScrollArea::killFocus();
+  setDefault(MAYBE);
+  }
+
+
 // Get default width
 FXint FXList::getDefaultWidth(){
   return FXScrollArea::getDefaultWidth();
@@ -406,15 +402,20 @@ void FXList::setNumVisible(FXint nvis){
 
 // Recompute interior
 void FXList::recompute(){
-  register FXint w,h,i;
-  itemWidth=1;
-  itemHeight=1;
+  register FXint x,y,w,h,i;
+  x=0;
+  y=0;
+  listWidth=0;
+  listHeight=0;
   for(i=0; i<nitems; i++){
+    items[i]->x=x;
+    items[i]->y=y;
     w=items[i]->getWidth(this);
     h=items[i]->getHeight(this);
-    if(w>itemWidth) itemWidth=w;
-    if(h>itemHeight) itemHeight=h;
+    if(w>listWidth) listWidth=w;
+    y+=h;
     }
+  listHeight=y;
   flags&=~FLAG_RECALC;
   }
 
@@ -422,14 +423,14 @@ void FXList::recompute(){
 // Determine content width of list
 FXint FXList::getContentWidth(){
   if(flags&FLAG_RECALC) recompute();
-  return itemWidth;
+  return listWidth;
   }
 
 
 // Determine content height of list
 FXint FXList::getContentHeight(){
   if(flags&FLAG_RECALC) recompute();
-  return nitems*itemHeight;
+  return listHeight;
   }
 
 
@@ -443,8 +444,10 @@ void FXList::layout(){
   FXScrollArea::layout();
 
   // Determine line size for scroll bars
-  vertical->setLine(itemHeight);
-  horizontal->setLine(1);
+  if(0<nitems){
+    vertical->setLine(items[0]->getHeight(this));
+    horizontal->setLine(items[0]->getWidth(this)/10);
+    }
 
   update();
 
@@ -521,29 +524,48 @@ FXbool FXList::isItemEnabled(FXint index) const {
 // True if item (partially) visible
 FXbool FXList::isItemVisible(FXint index) const {
   if(index<0 || nitems<=index){ fxerror("%s::isItemVisible: index out of range.\n",getClassName()); }
-  return (0 < (pos_y+index*itemHeight+itemHeight)) && ((pos_y+index*itemHeight) < viewport_h);
+  return (0 < (pos_y+items[index]->y+items[index]->getHeight(this))) && ((pos_y+items[index]->y) < viewport_h);
   }
 
 
 // Make item fully visible
 void FXList::makeItemVisible(FXint index){
+  FXint y,h;
   if(xid==0) return;
   if(0<=index && index<nitems){
-    if((pos_y+index*itemHeight) < 0){
-      setPosition(pos_x,-index*itemHeight);
-      }
-    else if(viewport_h<=(pos_y+index*itemHeight+itemHeight)){
-      setPosition(pos_x,viewport_h-index*itemHeight-itemHeight);
-      }
+    y=pos_y;
+    h=items[index]->getHeight(this);
+    if(viewport_h<=y+items[index]->y+h) y=viewport_h-items[index]->y-h;
+    if(y+items[index]->y<=0) y=-items[index]->y;
+    setPosition(pos_x,y);
     }
   }
 
 
+// Return item width
+FXint FXList::getItemWidth(FXint index) const {
+  if(index<0 || nitems<=index){ fxerror("%s::getItemWidth: index out of range.\n",getClassName()); }
+  return items[index]->getWidth(this);
+  }
+
+
+// Return item height
+FXint FXList::getItemHeight(FXint index) const {
+  if(index<0 || nitems<=index){ fxerror("%s::getItemHeight: index out of range.\n",getClassName()); }
+  return items[index]->getHeight(this);
+  }
+
+
 // Get item at position x,y
 FXint FXList::getItemAt(FXint,FXint y) const {
-  FXint index=(y-pos_y)/itemHeight;
-  if(index<0 || index>=nitems) index=-1;
-  return index;
+  register FXint index;
+  y-=pos_y;
+  for(index=0; index<nitems; index++){
+    if(items[index]->y<y && y<items[index]->y+items[index]->getHeight(this)){
+      return index;
+      }
+    }
+  return -1;
   }
 
 
@@ -553,8 +575,8 @@ FXint FXList::hitItem(FXint index,FXint x,FXint y) const {
   if(0<=index && index<nitems){
     x-=pos_x;
     y-=pos_y;
-    ix=0;
-    iy=itemHeight*index;
+    ix=items[index]->x;
+    iy=items[index]->y;
     hit=items[index]->hitItem(this,x-ix,y-iy);
     }
   return hit;
@@ -564,7 +586,7 @@ FXint FXList::hitItem(FXint index,FXint x,FXint y) const {
 // Repaint
 void FXList::updateItem(FXint index){
   if(0<=index && index<nitems){
-    update(0,pos_y+index*itemHeight,viewport_w,itemHeight);
+    update(0,pos_y+items[index]->y,viewport_w,items[index]->getHeight(this));
     }
   }
 
@@ -605,7 +627,7 @@ FXbool FXList::selectItem(FXint index,FXbool notify){
       case LIST_MULTIPLESELECT:
         items[index]->setSelected(TRUE);
         updateItem(index);
-        if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)index);}
+        if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)(FXival)index);}
         break;
       }
     return TRUE;
@@ -624,7 +646,7 @@ FXbool FXList::deselectItem(FXint index,FXbool notify){
       case LIST_SINGLESELECT:
         items[index]->setSelected(FALSE);
         updateItem(index);
-        if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)index);}
+        if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)(FXival)index);}
         break;
       }
     return TRUE;
@@ -642,7 +664,7 @@ FXbool FXList::toggleItem(FXint index,FXbool notify){
         killSelection(notify);
         items[index]->setSelected(TRUE);
         updateItem(index);
-        if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)index);}
+        if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)(FXival)index);}
         }
       break;
     case LIST_SINGLESELECT:
@@ -650,12 +672,12 @@ FXbool FXList::toggleItem(FXint index,FXbool notify){
         killSelection(notify);
         items[index]->setSelected(TRUE);
         updateItem(index);
-        if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)index);}
+        if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)(FXival)index);}
         }
       else{
         items[index]->setSelected(FALSE);
         updateItem(index);
-        if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)index);}
+        if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)(FXival)index);}
         }
       break;
     case LIST_EXTENDEDSELECT:
@@ -663,12 +685,12 @@ FXbool FXList::toggleItem(FXint index,FXbool notify){
       if(!items[index]->isSelected()){
         items[index]->setSelected(TRUE);
         updateItem(index);
-        if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)index);}
+        if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)(FXival)index);}
         }
       else{
         items[index]->setSelected(FALSE);
         updateItem(index);
-        if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)index);}
+        if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)(FXival)index);}
         }
       break;
     }
@@ -678,7 +700,7 @@ FXbool FXList::toggleItem(FXint index,FXbool notify){
 
 // Update value from a message
 long FXList::onCmdSetValue(FXObject*,FXSelector,void* ptr){
-  setCurrentItem((FXint)(long)ptr);
+  setCurrentItem((FXint)(FXival)ptr);
   return 1;
   }
 
@@ -709,7 +731,7 @@ long FXList::onEnter(FXObject* sender,FXSelector sel,void* ptr){
 // Leave window
 long FXList::onLeave(FXObject* sender,FXSelector sel,void* ptr){
   FXScrollArea::onLeave(sender,sel,ptr);
-  if(timer){getApp()->removeTimeout(timer);timer=NULL;}
+  if(timer){timer=getApp()->removeTimeout(timer);}
   cursor=-1;
   return 1;
   }
@@ -743,16 +765,19 @@ long FXList::onFocusOut(FXObject* sender,FXSelector sel,void* ptr){
 long FXList::onPaint(FXObject*,FXSelector,void* ptr){
   FXEvent* event=(FXEvent*)ptr;
   FXDCWindow dc(this,event);
-  FXint indexlo=(event->rect.y-pos_y)/itemHeight;
-  FXint indexhi=(event->rect.y+event->rect.h-pos_y)/itemHeight;
-  FXint i,y;
-  if(indexlo<0) indexlo=0;
-  if(indexhi>=nitems) indexhi=nitems-1;
-  y=pos_y+indexlo*itemHeight;
-  for(i=indexlo; i<=indexhi; i++){
-    items[i]->draw(this,dc,pos_x,y,content_w,itemHeight);
-    y+=itemHeight;
+  FXint i,y,h;
+
+  // Paint items
+  y=pos_y;
+  for(i=0; i<nitems; i++){
+    h=items[i]->getHeight(this);
+    if(event->rect.y<=y+h && y<event->rect.y+event->rect.h){
+      items[i]->draw(this,dc,pos_x,y,content_w,h);
+      }
+    y+=h;
     }
+
+  // Paint blank area below items
   if(y<event->rect.y+event->rect.h){
     dc.setForeground(backColor);
     dc.fillRectangle(event->rect.x,y,event->rect.w,event->rect.y+event->rect.h-y);
@@ -763,7 +788,6 @@ long FXList::onPaint(FXObject*,FXSelector,void* ptr){
 
 // We timed out, i.e. the user didn't move for a while
 long FXList::onTipTimer(FXObject*,FXSelector,void*){
-  FXTRACE((250,"%s::onTipTimer %p\n",getClassName(),this));
   timer=NULL;
   flags|=FLAG_TIP;
   return 1;
@@ -794,7 +818,6 @@ long FXList::onQueryTip(FXObject* sender,FXSelector,void*){
 // We were asked about status text
 long FXList::onQueryHelp(FXObject* sender,FXSelector,void*){
   if(!help.empty() && (flags&FLAG_HELP)){
-    FXTRACE((250,"%s::onQueryHelp %p\n",getClassName(),this));
     sender->handle(this,MKUINT(ID_SETSTRINGVALUE,SEL_COMMAND),(void*)&help);
     return 1;
     }
@@ -806,130 +829,138 @@ long FXList::onQueryHelp(FXObject* sender,FXSelector,void*){
 long FXList::onKeyPress(FXObject*,FXSelector,void* ptr){
   FXEvent* event=(FXEvent*)ptr;
   FXint index=current;
-  char entry;
   flags&=~FLAG_TIP;
-  if(isEnabled()){
-    flags&=~FLAG_UPDATE;
-    if(target && target->handle(this,MKUINT(message,SEL_KEYPRESS),ptr)) return 1;
-    if(index<0) index=0;
-    switch(event->code){
-      case KEY_Page_Up:
-      case KEY_KP_Page_Up:
-        lookup=FXString::null;
-        setPosition(pos_x,pos_y+verticalScrollbar()->getPage());
-        return 1;
-      case KEY_Page_Down:
-      case KEY_KP_Page_Down:
-        lookup=FXString::null;
-        setPosition(pos_x,pos_y-verticalScrollbar()->getPage());
-        return 1;
-      case KEY_Up:
-      case KEY_KP_Up:
-        index-=1;
-        goto hop;
-      case KEY_Down:
-      case KEY_KP_Down:
-        index+=1;
-        goto hop;
-      case KEY_Home:
-      case KEY_KP_Home:
-        index=0;
-        goto hop;
-      case KEY_End:
-      case KEY_KP_End:
-        index=nitems-1;
-hop:    lookup=FXString::null;
-        if(0<=index && index<nitems){
-          setCurrentItem(index,TRUE);
-          makeItemVisible(index);
+  if(!isEnabled()) return 0;
+  if(target && target->handle(this,MKUINT(message,SEL_KEYPRESS),ptr)) return 1;
+  if(index<0) index=0;
+  switch(event->code){
+    case KEY_Control_L:
+    case KEY_Control_R:
+    case KEY_Shift_L:
+    case KEY_Shift_R:
+    case KEY_Alt_L:
+    case KEY_Alt_R:
+      if(flags&FLAG_DODRAG){handle(this,MKUINT(0,SEL_DRAGGED),ptr);}
+      return 1;
+    case KEY_Page_Up:
+    case KEY_KP_Page_Up:
+      lookup=FXString::null;
+      setPosition(pos_x,pos_y+verticalScrollbar()->getPage());
+      return 1;
+    case KEY_Page_Down:
+    case KEY_KP_Page_Down:
+      lookup=FXString::null;
+      setPosition(pos_x,pos_y-verticalScrollbar()->getPage());
+      return 1;
+    case KEY_Up:
+    case KEY_KP_Up:
+      index-=1;
+      goto hop;
+    case KEY_Down:
+    case KEY_KP_Down:
+      index+=1;
+      goto hop;
+    case KEY_Home:
+    case KEY_KP_Home:
+      index=0;
+      goto hop;
+    case KEY_End:
+    case KEY_KP_End:
+      index=nitems-1;
+hop:  lookup=FXString::null;
+      if(0<=index && index<nitems){
+        setCurrentItem(index,TRUE);
+        makeItemVisible(index);
+        if(items[index]->isEnabled()){
           if((options&SELECT_MASK)==LIST_EXTENDEDSELECT){
-            if(items[index]->isEnabled()){
-              if(event->state&SHIFTMASK){
-                if(0<=anchor){
-                  selectItem(anchor,TRUE);
-                  extendSelection(index,TRUE);
-                  }
-                else{
-                  selectItem(index,TRUE);
-                  setAnchorItem(index);
-                  }
+            if(event->state&SHIFTMASK){
+              if(0<=anchor){
+                selectItem(anchor,TRUE);
+                extendSelection(index,TRUE);
                 }
-              else if(!(event->state&CONTROLMASK)){
-                killSelection(TRUE);
+              else{
                 selectItem(index,TRUE);
                 setAnchorItem(index);
                 }
               }
-            }
-          }
-        return 1;
-      case KEY_space:
-      case KEY_KP_Space:
-        lookup=FXString::null;
-        if(0<=index && items[index]->isEnabled()){
-          switch(options&SELECT_MASK){
-            case LIST_EXTENDEDSELECT:
-              if(event->state&SHIFTMASK){
-                if(0<=anchor){
-                  selectItem(anchor,TRUE);
-                  extendSelection(index,TRUE);
-                  }
-                else{
-                  selectItem(index,TRUE);
-                  }
-                }
-              else if(event->state&CONTROLMASK){
-                toggleItem(index,TRUE);
-                }
-              else{
-                killSelection(TRUE);
-                selectItem(index,TRUE);
-                }
-              break;
-            case LIST_MULTIPLESELECT:
-            case LIST_SINGLESELECT:
-              toggleItem(index,TRUE);
-              break;
-            }
-          setAnchorItem(index);
-          }
-        return 1;
-      case KEY_Return:
-      case KEY_KP_Enter:
-        lookup=FXString::null;
-        return 1;
-      case KEY_Control_L:
-      case KEY_Control_R:
-      case KEY_Shift_L:
-      case KEY_Shift_R:
-      case KEY_Alt_L:
-      case KEY_Alt_R:
-        if(flags&FLAG_DODRAG){handle(this,MKUINT(0,SEL_DRAGGED),ptr);}
-        return 1;
-      default:
-        if(!(event->state&(CONTROLMASK|ALTMASK))){
-          entry=fxkeyval(event->code,event->state);
-          if(' '<=(FXuchar)entry){
-            lookup.append(entry);
-            if(lookuptimer) getApp()->removeTimeout(lookuptimer);
-            lookuptimer=getApp()->addTimeout(getApp()->getTypingSpeed(),this,ID_LOOKUPTIMER);
-            index=findItem(lookup,current,SEARCH_FORWARD|SEARCH_WRAP|SEARCH_PREFIX);
-            if(0<=index){
-              setCurrentItem(index,TRUE);
-              makeItemVisible(index);
-              if((options&SELECT_MASK)==LIST_EXTENDEDSELECT){
-                if(items[index]->isEnabled()){
-                  killSelection(TRUE);
-                  selectItem(index,TRUE);
-                  }
-                }
+            else if(!(event->state&CONTROLMASK)){
+              killSelection(TRUE);
+              selectItem(index,TRUE);
               setAnchorItem(index);
               }
-            return 1;
             }
           }
-        break;
-      }
+        }
+      handle(this,MKUINT(0,SEL_CLICKED),(void*)(FXival)current);
+      if(0<=current && items[current]->isEnabled()){
+        handle(this,MKUINT(0,SEL_COMMAND),(void*)(FXival)current);
+        }
+      return 1;
+    case KEY_space:
+    case KEY_KP_Space:
+      lookup=FXString::null;
+      if(0<=current && items[current]->isEnabled()){
+        switch(options&SELECT_MASK){
+          case LIST_EXTENDEDSELECT:
+            if(event->state&SHIFTMASK){
+              if(0<=anchor){
+                selectItem(anchor,TRUE);
+                extendSelection(current,TRUE);
+                }
+              else{
+                selectItem(current,TRUE);
+                }
+              }
+            else if(event->state&CONTROLMASK){
+              toggleItem(current,TRUE);
+              }
+            else{
+              killSelection(TRUE);
+              selectItem(current,TRUE);
+              }
+            break;
+          case LIST_MULTIPLESELECT:
+          case LIST_SINGLESELECT:
+            toggleItem(current,TRUE);
+            break;
+          }
+        setAnchorItem(current);
+        }
+      handle(this,MKUINT(0,SEL_CLICKED),(void*)(FXival)current);
+      if(0<=current && items[current]->isEnabled()){
+        handle(this,MKUINT(0,SEL_COMMAND),(void*)(FXival)current);
+        }
+      return 1;
+    case KEY_Return:
+    case KEY_KP_Enter:
+      lookup=FXString::null;
+      handle(this,MKUINT(0,SEL_DOUBLECLICKED),(void*)(FXival)current);
+      if(0<=current && items[current]->isEnabled()){
+        handle(this,MKUINT(0,SEL_COMMAND),(void*)(FXival)current);
+        }
+      return 1;
+    default:
+      if((event->state&(CONTROLMASK|ALTMASK)) || !isprint((FXuchar)event->text[0])) return 0;
+      lookup.append(event->text);
+      if(lookuptimer) getApp()->removeTimeout(lookuptimer);
+      lookuptimer=getApp()->addTimeout(getApp()->getTypingSpeed(),this,ID_LOOKUPTIMER);
+      index=findItem(lookup,current,SEARCH_FORWARD|SEARCH_WRAP|SEARCH_PREFIX);
+      if(0<=index){
+	setCurrentItem(index,TRUE);
+	makeItemVisible(index);
+	if((options&SELECT_MASK)==LIST_EXTENDEDSELECT){
+	  if(items[index]->isEnabled()){
+	    killSelection(TRUE);
+	    selectItem(index,TRUE);
+	    }
+	  }
+	setAnchorItem(index);
+        }
+      handle(this,MKUINT(0,SEL_CLICKED),(void*)(FXival)current);
+      if(0<=current && items[current]->isEnabled()){
+	handle(this,MKUINT(0,SEL_COMMAND),(void*)(FXival)current);
+	}
+      return 1;
     }
   return 0;
   }
@@ -938,70 +969,17 @@ hop:    lookup=FXString::null;
 // Key Release
 long FXList::onKeyRelease(FXObject*,FXSelector,void* ptr){
   FXEvent* event=(FXEvent*)ptr;
-  char entry;
-  if(isEnabled()){
-    flags|=FLAG_UPDATE;
-    if(target && target->handle(this,MKUINT(message,SEL_KEYRELEASE),ptr)) return 1;
-    switch(event->code){
-      case KEY_Page_Up:
-      case KEY_KP_Page_Up:
-      case KEY_Page_Down:
-      case KEY_KP_Page_Down:
-        return 1;
-      case KEY_Up:
-      case KEY_KP_Up:
-      case KEY_Down:
-      case KEY_KP_Down:
-      case KEY_Home:
-      case KEY_KP_Home:
-      case KEY_End:
-      case KEY_KP_End:
-        if((options&SELECT_MASK)==LIST_BROWSESELECT){
-          handle(this,MKUINT(0,SEL_CLICKED),(void*)current);
-          if(0<=current && items[current]->isEnabled()){
-            handle(this,MKUINT(0,SEL_COMMAND),(void*)current);
-            }
-          }
-        return 1;
-      case KEY_space:
-      case KEY_KP_Space:
-        if((options&SELECT_MASK)!=LIST_BROWSESELECT){
-          handle(this,MKUINT(0,SEL_CLICKED),(void*)current);
-          if(0<=current && items[current]->isEnabled()){
-            handle(this,MKUINT(0,SEL_COMMAND),(void*)current);
-            }
-          }
-        return 1;
-      case KEY_Return:
-      case KEY_KP_Enter:
-        handle(this,MKUINT(0,SEL_DOUBLECLICKED),(void*)current);
-        if(0<=current && items[current]->isEnabled()){
-          handle(this,MKUINT(0,SEL_COMMAND),(void*)current);
-          }
-        return 1;
-      case KEY_Shift_L:
-      case KEY_Shift_R:
-      case KEY_Control_L:
-      case KEY_Control_R:
-      case KEY_Alt_L:
-      case KEY_Alt_R:
-        if(flags&FLAG_DODRAG){handle(this,MKUINT(0,SEL_DRAGGED),ptr);}
-        return 1;
-      default:
-        if(!(event->state&(CONTROLMASK|ALTMASK))){
-          entry=fxkeyval(event->code,event->state);
-          if(' '<=(FXuchar)entry){
-            if((options&SELECT_MASK)==LIST_BROWSESELECT){
-              handle(this,MKUINT(0,SEL_CLICKED),(void*)current);
-              if(0<=current && items[current]->isEnabled()){
-                handle(this,MKUINT(0,SEL_COMMAND),(void*)current);
-                }
-              }
-            return 1;
-            }
-          }
-        break;
-      }
+  if(!isEnabled()) return 0;
+  if(target && target->handle(this,MKUINT(message,SEL_KEYRELEASE),ptr)) return 1;
+  switch(event->code){
+    case KEY_Shift_L:
+    case KEY_Shift_R:
+    case KEY_Control_L:
+    case KEY_Control_R:
+    case KEY_Alt_L:
+    case KEY_Alt_R:
+      if(flags&FLAG_DODRAG){handle(this,MKUINT(0,SEL_DRAGGED),ptr);}
+      return 1;
     }
   return 0;
   }
@@ -1136,7 +1114,6 @@ long FXList::onLeftBtnPress(FXObject*,FXSelector,void* ptr){
 
     // Locate item
     index=getItemAt(event->win_x,event->win_y);
-    code=hitItem(index,event->win_x,event->win_y);
 
     // No item
     if(index<0) return 1;
@@ -1238,18 +1215,18 @@ long FXList::onLeftBtnRelease(FXObject*,FXSelector,void* ptr){
 
     // Generate clicked callbacks
     if(event->click_count==1){
-      handle(this,MKUINT(0,SEL_CLICKED),(void*)current);
+      handle(this,MKUINT(0,SEL_CLICKED),(void*)(FXival)current);
       }
     else if(event->click_count==2){
-      handle(this,MKUINT(0,SEL_DOUBLECLICKED),(void*)current);
+      handle(this,MKUINT(0,SEL_DOUBLECLICKED),(void*)(FXival)current);
       }
     else if(event->click_count==3){
-      handle(this,MKUINT(0,SEL_TRIPLECLICKED),(void*)current);
+      handle(this,MKUINT(0,SEL_TRIPLECLICKED),(void*)(FXival)current);
       }
 
     // Command callback only when clicked on item
     if(0<=current && items[current]->isEnabled()){
-      handle(this,MKUINT(0,SEL_COMMAND),(void*)current);
+      handle(this,MKUINT(0,SEL_COMMAND),(void*)(FXival)current);
       }
     return 1;
     }
@@ -1346,7 +1323,7 @@ FXbool FXList::extendSelection(FXint index,FXbool notify){
           items[i]->setSelected(TRUE);
           updateItem(i);
           changes=TRUE;
-          if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)i);}
+          if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)(FXival)i);}
           }
         }
 
@@ -1357,7 +1334,7 @@ FXbool FXList::extendSelection(FXint index,FXbool notify){
           items[i]->setSelected(FALSE);
           updateItem(i);
           changes=TRUE;
-          if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)i);}
+          if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)(FXival)i);}
           }
         }
       }
@@ -1372,7 +1349,7 @@ FXbool FXList::extendSelection(FXint index,FXbool notify){
           items[i]->setSelected(TRUE);
           updateItem(i);
           changes=TRUE;
-          if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)i);}
+          if(notify && target){target->handle(this,MKUINT(message,SEL_SELECTED),(void*)(FXival)i);}
           }
         }
 
@@ -1383,7 +1360,7 @@ FXbool FXList::extendSelection(FXint index,FXbool notify){
           items[i]->setSelected(FALSE);
           updateItem(i);
           changes=TRUE;
-          if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)i);}
+          if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)(FXival)i);}
           }
         }
       }
@@ -1402,7 +1379,7 @@ FXbool FXList::killSelection(FXbool notify){
       items[i]->setSelected(FALSE);
       updateItem(i);
       changes=TRUE;
-      if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)i);}
+      if(notify && target){target->handle(this,MKUINT(message,SEL_DESELECTED),(void*)(FXival)i);}
       }
     }
   return changes;
@@ -1421,28 +1398,32 @@ FXint FXList::descending(const FXListItem* a,const FXListItem* b){
   }
 
 
-// Sort the items based on the sort function
+// Sort the items based on the sort function.
 void FXList::sortItems(){
-  register FXListItem *v;
+  register FXListItem *v,*c;
   register FXint i,j,h;
-  register FXbool exch=FALSE;
   if(sortfunc){
+    if(0<=current){
+      c=items[current];
+      }
     for(h=1; h<=nitems/9; h=3*h+1);
-    if(hasFocus() && 0<=current) items[current]->setFocus(FALSE);
     for(; h>0; h/=3){
       for(i=h+1;i<=nitems;i++){
         v=items[i-1];
         j=i;
         while(j>h && sortfunc(items[j-h-1],v)>0){
           items[j-1]=items[j-h-1];
-          exch=TRUE;
           j-=h;
           }
         items[j-1]=v;
         }
       }
-    if(hasFocus() && 0<=current) items[current]->setFocus(TRUE);
-    if(exch) update();
+    if(0<=current){
+      for(i=0; i<nitems; i++){
+        if(items[i]==c){ current=i; break; }
+        }
+      }
+    recalc();
     }
   }
 
@@ -1475,7 +1456,7 @@ void FXList::setCurrentItem(FXint index,FXbool notify){
       }
 
     // Notify item change
-    if(notify && target){target->handle(this,MKUINT(message,SEL_CHANGED),(void*)current);}
+    if(notify && target){target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)current);}
     }
 
   // In browse select mode, select this item
@@ -1516,7 +1497,7 @@ FXint FXList::replaceItem(FXint index,FXListItem* item,FXbool notify){
   if(index<0 || nitems<=index){ fxerror("%s::replaceItem: index out of range.\n",getClassName()); }
 
   // Notify item will be replaced
-  if(notify && target){target->handle(this,MKUINT(message,SEL_REPLACED),(void*)index);}
+  if(notify && target){target->handle(this,MKUINT(message,SEL_REPLACED),(void*)(FXival)index);}
 
   // Copy the state over
   item->state=items[index]->state;
@@ -1562,11 +1543,11 @@ FXint FXList::insertItem(FXint index,FXListItem* item,FXbool notify){
   if(current<0 && nitems==1) current=0;
 
   // Notify item has been inserted
-  if(notify && target){target->handle(this,MKUINT(message,SEL_INSERTED),(void*)index);}
+  if(notify && target){target->handle(this,MKUINT(message,SEL_INSERTED),(void*)(FXival)index);}
 
   // Current item may have changed
   if(old!=current){
-    if(notify && target){target->handle(this,MKUINT(message,SEL_CHANGED),(void*)current);}
+    if(notify && target){target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)current);}
     }
 
   // Was new item
@@ -1622,7 +1603,7 @@ void FXList::removeItem(FXint index,FXbool notify){
   if(index<0 || nitems<=index){ fxerror("%s::removeItem: index out of range.\n",getClassName()); }
 
   // Notify item will be deleted
-  if(notify && target){target->handle(this,MKUINT(message,SEL_DELETED),(void*)index);}
+  if(notify && target){target->handle(this,MKUINT(message,SEL_DELETED),(void*)(FXival)index);}
 
   // Remove item from list
   nitems--;
@@ -1635,8 +1616,8 @@ void FXList::removeItem(FXint index,FXbool notify){
   if(current>index || current>=nitems) current--;
 
   // Current item has changed
-  if(old!=current){
-    if(notify && target){target->handle(this,MKUINT(message,SEL_CHANGED),(void*)current);}
+  if(index<=old){
+    if(notify && target){target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)current);}
     }
 
   // Deleted current item
@@ -1656,12 +1637,15 @@ void FXList::removeItem(FXint index,FXbool notify){
 
 // Remove all items
 void FXList::clearItems(FXbool notify){
+  register FXint old=current;
 
   // Delete items
-  for(FXint index=0; index<nitems; index++){
-    if(notify && target){target->handle(this,MKUINT(message,SEL_DELETED),(void*)index);}
+  for(FXint index=nitems-1; 0<=index; index--){
+    if(notify && target){target->handle(this,MKUINT(message,SEL_DELETED),(void*)(FXival)index);}
     delete items[index];
     }
+
+  // Free array
   FXFREE(&items);
   nitems=0;
 
@@ -1671,7 +1655,9 @@ void FXList::clearItems(FXbool notify){
   extent=-1;
 
   // Current item has changed
-  if(notify && target){target->handle(this,MKUINT(message,SEL_CHANGED),(void*)-1);}
+  if(old!=current){
+    if(notify && target){target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)-1);}
+    }
 
   // Redo layout
   recalc();
@@ -1726,22 +1712,28 @@ void FXList::setFont(FXFont* fnt){
 
 // Set text color
 void FXList::setTextColor(FXColor clr){
-  textColor=clr;
-  update();
+  if(textColor!=clr){
+    textColor=clr;
+    update();
+    }
   }
 
 
 // Set select background color
 void FXList::setSelBackColor(FXColor clr){
-  selbackColor=clr;
-  update();
+  if(selbackColor!=clr){
+    selbackColor=clr;
+    update();
+    }
   }
 
 
 // Set selected text color
 void FXList::setSelTextColor(FXColor clr){
-  seltextColor=clr;
-  update();
+  if(seltextColor!=clr){
+    seltextColor=clr;
+    update();
+    }
   }
 
 
@@ -1775,8 +1767,8 @@ void FXList::save(FXStream& store) const {
   store << textColor;
   store << selbackColor;
   store << seltextColor;
-  store << itemWidth;
-  store << itemHeight;
+  store << listWidth;
+  store << listHeight;
   store << visible;
   store << font;
   store << help;
@@ -1796,8 +1788,8 @@ void FXList::load(FXStream& store){
   store >> textColor;
   store >> selbackColor;
   store >> seltextColor;
-  store >> itemWidth;
-  store >> itemHeight;
+  store >> listWidth;
+  store >> listHeight;
   store >> visible;
   store >> font;
   store >> help;
