@@ -3,7 +3,7 @@
 *          M u l t i p l e   D o c u m e n t   C h i l d   W i n d o w          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMDIChild.cpp,v 1.33 2001/07/17 07:25:02 jeroen Exp $                   *
+* $Id: FXMDIChild.cpp,v 1.36.4.1 2002/07/17 01:58:32 fox Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -29,18 +29,11 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
 #include "FXFont.h"
-#include "FXDrawable.h"
-#include "FXImage.h"
 #include "FXIcon.h"
 #include "FXGIFIcon.h"
 #include "FXWindow.h"
@@ -495,7 +488,7 @@ void FXMDIChild::drawRubberBox(FXint x,FXint y,FXint w,FXint h){
     dc.setFunction(BLT_SRC_XOR_DST);
     dc.setForeground(getParent()->getBackColor());
     translateCoordinatesTo(xx,yy,getParent(),x,y);
-    //dc.drawHashBox(xx,yy,w,h,BORDERWIDTH);
+   // dc.drawHashBox(xx,yy,w,h,BORDERWIDTH);
     dc.setLineWidth(BORDERWIDTH);
     dc.drawRectangle(xx+BORDERWIDTH/2,yy+BORDERWIDTH/2,w-BORDERWIDTH,h-BORDERWIDTH);
     }
@@ -520,10 +513,10 @@ void FXMDIChild::animateRectangles(FXint ox,FXint oy,FXint ow,FXint oh,FXint nx,
         getApp()->flush(TRUE);
         fxsleep(getApp()->getAnimSpeed()*1000);
         dc.drawHashBox(bx,by,bw,bh,BORDERWIDTH);
-        getApp()->flush(TRUE);    
+        getApp()->flush(TRUE);
         }
       }
-    } 
+    }
   }
 
 
@@ -1128,43 +1121,55 @@ long FXMDIChild::onUpdMenuWindow(FXObject* sender,FXSelector,void*){
 
 // Set base color
 void FXMDIChild::setBaseColor(FXColor clr){
-  baseColor=clr;
-  update();
+  if(baseColor!=clr){
+    baseColor=clr;
+    update();
+    }
   }
 
 
 // Set highlight color
 void FXMDIChild::setHiliteColor(FXColor clr){
-  hiliteColor=clr;
-  update();
+  if(hiliteColor!=clr){
+    hiliteColor=clr;
+    update();
+    }
   }
 
 
 // Set shadow color
 void FXMDIChild::setShadowColor(FXColor clr){
-  shadowColor=clr;
-  update();
+  if(shadowColor!=clr){
+    shadowColor=clr;
+    update();
+    }
   }
 
 
 // Set border color
 void FXMDIChild::setBorderColor(FXColor clr){
-  borderColor=clr;
-  update();
+  if(borderColor!=clr){
+    borderColor=clr;
+    update();
+    }
   }
 
 
 // Set title color
 void FXMDIChild::setTitleColor(FXColor clr){
-  titleColor=clr;
-  update();
+  if(titleColor!=clr){
+    titleColor=clr;
+    update();
+    }
   }
 
 
 // Set title color
 void FXMDIChild::setTitleBackColor(FXColor clr){
-  titleBackColor=clr;
-  update();
+  if(titleBackColor!=clr){
+    titleBackColor=clr;
+    update();
+    }
   }
 
 
