@@ -3,7 +3,7 @@
 *                     M a i n   W i n d o w   O b j e c t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMainWindow.cpp,v 1.10 2001/04/27 14:30:34 jeroen Exp $                  *
+* $Id: FXMainWindow.cpp,v 1.13 2002/01/18 22:43:01 jeroen Exp $                 *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -29,21 +29,11 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXApp.h"
-#include "FXId.h"
 #include "FXCursor.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
-#include "FXComposite.h"
 #include "FXRootWindow.h"
-#include "FXShell.h"
-#include "FXTopWindow.h"
 #include "FXMainWindow.h"
 
 /*
