@@ -3,7 +3,7 @@
 *                   M a t r i x   C o n t a i n e r   O b j e c t               *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMatrix.cpp,v 1.13 2001/06/06 14:23:09 jeroen Exp $                     *
+* $Id: FXMatrix.cpp,v 1.17.4.1 2002/05/31 15:00:46 fox Exp $                     *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -29,17 +29,8 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
-#include "FXComposite.h"
-#include "FXPacker.h"
 #include "FXMatrix.h"
 
 
@@ -55,7 +46,7 @@
   - We should probably change layout so hidden children do not
     affect numbering (but if all children in a row/column are
     hidden, make the whole row disappear!).
-  - Navigating around 
+  - Navigating around
   - Packing order:
 
     MATRIX_BY_ROWS:
@@ -67,7 +58,7 @@
     [1] [2] [3]
     [4] [5] [6]
     [7] [8] [9]
-    
+
 
 */
 
@@ -99,7 +90,12 @@ FXMatrix::FXMatrix(FXComposite* p,FXint n,FXuint opts,FXint x,FXint y,FXint w,FX
 
 // Find child at given row, column
 FXWindow* FXMatrix::childAtRowCol(FXint r,FXint c) const {
-  return (options&MATRIX_BY_COLUMNS) ? childAtIndex(num*r+c) : childAtIndex(r+num*c);
+  if(options&MATRIX_BY_COLUMNS){
+    return (0<=c && c<num) ? childAtIndex(num*r+c) : NULL;
+    }
+  else{
+    return (0<=r && r<num) ? childAtIndex(r+num*c) : NULL;
+    }
   }
 
 
@@ -124,13 +120,14 @@ long FXMatrix::onFocusUp(FXObject*,FXSelector sel,void* ptr){
   if(getFocus()){
     r=rowOfChild(getFocus());
     c=colOfChild(getFocus());
-    child=childAtRowCol(r-1,c);
-    if(child){
-      if(child->isEnabled() && child->canFocus()){
-        child->handle(this,MKUINT(0,SEL_FOCUS_SELF),ptr);
-        return 1;
+    while((child=childAtRowCol(--r,c))!=NULL){
+      if(child->shown()){
+        if(child->isEnabled() && child->canFocus()){
+          child->handle(this,MKUINT(0,SEL_FOCUS_SELF),ptr);
+          return 1;
+          }
+        if(child->isComposite() && child->handle(this,sel,ptr)) return 1;
         }
-      if(child->isComposite() && child->handle(this,sel,ptr)) return 1;
       }
     }
   else{
@@ -157,14 +154,14 @@ long FXMatrix::onFocusDown(FXObject*,FXSelector sel,void* ptr){
   if(getFocus()){
     r=rowOfChild(getFocus());
     c=colOfChild(getFocus());
-    child=childAtRowCol(r+1,c);
-    FXTRACE((100,"r=%d c=%d child=%p\n",r,c,child));
-    if(child){
-      if(child->isEnabled() && child->canFocus()){
-        child->handle(this,MKUINT(0,SEL_FOCUS_SELF),ptr);
-        return 1;
+    while((child=childAtRowCol(++r,c))!=NULL){
+      if(child->shown()){
+        if(child->isEnabled() && child->canFocus()){
+          child->handle(this,MKUINT(0,SEL_FOCUS_SELF),ptr);
+          return 1;
+          }
+        if(child->isComposite() && child->handle(this,sel,ptr)) return 1;
         }
-      if(child->isComposite() && child->handle(this,sel,ptr)) return 1;
       }
     }
   else{
@@ -191,13 +188,14 @@ long FXMatrix::onFocusLeft(FXObject*,FXSelector sel,void* ptr){
   if(getFocus()){
     r=rowOfChild(getFocus());
     c=colOfChild(getFocus());
-    child=childAtRowCol(r,c-1);
-    if(child){
-      if(child->isEnabled() && child->canFocus()){
-        child->handle(this,MKUINT(0,SEL_FOCUS_SELF),ptr);
-        return 1;
+    while((child=childAtRowCol(r,--c))!=NULL){
+      if(child->shown()){
+        if(child->isEnabled() && child->canFocus()){
+          child->handle(this,MKUINT(0,SEL_FOCUS_SELF),ptr);
+          return 1;
+          }
+        if(child->isComposite() && child->handle(this,sel,ptr)) return 1;
         }
-      if(child->isComposite() && child->handle(this,sel,ptr)) return 1;
       }
     }
   else{
@@ -224,14 +222,14 @@ long FXMatrix::onFocusRight(FXObject*,FXSelector sel,void* ptr){
   if(getFocus()){
     r=rowOfChild(getFocus());
     c=colOfChild(getFocus());
-    child=childAtRowCol(r,c+1);
-    FXTRACE((100,"r=%d c=%d child=%p\n",r,c,child));
-    if(child){
-      if(child->isEnabled() && child->canFocus()){
-        child->handle(this,MKUINT(0,SEL_FOCUS_SELF),ptr);
-        return 1;
+    while((child=childAtRowCol(r,++c))!=NULL){
+      if(child->shown()){
+        if(child->isEnabled() && child->canFocus()){
+          child->handle(this,MKUINT(0,SEL_FOCUS_SELF),ptr);
+          return 1;
+          }
+        if(child->isComposite() && child->handle(this,sel,ptr)) return 1;
         }
-      if(child->isComposite() && child->handle(this,sel,ptr)) return 1;
       }
     }
   else{
@@ -260,11 +258,7 @@ void FXMatrix::setNumRows(FXint nr){
 
 // Get number of rows
 FXint FXMatrix::getNumRows() const {
-  register FXWindow *child;
-  register FXint n;
-  if(!(options&MATRIX_BY_COLUMNS)) return num;
-  for(child=getFirst(),n=0; child; child=child->getNext()){ if(child->shown()) n++; }
-  return (n+num-1)/num;
+  return (options&MATRIX_BY_COLUMNS) ? (numChildren()+num-1)/num : num;
   }
 
 
@@ -277,11 +271,7 @@ void FXMatrix::setNumColumns(FXint nc){
 
 // Get number of columns
 FXint FXMatrix::getNumColumns() const {
-  register FXWindow *child;
-  register FXint n;
-  if(options&MATRIX_BY_COLUMNS) return num;
-  for(child=getFirst(),n=0; child; child=child->getNext()){ if(child->shown()) n++; }
-  return (n+num-1)/num;
+  return (options&MATRIX_BY_COLUMNS) ? num : (numChildren()+num-1)/num;
   }
 
 
