@@ -3,7 +3,7 @@
 *                       M e n u    B u t t o n    O b j e c t                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMenuButton.cpp,v 1.22 2001/08/10 18:09:52 jeroen Exp $                 *
+* $Id: FXMenuButton.cpp,v 1.25.4.1 2002/07/08 15:16:58 fox Exp $                 *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,26 +30,13 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
 #include "FXFont.h"
-#include "FXDrawable.h"
-#include "FXImage.h"
 #include "FXIcon.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
-#include "FXLabel.h"
 #include "FXMenuButton.h"
-#include "FXComposite.h"
-#include "FXShell.h"
-#include "FXPopup.h"
 #include "FXMenuPane.h"
 
 /*
@@ -614,7 +601,7 @@ long FXMenuButton::onPaint(FXObject*,FXSelector,void* ptr){
       dc.setForeground(textColor);
       drawLabel(dc,label,hotoff,tx,ty,tw,th);
       if(hasFocus()){
-        drawFocusRectangle(dc,border+2,border+2,width-2*border-4,height-2*border-4);
+        dc.drawFocusRectangle(border+1,border+1,width-2*border-2,height-2*border-2);
         }
       }
     else{
