@@ -3,7 +3,7 @@
 *                       M e n u   C a s c a d e   W i d g e t                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMenuCascade.cpp,v 1.28 2001/08/10 18:09:52 jeroen Exp $                *
+* $Id: FXMenuCascade.cpp,v 1.32 2002/01/18 22:43:01 jeroen Exp $                *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,24 +30,12 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
 #include "FXFont.h"
-#include "FXDrawable.h"
-#include "FXImage.h"
 #include "FXIcon.h"
-#include "FXWindow.h"
-#include "FXComposite.h"
-#include "FXShell.h"
-#include "FXPopup.h"
 #include "FXMenuPane.h"
-#include "FXMenuCaption.h"
 #include "FXMenuCascade.h"
 
 /*
@@ -92,7 +80,7 @@ FXDEFMAP(FXMenuCascade) FXMenuCascadeMap[]={
 // Object implementation
 FXIMPLEMENT(FXMenuCascade,FXMenuCaption,FXMenuCascadeMap,ARRAYNUMBER(FXMenuCascadeMap))
 
-  
+
 // Make cascade menu button
 FXMenuCascade::FXMenuCascade(){
   flags|=FLAG_ENABLED;
@@ -345,9 +333,6 @@ long FXMenuCascade::onPaint(FXObject*,FXSelector,void* ptr){
       dc.setTextFont(font);
       dc.setForeground(isEnabled() ? seltextColor : shadowColor);
       dc.drawText(xx,yy,label.text(),label.length());
-      if(options&MENU_DEFAULT){
-        dc.drawText(xx+1,1+font->getFontAscent(),label.text(),label.length());
-        }
       if(0<=hotoff){
         dc.fillRectangle(xx+1+font->getTextWidth(&label[0],hotoff),yy+1,font->getTextWidth(&label[hotoff],1),1);
         }
@@ -370,9 +355,6 @@ long FXMenuCascade::onPaint(FXObject*,FXSelector,void* ptr){
       dc.setTextFont(font);
       dc.setForeground(textColor);
       dc.drawText(xx,yy,label.text(),label.length());
-      if(options&MENU_DEFAULT){
-        dc.drawText(xx+1,yy,label.text(),label.length());
-        }
       if(0<=hotoff){
         dc.fillRectangle(xx+1+font->getTextWidth(&label[0],hotoff),yy+1,font->getTextWidth(&label[hotoff],1),1);
         }
