@@ -3,7 +3,7 @@
 *                         M e n u   C o m m a n d    W i d g e t                *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMenuCommand.cpp,v 1.34 2001/08/10 18:09:52 jeroen Exp $                *
+* $Id: FXMenuCommand.cpp,v 1.39 2002/01/18 22:43:01 jeroen Exp $                *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,21 +30,12 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
 #include "FXFont.h"
-#include "FXDrawable.h"
-#include "FXImage.h"
 #include "FXIcon.h"
-#include "FXWindow.h"
-#include "FXMenuCaption.h"
 #include "FXMenuCommand.h"
 
 /*
@@ -95,7 +86,7 @@ FXDEFMAP(FXMenuCommand) FXMenuCommandMap[]={
 // Object implementation
 FXIMPLEMENT(FXMenuCommand,FXMenuCaption,FXMenuCommandMap,ARRAYNUMBER(FXMenuCommandMap))
 
-  
+
 // Command menu item
 FXMenuCommand::FXMenuCommand(){
   flags|=FLAG_ENABLED;
@@ -307,30 +298,6 @@ void FXMenuCommand::killFocus(){
   }
 
 
-// Show as default
-void FXMenuCommand::setDefault(){
-  if(!(options&MENU_DEFAULT)){
-    options|=MENU_DEFAULT;
-    update();
-    }
-  }
-
-
-// Show as other
-void FXMenuCommand::setOther(){
-  if(options&MENU_DEFAULT){
-    options&=~MENU_DEFAULT;
-    update();
-    }
-  }
-
-
-// See if its default
-FXint FXMenuCommand::isDefault() const {
-  return (options&MENU_DEFAULT)!=0;
-  }
-
-
 // Show checked
 void FXMenuCommand::check(){
   if(state!=MENUSTATE_CHECKED){
@@ -386,7 +353,7 @@ long FXMenuCommand::onPaint(FXObject*,FXSelector,void* ptr){
   FXint xx,yy;
 
   xx=LEADSPACE;
-  
+
   // Grayed out
   if(!isEnabled()){
     dc.setForeground(backColor);
@@ -435,10 +402,6 @@ long FXMenuCommand::onPaint(FXObject*,FXSelector,void* ptr){
       dc.setForeground(isEnabled() ? seltextColor : shadowColor);
       dc.drawText(xx,yy,label.text(),label.length());
       if(!accel.empty()) dc.drawText(width-TRAILSPACE-font->getTextWidth(accel.text(),accel.length()),yy,accel.text(),accel.length());
-      if(options&MENU_DEFAULT){
-        dc.drawText(xx+1,yy,label.text(),label.length());
-        if(!accel.empty()) dc.drawText(width-TRAILSPACE-1-font->getTextWidth(accel.text(),accel.length()),yy,accel.text(),accel.length());
-        }
       if(0<=hotoff){
         dc.fillRectangle(xx+font->getTextWidth(&label[0],hotoff),yy+1,font->getTextWidth(&label[hotoff],1),1);
         }
@@ -467,10 +430,6 @@ long FXMenuCommand::onPaint(FXObject*,FXSelector,void* ptr){
       dc.setForeground(textColor);
       dc.drawText(xx,yy,label.text(),label.length());
       if(!accel.empty()) dc.drawText(width-TRAILSPACE-font->getTextWidth(accel.text(),accel.length()),yy,accel.text(),accel.length());
-      if(options&MENU_DEFAULT){
-        dc.drawText(xx+1,yy,label.text(),label.length());
-        if(!accel.empty()) dc.drawText(width-TRAILSPACE-1-font->getTextWidth(accel.text(),accel.length()),yy,accel.text(),accel.length());
-        }
       if(0<=hotoff){
         dc.fillRectangle(xx+font->getTextWidth(&label[0],hotoff),yy+1,font->getTextWidth(&label[hotoff],1),1);
         }
