@@ -3,7 +3,7 @@
 *                             O p t i o n   M e n u                             *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXOptionMenu.cpp,v 1.29 2001/08/10 18:09:52 jeroen Exp $                 *
+* $Id: FXOptionMenu.cpp,v 1.32.4.2 2003/06/20 19:02:07 fox Exp $                 *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,24 +30,13 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
 #include "FXFont.h"
-#include "FXDrawable.h"
-#include "FXImage.h"
 #include "FXIcon.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
 #include "FXLabel.h"
-#include "FXComposite.h"
-#include "FXShell.h"
 #include "FXPopup.h"
 #include "FXButton.h"
 #include "FXMenuButton.h"
@@ -444,7 +433,7 @@ long FXOptionMenu::onPaint(FXObject*,FXSelector,void* ptr){
       dc.setForeground(textColor);
       drawLabel(dc,label,hotoff,tx,ty,tw,th);
       if(hasFocus()){
-        drawFocusRectangle(dc,border+2,border+2,width-2*border-4,height-2*border-4);
+        dc.drawFocusRectangle(border+2,border+2,width-2*border-4,height-2*border-4);
         }
       }
     else{
@@ -514,8 +503,6 @@ long FXOptionMenu::onLeftBtnPress(FXObject*,FXSelector,void* ptr){
         handle(this,MKUINT(ID_POST,SEL_COMMAND),NULL);
         }
       }
-    flags|=FLAG_PRESSED;
-    flags&=~FLAG_UPDATE;
     return 1;
     }
   return 0;
@@ -527,8 +514,6 @@ long FXOptionMenu::onLeftBtnRelease(FXObject*,FXSelector,void* ptr){
   FXEvent* ev=(FXEvent*)ptr;
   flags&=~FLAG_TIP;
   if(isEnabled()){
-    flags|=FLAG_UPDATE;
-    flags&=~FLAG_PRESSED;
     if(target && target->handle(this,MKUINT(message,SEL_LEFTBUTTONRELEASE),ptr)) return 1;
     if(ev->moved && pane){ handle(this,MKUINT(ID_UNPOST,SEL_COMMAND),NULL); }
     return 1;
@@ -566,6 +551,7 @@ long FXOptionMenu::onCmdPost(FXObject*,FXSelector,void*){
     pane->popup(this,x,y,width,pane->getDefaultHeight());
     current->setFocus();
     if(!grabbed()) grab();
+    flags&=~FLAG_UPDATE;
     }
   return 1;
   }
@@ -577,6 +563,7 @@ long FXOptionMenu::onCmdUnpost(FXObject*,FXSelector,void* ptr){
   if(pane && pane->shown()){
     pane->popdown();
     if(grabbed()) ungrab();
+    flags|=FLAG_UPDATE;
     if(ptr) setCurrent((FXOption*)ptr);
     }
   return 1;
@@ -585,7 +572,7 @@ long FXOptionMenu::onCmdUnpost(FXObject*,FXSelector,void* ptr){
 
 // Update value from a message
 long FXOptionMenu::onCmdSetValue(FXObject*,FXSelector,void* ptr){
-  setCurrentNo((FXint)(long)ptr);
+  setCurrentNo((FXint)(FXival)ptr);
   return 1;
   }
 
