@@ -3,7 +3,7 @@
 *                     P o p u p   W i n d o w   O b j e c t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXPopup.cpp,v 1.44 2001/08/29 04:12:48 jeroen Exp $                      *
+* $Id: FXPopup.cpp,v 1.49.4.2 2002/07/24 21:29:14 fox Exp $                      *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,19 +30,9 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
-#include "FXComposite.h"
-#include "FXShell.h"
 #include "FXPopup.h"
 
 /*
@@ -128,14 +118,14 @@ const char* FXPopup::GetClass() const { return "FXPopup"; }
 
 
 // Popup can not get focus
-void FXPopup::setFocus(){ 
+void FXPopup::setFocus(){
   FXShell::setFocus();
   //grabKeyboard();
   }
 
 
 // Popup can not get focus
-void FXPopup::killFocus(){ 
+void FXPopup::killFocus(){
   FXShell::killFocus();
   //ungrabKeyboard();
   }
@@ -455,18 +445,22 @@ long FXPopup::onFocusNext(FXObject*,FXSelector,void* ptr){
   if(getFocus()){
     child=getFocus()->getNext();
     while(child){
-      if(child->isEnabled() && child->canFocus()){
-        child->handle(this,MKUINT(0,SEL_FOCUS_SELF),ptr);
-        return 1;
+      if(child->shown()){
+        if(child->isEnabled() && child->canFocus()){
+          child->handle(this,MKUINT(0,SEL_FOCUS_SELF),ptr);
+          return 1;
+          }
         }
       child=child->getNext();
       }
     }
   child=getFirst();
   while(child){
-    if(child->isEnabled() && child->canFocus()){
-      child->handle(this,MKUINT(0,SEL_FOCUS_SELF),ptr);
-      return 1;
+    if(child->shown()){
+      if(child->isEnabled() && child->canFocus()){
+        child->handle(this,MKUINT(0,SEL_FOCUS_SELF),ptr);
+        return 1;
+        }
       }
     child=child->getNext();
     }
@@ -480,18 +474,22 @@ long FXPopup::onFocusPrev(FXObject*,FXSelector,void* ptr){
   if(getFocus()){
     child=getFocus()->getPrev();
     while(child){
-      if(child->isEnabled() && child->canFocus()){
-        child->handle(this,MKUINT(0,SEL_FOCUS_SELF),ptr);
-        return 1;
+      if(child->shown()){
+        if(child->isEnabled() && child->canFocus()){
+          child->handle(this,MKUINT(0,SEL_FOCUS_SELF),ptr);
+          return 1;
+          }
         }
       child=child->getPrev();
       }
     }
   child=getLast();
   while(child){
-    if(child->isEnabled() && child->canFocus()){
-      child->handle(this,MKUINT(0,SEL_FOCUS_SELF),ptr);
-      return 1;
+    if(child->shown()){
+      if(child->isEnabled() && child->canFocus()){
+        child->handle(this,MKUINT(0,SEL_FOCUS_SELF),ptr);
+        return 1;
+        }
       }
     child=child->getPrev();
     }
@@ -501,10 +499,13 @@ long FXPopup::onFocusPrev(FXObject*,FXSelector,void* ptr){
 
 // Moved into the popup:- tell the target
 long FXPopup::onEnter(FXObject* sender,FXSelector sel,void* ptr){
+  FXEvent* event=(FXEvent*)ptr;
+  FXint px, py;
   FXShell::onEnter(sender,sel,ptr);
-  if(((FXEvent*)ptr)->code==CROSSINGNORMAL){
+  if(event->code==CROSSINGNORMAL){
   //if(((FXEvent*)ptr)->code!=CROSSINGGRAB){
-    if(getGrabOwner()->grabbed()) getGrabOwner()->ungrab();
+    translateCoordinatesTo(px,py,getParent(),event->win_x,event->win_y); // Patch from Michael Nold <mn@sol-3.de>
+    if(contains(px,py) && getGrabOwner()->grabbed()) getGrabOwner()->ungrab();
     }
   return 1;
   }
@@ -512,10 +513,13 @@ long FXPopup::onEnter(FXObject* sender,FXSelector sel,void* ptr){
 
 // Moved outside the popup:- tell the target
 long FXPopup::onLeave(FXObject* sender,FXSelector sel,void* ptr){
+  FXEvent* event=(FXEvent*)ptr;
+  FXint px,py;
   FXShell::onLeave(sender,sel,ptr);
-  if(((FXEvent*)ptr)->code==CROSSINGNORMAL){
+  if(event->code==CROSSINGNORMAL){
   //if(((FXEvent*)ptr)->code!=CROSSINGGRAB){
-    if(shown() && !getGrabOwner()->grabbed() && getGrabOwner()->shown()) getGrabOwner()->grab();
+    translateCoordinatesTo(px,py,getParent(),event->win_x,event->win_y); // Patch from Michael Nold <mn@sol-3.de>
+    if(!contains(px,py) && shown() && !getGrabOwner()->grabbed() && getGrabOwner()->shown()) getGrabOwner()->grab();
     }
   return 1;
   }
@@ -603,7 +607,7 @@ long FXPopup::onKeyRelease(FXObject* sender,FXSelector sel,void* ptr){
 // Unpost menu in case it was its own owner; otherwise
 // tell the owner to do so.
 long FXPopup::onCmdUnpost(FXObject*,FXSelector,void* ptr){
-  FXTRACE((200,"%s::onCmdUnpost %p\n",getClassName(),this));
+  FXTRACE((150,"%s::onCmdUnpost %p\n",getClassName(),this));
   if(grabowner){
     grabowner->handle(this,MKUINT(ID_UNPOST,SEL_COMMAND),ptr);
     }
@@ -615,11 +619,11 @@ long FXPopup::onCmdUnpost(FXObject*,FXSelector,void* ptr){
   }
 
 
-
 // Popup the menu at some location
 void FXPopup::popup(FXWindow* grabto,FXint x,FXint y,FXint w,FXint h){
   FXint rw=getRoot()->getWidth();
   FXint rh=getRoot()->getHeight();
+  FXTRACE((150,"%s::popup %p\n",getClassName(),this));
   grabowner=grabto;
   if((options&POPUP_SHRINKWRAP) || w<=1) w=getDefaultWidth();
   if((options&POPUP_SHRINKWRAP) || h<=1) h=getDefaultHeight();
@@ -631,12 +635,14 @@ void FXPopup::popup(FXWindow* grabto,FXint x,FXint y,FXint w,FXint h){
   show();
   raise();
   setFocus();
-  if(!grabowner) grab();    // Perhaps should NOT grab here!
+  if(!grabowner) grab();
   }
 
 
 // Pops down menu and its submenus
 void FXPopup::popdown(){
+  FXTRACE((150,"%s::popdown %p\n",getClassName(),this));
+  if(!grabowner) ungrab();
   grabowner=NULL;
   //if(getFocus()) getFocus()->killFocus();
   killFocus();
@@ -662,8 +668,8 @@ void FXPopup::popdown(){
 //   //setFocus();
 //   return getApp()->runPopup(this);
 //   }
-// 
-// 
+//
+//
 // // Pop down the menu
 // void FXPopup::popdown(FXint value){
 //   getApp()->stopModal(this,value);
@@ -674,36 +680,44 @@ void FXPopup::popdown(){
 
 // Close popup
 long FXPopup::onCmdChoice(FXObject*,FXSelector sel,void*){
-  //popdown((SELID(sel)-ID_CHOICE));
+  //popdown(SELID(sel)-ID_CHOICE);
   return 1;
   }
 
 
 // Set base color
 void FXPopup::setBaseColor(FXColor clr){
-  baseColor=clr;
-  update();
+  if(baseColor!=clr){
+    baseColor=clr;
+    update();
+    }
   }
 
 
 // Set highlight color
 void FXPopup::setHiliteColor(FXColor clr){
-  hiliteColor=clr;
-  update();
+  if(hiliteColor!=clr){
+    hiliteColor=clr;
+    update();
+    }
   }
 
 
 // Set shadow color
 void FXPopup::setShadowColor(FXColor clr){
-  shadowColor=clr;
-  update();
+  if(shadowColor!=clr){
+    shadowColor=clr;
+    update();
+    }
   }
 
 
 // Set border color
 void FXPopup::setBorderColor(FXColor clr){
-  borderColor=clr;
-  update();
+  if(borderColor!=clr){
+    borderColor=clr;
+    update();
+    }
   }
 
 
