@@ -3,7 +3,7 @@
 *                        P r i n t   J o b   D i a l o g                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXPrintDialog.cpp,v 1.27 2001/06/26 21:05:54 jeroen Exp $                *
+* $Id: FXPrintDialog.cpp,v 1.31 2002/01/18 22:43:01 jeroen Exp $                *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,20 +30,11 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDrawable.h"
-#include "FXDC.h"
 #include "FXDCPrint.h"
-#include "FXImage.h"
-#include "FXIcon.h"
 #include "FXGIFIcon.h"
-#include "FXWindow.h"
 #include "FXRecentFiles.h"
 #include "FXFrame.h"
 #include "FXSeparator.h"
@@ -51,15 +42,12 @@
 #include "FXTextField.h"
 #include "FXButton.h"
 #include "FXRadioButton.h"
-#include "FXComposite.h"
 #include "FXPacker.h"
 #include "FXHorizontalFrame.h"
 #include "FXVerticalFrame.h"
 #include "FXMatrix.h"
 #include "FXSpinner.h"
 #include "FXGroupBox.h"
-#include "FXShell.h"
-#include "FXTopWindow.h"
 #include "FXDialogBox.h"
 #include "FXScrollArea.h"
 #include "FXList.h"
@@ -275,9 +263,9 @@ FXPrintDialog::FXPrintDialog(FXWindow* owner,const FXString& name,FXuint opts,FX
 
   // Close and cancel buttons
   FXHorizontalFrame* buttons=new FXHorizontalFrame(contents,LAYOUT_BOTTOM|LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0,0,0,0,0);
-  new FXButton(buttons,"&Print",NULL,this,ID_ACCEPT,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_CENTER_Y|LAYOUT_RIGHT,0,0,0,0,20,20);
-  new FXButton(buttons,"&Cancel",NULL,this,ID_CANCEL,FRAME_RAISED|FRAME_THICK|LAYOUT_CENTER_Y|LAYOUT_RIGHT,0,0,0,0,20,20);
-#ifdef HAVE_CUPS_H  
+  new FXButton(buttons,"&Print",NULL,this,ID_ACCEPT,BUTTON_INITIAL|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_CENTER_Y|LAYOUT_RIGHT,0,0,0,0,20,20);
+  new FXButton(buttons,"&Cancel",NULL,this,ID_CANCEL,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_CENTER_Y|LAYOUT_RIGHT,0,0,0,0,20,20);
+#ifdef HAVE_CUPS_H
   FXLabel *label=new FXLabel(buttons,"Using CUPS",NULL,LAYOUT_CENTER_Y|LAYOUT_LEFT,0,0,0,0,0,0);
   label->setTextColor(label->getShadowColor());
 #endif
@@ -356,6 +344,9 @@ FXPrintDialog::FXPrintDialog(FXWindow* owner,const FXString& name,FXuint opts,FX
   printinblacknwhite->setCheck(TRUE);
   orientportrait->setCheck(TRUE);
 
+  // Initial focus on printer name
+  printername->setFocus();
+
   // Make sure we have at least a couple
   if(!getApp()->reg().readStringEntry("PAPER","0",NULL)){
     getApp()->reg().writeStringEntry("PAPER","0","[US Letter] 612 792 72 72 72 72");
@@ -435,14 +426,14 @@ void FXPrintDialog::create(){
   FXDialogBox::create();
 #ifndef WIN32
 #ifdef HAVE_CUPS_H
-  
+
   // Use CUPS to determine list of printers
   cups_dest_t *dests;
   int          num_dests;
-  
+
   // Obtain list of destinations
   num_dests=cupsGetDests(&dests);
-  
+
   // Fill list of printers
   for(int d=0; d<num_dests; d++){
     printername->appendItem(dests[d].name);
@@ -499,7 +490,7 @@ void FXPrintDialog::create(){
 
   // Close the file
   fclose(pc);
-  
+
 #endif
 #else
 
@@ -525,7 +516,7 @@ void FXPrintDialog::create(){
       FXFREE(&prtinfo);
       }
     }
-  
+
   // Determine list of printers on Windows 9x
   else if(osvi.dwPlatformId==VER_PLATFORM_WIN32_WINDOWS){
     DWORD dwFlags=PRINTER_ENUM_LOCAL;
@@ -542,7 +533,7 @@ void FXPrintDialog::create(){
       FXFREE(&prtinfo);
       }
     }
-  
+
 #endif
   }
 
@@ -607,7 +598,7 @@ long FXPrintDialog::onCmdToPrinter(FXObject*,FXSelector,void*){
 //   const char *defdest;
 //   defdest=cupsGetDefault();
 //   FXTRACE((1,"default destination=%s\n",defdest));
-// #endif  
+// #endif
   return 1;
   }
 
@@ -739,7 +730,7 @@ long FXPrintDialog::onCmdPrinterName(FXObject*,FXSelector,void*){
   if(!(printer.flags&PRINT_DEST_FILE)){
     printer.name=name;
     FXTRACE((100,"Print to printer: %s\n",printer.name.text()));
-//   
+//
 //   // If using CUPS, we list the available media types for this printer
 // #ifndef WIN32
 // #ifdef HAVE_CUPS_H
@@ -756,8 +747,8 @@ long FXPrintDialog::onCmdPrinterName(FXObject*,FXSelector,void*){
 //     media->appendItem(ppd->sizes[s].name);
 //     }
 //   ppdClose(ppd);
-// #endif  
-// #endif  
+// #endif
+// #endif
     }
   return 1;
   }
