@@ -3,7 +3,7 @@
 *                      P r o g r e s s B a r   W i d g e t                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * Contributed by: Jonathan Bush and Sander Jansen <sxj@cfdrc.com>               *
 *********************************************************************************
@@ -21,7 +21,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXProgressBar.cpp,v 1.20 2001/08/29 18:28:57 jeroen Exp $                *
+* $Id: FXProgressBar.cpp,v 1.26.4.3 2003/06/20 19:02:07 fox Exp $                *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -31,18 +31,10 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
 #include "FXFont.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
 #include "FXProgressBar.h"
 
 
@@ -109,21 +101,21 @@ FXint FXProgressBar::getDefaultWidth(){
       if(w<t) w=t;
       }
     }
-  return w+padleft+padright+border;
+  return w+padleft+padright+(border<<1);
   }
 
 
 // Get minimum height
 FXint FXProgressBar::getDefaultHeight(){
   FXint h=1,t;
-  if(!(options&PROGRESSBAR_VERTICAL ) ||  (options&PROGRESSBAR_DIAL)){
+  if(!(options&PROGRESSBAR_VERTICAL) || (options&PROGRESSBAR_DIAL)){
     h=barsize;
     if(options&PROGRESSBAR_PERCENTAGE){
       t=font->getFontHeight();
       if(h<t) h=t;
       }
     }
-  return h+padtop+padbottom+border;
+  return h+padtop+padbottom+(border<<1);
   }
 
 
@@ -143,7 +135,7 @@ void FXProgressBar::detach(){
 
 // Update progress value from a message
 long FXProgressBar::onCmdSetValue(FXObject*,FXSelector,void* ptr){
-  setProgress((FXuint)(long)ptr);
+  setProgress((FXuint)(FXuval)ptr);
   return 1;
   }
 
@@ -184,7 +176,7 @@ long FXProgressBar::onPaint(FXObject*,FXSelector,void *ptr){
 
     tw=width-(border<<1)-padleft-padright;
     th=height-(border<<1)-padtop-padbottom;
-    d=FXMIN(tw,th);
+    d=FXMIN(tw,th)-1;
 
     tx=border+padleft+((tw-d)/2);
     ty=border+padtop+((th-d)/2);
@@ -194,29 +186,28 @@ long FXProgressBar::onPaint(FXObject*,FXSelector,void *ptr){
 
     if(barfilled!=23040){
       dc.setForeground(barBGColor);
-      dc.fillArc(tx+2,ty+2,d-4,d-4,5760,23040-barfilled);
+      dc.fillArc(tx,ty,d,d,5760,23040-barfilled);
       }
     if(barfilled!=0){
       dc.setForeground(barColor);
-      dc.fillArc(tx+2,ty+2,d-4,d-4,5760,-barfilled);
+      dc.fillArc(tx,ty,d,d,5760,-barfilled);
       }
 
-//    int ang2 = (-ar*64) + (90*64);
-//    int xStart=int(tx+0.5*d+(d/2)*cos((90*64)*PI/(180.0*64.0)));
-//    int yStart=int(ty+0.5*d-(d/2)*sin((90*64)*PI/(180.0*64.0)));
-//    int xEnd=int(tx+0.5*d+(d/2)*cos(ang2*PI/(180.0*64.0)));
-//    int yEnd=int(ty+0.5*d-(d/2)*sin(ang2*PI/(180.0*64.0)));
+    dc.setForeground(borderColor);
+    dc.drawArc(tx+1,ty,d,d,90*64,45*64);
+    dc.drawArc(tx,ty+1,d,d,135*64,45*64);
+    dc.setForeground(baseColor);
+    dc.drawArc(tx-1,ty,d,d,270*64,45*64);
+    dc.drawArc(tx,ty-1,d,d,315*64,45*64);
 
-
-//    dc.setForeground(barBGColor);
-//    dc.drawLine(xStart,yStart,tx+d/2,ty+d/2);
-//    dc.drawLine(xEnd,yEnd,tx+d/2,ty+d/2);
-
-    // Draw outside circle
-//    dc.drawArc(tx,ty,d,d,0,64*360);
+    dc.setForeground(shadowColor);
+    dc.drawArc(tx,ty,d,d,45*64,180*64);
+    dc.setForeground(hiliteColor);
+    dc.drawArc(tx,ty,d,d,225*64,180*64);
 
     // Draw text
     if(options&PROGRESSBAR_PERCENTAGE){
+      dc.setTextFont(font);
       tw=font->getTextWidth("100%",4);
       if(tw>(11*d)/16) return 1;
       th=font->getFontHeight();
@@ -260,6 +251,7 @@ long FXProgressBar::onPaint(FXObject*,FXSelector,void *ptr){
 
     // Draw text
     if(options&PROGRESSBAR_PERCENTAGE){
+      dc.setTextFont(font);
       sprintf(numtext,"%d%%",percent);
       n=strlen(numtext);
       tw=font->getTextWidth(numtext,n);
@@ -312,6 +304,7 @@ long FXProgressBar::onPaint(FXObject*,FXSelector,void *ptr){
 
     // Draw text
     if(options&PROGRESSBAR_PERCENTAGE){
+      dc.setTextFont(font);
       sprintf(numtext,"%d%%",percent);
       n=strlen(numtext);
       tw=font->getTextWidth(numtext,n-1); // Not including the % looks better
@@ -348,6 +341,7 @@ void FXProgressBar::setProgress(FXuint value){
     progress=value;
     update(border,border,width-(border<<1),height-(border<<1));
     repaint(border,border,width-(border<<1),height-(border<<1));
+    getApp()->flush();
     }
   }
 
@@ -358,6 +352,7 @@ void FXProgressBar::increment(FXuint value){
     progress+=value;
     if(progress>total) progress=total;
     update(border,border,width-(border<<1),height-(border<<1));
+    repaint(border,border,width-(border<<1),height-(border<<1));
     getApp()->flush();
     }
   }
@@ -368,6 +363,7 @@ void FXProgressBar::setTotal(FXuint value){
   if(value!=total){
     total=value;
     update(border,border,width-(border<<1),height-(border<<1));
+    repaint(border,border,width-(border<<1),height-(border<<1));
     getApp()->flush();
     }
   }
@@ -375,29 +371,37 @@ void FXProgressBar::setTotal(FXuint value){
 
 // Change bar color
 void FXProgressBar::setBarColor(FXColor clr){
-  barColor=clr;
-  update(border,border,width-(border<<1),height-(border<<1));
+  if(barColor!=clr){
+    barColor=clr;
+    update(border,border,width-(border<<1),height-(border<<1));
+    }
   }
 
 
 // Change bar background color
 void FXProgressBar::setBarBGColor(FXColor clr){
-  barBGColor=clr;
-  update(border,border,width-(border<<1),height-(border<<1));
+  if(barBGColor!=clr){
+    barBGColor=clr;
+    update(border,border,width-(border<<1),height-(border<<1));
+    }
   }
 
 
 // Change text foreground color
-void FXProgressBar::setTextColor(FXColor clr) {
-  textNumColor=clr;
-  update();
+void FXProgressBar::setTextColor(FXColor clr){
+  if(textNumColor!=clr){
+    textNumColor=clr;
+    update();
+    }
   }
 
 
 // Change alternate text color
 void FXProgressBar::setTextAltColor(FXColor clr) {
-  textAltColor=clr;
-  update();
+  if(textAltColor!=clr){
+    textAltColor=clr;
+    update();
+    }
   }
 
 
