@@ -3,7 +3,7 @@
 *                  R a d i o   B u t t o n    O b j e c t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXRadioButton.cpp,v 1.33 2001/05/24 13:16:23 jeroen Exp $                *
+* $Id: FXRadioButton.cpp,v 1.38.4.1 2003/06/20 19:02:07 fox Exp $                *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,18 +30,9 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
-#include "FXLabel.h"
 #include "FXRadioButton.h"
 
 /*
@@ -166,14 +157,14 @@ long FXRadioButton::onUnknown(FXObject*,FXSelector,void*){
 
 // Update value from a message
 long FXRadioButton::onCmdSetValue(FXObject*,FXSelector,void* ptr){
-  setCheck((FXint)(long)ptr);
+  setCheck((FXbool)(FXuval)ptr);
   return 1;
   }
 
 
 // Update value from a message
 long FXRadioButton::onCmdSetIntValue(FXObject*,FXSelector,void* ptr){
-  setCheck(*((FXint*)ptr));
+  setCheck((FXbool)*((FXint*)ptr));
   return 1;
   }
 
@@ -189,7 +180,7 @@ long FXRadioButton::onCmdGetIntValue(FXObject*,FXSelector,void* ptr){
 long FXRadioButton::onUncheckRadio(FXObject*,FXSelector,void*){
   if(check){
     setCheck(FALSE);
-    if(target && target->handle(this,MKUINT(message,SEL_COMMAND),(void*)check)) return 1;
+    if(target && target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(long)check)) return 1;
     }
   return 0;
   }
@@ -261,9 +252,9 @@ long FXRadioButton::onLeftBtnRelease(FXObject*,FXSelector,void* ptr){
     if(target && target->handle(this,MKUINT(message,SEL_LEFTBUTTONRELEASE),ptr)) return 1;
     flags|=FLAG_UPDATE;
     flags&=~FLAG_PRESSED;
-    if(check!=oldcheck){ 
+    if(check!=oldcheck){
       getParent()->handle(this,MKUINT(0,SEL_UNCHECK_OTHER),NULL);
-      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)check); 
+      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(long)check);
       }
     return 1;
     }
@@ -309,7 +300,7 @@ long FXRadioButton::onKeyRelease(FXObject*,FXSelector,void* ptr){
       flags&=~FLAG_PRESSED;
       if(check!=oldcheck){
         getParent()->handle(this,MKUINT(0,SEL_UNCHECK_OTHER),NULL);
-        if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)check);
+        if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(long)check);
         }
       return 1;
       }
@@ -340,7 +331,7 @@ long FXRadioButton::onHotKeyRelease(FXObject*,FXSelector,void*){
     flags&=~FLAG_PRESSED;
     if(check!=oldcheck){
       getParent()->handle(this,MKUINT(0,SEL_UNCHECK_OTHER),NULL);
-      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)check);
+      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(long)check);
       }
     }
   return 1;
@@ -478,7 +469,7 @@ long FXRadioButton::onPaint(FXObject*,FXSelector,void* ptr){
       dc.setForeground(textColor);
       drawLabel(dc,label,hotoff,tx,ty,tw,th);
       if(hasFocus()){
-        drawFocusRectangle(dc,tx-1,ty-1,tw+2,th+2);
+        dc.drawFocusRectangle(tx-1,ty-1,tw+2,th+2);
         }
       }
     else{
