@@ -3,7 +3,7 @@
 *                     R e c e n t   F i l e s   L i s t                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXRecentFiles.cpp,v 1.15 2001/04/27 14:30:34 jeroen Exp $                *
+* $Id: FXRecentFiles.cpp,v 1.18 2002/01/18 22:43:02 jeroen Exp $                *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -29,13 +29,8 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDrawable.h"
 #include "FXWindow.h"
 #include "FXRecentFiles.h"
 
