@@ -3,7 +3,7 @@
 *                           R e g i s t r y   C l a s s                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,17 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXRegistry.cpp,v 1.27 2001/07/05 16:12:35 jeroen Exp $                   *
+* $Id: FXRegistry.cpp,v 1.32.4.1 2003/05/16 10:54:30 fox Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
 #include "FXStream.h"
 #include "FXObject.h"
-#include "FXDict.h"
 #include "FXString.h"
 #include "FXFile.h"
-#include "FXSettings.h"
+#include "FXStringDict.h"
 #include "FXRegistry.h"
 
 /*
@@ -110,6 +109,9 @@
 
 /*******************************************************************************/
 
+// Object implementation
+FXIMPLEMENT(FXRegistry,FXSettings,NULL,0)
+
 // Make registry object
 FXRegistry::FXRegistry(const FXString& akey,const FXString& vkey):applicationkey(akey),vendorkey(vkey){
 #ifndef WIN32
@@ -229,14 +231,14 @@ FXbool FXRegistry::readFromDir(const FXString& dirname,FXbool mark){
     if(parseFile(dirname+PATHSEPSTRING DESKTOP ".ini",FALSE)) ok=TRUE;
 #endif
 
-    // Have vendor key 
+    // Have vendor key
     if(!vendorkey.empty()){
 #ifndef WIN32
       if(parseFile(dirname+PATHSEPSTRING+vendorkey+PATHSEPSTRING+vendorkey,FALSE)) ok=TRUE;
 #else
       if(parseFile(dirname+PATHSEPSTRING+vendorkey+PATHSEPSTRING+vendorkey+".ini",FALSE)) ok=TRUE;
 #endif
-      // Have application key 
+      // Have application key
       if(!applicationkey.empty()){
 #ifndef WIN32
         if(parseFile(dirname+PATHSEPSTRING+vendorkey+PATHSEPSTRING+applicationkey,mark)) ok=TRUE;
@@ -245,11 +247,11 @@ FXbool FXRegistry::readFromDir(const FXString& dirname,FXbool mark){
 #endif
         }
       }
-    
+
     // No vendor key
     else{
 
-      // Have application key 
+      // Have application key
       if(!applicationkey.empty()){
 #ifndef WIN32
         if(parseFile(dirname+PATHSEPSTRING+applicationkey,mark)) ok=TRUE;
@@ -297,7 +299,7 @@ FXbool FXRegistry::readFromRegistry(void* hRootKey,FXbool mark){
 
     // No vendor key
     else{
-      
+
       // Have application key
       if(!applicationkey.empty()){
 
@@ -323,7 +325,7 @@ FXbool FXRegistry::readFromRegistryGroup(void* org,const char* groupname,FXbool
     sectionsize=MAXNAME;
     FXTRACE((100,"Reading registry group %s\n",groupname));
     while(RegEnumKeyEx(groupkey,sectionindex,section,&sectionsize,NULL,NULL,NULL,&writetime)==ERROR_SUCCESS){
-      group=sections.insert(section);
+      group=insert(section);
       FXTRACE((100,"[%s]\n",section));
       if(RegOpenKeyEx(groupkey,section,0,KEY_READ,&sectionkey)==ERROR_SUCCESS){
         index=0;
@@ -368,7 +370,7 @@ FXbool FXRegistry::write(){
     if(ascii){
 
       FXTRACE((100,"Writing to file based settings database.\n"));
-  
+
       // Changes written only in the per-user registry
       pathname=FXFile::getHomeDirectory()+PATHSEPSTRING ".foxrc";
 
@@ -424,9 +426,9 @@ FXbool FXRegistry::write(){
     }
 
   else{
-    
+
     FXTRACE((100,"Writing to registry HKEY_CURRENT_USER.\n"));
-    
+
     // Write back modified resources for current user
     if(writeToRegistry(HKEY_CURRENT_USER)) return TRUE;
     }
@@ -540,13 +542,14 @@ FXbool FXRegistry::writeToRegistry(void* hRootKey){
 
 // Write to registry group
 FXbool FXRegistry::writeToRegistryGroup(void* org,const char* groupname){
-  FXchar section[MAXNAME],name[MAXNAME],value[MAXVALUE];
-  DWORD sectionsize,sectionindex,namesize,disp,s,e;
+  FXchar section[MAXNAME];
+  DWORD sectionsize,sectionindex,disp,s,e;
   HKEY groupkey,sectionkey;
   FILETIME writetime;
   FXStringDict *group;
   if(RegCreateKeyEx((HKEY)org,groupname,0,REG_NONE,REG_OPTION_NON_VOLATILE,KEY_WRITE|KEY_READ,NULL,&groupkey,&disp)==ERROR_SUCCESS){
 
+/*
     // First, purge all existing sections
     sectionindex=0;
     sectionsize=MAXNAME;
@@ -555,18 +558,26 @@ FXbool FXRegistry::writeToRegistryGroup(void* org,const char* groupname){
       sectionsize=MAXNAME;
       sectionindex++;
       }
+*/
+    // First, purge all existing sections
+    while(1){
+      sectionindex=0;
+      sectionsize=MAXNAME;
+      if(RegEnumKeyEx(groupkey,sectionindex,section,&sectionsize,NULL,NULL,NULL,&writetime)!=ERROR_SUCCESS) break;
+      RegDeleteKey(groupkey,section);
+      }
 
     // Dump the registry, writing only marked entries
-    s=sections.first();
-    while(s<sections.size()){
+    s=first();
+    while(s<size()){
       sectionkey=NULL;
-      group=sections.data(s);
+      group=data(s);
       FXASSERT(group);
       for(e=group->first(); e<group->size(); e=group->next(e)){
         if(group->mark(e)){
           if(sectionkey==NULL){
-            FXASSERT(sections.key(s));
-            if(RegCreateKeyEx(groupkey,sections.key(s),0,REG_NONE,REG_OPTION_NON_VOLATILE,KEY_WRITE|KEY_READ,NULL,&sectionkey,&disp)!=ERROR_SUCCESS) goto x;
+            FXASSERT(key(s));
+            if(RegCreateKeyEx(groupkey,key(s),0,REG_NONE,REG_OPTION_NON_VOLATILE,KEY_WRITE|KEY_READ,NULL,&sectionkey,&disp)!=ERROR_SUCCESS) goto x;
             }
           FXASSERT(group->key(e));
           FXASSERT(group->data(e));
@@ -578,7 +589,7 @@ FXbool FXRegistry::writeToRegistryGroup(void* org,const char* groupname){
       if(sectionkey) RegCloseKey(sectionkey);
 
       // Process next registry section
-x:    s=sections.next(s);
+x:    s=next(s);
       }
     RegCloseKey(groupkey);
     return TRUE;
