@@ -3,7 +3,7 @@
 *                      T e x t   R e p l a c e   D i a l o g                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2000,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXReplaceDialog.cpp,v 1.20 2001/08/23 04:53:16 jeroen Exp $              *
+* $Id: FXReplaceDialog.cpp,v 1.28 2002/02/08 14:27:20 fox Exp $              *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,15 +30,10 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXApp.h"
-#include "FXId.h"
 #include "FXFont.h"
-#include "FXDrawable.h"
 #include "FXImage.h"
 #include "FXIcon.h"
 #include "FXGIFIcon.h"
@@ -50,11 +45,7 @@
 #include "FXButton.h"
 #include "FXCheckButton.h"
 #include "FXRadioButton.h"
-#include "FXComposite.h"
 #include "FXPacker.h"
-#include "FXShell.h"
-#include "FXTopWindow.h"
-#include "FXDialogBox.h"
 #include "FXScrollbar.h"
 #include "FXTextField.h"
 #include "FXVerticalFrame.h"
@@ -112,9 +103,9 @@ FXIMPLEMENT(FXReplaceDialog,FXDialogBox,FXReplaceDialogMap,ARRAYNUMBER(FXReplace
 FXReplaceDialog::FXReplaceDialog(FXWindow* owner,const FXString& caption,FXIcon* ic,FXuint opts,FXint x,FXint y,FXint w,FXint h):
   FXDialogBox(owner,caption,opts|DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,x,y,w,h,10,10,10,10, 10,10){
   FXHorizontalFrame* buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|PACK_UNIFORM_WIDTH|PACK_UNIFORM_HEIGHT,0,0,0,0,0,0,0,0);
-  accept=new FXButton(buttons,"&Replace",NULL,this,ID_ACCEPT,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_Y|LAYOUT_RIGHT,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
-  every=new FXButton(buttons,"Replace &All",NULL,this,ID_ALL,FRAME_RAISED|FRAME_THICK|LAYOUT_CENTER_Y|LAYOUT_RIGHT,0,0,0,0,6,6,VERT_PAD,VERT_PAD);
-  cancel=new FXButton(buttons,"&Cancel",NULL,this,ID_CANCEL,FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_Y|LAYOUT_RIGHT,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
+  accept=new FXButton(buttons,"&Replace",NULL,this,ID_ACCEPT,BUTTON_INITIAL|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_Y|LAYOUT_RIGHT,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
+  every=new FXButton(buttons,"Replace &All",NULL,this,ID_ALL,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_CENTER_Y|LAYOUT_RIGHT,0,0,0,0,6,6,VERT_PAD,VERT_PAD);
+  cancel=new FXButton(buttons,"&Cancel",NULL,this,ID_CANCEL,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_Y|LAYOUT_RIGHT,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
   FXHorizontalFrame* pair=new FXHorizontalFrame(buttons,LAYOUT_FILL_Y|LAYOUT_RIGHT,0,0,0,0, 0,0,0,0);
   FXArrowButton* searchlast=new FXArrowButton(pair,this,ID_PREV,ARROW_LEFT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_Y,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
   FXArrowButton* searchnext=new FXArrowButton(pair,this,ID_NEXT,ARROW_RIGHT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_Y,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
@@ -122,7 +113,7 @@ FXReplaceDialog::FXReplaceDialog(FXWindow* owner,const FXString& caption,FXIcon*
   FXHorizontalFrame* toppart=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|LAYOUT_CENTER_Y,0,0,0,0, 0,0,0,0, 10,10);
   new FXLabel(toppart,NULL,ic,ICON_BEFORE_TEXT|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_Y|LAYOUT_FILL_X);
   FXVerticalFrame* entry=new FXVerticalFrame(toppart,LAYOUT_FILL_X|LAYOUT_CENTER_Y,0,0,0,0, 0,0,0,0);
-  searchlabel=new FXLabel(entry,"&Search for:",NULL,JUSTIFY_LEFT|ICON_BEFORE_TEXT|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X);
+  searchlabel=new FXLabel(entry,"S&earch for:",NULL,JUSTIFY_LEFT|ICON_BEFORE_TEXT|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X);
   searchbox=new FXHorizontalFrame(entry,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_CENTER_Y,0,0,0,0, 0,0,0,0, 0,0);
   searchtext=new FXTextField(searchbox,26,this,ID_SEARCH_TEXT,TEXTFIELD_ENTER_ONLY|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 4,4,4,4);
   FXVerticalFrame* searcharrows=new FXVerticalFrame(searchbox,LAYOUT_RIGHT|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0, 0,0);
@@ -140,17 +131,16 @@ FXReplaceDialog::FXReplaceDialog(FXWindow* owner,const FXString& caption,FXIcon*
   ar4->setArrowSize(3);
   FXHorizontalFrame* options1=new FXHorizontalFrame(entry,LAYOUT_FILL_X,0,0,0,0, 0,0,0,0);
   new FXRadioButton(options1,"Ex&act",this,ID_MODE+SEARCH_EXACT,ICON_BEFORE_TEXT|LAYOUT_CENTER_X);
-  new FXRadioButton(options1,"&Ignore Case",this,ID_MODE+SEARCH_REGEX,ICON_BEFORE_TEXT|LAYOUT_CENTER_X);
-  new FXRadioButton(options1,"E&xpression",this,ID_MODE+SEARCH_IGNORECASE,ICON_BEFORE_TEXT|LAYOUT_CENTER_X);
+  new FXRadioButton(options1,"&Ignore Case",this,ID_MODE+SEARCH_IGNORECASE,ICON_BEFORE_TEXT|LAYOUT_CENTER_X);
+  new FXRadioButton(options1,"E&xpression",this,ID_MODE+SEARCH_REGEX,ICON_BEFORE_TEXT|LAYOUT_CENTER_X);
   new FXCheckButton(options1,"&Backward",this,ID_DIR,ICON_BEFORE_TEXT|LAYOUT_CENTER_X);
   searchlast->addHotKey(MKUINT(KEY_b,CONTROLMASK));
   searchnext->addHotKey(MKUINT(KEY_f,CONTROLMASK));
-  searchtext->setFocus();
   searchmode=SEARCH_EXACT|SEARCH_FORWARD;
   current=0;
   }
-    
-    
+
+
 // Set text or pattern to search for
 void FXReplaceDialog::setSearchText(const FXString& text){
   searchtext->setText(text);
@@ -235,7 +225,7 @@ void FXReplaceDialog::appendHistory(const FXString& search,const FXString& repla
   register const char* val;
   register int i;
   if(!search.empty()){
-    if(search!=getApp()->reg().readStringEntry(searchgroup,skey[0],FXString::null)){ 
+    if(search!=getApp()->reg().readStringEntry(searchgroup,skey[0],FXString::null)){
       for(i=19; i>0; i--){
         if((val=getApp()->reg().readStringEntry(searchgroup,skey[i-1],NULL))) getApp()->reg().writeStringEntry(searchgroup,skey[i],val);
         if((val=getApp()->reg().readStringEntry(searchgroup,rkey[i-1],NULL))) getApp()->reg().writeStringEntry(searchgroup,rkey[i],val);
@@ -249,7 +239,7 @@ void FXReplaceDialog::appendHistory(const FXString& search,const FXString& repla
   }
 
 
-// Scroll bar in search history
+// Scroll back in search history
 long FXReplaceDialog::onCmdSearchHist(FXObject*,FXSelector sel,void*){
   if(SELID(sel)==ID_SEARCH_UP){
     if(current<20 && getApp()->reg().readStringEntry(searchgroup,skey[current],NULL)) current++;
@@ -267,7 +257,7 @@ long FXReplaceDialog::onCmdSearchHist(FXObject*,FXSelector sel,void*){
     setReplaceText(FXString::null);
     setSearchMode(SEARCH_EXACT|SEARCH_FORWARD);
     }
-  return 1;  
+  return 1;
   }
 
 
@@ -285,7 +275,7 @@ long FXReplaceDialog::onCmdReplaceHist(FXObject*,FXSelector sel,void*){
   else{
     setReplaceText(FXString::null);
     }
-  return 1;  
+  return 1;
   }
 
 
@@ -293,15 +283,15 @@ long FXReplaceDialog::onCmdReplaceHist(FXObject*,FXSelector sel,void*){
 long FXReplaceDialog::onSearchKey(FXObject*,FXSelector,void* ptr){
   switch(((FXEvent*)ptr)->code){
     case KEY_Up:
-    case KEY_KP_Up: 
+    case KEY_KP_Up:
       onCmdSearchHist(this,MKUINT(ID_SEARCH_UP,SEL_COMMAND),NULL);
       return 1;
     case KEY_Down:
-    case KEY_KP_Down: 
+    case KEY_KP_Down:
       onCmdSearchHist(this,MKUINT(ID_SEARCH_DN,SEL_COMMAND),NULL);
       return 1;
     }
-  return 0;  
+  return 0;
   }
 
 
@@ -309,15 +299,15 @@ long FXReplaceDialog::onSearchKey(FXObject*,FXSelector,void* ptr){
 long FXReplaceDialog::onReplaceKey(FXObject*,FXSelector,void* ptr){
   switch(((FXEvent*)ptr)->code){
     case KEY_Up:
-    case KEY_KP_Up: 
+    case KEY_KP_Up:
       onCmdReplaceHist(this,MKUINT(ID_REPLACE_UP,SEL_COMMAND),NULL);
       return 1;
     case KEY_Down:
-    case KEY_KP_Down: 
+    case KEY_KP_Down:
       onCmdReplaceHist(this,MKUINT(ID_REPLACE_DN,SEL_COMMAND),NULL);
       return 1;
     }
-  return 0;  
+  return 0;
   }
 
 
