@@ -3,7 +3,7 @@
 *                      S c r o l l A r e a   W i d g e t                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXScrollArea.cpp,v 1.18 2001/04/27 14:30:34 jeroen Exp $                 *
+* $Id: FXScrollArea.cpp,v 1.22.4.1 2003/06/20 19:02:07 fox Exp $                 *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -29,24 +29,10 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
-#include "FXDrawable.h"
-#include "FXImage.h"
-#include "FXIcon.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
-#include "FXComposite.h"
-#include "FXCanvas.h"
-#include "FXLabel.h"
-#include "FXButton.h"
 #include "FXScrollbar.h"
 #include "FXScrollArea.h"
 
@@ -67,6 +53,11 @@
   - Need margins [and item spacing]
   - Here's a new idea:- perhaps the scrollbars should be GUI-updated from the
     FXScrollArea.  Then layout() will do nothing but place the bars.
+  - What if we want to keep two scrolled windows in sync, i.e. scroll them
+    both the same amount.
+  - Do we need to be able to map mouse wheel to horizontal scrollbar instead?
+    or perhaps even both ways (depending on whether scrolling is possible
+    in one or another direction).
 */
 
 
@@ -78,7 +69,7 @@
 
 
 FXDEFMAP(FXScrollArea) FXScrollAreaMap[]={
-  FXMAPFUNC(SEL_MOUSEWHEEL,0,FXScrollArea::onMouseWheel),
+  FXMAPFUNC(SEL_MOUSEWHEEL,0,FXScrollArea::onVMouseWheel),
   FXMAPFUNC(SEL_COMMAND,FXWindow::ID_HSCROLLED,FXScrollArea::onHScrollerChanged),
   FXMAPFUNC(SEL_COMMAND,FXWindow::ID_VSCROLLED,FXScrollArea::onVScrollerChanged),
   FXMAPFUNC(SEL_CHANGED,FXWindow::ID_HSCROLLED,FXScrollArea::onHScrollerDragged),
@@ -169,7 +160,7 @@ void FXScrollArea::moveContents(FXint x,FXint y){
 
 // Changed
 long FXScrollArea::onHScrollerChanged(FXObject*,FXSelector,void* ptr){
-  FXint new_x=-(FXint)(long)ptr;
+  FXint new_x=-(FXint)(FXival)ptr;
   if(new_x!=pos_x){
     moveContents(new_x,pos_y);
     }
@@ -180,7 +171,7 @@ long FXScrollArea::onHScrollerChanged(FXObject*,FXSelector,void* ptr){
 
 // Changed
 long FXScrollArea::onVScrollerChanged(FXObject*,FXSelector,void* ptr){
-  FXint new_y=-(FXint)(long)ptr;
+  FXint new_y=-(FXint)(FXival)ptr;
   if(new_y!=pos_y){
     moveContents(pos_x,new_y);
     }
@@ -192,7 +183,7 @@ long FXScrollArea::onVScrollerChanged(FXObject*,FXSelector,void* ptr){
 // Dragged
 long FXScrollArea::onHScrollerDragged(FXObject*,FXSelector,void* ptr){
   if(!(options&SCROLLERS_DONT_TRACK)){
-    FXint new_x=-(FXint)(long)ptr;
+    FXint new_x=-(FXint)(FXival)ptr;
     if(new_x!=pos_x){
       moveContents(new_x,pos_y);
       }
@@ -205,7 +196,7 @@ long FXScrollArea::onHScrollerDragged(FXObject*,FXSelector,void* ptr){
 // Dragged
 long FXScrollArea::onVScrollerDragged(FXObject*,FXSelector,void* ptr){
   if(!(options&SCROLLERS_DONT_TRACK)){
-    FXint new_y=-(FXint)(long)ptr;
+    FXint new_y=-(FXint)(FXival)ptr;
     if(new_y!=pos_y){
       moveContents(pos_x,new_y);
       }
@@ -215,13 +206,20 @@ long FXScrollArea::onVScrollerDragged(FXObject*,FXSelector,void* ptr){
   }
 
 
-// Mouse wheel
-long FXScrollArea::onMouseWheel(FXObject* sender,FXSelector sel,void* ptr){
+// Mouse wheel used for vertical scrolling
+long FXScrollArea::onVMouseWheel(FXObject* sender,FXSelector sel,void* ptr){
   vertical->handle(sender,sel,ptr);
   return 1;
   }
 
 
+// Mouse wheel used for horizontal scrolling
+long FXScrollArea::onHMouseWheel(FXObject* sender,FXSelector sel,void* ptr){
+  horizontal->handle(sender,sel,ptr);
+  return 1;
+  }
+
+
 // Timeout
 long FXScrollArea::onAutoScroll(FXObject*,FXSelector sel,void*){
   FXint dx,dy;
