@@ -3,7 +3,7 @@
 *                         S c r o l l b a r   O b j e c t s                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXScrollbar.cpp,v 1.37 2001/07/26 22:28:08 jeroen Exp $                  *
+* $Id: FXScrollbar.cpp,v 1.40.4.2 2003/06/20 19:02:07 fox Exp $                  *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,16 +30,9 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
 #include "FXScrollbar.h"
 
 /*
@@ -50,8 +43,6 @@
   - In case of a coarse range, we have rounding also.
   - The API's setPosition(), setRange() and setPage() should probably have
     an optional notify callback.
-  - The calculation (pos*travel)/(range-page) can overflow for
-    extremely large documents.
 */
 
 
@@ -154,7 +145,7 @@ void FXScrollbar::layout(){
 
 // Update value from a message
 long FXScrollbar::onCmdSetValue(FXObject*,FXSelector,void* ptr){
-  setPosition((FXint)(long)ptr);
+  setPosition((FXint)(FXival)ptr);
   return 1;
   }
 
@@ -266,7 +257,7 @@ long FXScrollbar::onLeftBtnPress(FXObject*,FXSelector,void* ptr){
     if(p>(range-page)) p=range-page;
     if(p!=pos){
       setPosition(p);
-      if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)pos);
+      if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)pos);
       flags|=FLAG_CHANGED;
       }
     return 1;
@@ -290,7 +281,7 @@ long FXScrollbar::onLeftBtnRelease(FXObject*,FXSelector,void* ptr){
     if(timer){ timer=getApp()->removeTimeout(timer); }
     if(target && target->handle(this,MKUINT(message,SEL_LEFTBUTTONRELEASE),ptr)) return 1;
     if(flgs&FLAG_CHANGED){
-      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)pos);
+      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(FXival)pos);
       }
     return 1;
     }
@@ -321,7 +312,6 @@ long FXScrollbar::onMiddleBtnPress(FXObject*,FXSelector,void* ptr){
         update(lo,0,hi+thumbsize-lo,height);
         thumbpos=t;
         }
-//      if(travel>0){ p=((thumbpos-height)*(range-page))/travel; } else { p=0; }
       if(travel>0){ p=(((FXdouble)(thumbpos-height))*(range-page))/travel; } else { p=0; }
       }
     else{
@@ -334,14 +324,13 @@ long FXScrollbar::onMiddleBtnPress(FXObject*,FXSelector,void* ptr){
         update(0,lo,width,hi+thumbsize-lo);
         thumbpos=t;
         }
-//      if(travel>0){ p=((thumbpos-width)*(range-page))/travel; } else { p=0; }
       if(travel>0){ p=(((FXdouble)(thumbpos-width))*(range-page))/travel; } else { p=0; }
       }
     if(p<0) p=0;
     if(p>(range-page)) p=range-page;
     if(pos!=p){
       pos=p;
-      if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)pos);
+      if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)pos);
       flags|=FLAG_CHANGED;
       }
     return 1;
@@ -365,7 +354,7 @@ long FXScrollbar::onMiddleBtnRelease(FXObject*,FXSelector,void* ptr){
     if(timer){ timer=getApp()->removeTimeout(timer); }
     if(target && target->handle(this,MKUINT(message,SEL_MIDDLEBUTTONRELEASE),ptr)) return 1;
     if(flgs&FLAG_CHANGED){
-      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)pos);
+      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(FXival)pos);
       }
     return 1;
     }
@@ -447,7 +436,7 @@ long FXScrollbar::onRightBtnPress(FXObject*,FXSelector,void* ptr){
     if(p>(range-page)) p=range-page;
     if(p!=pos){
       setPosition(p);
-      if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)pos);
+      if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)pos);
       flags|=FLAG_CHANGED;
       }
     return 1;
@@ -471,7 +460,7 @@ long FXScrollbar::onRightBtnRelease(FXObject*,FXSelector,void* ptr){
     if(timer){ timer=getApp()->removeTimeout(timer); }
     if(target && target->handle(this,MKUINT(message,SEL_RIGHTBUTTONRELEASE),ptr)) return 1;
     if(flgs&FLAG_CHANGED){
-      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)pos);
+      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(FXival)pos);
       }
     return 1;
     }
@@ -511,7 +500,6 @@ long FXScrollbar::onMotion(FXObject*,FXSelector,void* ptr){
           update(lo,0,hi+thumbsize-lo,height);
           thumbpos=t;
           }
-//        if(travel>0){ p=((thumbpos-height)*(range-page)+travel/2)/travel; }
         if(travel>0){ p=(((FXdouble)(thumbpos-height))*(range-page)+travel/2)/travel; }
         }
       else{
@@ -524,7 +512,6 @@ long FXScrollbar::onMotion(FXObject*,FXSelector,void* ptr){
           update(0,lo,width,hi+thumbsize-lo);
           thumbpos=t;
           }
-//        if(travel>0){ p=((thumbpos-width)*(range-page)+travel/2)/travel; }
         if(travel>0){ p=(((FXdouble)(thumbpos-width))*(range-page)+travel/2)/travel; }
         }
       }
@@ -534,7 +521,6 @@ long FXScrollbar::onMotion(FXObject*,FXSelector,void* ptr){
         p=pos+event->win_x-event->last_x;
         if(p<0) p=0;
         if(p>(range-page)) p=range-page;
-//        if(range>page){ t=height+(pos*travel)/(range-page); } else { t=height; }
         if(range>page){ t=height+(((FXdouble)pos)*travel)/(range-page); } else { t=height; }
         if(t!=thumbpos){
           FXMINMAX(lo,hi,t,thumbpos);
@@ -547,7 +533,6 @@ long FXScrollbar::onMotion(FXObject*,FXSelector,void* ptr){
         p=pos+event->win_y-event->last_y;
         if(p<0) p=0;
         if(p>(range-page)) p=range-page;
-//        if(range>page){ t=width+(pos*travel)/(range-page); } else { t=width; }
         if(range>page){ t=width+(((FXdouble)pos)*travel)/(range-page); } else { t=width; }
         if(t!=thumbpos){
           FXMINMAX(lo,hi,t,thumbpos);
@@ -560,7 +545,7 @@ long FXScrollbar::onMotion(FXObject*,FXSelector,void* ptr){
     if(p>(range-page)) p=range-page;
     if(pos!=p){
       pos=p;
-      if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)pos);
+      if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)pos);
       flags|=FLAG_CHANGED;
       return 1;
       }
@@ -576,7 +561,7 @@ long FXScrollbar::onMouseWheel(FXObject*,FXSelector,void* ptr){
   if(isEnabled()){
     if(timer) timer=getApp()->removeTimeout(timer);
     if(!(ev->state&(LEFTBUTTONMASK|MIDDLEBUTTONMASK|RIGHTBUTTONMASK))){
-      if(ev->state&ALTMASK) jump=1;                         // Fine scrolling
+      if(ev->state&ALTMASK) jump=line;                      // Fine scrolling
       else if(ev->state&CONTROLMASK) jump=page;             // Coarse scrolling
       else jump=FXMIN(page,getApp()->getWheelLines()*line); // Normal scrolling
       if(dragpoint==0) dragpoint=pos;                       // Were not scrolling already?
@@ -603,12 +588,12 @@ long FXScrollbar::onTimeWheel(FXObject*,FXSelector,void*){
     p=pos+dragjump;
     if(p<=dragpoint){
       setPosition(dragpoint);
-      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)pos);
+      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(FXival)pos);
       dragpoint=0;
       }
     else{
       setPosition(p);
-      if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)pos);
+      if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)pos);
       timer=getApp()->addTimeout(5,this,ID_TIMEWHEEL);
       }
     }
@@ -616,12 +601,12 @@ long FXScrollbar::onTimeWheel(FXObject*,FXSelector,void*){
     p=pos+dragjump;
     if(p>=dragpoint){
       setPosition(dragpoint);
-      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)pos);
+      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(FXival)pos);
       dragpoint=0;
       }
     else{
       setPosition(p);
-      if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)pos);
+      if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)pos);
       timer=getApp()->addTimeout(5,this,ID_TIMEWHEEL);
       }
     }
@@ -641,7 +626,7 @@ long FXScrollbar::onTimeIncPix(FXObject*,FXSelector,void*){
     }
   if(p!=pos){
     setPosition(p);
-    if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)pos);
+    if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)pos);
     flags|=FLAG_CHANGED;
     return 1;
     }
@@ -661,7 +646,7 @@ long FXScrollbar::onTimeIncLine(FXObject*,FXSelector,void*){
     }
   if(p!=pos){
     setPosition(p);
-    if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)pos);
+    if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)pos);
     flags|=FLAG_CHANGED;
     return 1;
     }
@@ -681,7 +666,7 @@ long FXScrollbar::onTimeIncPage(FXObject*,FXSelector,void*){
     }
   if(p!=pos){
     setPosition(p);
-    if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)pos);
+    if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)pos);
     flags|=FLAG_CHANGED;
     return 1;
     }
@@ -701,7 +686,7 @@ long FXScrollbar::onTimeDecPix(FXObject*,FXSelector,void*){
     }
   if(p!=pos){
     setPosition(p);
-    if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)pos);
+    if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)pos);
     flags|=FLAG_CHANGED;
     return 1;
     }
@@ -721,7 +706,7 @@ long FXScrollbar::onTimeDecLine(FXObject*,FXSelector,void*){
     }
   if(p!=pos){
     setPosition(p);
-    if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)pos);
+    if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)pos);
     flags|=FLAG_CHANGED;
     return 1;
     }
@@ -741,7 +726,7 @@ long FXScrollbar::onTimeDecPage(FXObject*,FXSelector,void*){
     }
   if(p!=pos){
     setPosition(p);
-    if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)pos);
+    if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)pos);
     flags|=FLAG_CHANGED;
     return 1;
     }
@@ -977,7 +962,7 @@ void FXScrollbar::setLine(FXint l){
   }
 
 
-// Set position; tricky because the thumb size may have changes
+// Set position; tricky because the thumb size may have changed
 // as well; we do the minimal possible update to repaint properly.
 void FXScrollbar::setPosition(FXint p){
   FXint total,travel,lo,hi,l,h;
@@ -991,11 +976,10 @@ void FXScrollbar::setPosition(FXint p){
     thumbsize=(total*page)/range;
     if(thumbsize<THUMB_MINIMUM) thumbsize=THUMB_MINIMUM;
     travel=total-thumbsize;
-//    if(range>page){ thumbpos=height+(pos*travel)/(range-page); } else { thumbpos=height; }
     if(range>page){ thumbpos=height+(((FXdouble)pos)*travel)/(range-page); } else { thumbpos=height; }
     l=thumbpos;
     h=thumbpos+thumbsize;
-    if(l<=lo || hi<=h){
+    if(l!=lo || h!=hi){
       update(FXMIN(l,lo),0,FXMAX(h,hi)-FXMIN(l,lo),height);
       }
     }
@@ -1004,11 +988,10 @@ void FXScrollbar::setPosition(FXint p){
     thumbsize=(total*page)/range;
     if(thumbsize<THUMB_MINIMUM) thumbsize=THUMB_MINIMUM;
     travel=total-thumbsize;
-//    if(range>page){ thumbpos=width+(pos*travel)/(range-page); } else { thumbpos=width; }
     if(range>page){ thumbpos=width+(((FXdouble)pos)*travel)/(range-page); } else { thumbpos=width; }
     l=thumbpos;
     h=thumbpos+thumbsize;
-    if(l<=lo || hi<=h){
+    if(l!=lo || h!=hi){
       update(0,FXMIN(l,lo),width,FXMAX(h,hi)-FXMIN(l,lo));
       }
     }
@@ -1017,22 +1000,28 @@ void FXScrollbar::setPosition(FXint p){
 
 // Set highlight color
 void FXScrollbar::setHiliteColor(FXColor clr){
-  hiliteColor=clr;
-  update();
+  if(hiliteColor!=clr){
+    hiliteColor=clr;
+    update();
+    }
   }
 
 
 // Set shadow color
 void FXScrollbar::setShadowColor(FXColor clr){
-  shadowColor=clr;
-  update();
+  if(shadowColor!=clr){
+    shadowColor=clr;
+    update();
+    }
   }
 
 
 // Set border color
 void FXScrollbar::setBorderColor(FXColor clr){
-  borderColor=clr;
-  update();
+  if(borderColor!=clr){
+    borderColor=clr;
+    update();
+    }
   }
 
 
