@@ -3,7 +3,7 @@
 *                           S e t t i n g s   C l a s s                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,15 +19,19 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXSettings.cpp,v 1.5 2001/07/06 21:33:12 jeroen Exp $                    *
+* $Id: FXSettings.cpp,v 1.16.4.1 2002/11/13 15:14:07 fox Exp $                      *
 ********************************************************************************/
+#ifdef HAVE_VSSCANF
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE
+#endif
+#endif
 #include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
 #include "FXStream.h"
-#include "FXObject.h"
-#include "FXDict.h"
 #include "FXString.h"
+#include "FXStringDict.h"
 #include "FXSettings.h"
 
 /*
@@ -44,6 +48,8 @@
 
   - Leading/trailing spaces are NOT part of the EntryKey.
 
+  - FXSectionDict should go; FXSettings should simply derive from FXDict.
+
 */
 
 #define MAXBUFFER 2000
@@ -53,12 +59,28 @@
 
 /*******************************************************************************/
 
+// Object implementation
+FXIMPLEMENT(FXSettings,FXDict,NULL,0)
+
+
 // Make registry object
 FXSettings::FXSettings(){
   modified=FALSE;
   }
 
 
+// Create data
+void *FXSettings::createData(const void*){
+  return new FXStringDict;
+  }
+
+
+// Delete data
+void FXSettings::deleteData(void* ptr){
+  delete ((FXStringDict*)ptr);
+  }
+
+
 // Parse filename
 FXbool FXSettings::parseFile(const FXString& filename,FXbool mark){
   FXchar buffer[MAXBUFFER],name[MAXNAME],value[MAXVALUE];
@@ -73,7 +95,7 @@ FXbool FXSettings::parseFile(const FXString& filename,FXbool mark){
     group=NULL;
     lineno=1;
     while(fgets(buffer,MAXBUFFER,file)!=NULL){
-      
+
       // Parse buffer
       ptr=buffer;
 
@@ -88,12 +110,12 @@ FXbool FXSettings::parseFile(const FXString& filename,FXbool mark){
         ptr++;
         len=0;
         while((c=*ptr)!='\0' && c!=']'){
-          if(!isalnum((FXuchar)c) && c!='_' && c!='-' && c!='.' && c!=' '){
+          if((FXuchar)c<' '){
             fxwarning("%s:%d: illegal section name.\n",filename.text(),lineno);
             goto next;
             }
           if(len>=MAXNAME){
-            fxwarning("%s:%d: section name to long.\n",filename.text(),lineno);
+            fxwarning("%s:%d: section name too long.\n",filename.text(),lineno);
             goto next;
             }
           name[len]=c;
@@ -103,7 +125,7 @@ FXbool FXSettings::parseFile(const FXString& filename,FXbool mark){
         name[len]='\0';
 
         // Add new section dict
-        group=sections.insert(name);
+        group=insert(name);
         }
 
       // Parse key name
@@ -118,12 +140,12 @@ FXbool FXSettings::parseFile(const FXString& filename,FXbool mark){
         // Transfer key, checking validity
         len=0;
         while((c=*ptr)!='\0' && c!='='){
-          if(!isalnum((FXuchar)c) && c!='_' && c!='-' && c!='.' && c!=' ' && c!='/' && c!='\\' && c!=':'){
+          if((FXuchar)c<' '){
             fxwarning("%s:%d: illegal key name.\n",filename.text(),lineno);
             goto next;
             }
           if(len>=MAXNAME-1){
-            fxwarning("%s:%d: key name to long.\n",filename.text(),lineno);
+            fxwarning("%s:%d: key name too long.\n",filename.text(),lineno);
             goto next;
             }
           name[len]=c;
@@ -253,55 +275,55 @@ FXbool FXSettings::unparseFile(const FXString& filename){
   file=fopen(filename.text(),"w");
   if(file){
     FXTRACE((100,"Writing settings file: %s\n",filename.text()));
-    
+
     // Loop over all sections
-    for(s=sections.first(); s<sections.size(); s=sections.next(s)){
-      
+    for(s=first(); s<size(); s=next(s)){
+
       // Get group
-      group=sections.data(s);
+      group=data(s);
       FXASSERT(group);
       sec=FALSE;
-      
+
       // Loop over all entries
       for(e=group->first(); e<group->size(); e=group->next(e)){
         mrk=group->mark(e);
-        
+
         // Write section name if not written yet
         if(mrk && !sec){
-          FXASSERT(sections.key(s));
+          FXASSERT(key(s));
           fputc('[',file);
-          fputs(sections.key(s),file);
+          fputs(key(s),file);
           fputc(']',file);
           fputc('\n',file);
           sec=TRUE;
           }
-        
+
         // Only write marked entries
         if(mrk){
           FXASSERT(group->key(e));
           FXASSERT(group->data(e));
-          
+
           // Write key name
           fputs(group->key(e),file);
           fputc('=',file);
-          
+
           // Write quoted value
           if(unparseValue(buffer,group->data(e))){
             fputc('"',file);
             fputs(buffer,file);
             fputc('"',file);
             }
-          
+
           // Write unquoted
           else{
             fputs(buffer,file);
             }
-          
+
           // End of line
           fputc('\n',file);
           }
         }
-      
+
       // Blank line after end
       if(sec){
         fputc('\n',file);
@@ -394,11 +416,37 @@ FXbool FXSettings::unparseValue(FXchar* buffer,const FXchar* value){
   }
 
 
+// Furnish our own version if we have to
+#ifndef HAVE_VSSCANF
+extern "C" int vsscanf(const char* str, const char* format, va_list arg_ptr);
+#endif
+
+
+// Read a formatted registry entry
+FXint FXSettings::readFormatEntry(const FXchar *section,const FXchar *key,const FXchar *fmt,...){
+  if(!section){ fxerror("FXSettings::readFormatEntry: NULL section argument.\n"); }
+  if(!key){ fxerror("FXSettings::readFormatEntry: NULL key argument.\n"); }
+  if(!fmt){ fxerror("FXSettings::readFormatEntry: NULL fmt argument.\n"); }
+  FXStringDict *group=find(section);
+  va_list args;
+  va_start(args,fmt);
+  FXint result=0;
+  if(group){
+    const char *value=group->find(key);
+    if(value){
+      result=vsscanf((char*)value,fmt,args);    // Cast needed for HP-UX 11, which has wrong prototype for vsscanf
+      }
+    }
+  va_end(args);
+  return result;
+  }
+
+
 // Read a string-valued registry entry
 const FXchar *FXSettings::readStringEntry(const FXchar *section,const FXchar *key,const FXchar *def){
   if(!section){ fxerror("FXSettings::readStringEntry: NULL section argument.\n"); }
   if(!key){ fxerror("FXSettings::readStringEntry: NULL key argument.\n"); }
-  FXStringDict *group=sections.find(section);
+  FXStringDict *group=find(section);
   if(group){
     const char *value=group->find(key);
     if(value) return value;
@@ -411,7 +459,7 @@ const FXchar *FXSettings::readStringEntry(const FXchar *section,const FXchar *ke
 FXint FXSettings::readIntEntry(const FXchar *section,const FXchar *key,FXint def){
   if(!section){ fxerror("FXSettings::readIntEntry: NULL section argument.\n"); }
   if(!key){ fxerror("FXSettings::readIntEntry: NULL key argument.\n"); }
-  FXStringDict *group=sections.find(section);
+  FXStringDict *group=find(section);
   if(group){
     const char *value=group->find(key);
     if(value){
@@ -432,7 +480,7 @@ FXint FXSettings::readIntEntry(const FXchar *section,const FXchar *key,FXint def
 FXuint FXSettings::readUnsignedEntry(const FXchar *section,const FXchar *key,FXuint def){
   if(!section){ fxerror("FXSettings::readUnsignedEntry: NULL section argument.\n"); }
   if(!key){ fxerror("FXSettings::readUnsignedEntry: NULL key argument.\n"); }
-  FXStringDict *group=sections.find(section);
+  FXStringDict *group=find(section);
   if(group){
     const char *value=group->find(key);
     if(value){
@@ -453,7 +501,7 @@ FXuint FXSettings::readUnsignedEntry(const FXchar *section,const FXchar *key,FXu
 FXdouble FXSettings::readRealEntry(const FXchar *section,const FXchar *key,FXdouble def){
   if(!section){ fxerror("FXSettings::readRealEntry: NULL section argument.\n"); }
   if(!key){ fxerror("FXSettings::readRealEntry: NULL key argument.\n"); }
-  FXStringDict *group=sections.find(section);
+  FXStringDict *group=find(section);
   if(group){
     const char *value=group->find(key);
     if(value){
@@ -469,7 +517,7 @@ FXdouble FXSettings::readRealEntry(const FXchar *section,const FXchar *key,FXdou
 FXColor FXSettings::readColorEntry(const FXchar *section,const FXchar *key,FXColor def){
   if(!section){ fxerror("FXSettings::readColorEntry: NULL section argument.\n"); }
   if(!key){ fxerror("FXSettings::readColorEntry: NULL key argument.\n"); }
-  FXStringDict *group=sections.find(section);
+  FXStringDict *group=find(section);
   if(group){
     const char *value=group->find(key);
     if(value){
@@ -480,11 +528,35 @@ FXColor FXSettings::readColorEntry(const FXchar *section,const FXchar *key,FXCol
   }
 
 
+// Write a formatted registry entry
+FXint FXSettings::writeFormatEntry(const FXchar *section,const FXchar *key,const FXchar *fmt,...){
+  if(!section){ fxerror("FXSettings::writeFormatEntry: NULL section argument.\n"); }
+  if(!key){ fxerror("FXSettings::writeFormatEntry: NULL key argument.\n"); }
+  if(!fmt){ fxerror("FXSettings::writeFormatEntry: NULL fmt argument.\n"); }
+  FXStringDict *group=insert(section);
+  va_list args;
+  va_start(args,fmt);
+  FXint result=0;
+  if(group){
+    FXchar buffer[2000];
+#if defined(__GLIBC__) || defined(WIN32)                // Try to be safe about it...
+    result=vsnprintf(buffer,sizeof(buffer),fmt,args);
+#else
+    result=vsprintf(buffer,fmt,args);
+#endif
+    group->replace(key,buffer,TRUE);
+    modified=TRUE;
+    }
+  va_end(args);
+  return result;
+  }
+
+
 // Write a string-valued registry entry
 FXbool FXSettings::writeStringEntry(const FXchar *section,const FXchar *key,const FXchar *val){
   if(!section){ fxerror("FXSettings::writeStringEntry: NULL section argument.\n"); }
   if(!key){ fxerror("FXSettings::writeStringEntry: NULL key argument.\n"); }
-  FXStringDict *group=sections.insert(section);
+  FXStringDict *group=insert(section);
   if(group){
     group->replace(key,val,TRUE);
     modified=TRUE;
@@ -498,7 +570,7 @@ FXbool FXSettings::writeStringEntry(const FXchar *section,const FXchar *key,cons
 FXbool FXSettings::writeIntEntry(const FXchar *section,const FXchar *key,FXint val){
   if(!section){ fxerror("FXSettings::writeIntEntry: NULL section argument.\n"); }
   if(!key){ fxerror("FXSettings::writeIntEntry: NULL key argument.\n"); }
-  FXStringDict *group=sections.insert(section);
+  FXStringDict *group=insert(section);
   if(group){
     FXchar buffer[10];
     sprintf(buffer,"%d",val);
@@ -514,7 +586,7 @@ FXbool FXSettings::writeIntEntry(const FXchar *section,const FXchar *key,FXint v
 FXbool FXSettings::writeUnsignedEntry(const FXchar *section,const FXchar *key,FXuint val){
   if(!section){ fxerror("FXSettings::writeUnsignedEntry: NULL section argument.\n"); }
   if(!key){ fxerror("FXSettings::writeUnsignedEntry: NULL key argument.\n"); }
-  FXStringDict *group=sections.insert(section);
+  FXStringDict *group=insert(section);
   if(group){
     FXchar buffer[10];
     sprintf(buffer,"%u",val);
@@ -530,7 +602,7 @@ FXbool FXSettings::writeUnsignedEntry(const FXchar *section,const FXchar *key,FX
 FXbool FXSettings::writeRealEntry(const FXchar *section,const FXchar *key,FXdouble val){
   if(!section){ fxerror("FXSettings::writeRealEntry: NULL section argument.\n"); }
   if(!key){ fxerror("FXSettings::writeRealEntry: NULL key argument.\n"); }
-  FXStringDict *group=sections.insert(section);
+  FXStringDict *group=insert(section);
   if(group){
     FXchar buffer[60];
     sprintf(buffer,"%.16g",val);
@@ -546,7 +618,7 @@ FXbool FXSettings::writeRealEntry(const FXchar *section,const FXchar *key,FXdoub
 FXbool FXSettings::writeColorEntry(const FXchar *section,const FXchar *key,FXColor val){
   if(!section){ fxerror("FXSettings::writeColorEntry: NULL section argument.\n"); }
   if(!key){ fxerror("FXSettings::writeColorEntry: NULL key argument.\n"); }
-  FXStringDict *group=sections.insert(section);
+  FXStringDict *group=insert(section);
   if(group){
     FXchar buffer[60];
     group->replace(key,fxnamefromcolor(buffer,val),TRUE);
@@ -561,7 +633,7 @@ FXbool FXSettings::writeColorEntry(const FXchar *section,const FXchar *key,FXCol
 FXbool FXSettings::deleteEntry(const FXchar *section,const FXchar *key){
   if(!section){ fxerror("FXSettings::deleteEntry: NULL section argument.\n"); }
   if(!key){ fxerror("FXSettings::deleteEntry: NULL key argument.\n"); }
-  FXStringDict *group=sections.insert(section);
+  FXStringDict *group=insert(section);
   if(group){
     group->remove(key);
     modified=TRUE;
@@ -574,7 +646,7 @@ FXbool FXSettings::deleteEntry(const FXchar *section,const FXchar *key){
 // Delete section
 FXbool FXSettings::deleteSection(const FXchar *section){
   if(!section){ fxerror("FXSettings::deleteSection: NULL section argument.\n"); }
-  sections.remove(section);
+  remove(section);
   modified=TRUE;
   return TRUE;
   }
@@ -582,7 +654,7 @@ FXbool FXSettings::deleteSection(const FXchar *section){
 
 // Clear all sections
 FXbool FXSettings::clear(){
-  sections.clear();
+  FXDict::clear();
   modified=TRUE;
   return TRUE;
   }
@@ -591,7 +663,7 @@ FXbool FXSettings::clear(){
 // See if section exists
 FXbool FXSettings::existingSection(const FXchar *section){
   if(!section){ fxerror("FXSettings::existingSection: NULL section argument.\n"); }
-  return sections.find(section)!=NULL;
+  return find(section)!=NULL;
   }
 
 
@@ -599,7 +671,12 @@ FXbool FXSettings::existingSection(const FXchar *section){
 FXbool FXSettings::existingEntry(const FXchar *section,const FXchar *key){
   if(!section){ fxerror("FXSettings::existingEntry: NULL section argument.\n"); }
   if(!key){ fxerror("FXSettings::existingEntry: NULL key argument.\n"); }
-  FXStringDict *group=sections.find(section);
+  FXStringDict *group=find(section);
   return group && group->find(key)!=NULL;
   }
 
+
+// Clean up
+FXSettings::~FXSettings(){
+  clear();
+  }
