@@ -3,7 +3,7 @@
 *                     S h e l l   W i n d o w   O b j e c t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXShell.cpp,v 1.42 2001/08/15 06:33:38 jeroen Exp $                      *
+* $Id: FXShell.cpp,v 1.55 2002/01/18 22:43:04 jeroen Exp $                      *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,18 +30,9 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXCursor.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXComposite.h"
-#include "FXRootWindow.h"
 #include "FXShell.h"
 
 
@@ -54,13 +45,13 @@
 */
 
 
-#define DISPLAY(app) ((Display*)((app)->display))
-
 /*******************************************************************************/
 
 // Map
 FXDEFMAP(FXShell) FXShellMap[]={
   FXMAPFUNC(SEL_CONFIGURE,0,FXShell::onConfigure),
+  FXMAPFUNC(SEL_KEYPRESS,0,FXShell::onKeyPress),
+  FXMAPFUNC(SEL_KEYRELEASE,0,FXShell::onKeyRelease),
   FXMAPFUNC(SEL_FOCUS_NEXT,0,FXShell::onFocusNext),
   FXMAPFUNC(SEL_FOCUS_PREV,0,FXShell::onFocusPrev),
   };
@@ -120,6 +111,25 @@ void FXShell::killFocus(){
   }
 
 
+// // Set initial default window
+// void FXShell::setInitialWindow(FXWindow* window){
+//   initialWindow=window;
+//   defaultWindow=window;
+//   if(window) window->setDefault(TRUE);
+//   }
+//
+//
+// // Set default window
+// void FXShell::setDefaultWindow(FXWindow *window){
+//   if(!window) window=initialWindow;
+//   if(defaultWindow!=window){
+//     if(defaultWindow) defaultWindow->setDefault(FALSE);
+//     defaultWindow=window;
+//     if(defaultWindow) defaultWindow->setDefault(TRUE);
+//     }
+//   }
+//
+
 // Handle configure notify
 long FXShell::onConfigure(FXObject* sender,FXSelector sel,void* ptr){
   FXEvent *ev=(FXEvent*)ptr;
@@ -192,6 +202,123 @@ long FXShell::onFocusPrev(FXObject* sender,FXSelector sel,void* ptr){
   }
 
 
+// // Keyboard press
+// long FXShell::onKeyPress(FXObject* sender,FXSelector sel,void* ptr){
+//   register FXWindow *def;
+//
+//   // Handle normal keys
+//   if(((FXEvent*)ptr)->code!=KEY_Return && ((FXEvent*)ptr)->code!=KEY_KP_Enter){
+//
+//     // Bounce to focus widget
+//     if(getFocus() && getFocus()->handle(sender,sel,ptr)) return 1;
+//
+//     // Try target first
+//     if(isEnabled() && target && target->handle(this,MKUINT(message,SEL_KEYPRESS),ptr)) return 1;
+//
+//     // Check the accelerators
+//     if(getAccelTable() && getAccelTable()->handle(this,sel,ptr)) return 1;
+//
+//     // Otherwise, perform the default keyboard processing
+//     switch(((FXEvent*)ptr)->code){
+//       case KEY_Tab:
+//         if(((FXEvent*)ptr)->state&SHIFTMASK) goto prv;
+//       case KEY_Next:
+//         return handle(this,MKUINT(0,SEL_FOCUS_NEXT),ptr);
+//       case KEY_Prior:
+//       case KEY_ISO_Left_Tab:
+// prv:    return handle(this,MKUINT(0,SEL_FOCUS_PREV),ptr);
+//       case KEY_Up:
+//       case KEY_KP_Up:
+//         return handle(this,MKUINT(0,SEL_FOCUS_UP),ptr);
+//       case KEY_Down:
+//       case KEY_KP_Down:
+//         return handle(this,MKUINT(0,SEL_FOCUS_DOWN),ptr);
+//       case KEY_Left:
+//       case KEY_KP_Left:
+//         return handle(this,MKUINT(0,SEL_FOCUS_LEFT),ptr);
+//       case KEY_Right:
+//       case KEY_KP_Right:
+//         return handle(this,MKUINT(0,SEL_FOCUS_RIGHT),ptr);
+//       }
+//     return 0;
+//     }
+//
+//   // Find default widget
+//   def=findDefault(this);
+//
+//   // Handle default key
+//   if(def && def->handle(sender,sel,ptr)) return 1;
+//
+//   return 0;
+//   }
+
+// // Keyboard release
+// long FXShell::onKeyRelease(FXObject* sender,FXSelector sel,void* ptr){
+//   register FXWindow *def;
+//
+//   // Handle normal keys
+//   if(((FXEvent*)ptr)->code!=KEY_Return && ((FXEvent*)ptr)->code!=KEY_KP_Enter){
+//
+//     // Bounce to focus widget
+//     if(getFocus() && getFocus()->handle(sender,sel,ptr)) return 1;
+//
+//     // Try target first
+//     if(isEnabled() && target && target->handle(this,MKUINT(message,SEL_KEYRELEASE),ptr)) return 1;
+//
+//     // Check the accelerators
+//     if(getAccelTable() && getAccelTable()->handle(this,sel,ptr)) return 1;
+//
+//     return 0;
+//     }
+//
+//   // Find default widget
+//   def=findDefault(this);
+//
+//   // Handle default key
+//   if(def && def->handle(sender,sel,ptr)) return 1;
+//
+//   return 0;
+//   }
+
+
+// Keyboard press
+long FXShell::onKeyPress(FXObject* sender,FXSelector sel,void* ptr){
+
+  // Try to handle normally
+  if(FXComposite::onKeyPress(sender,sel,ptr)) return 1;
+
+  // If not handled yet, try the default button
+  if(((FXEvent*)ptr)->code==KEY_Return || ((FXEvent*)ptr)->code==KEY_KP_Enter){
+
+    // Find default widget
+    FXWindow *def=findDefault(this);
+
+    // Handle default key
+    if(def && def->handle(sender,sel,ptr)) return 1;
+    }
+  return 0;
+  }
+
+
+// Keyboard release
+long FXShell::onKeyRelease(FXObject* sender,FXSelector sel,void* ptr){
+
+  // Try to handle normally
+  if(FXComposite::onKeyRelease(sender,sel,ptr)) return 1;
+
+  // If not handled yet, try the default button
+  if(((FXEvent*)ptr)->code==KEY_Return || ((FXEvent*)ptr)->code==KEY_KP_Enter){
+
+    // Find default widget
+    FXWindow *def=findDefault(this);
+
+    // Handle default key
+    if(def && def->handle(sender,sel,ptr)) return 1;
+    }
+  return 0;
+  }
+
+
 // Destruct
 FXShell::~FXShell(){
   }
