@@ -3,7 +3,7 @@
 *                 V e r t i c a l   C o n t a i n e r   O b j e c t             *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * Contributed by: Charles W. Warren                                             *
 *********************************************************************************
@@ -21,7 +21,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXShutter.cpp,v 1.16 2001/04/27 14:30:34 jeroen Exp $                    *
+* $Id: FXShutter.cpp,v 1.18.4.2 2003/06/20 19:02:07 fox Exp $                    *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -31,28 +31,18 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDrawable.h"
-#include "FXImage.h"
 #include "FXIcon.h"
-#include "FXWindow.h"
 #include "FXFrame.h"
-#include "FXComposite.h"
 #include "FXPacker.h"
 #include "FXVerticalFrame.h"
 #include "FXLabel.h"
 #include "FXButton.h"
 #include "FXScrollbar.h"
-#include "FXScrollArea.h"
 #include "FXScrollWindow.h"
 #include "FXShutter.h"
-#include "FXShell.h"
 
 /*
   Notes:
@@ -154,7 +144,7 @@ FXDEFMAP(FXShutter) FXShutterMap[]={
 
 
 // Object implementation
-FXIMPLEMENT(FXShutter,FXPacker,FXShutterMap,ARRAYNUMBER(FXShutterMap))
+FXIMPLEMENT(FXShutter,FXVerticalFrame,FXShutterMap,ARRAYNUMBER(FXShutterMap))
 
 
 // Make shutter
@@ -182,9 +172,10 @@ long FXShutter::onFocusDown(FXObject* sender,FXSelector sel,void* ptr){
   return FXVerticalFrame::onFocusNext(sender,sel,ptr);
   }
 
+
 // Update value from a message
 long FXShutter::onCmdSetValue(FXObject*,FXSelector,void* ptr){
-  setCurrent((FXint)(long)ptr);
+  setCurrent((FXint)(FXival)ptr);
   return 1;
   }
 
@@ -231,7 +222,7 @@ long FXShutter::onOpenItem(FXObject* sender,FXSelector,void*){
     closingHeight=closingItem->getHeight();
     closingHadScrollbar=closingItem->scrollWindow->verticalScrollbar()->shown();
     timer=getApp()->addTimeout(getApp()->getAnimSpeed(),this,FXShutter::ID_SHUTTER_TIMEOUT);
-    if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)current);
+    if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(FXival)current);
     }
   return 1;
   }
