@@ -3,7 +3,7 @@
 *                             S l i d e r   O b j e c t s                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXSlider.cpp,v 1.28 2001/08/28 22:52:27 jeroen Exp $                     *
+* $Id: FXSlider.cpp,v 1.33.4.2 2003/06/20 19:02:07 fox Exp $                     *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -29,17 +29,9 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
 #include "FXSlider.h"
 
 
@@ -47,7 +39,6 @@
 
 /*
   Notes:
-  - Add other options for tickmarks and so on.
   - Add API's to change sizes and appearance.
   - Dual/triple head options.
   - Need to be able to disable/enable, head should show/hide.
@@ -62,12 +53,13 @@
   - In case of a coarse range, we have rounding also.
 */
 
+#define TICKSIZE        4           // Length of ticks
 #define OVERHANG        4           // Default amount of overhang
 #define MINOVERHANG     3           // Minimal amount of overhang
 #define HEADINSIDEBAR   20          // Default for inside bar head size
 #define HEADOVERHANGING 9           // Default for overhanging head size
 
-#define SLIDER_MASK (SLIDER_VERTICAL|SLIDER_ARROW_UP|SLIDER_ARROW_DOWN|SLIDER_INSIDE_BAR)
+#define SLIDER_MASK (SLIDER_VERTICAL|SLIDER_ARROW_UP|SLIDER_ARROW_DOWN|SLIDER_INSIDE_BAR|SLIDER_TICKS_TOP|SLIDER_TICKS_BOTTOM)
 
 /*******************************************************************************/
 
@@ -121,6 +113,7 @@ FXSlider::FXSlider(FXComposite* p,FXObject* tgt,FXSelector sel,FXuint opts,FXint
   range[1]=100;
   pos=50;
   incr=1;
+  delta=0;
   slotColor=getApp()->getBackColor();
   baseColor=getApp()->getBaseColor();
   hiliteColor=getApp()->getHiliteColor();
@@ -151,6 +144,46 @@ void FXSlider::disable(){
   }
 
 
+// Return head position from value
+FXint FXSlider::headPos(FXint v) const {
+  register FXint travel,rr,p;
+  if(v<range[0]) v=range[0];
+  if(v>range[1]) v=range[1];
+  rr=range[1]-range[0];
+  if(options&SLIDER_VERTICAL){
+    p=border+padtop+2;
+    travel=height-(border<<1)-padtop-padbottom-headsize-4;
+    if(rr>0) p+=(travel*(range[1]-v))/rr;
+    }
+  else{
+    p=border+padleft+2;
+    travel=width-(border<<1)-padleft-padright-headsize-4;
+    if(rr>0) p+=(travel*(v-range[0]))/rr;
+    }
+  return p;
+  }
+
+
+// Return value from head position
+FXint FXSlider::headVal(FXint p) const {
+  register FXint travel,rr,v;
+  rr=range[1]-range[0];
+  if(options&SLIDER_VERTICAL){
+    v=range[0];
+    travel=height-(border<<1)-padtop-padbottom-headsize-4;
+    if(travel>0) v+=(rr*(border+padtop+2+travel-p)+travel/2)/travel;
+    }
+  else{
+    v=range[0];
+    travel=width-(border<<1)-padleft-padright-headsize-4;
+    if(travel>0) v+=(rr*(p-border-padleft-2)+travel/2)/travel;
+    }
+  if(v<range[0]) v=range[0];
+  if(v>range[1]) v=range[1];
+  return v;
+  }
+
+
 // Get default size
 FXint FXSlider::getDefaultWidth(){
   FXint w;
@@ -158,6 +191,8 @@ FXint FXSlider::getDefaultWidth(){
     if(options&SLIDER_INSIDE_BAR) w=4+headsize/2;
     else if(options&(SLIDER_ARROW_LEFT|SLIDER_ARROW_RIGHT)) w=slotsize+MINOVERHANG*2+headsize/2;
     else w=slotsize+MINOVERHANG*2;
+    if(options&SLIDER_TICKS_LEFT) w+=TICKSIZE;
+    if(options&SLIDER_TICKS_RIGHT) w+=TICKSIZE;
     }
   else{
     w=headsize+4;
@@ -175,6 +210,8 @@ FXint FXSlider::getDefaultHeight(){
     if(options&SLIDER_INSIDE_BAR) h=4+headsize/2;
     else if(options&(SLIDER_ARROW_UP|SLIDER_ARROW_DOWN)) h=slotsize+2*MINOVERHANG+headsize/2;
     else h=slotsize+MINOVERHANG*2;
+    if(options&SLIDER_TICKS_TOP) h+=TICKSIZE;
+    if(options&SLIDER_TICKS_BOTTOM) h+=TICKSIZE;
     }
   return h+padtop+padbottom+(border<<1);
   }
@@ -210,7 +247,7 @@ long FXSlider::onQueryTip(FXObject* sender,FXSelector,void*){
 
 // Update value from a message
 long FXSlider::onCmdSetValue(FXObject*,FXSelector,void* ptr){
-  setValue((FXint)(long)ptr);
+  setValue((FXint)(FXival)ptr);
   return 1;
   }
 
@@ -313,7 +350,7 @@ long FXSlider::onLeftBtnPress(FXObject*,FXSelector,void* ptr){
     if(p>range[1]) p=range[1];
     if(p!=pos){
       setValue(p);
-      if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)pos);
+      if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)pos);
       flags|=FLAG_CHANGED;
       }
     flags&=~FLAG_UPDATE;
@@ -333,9 +370,9 @@ long FXSlider::onLeftBtnRelease(FXObject*,FXSelector,void* ptr){
     flags&=~FLAG_PRESSED;
     flags&=~FLAG_CHANGED;
     flags|=FLAG_UPDATE;
-    if(target && target->handle(this,MKUINT(message,SEL_LEFTBUTTONPRESS),ptr)) return 1;
+    if(target && target->handle(this,MKUINT(message,SEL_LEFTBUTTONRELEASE),ptr)) return 1;
     if(flgs&FLAG_CHANGED){
-      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)pos);
+      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(FXival)pos);
       }
     return 1;
     }
@@ -349,37 +386,37 @@ long FXSlider::onMotion(FXObject*,FXSelector,void* ptr){
   register FXint xx,yy,ww,hh,lo,hi,p,h,travel;
   if(!isEnabled()) return 0;
   if(flags&FLAG_PRESSED){
-    yy=border+padtop;
-    xx=border+padleft;
-    hh=height-(border<<1)-padtop-padbottom;
-    ww=width-(border<<1)-padleft-padright;
+    yy=border+padtop+2;
+    xx=border+padleft+2;
+    hh=height-(border<<1)-padtop-padbottom-4;
+    ww=width-(border<<1)-padleft-padright-4;
     if(options&SLIDER_VERTICAL){
       h=event->win_y-dragpoint;
-      travel=hh-headsize-4;
-      if(h<yy+2) h=yy+2;
-      if(h>(yy+2+travel)) h=yy+2+travel;
+      travel=hh-headsize;
+      if(h<yy) h=yy;
+      if(h>yy+travel) h=yy+travel;
       if(h!=headpos){
         FXMINMAX(lo,hi,headpos,h);
         headpos=h;
         update(border,lo-1,width-(border<<1),hi+headsize+2-lo);
         }
       if(travel>0)
-        p=range[0]+((range[1]-range[0])*(yy+2+travel-h)+travel/2)/travel;    // Use rounding!!
+        p=range[0]+((range[1]-range[0])*(yy+travel-h)+travel/2)/travel;    // Use rounding!!
       else
         p=range[0];
       }
     else{
-      travel=ww-headsize-4;
       h=event->win_x-dragpoint;
-      if(h<xx+2) h=xx+2;
-      if(h>(xx+2+travel)) h=xx+2+travel;
+      travel=ww-headsize;
+      if(h<xx) h=xx;
+      if(h>xx+travel) h=xx+travel;
       if(h!=headpos){
         FXMINMAX(lo,hi,headpos,h);
         headpos=h;
         update(lo-1,border,hi+headsize+2-lo,height-(border<<1));
         }
       if(travel>0)
-        p=range[0]+((range[1]-range[0])*(h-xx-2)+travel/2)/travel;    // Use rounding!!
+        p=range[0]+((range[1]-range[0])*(h-xx)+travel/2)/travel;    // Use rounding!!
       else
         p=range[0];
       }
@@ -387,7 +424,7 @@ long FXSlider::onMotion(FXObject*,FXSelector,void* ptr){
     if(p>range[1]) p=range[1];
     if(pos!=p){
       pos=p;
-      if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)pos);
+      if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)pos);
       flags|=FLAG_CHANGED;
       }
     return 1;
@@ -403,39 +440,39 @@ long FXSlider::onMiddleBtnPress(FXObject*,FXSelector,void* ptr){
   flags&=~FLAG_TIP;
   if(isEnabled()){
     grab();
-    if(target && target->handle(this,MKUINT(message,SEL_MIDDLEBUTTONRELEASE),ptr)) return 1;
+    if(target && target->handle(this,MKUINT(message,SEL_MIDDLEBUTTONPRESS),ptr)) return 1;
     dragpoint=headsize/2;
-    yy=border+padtop;
-    xx=border+padleft;
-    hh=height-(border<<1)-padtop-padbottom;
-    ww=width-(border<<1)-padleft-padright;
+    yy=border+padtop+2;
+    xx=border+padleft+2;
+    hh=height-(border<<1)-padtop-padbottom-4;
+    ww=width-(border<<1)-padleft-padright-4;
     if(options&SLIDER_VERTICAL){
       h=event->win_y-dragpoint;
-      travel=hh-headsize-4;
-      if(h<yy+2) h=yy+2;
-      if(h>(yy+2+travel)) h=yy+2+travel;
+      travel=hh-headsize;
+      if(h<yy) h=yy;
+      if(h>yy+travel) h=yy+travel;
       if(h!=headpos){
         FXMINMAX(lo,hi,headpos,h);
         headpos=h;
         update(border,lo-1,width-(border<<1),hi+headsize+2-lo);
         }
       if(travel>0)
-        p=range[0]+((range[1]-range[0])*(yy+2+travel-h)+travel/2)/travel;    // Use rounding!!
+        p=range[0]+((range[1]-range[0])*(yy+travel-h)+travel/2)/travel;    // Use rounding!!
       else
         p=range[0];
       }
     else{
       h=event->win_x-dragpoint;
-      travel=ww-headsize-4;
-      if(h<2) h=2;
-      if(h>(xx+2+travel)) h=xx+2+travel;
+      travel=ww-headsize;
+      if(h<xx) h=xx;
+      if(h>xx+travel) h=xx+travel;
       if(h!=headpos){
         FXMINMAX(lo,hi,headpos,h);
         headpos=h;
         update(lo-1,border,hi+headsize+2-lo,height-(border<<1));
         }
       if(travel>0)
-        p=range[0]+((range[1]-range[0])*(h-xx-2)+travel/2)/travel;    // Use rounding!!
+        p=range[0]+((range[1]-range[0])*(h-xx)+travel/2)/travel;    // Use rounding!!
       else
         p=range[0];
       }
@@ -443,7 +480,7 @@ long FXSlider::onMiddleBtnPress(FXObject*,FXSelector,void* ptr){
     if(p>range[1]) p=range[1];
     if(p!=pos){
       pos=p;
-      if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)pos);
+      if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)pos);
       flags|=FLAG_CHANGED;
       }
     flags|=FLAG_PRESSED;
@@ -466,7 +503,7 @@ long FXSlider::onMiddleBtnRelease(FXObject*,FXSelector,void* ptr){
     setValue(pos);                                                 // Hop to exact position
     if(target && target->handle(this,MKUINT(message,SEL_MIDDLEBUTTONRELEASE),ptr)) return 1;
     if(flgs&FLAG_CHANGED){
-      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)pos);
+      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(FXival)pos);
       }
     return 1;
     }
@@ -497,7 +534,7 @@ long FXSlider::onTimeInc(FXObject*,FXSelector,void*){
     }
   if(p!=pos){
     setValue(p);
-    if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)pos);
+    if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)pos);
     flags|=FLAG_CHANGED;
     return 1;
     }
@@ -517,7 +554,7 @@ long FXSlider::onTimeDec(FXObject*,FXSelector,void*){
     }
   if(p!=pos){
     setValue(p);
-    if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)pos);
+    if(target) target->handle(this,MKUINT(message,SEL_CHANGED),(void*)(FXival)pos);
     flags|=FLAG_CHANGED;
     return 1;
     }
@@ -525,6 +562,36 @@ long FXSlider::onTimeDec(FXObject*,FXSelector,void*){
   }
 
 
+// Draw horizontal ticks
+void FXSlider::drawHorzTicks(FXDCWindow& dc,FXint,FXint y,FXint,FXint){
+  FXint v,d,p;
+  if(range[0]<range[1]){
+    d=delta;
+    if(d==0) d=incr;
+    dc.setForeground(FXRGB(0,0,0));
+    for(v=range[0]; v<=range[1]; v+=d){
+      p=headPos(v)+headsize/2;
+      dc.fillRectangle(p,y,1,TICKSIZE);
+      }
+    }
+  }
+
+
+// Draw vertical ticks
+void FXSlider::drawVertTicks(FXDCWindow& dc,FXint x,FXint,FXint,FXint){
+  FXint v,d,p;
+  if(range[0]<range[1]){
+    d=delta;
+    if(d==0) d=incr;
+    dc.setForeground(FXRGB(0,0,0));
+    for(v=range[0]; v<=range[1]; v+=d){
+      p=headPos(v)+headsize/2;
+      dc.fillRectangle(x,p,TICKSIZE,1);
+      }
+    }
+  }
+
+
 // Draw slider head
 void FXSlider::drawSliderHead(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint h){
   FXint m;
@@ -633,17 +700,25 @@ long FXSlider::onPaint(FXObject*,FXSelector,void* ptr){
   yy=border+padtop;
   ww=width-(border<<1)-padleft-padright;
   hh=height-(border<<1)-padtop-padbottom;
-
   FXASSERT(range[0]<=pos && pos<=range[1]);
 
+  dc.setForeground(backColor);
+  dc.fillRectangle(xx,yy,ww,hh);
+
   // Draw the slot
   if(options&SLIDER_VERTICAL){
+
+    // Adjust slot placement for tickmarks
+    if(options&SLIDER_TICKS_LEFT){ xx+=TICKSIZE; ww-=TICKSIZE; }
+    if(options&SLIDER_TICKS_RIGHT){ ww-=TICKSIZE; }
+
+    // Draw slider
     if(options&SLIDER_INSIDE_BAR){
-      dc.setForeground(backColor);
-      dc.fillRectangle(border,border,width-(border<<1),padtop);
-      dc.fillRectangle(border,height-border-padbottom,width-(border<<1),padbottom);
-      dc.fillRectangle(border,border+padtop,padleft,hh);
-      dc.fillRectangle(width-border-padright,border+padtop,padright,hh);
+//       dc.setForeground(backColor);
+//       dc.fillRectangle(border,border,width-(border<<1),padtop);
+//       dc.fillRectangle(border,height-border-padbottom,width-(border<<1),padbottom);
+//       dc.fillRectangle(border,border+padtop,padleft,hh);
+//       dc.fillRectangle(width-border-padright,border+padtop,padright,hh);
       drawDoubleSunkenRectangle(dc,xx,yy,ww,hh);
       dc.setStipple(STIPPLE_GRAY);
       dc.setForeground(slotColor);
@@ -651,30 +726,40 @@ long FXSlider::onPaint(FXObject*,FXSelector,void* ptr){
       dc.setFillStyle(FILL_OPAQUESTIPPLED);
       dc.fillRectangle(xx+2,yy+2,ww-4,hh-4);
       dc.setFillStyle(FILL_SOLID);
+      if(options&SLIDER_TICKS_LEFT) drawVertTicks(dc,border+padleft,yy,ww,hh);
+      if(options&SLIDER_TICKS_RIGHT) drawVertTicks(dc,width-padright-border-TICKSIZE,yy,ww,hh);
       if(isEnabled()) drawSliderHead(dc,xx+2,headpos,ww-4,headsize);
       }
     else{
       if(options&SLIDER_ARROW_LEFT) tx=xx+hhs+(ww-slotsize-hhs)/2;
       else if(options&SLIDER_ARROW_RIGHT) tx=xx+(ww-slotsize-hhs)/2;
       else tx=xx+(ww-slotsize)/2;
-      dc.setForeground(backColor);
-      dc.fillRectangle(border,border,width-(border<<1),padtop);
-      dc.fillRectangle(border,height-border-padbottom,width-(border<<1),padbottom);
-      dc.fillRectangle(border,border+padtop,tx-border,hh);
-      dc.fillRectangle(tx+slotsize,border+padtop,width-border-tx-slotsize,hh);
+//       dc.setForeground(backColor);
+//       dc.fillRectangle(border,border,width-(border<<1),padtop);
+//       dc.fillRectangle(border,height-border-padbottom,width-(border<<1),padbottom);
+//       dc.fillRectangle(border,border+padtop,tx-border,hh);
+//       dc.fillRectangle(tx+slotsize,border+padtop,width-border-tx-slotsize,hh);
       drawDoubleSunkenRectangle(dc,tx,yy,slotsize,hh);
       dc.setForeground(slotColor);
       dc.fillRectangle(tx+2,yy+2,slotsize-4,hh-4);
+      if(options&SLIDER_TICKS_LEFT) drawVertTicks(dc,border+padleft,yy,ww,hh);
+      if(options&SLIDER_TICKS_RIGHT) drawVertTicks(dc,width-padright-border-TICKSIZE,yy,ww,hh);
       if(isEnabled()) drawSliderHead(dc,xx,headpos,ww,headsize);
       }
     }
   else{
+
+    // Adjust slot placement for tickmarks
+    if(options&SLIDER_TICKS_TOP){ yy+=TICKSIZE; hh-=TICKSIZE; }
+    if(options&SLIDER_TICKS_BOTTOM){ hh-=TICKSIZE; }
+
+    // Draw slider
     if(options&SLIDER_INSIDE_BAR){
-      dc.setForeground(backColor);
-      dc.fillRectangle(border,border,width-(border<<1),padtop);
-      dc.fillRectangle(border,height-border-padbottom,width-(border<<1),padbottom);
-      dc.fillRectangle(border,border+padtop,padleft,hh);
-      dc.fillRectangle(width-border-padright,border+padtop,padright,hh);
+//       dc.setForeground(backColor);
+//       dc.fillRectangle(border,border,width-(border<<1),padtop);
+//       dc.fillRectangle(border,height-border-padbottom,width-(border<<1),padbottom);
+//       dc.fillRectangle(border,border+padtop,padleft,hh);
+//       dc.fillRectangle(width-border-padright,border+padtop,padright,hh);
       drawDoubleSunkenRectangle(dc,xx,yy,ww,hh);
       dc.setForeground(slotColor);
       dc.setStipple(STIPPLE_GRAY);
@@ -683,20 +768,24 @@ long FXSlider::onPaint(FXObject*,FXSelector,void* ptr){
       dc.setFillStyle(FILL_OPAQUESTIPPLED);
       dc.fillRectangle(xx+2,yy+2,ww-4,hh-4);
       dc.setFillStyle(FILL_SOLID);
+      if(options&SLIDER_TICKS_TOP) drawHorzTicks(dc,xx,border+padtop,ww,hh);
+      if(options&SLIDER_TICKS_BOTTOM) drawHorzTicks(dc,xx,height-border-padbottom-TICKSIZE,ww,hh);
       if(isEnabled()) drawSliderHead(dc,headpos,yy+2,headsize,hh-4);
       }
     else{
       if(options&SLIDER_ARROW_UP) ty=yy+hhs+(hh-slotsize-hhs)/2;
       else if(options&SLIDER_ARROW_DOWN) ty=yy+(hh-slotsize-hhs)/2;
       else ty=yy+(hh-slotsize)/2;
-      dc.setForeground(backColor);
-      dc.fillRectangle(border,border,width-(border<<1),ty-border);
-      dc.fillRectangle(border,ty+slotsize,width-(border<<1),height-border-ty-slotsize);
-      dc.fillRectangle(border,border+padtop,padleft,hh);
-      dc.fillRectangle(width-border-padright,border+padtop,padright,hh);
+//       dc.setForeground(backColor);
+//       dc.fillRectangle(border,border,width-(border<<1),ty-border);
+//       dc.fillRectangle(border,ty+slotsize,width-(border<<1),height-border-ty-slotsize);
+//       dc.fillRectangle(border,border+padtop,padleft,hh);
+//       dc.fillRectangle(width-border-padright,border+padtop,padright,hh);
       drawDoubleSunkenRectangle(dc,xx,ty,ww,slotsize);
       dc.setForeground(slotColor);
       dc.fillRectangle(xx+2,ty+2,ww-4,slotsize-4);
+      if(options&SLIDER_TICKS_TOP) drawHorzTicks(dc,xx,border+padtop,ww,hh);
+      if(options&SLIDER_TICKS_BOTTOM) drawHorzTicks(dc,xx,height-border-padbottom-TICKSIZE,ww,hh);
       if(isEnabled()) drawSliderHead(dc,headpos,yy,headsize,hh);
       }
     }
@@ -819,12 +908,25 @@ void FXSlider::setTipText(const FXString& text){
   }
 
 
+// Change the delta between ticks
+void FXSlider::setTickDelta(FXint dist){
+  if(dist<0) dist=0;
+  if(delta!=dist){
+    delta=dist;
+    if(options&(SLIDER_TICKS_TOP|SLIDER_TICKS_BOTTOM)){
+      recalc();
+      }
+    }
+  }
+
+
 // Save object to stream
 void FXSlider::save(FXStream& store) const {
   FXFrame::save(store);
   store << range[0] << range[1];
   store << pos;
   store << incr;
+  store << delta;
   store << slotColor;
   store << headsize;
   store << slotsize;
@@ -839,6 +941,7 @@ void FXSlider::load(FXStream& store){
   store >> range[0] >> range[1];
   store >> pos;
   store >> incr;
+  store >> delta;
   store >> slotColor;
   store >> headsize;
   store >> slotsize;
