@@ -3,7 +3,7 @@
 *                S p l i t t e r   W i n d o w   O b j e c t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXSplitter.cpp,v 1.24 2001/08/14 21:56:16 jeroen Exp $                   *
+* $Id: FXSplitter.cpp,v 1.26.4.1 2003/06/06 19:32:03 fox Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -29,18 +29,9 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
-#include "FXComposite.h"
 #include "FXSplitter.h"
 
 
@@ -58,7 +49,7 @@
     but only if both width and height of child is <=1 at the same time.
   - Should we send SEL_CHANGED and SEL_COMMAND also when splitter arrangement
     was changed programmatically?  When bar size changed?
-  - FXSplitter interprets layout hints on some of the children so that certain 
+  - FXSplitter interprets layout hints on some of the children so that certain
     children have a minimum width (height) constraint on them.
     Note that this rule must have one exception: the last (or first if the option
     SPLITTER_REVERSED has been passed) must necessarily be allowed to be
@@ -135,17 +126,17 @@ FXint FXSplitter::getDefaultWidth(){
   wmax=numc=0;
   if(options&SPLITTER_VERTICAL){
     for(child=getFirst(); child; child=child->getNext()){
-      if(child->shown()){ 
+      if(child->shown()){
         w=child->getDefaultWidth();
-        if(wmax<w) wmax=w; 
+        if(wmax<w) wmax=w;
         }
       }
     }
   else{
     for(child=getFirst(); child; child=child->getNext()){
-      if(child->shown()){ 
-        wmax+=child->getDefaultWidth(); 
-        numc++; 
+      if(child->shown()){
+        wmax+=child->getDefaultWidth();
+        numc++;
         }
       }
     if(numc>1) wmax+=(numc-1)*barsize;
@@ -161,18 +152,18 @@ FXint FXSplitter::getDefaultHeight(){
   hmax=numc=0;
   if(options&SPLITTER_VERTICAL){
     for(child=getFirst(); child; child=child->getNext()){
-      if(child->shown()){ 
-        hmax+=child->getDefaultHeight(); 
-        numc++; 
+      if(child->shown()){
+        hmax+=child->getDefaultHeight();
+        numc++;
         }
       }
     if(numc>1) hmax+=(numc-1)*barsize;
     }
   else{
     for(child=getFirst(); child; child=child->getNext()){
-      if(child->shown()){ 
+      if(child->shown()){
         h=child->getDefaultHeight();
-        if(hmax<h) hmax=h; 
+        if(hmax<h) hmax=h;
         }
       }
     }
@@ -443,7 +434,7 @@ long FXSplitter::onLeftBtnPress(FXObject*,FXSelector,void* ptr){
   FXEvent* ev=(FXEvent*)ptr;
   if(isEnabled()){
     grab();
-    if(target && target->handle(this,MKUINT(message,SEL_LEFTBUTTONRELEASE),ptr)) return 1;
+    if(target && target->handle(this,MKUINT(message,SEL_LEFTBUTTONPRESS),ptr)) return 1;
     if(options&SPLITTER_VERTICAL){
       window=findVSplit(ev->win_y);
       if(window){
