@@ -3,7 +3,7 @@
 *                           S t r i n g   O b j e c t                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,12 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXString.cpp,v 1.57 2001/07/06 21:33:12 jeroen Exp $                     *
+* $Id: FXString.cpp,v 1.64.4.3 2003/01/09 18:35:37 fox Exp $                        *
 ********************************************************************************/
+#ifdef HAVE_VSSCANF
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE
+#endif
+#endif
 #include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
-#include "fxpriv.h"
 #include "FXStream.h"
 #include "FXString.h"
 
@@ -44,8 +48,10 @@
 // The string buffer is always rounded to a multiple of ROUNDVAL
 // which must be 2^n.  Thus, small size changes will not result in any
 // actual resizing of the buffer except when ROUNDVAL is exceeded.
-#define ROUNDVAL 16
+#define ROUNDVAL    16
 
+// Round up to nearest ROUNDVAL
+#define ROUNDUP(n)  (((n)+ROUNDVAL-1)&-ROUNDVAL)
 
 // Special NULL string
 const FXchar FXString::null[4]={0,0,0,0};
@@ -64,10 +70,10 @@ void FXString::size(FXint sz){
     if(str!=null){ free(str); str=(FXchar*)null; }
     }
   else if(str==null){
-    str=(FXchar*)malloc((sz+ROUNDVAL-1)&~(ROUNDVAL-1)); str[0]=0;
+    str=(FXchar*)malloc(ROUNDUP(sz)); str[0]=0;
     }
   else{
-    str=(FXchar*)realloc(str,(sz+ROUNDVAL-1)&~(ROUNDVAL-1));
+    str=(FXchar*)realloc(str,ROUNDUP(sz));
     }
   }
 
@@ -647,7 +653,10 @@ FXString& FXString::trimEnd(){
 
 // Truncate string
 FXString& FXString::trunc(FXint pos){
-  if(str!=null && pos<(FXint)strlen(str)) str[pos]=0;
+  if(str!=null){
+    if(pos<0) pos=0;
+    if(pos<(FXint)strlen(str)) str[pos]=0;
+    }
   return *this;
   }
 
@@ -661,26 +670,37 @@ FXString& FXString::clear(){
 
 // Get leftmost part
 FXString FXString::left(FXint n) const {
-  register FXint len=strlen(str);
-  if(n>len) n=len;
-  return FXString(str,n);
+  if(0<n){
+    register FXint len=strlen(str);
+    if(n>len) n=len;
+    return FXString(str,n);
+    }
+  return FXString::null;
   }
 
 
 // Get rightmost part
 FXString FXString::right(FXint n) const {
-  register FXint len=strlen(str);
-  if(n>len) n=len;
-  return FXString(str+len-n,n);
+  if(0<n){
+    register FXint len=strlen(str);
+    if(n>len) n=len;
+    return FXString(str+len-n,n);
+    }
+  return FXString::null;
   }
 
 
 // Get some part in the middle
 FXString FXString::mid(FXint pos,FXint n) const {
-  register FXint len=strlen(str);
-  if(pos>len) pos=len;
-  if(pos+n>len) n=len-pos;
-  return FXString(str+pos,n);
+  if(0<n){
+    register FXint len=strlen(str);
+    if(pos<len && pos+n>0){
+      if(pos<0){n+=pos;pos=0;}
+      if(pos+n>len){n=len-pos;}
+      return FXString(str+pos,n);
+      }
+    }
+  return FXString::null;
   }
 
 
@@ -1078,30 +1098,20 @@ FXStream& operator>>(FXStream& store,FXString& s){
 FXString& FXString::vformat(const char *fmt,va_list args){
   register FXint len=0;
   if(fmt && *fmt){
-    register FXint s=strlen(fmt);
-#if (__GLIBC__ > 2) || (__GLIBC__ == 2 && __GLIBC_MINOR__ >= 1)
-    s+=128;                    // Add a bit of slop
-    while(1){
-      size(s+1);
-      len=vsnprintf(str,s+1,fmt,args)+1;
-      if(len<=s) break;
-      s=len;
-      }
-#elif (__GLIBC__ == 2) || defined(WIN32)
-    s+=128;                    // Add a bit of slop
-    do{
-      size(s+1);
-      len=vsnprintf(str,s+1,fmt,args)+1;
-      s<<=1;                  // Double the buffer size if it didn't fit
-      }
-    while(len<=0);
+    register FXint s=strlen(fmt);       // Result is longer than format string
+#if (__GLIBC__ >= 2) || defined(WIN32)
+    s+=128;
+x:  size(s);
+    len=vsnprintf(str,s,fmt,args);
+    if(len<0){ s<<=1; goto x; }         // Some implementations return -1 if not enough room
+    if(s<=len){ s=len+1; goto x; }      // Others return how much space would be needed
 #else
-    s+=1024;                  // Add a lot of slop
-    size(s+1);
-    len=vsprintf(str,fmt,args)+1;
+    s+=1024;                            // Add a lot of slop
+    size(s);
+    len=vsprintf(str,fmt,args);
 #endif
     }
-  size(len);
+  size(len+1);
   return *this;
   }
 
@@ -1115,25 +1125,27 @@ FXString& FXString::format(const char *fmt,...){
   return *this;
   }
 
-//   /// Scan a string a-la scanf
-//   FXint scan(const char *fmt,...) const;
-//   FXint vscan(const char *fmt,va_list args) const;
-//
-//
-// // Scan
-// FXint FXString::vscan(const char *fmt,va_list args) const {
-//   return vsscanf(str,fmt,args);
-//   }
-//
-//
-// FXint FXString::scan(const char *fmt,...) const {
-//   FXint result;
-//   va_list args;
-//   va_start(args,fmt);
-//   result=vscan(fmt,args);
-//   va_end(args);
-//   return result;
-//   }
+
+// Furnish our own version if we have to
+#ifndef HAVE_VSSCANF
+extern "C" int vsscanf(const char* str, const char* format, va_list arg_ptr);
+#endif
+
+
+// Scan
+FXint FXString::vscan(const char *fmt,va_list args) const {
+  return vsscanf((char*)str,fmt,args);          // Cast needed for HP-UX 11, which has wrong prototype for vsscanf
+  }
+
+
+FXint FXString::scan(const char *fmt,...) const {
+  FXint result;
+  va_list args;
+  va_start(args,fmt);
+  result=vscan(fmt,args);
+  va_end(args);
+  return result;
+  }
 
 
 // Format a string a-la vprintf
