@@ -3,7 +3,7 @@
 *                      S w i t c h   P a n e l   C l a s s                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXSwitcher.cpp,v 1.14 2001/04/27 14:30:34 jeroen Exp $                   *
+* $Id: FXSwitcher.cpp,v 1.17.4.1 2003/06/20 19:02:07 fox Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -29,35 +29,26 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
-#include "FXComposite.h"
-#include "FXPacker.h"
 #include "FXSwitcher.h"
 
 
 /*
   Notes:
-  - Found out stacking order changes are very expensive, so just
-    hiding all but the current pane now.
-  - Also, only the current pane needs to be moved to the correct
-    position; when changing active panes, only then will the pane
-    be moved; this is a lot faster if there are many stacked panes!
   - We do not look at LAYOUT_FIX_WIDTH and LAYOUT_FIX_HEIGHT because
     FXSwitcher resizes its children anyway and doing this would cause
     the size to grow instead of shrinkwrap to the biggest child.
-  - We have to position invisible panes, too!!
+  - Thanks to Charles Warren for the suggestion for the collapse
+    modes.
 */
 
+
+// Switcher styles
+#define SWITCHER_MASK (SWITCHER_HCOLLAPSE|SWITCHER_VCOLLAPSE)
+
+
 /*******************************************************************************/
 
 // Map
@@ -96,7 +87,7 @@ long FXSwitcher::onPaint(FXObject*,FXSelector,void* ptr){
 
 // Update value from a message
 long FXSwitcher::onCmdSetValue(FXObject*,FXSelector,void* ptr){
-  setCurrent((FXint)(long)ptr);
+  setCurrent((FXint)(FXival)ptr);
   return 1;
   }
 
@@ -133,10 +124,12 @@ long FXSwitcher::onUpdOpen(FXObject* sender,FXSelector sel,void* ptr){
 // Get maximum child width
 FXint FXSwitcher::getDefaultWidth(){
   register FXWindow* child;
-  register int w,wmax=0;
-  for(child=getFirst(); child; child=child->getNext()){
+  register FXint i,w,wmax=0,wcur=0;
+  for(i=0,child=getFirst(); child; child=child->getNext(),i++){
+    if(i==current) wcur=child->getDefaultWidth();
     if(wmax<(w=child->getDefaultWidth())) wmax=w;
     }
+  if(options&SWITCHER_HCOLLAPSE) wmax=wcur;
   return padleft+padright+(border<<1)+wmax;
   }
 
@@ -144,10 +137,12 @@ FXint FXSwitcher::getDefaultWidth(){
 // Get maximum child height
 FXint FXSwitcher::getDefaultHeight(){
   register FXWindow* child;
-  register int h,hmax=0;
-  for(child=getFirst(); child; child=child->getNext()){
+  register FXint i,h,hmax=0,hcur=0;
+  for(i=0,child=getFirst(); child; child=child->getNext(),i++){
+    if(i==current) hcur=child->getDefaultHeight();
     if(hmax<(h=child->getDefaultHeight())) hmax=h;
     }
+  if(options&SWITCHER_VCOLLAPSE) hmax=hcur;
   return padtop+padbottom+(border<<1)+hmax;
   }
 
@@ -177,12 +172,28 @@ void FXSwitcher::layout(){
 void FXSwitcher::setCurrent(FXint panel,FXbool notify){
   if(0<=panel && current!=panel){
     current=panel;
-    if(notify && target){ target->handle(this,MKUINT(message,SEL_COMMAND),(void*)current); }
+    if(notify && target){ target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(FXival)current); }
     recalc();
     }
   }
 
 
+// Set switcher style
+void FXSwitcher::setSwitcherStyle(FXuint style){
+  FXuint opts=(options&~SWITCHER_MASK) | (style&SWITCHER_MASK);
+  if(options!=opts){
+    options=opts;
+    recalc();
+    }
+  }
+
+
+// Get switcher style
+FXuint FXSwitcher::getSwitcherStyle() const {
+  return (options&SWITCHER_MASK);
+  }
+
+
 // Save object to stream
 void FXSwitcher::save(FXStream& store) const {
   FXPacker::save(store);
