@@ -3,7 +3,7 @@
 *                         T e x t   F i e l d   O b j e c t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXTextField.cpp,v 1.67 2001/08/23 16:37:36 jeroen Exp $                  *
+* $Id: FXTextField.cpp,v 1.79.4.3 2003/02/25 23:10:54 fox Exp $                  *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,19 +30,11 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
 #include "FXFont.h"
 #include "FXCursor.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
 #include "FXLabel.h"
 #include "FXTextField.h"
 
@@ -99,7 +91,7 @@
 FXDEFMAP(FXTextField) FXTextFieldMap[]={
   FXMAPFUNC(SEL_PAINT,0,FXTextField::onPaint),
   FXMAPFUNC(SEL_MOTION,0,FXTextField::onMotion),
-  FXMAPFUNC(SEL_TIMEOUT,FXWindow::ID_CARETBLINK,FXTextField::onBlink),
+  FXMAPFUNC(SEL_TIMEOUT,FXTextField::ID_BLINK,FXTextField::onBlink),
   FXMAPFUNC(SEL_TIMEOUT,FXWindow::ID_AUTOSCROLL,FXTextField::onAutoScroll),
   FXMAPFUNC(SEL_LEFTBUTTONPRESS,0,FXTextField::onLeftBtnPress),
   FXMAPFUNC(SEL_LEFTBUTTONRELEASE,0,FXTextField::onLeftBtnRelease),
@@ -140,7 +132,7 @@ FXDEFMAP(FXTextField) FXTextFieldMap[]={
   FXMAPFUNC(SEL_COMMAND,FXTextField::ID_COPY_SEL,FXTextField::onCmdCopySel),
   FXMAPFUNC(SEL_COMMAND,FXTextField::ID_PASTE_SEL,FXTextField::onCmdPasteSel),
   FXMAPFUNC(SEL_COMMAND,FXTextField::ID_DELETE_SEL,FXTextField::onCmdDeleteSel),
-  FXMAPFUNC(SEL_COMMAND,FXTextField::ID_INSERT_CHAR,FXTextField::onCmdInsertChar),
+  FXMAPFUNC(SEL_COMMAND,FXTextField::ID_OVERST_STRING,FXTextField::onCmdOverstString),
   FXMAPFUNC(SEL_COMMAND,FXTextField::ID_INSERT_STRING,FXTextField::onCmdInsertString),
   FXMAPFUNC(SEL_COMMAND,FXTextField::ID_BACKSPACE,FXTextField::onCmdBackspace),
   FXMAPFUNC(SEL_COMMAND,FXTextField::ID_DELETE,FXTextField::onCmdDelete),
@@ -335,7 +327,7 @@ long FXTextField::onClipboardRequest(FXObject* sender,FXSelector sel,void* ptr){
 long FXTextField::onFocusIn(FXObject* sender,FXSelector sel,void* ptr){
   FXFrame::onFocusIn(sender,sel,ptr);
   if(isEditable()){
-    if(!blinker) blinker=getApp()->addTimeout(getApp()->getBlinkSpeed(),this,FXWindow::ID_CARETBLINK);
+    if(!blinker) blinker=getApp()->addTimeout(getApp()->getBlinkSpeed(),this,ID_BLINK);
     drawCursor(FLAG_CARET);
     }
   if(hasSelection()){
@@ -377,6 +369,7 @@ FXbool FXTextField::canFocus() const { return 1; }
 // Into focus chain
 void FXTextField::setFocus(){
   FXFrame::setFocus();
+  setDefault(TRUE);
   flags&=~FLAG_UPDATE;                    // Thanks to Derek Ney <derek@hipgraphics.com>
   }
 
@@ -384,6 +377,8 @@ void FXTextField::setFocus(){
 // Out of focus chain
 void FXTextField::killFocus(){
   FXFrame::killFocus();
+  setDefault(MAYBE);
+  flags|=FLAG_UPDATE;
   if(flags&FLAG_CHANGED){
     flags&=~FLAG_CHANGED;
     if(!(options&TEXTFIELD_ENTER_ONLY) && target){
@@ -662,7 +657,7 @@ long FXTextField::onAutoScroll(FXObject*,FXSelector,void*){
 // Blink the cursor
 long FXTextField::onBlink(FXObject*,FXSelector,void*){
   drawCursor(flags^FLAG_CARET);
-  blinker=getApp()->addTimeout(getApp()->getBlinkSpeed(),this,FXWindow::ID_CARETBLINK);
+  blinker=getApp()->addTimeout(getApp()->getBlinkSpeed(),this,ID_BLINK);
   return 0;
   }
 
@@ -939,7 +934,7 @@ void FXTextField::drawPWDTextFragment(FXDCWindow& dc,FXint x,FXint y,FXint fm,FX
 
 // Draw range of text
 void FXTextField::drawTextRange(FXDCWindow& dc,FXint fm,FXint to){
-  FXint sx,ex,xx,yy,cw,hh,ww; FXint si,ei;
+  register FXint sx,ex,xx,yy,cw,hh,ww,si,ei,lx,rx;
   if(to<=fm) return;
   dc.setTextFont(font);
 
@@ -986,6 +981,24 @@ void FXTextField::drawTextRange(FXDCWindow& dc,FXint fm,FXint to){
       xx=shift+border+padleft;
       }
 
+    // Reduce to avoid drawing excessive amounts of text
+    lx=xx+cw*fm;
+    rx=xx+cw*to;
+    while(fm<to){
+      if(lx+cw>=0) break;
+      lx+=cw;
+      fm++;
+      }
+    while(fm<to){
+      if(rx-cw<width) break;
+      rx-=cw;
+      to--;
+      }
+      
+    // Adjust selected range
+    if(si<fm) si=fm;
+    if(ei>to) ei=to;
+      
     // Nothing selected
     if(!hasSelection() || to<=si || ei<=fm){
       drawPWDTextFragment(dc,xx,yy,fm,to);
@@ -1038,6 +1051,26 @@ void FXTextField::drawTextRange(FXDCWindow& dc,FXint fm,FXint to){
       xx=shift+border+padleft;
       }
 
+    // Reduce to avoid drawing excessive amounts of text
+    lx=xx+font->getTextWidth(&contents[0],fm);
+    rx=lx+font->getTextWidth(&contents[fm],to-fm);
+    while(fm<to){
+      cw=font->getTextWidth(&contents[fm],1);
+      if(lx+cw>=0) break;
+      lx+=cw;
+      fm++;
+      }
+    while(fm<to){
+      cw=font->getTextWidth(&contents[to-1],1);
+      if(rx-cw<width) break;
+      rx-=cw;
+      to--;
+      }
+      
+    // Adjust selected range
+    if(si<fm) si=fm;
+    if(ei>to) ei=to;
+      
     // Nothing selected
     if(!hasSelection() || to<=si || ei<=fm){
       drawTextFragment(dc,xx,yy,fm,to);
@@ -1098,6 +1131,15 @@ long FXTextField::onPaint(FXObject*,FXSelector,void* ptr){
   // Draw text, clipped against frame interior
   dc.setClipRectangle(border,border,width-(border<<1),height-(border<<1));
   drawTextRange(dc,0,contents.length());
+
+  // Draw caret
+  if(flags&FLAG_CARET){
+    int xx=coord(cursor)-1;
+    dc.setForeground(textColor);
+    dc.fillRectangle(xx,padtop+border,1,height-padbottom-padtop-(border<<1));
+    dc.fillRectangle(xx-2,padtop+border,5,1);
+    dc.fillRectangle(xx-2,height-border-padbottom-1,5,1);
+    }
   return 1;
   }
 
@@ -1240,16 +1282,11 @@ long FXTextField::onCmdDeleteSel(FXObject*,FXSelector,void*){
   }
 
 
-// Insert a character
-long FXTextField::onCmdInsertChar(FXObject*,FXSelector,void* ptr){
+// Overstrike string
+long FXTextField::onCmdOverstString(FXObject*,FXSelector,void* ptr){
   FXString tentative=contents;
-  FXchar ch=(FXchar)(long)ptr;
-  if((options&TEXTFIELD_OVERSTRIKE) && cursor<tentative.length()){
-    tentative.replace(cursor,ch);
-    }
-  else{
-    tentative.insert(cursor,ch);
-    }
+  FXint len=strlen((FXchar*)ptr);
+  tentative.replace(cursor,len,(FXchar*)ptr,len);
   if(handle(this,MKUINT(0,SEL_VERIFY),(void*)tentative.text())){ getApp()->beep(); return 1; }
   contents=tentative;
   layout();
@@ -1356,72 +1393,140 @@ long FXTextField::onVerify(FXObject*,FXSelector,void* ptr){
 // Pressed a key
 long FXTextField::onKeyPress(FXObject*,FXSelector,void* ptr){
   FXEvent* event=(FXEvent*)ptr;
-  FXchar   entry;
   flags&=~FLAG_TIP;
-  if(!isEnabled()) return 0;
-  FXTRACE((200,"%s::onKeyPress keysym=0x%04x state=%04x\n",getClassName(),event->code,event->state));
-  if(target && target->handle(this,MKUINT(message,SEL_KEYPRESS),ptr)) return 1;
-  flags&=~FLAG_UPDATE;
-  switch(event->code){
-    case KEY_Right:
-    case KEY_KP_Right:
-      if(!(event->state&SHIFTMASK)){
-        handle(this,MKUINT(ID_DESELECT_ALL,SEL_COMMAND),NULL);
-        }
-      handle(this,MKUINT(ID_CURSOR_RIGHT,SEL_COMMAND),NULL);
-      if(event->state&SHIFTMASK){
-        handle(this,MKUINT(ID_EXTEND,SEL_COMMAND),NULL);
-        }
-      else{
-        handle(this,MKUINT(ID_MARK,SEL_COMMAND),NULL);
-        }
-      return 1;
-    case KEY_Left:
-    case KEY_KP_Left:
-      if(!(event->state&SHIFTMASK)){
-        handle(this,MKUINT(ID_DESELECT_ALL,SEL_COMMAND),NULL);
-        }
-      handle(this,MKUINT(ID_CURSOR_LEFT,SEL_COMMAND),NULL);
-      if(event->state&SHIFTMASK){
-        handle(this,MKUINT(ID_EXTEND,SEL_COMMAND),NULL);
-        }
-      else{
-        handle(this,MKUINT(ID_MARK,SEL_COMMAND),NULL);
-        }
-      return 1;
-    case KEY_Home:
-    case KEY_KP_Home:
-      if(!(event->state&SHIFTMASK)){
-        handle(this,MKUINT(ID_DESELECT_ALL,SEL_COMMAND),NULL);
-        }
-      handle(this,MKUINT(ID_CURSOR_HOME,SEL_COMMAND),NULL);
-      if(event->state&SHIFTMASK){
-        handle(this,MKUINT(ID_EXTEND,SEL_COMMAND),NULL);
-        }
-      else{
-        handle(this,MKUINT(ID_MARK,SEL_COMMAND),NULL);
-        }
-      return 1;
-    case KEY_End:
-    case KEY_KP_End:
-      if(!(event->state&SHIFTMASK)){
-        handle(this,MKUINT(ID_DESELECT_ALL,SEL_COMMAND),NULL);
-        }
-      handle(this,MKUINT(ID_CURSOR_END,SEL_COMMAND),NULL);
-      if(event->state&SHIFTMASK){
-        handle(this,MKUINT(ID_EXTEND,SEL_COMMAND),NULL);
-        }
-      else{
-        handle(this,MKUINT(ID_MARK,SEL_COMMAND),NULL);
-        }
-      return 1;
-    case KEY_Insert:
-    case KEY_KP_Insert:
-      if(event->state&CONTROLMASK){
+  if(isEnabled()){
+    FXTRACE((200,"%s::onKeyPress keysym=0x%04x state=%04x\n",getClassName(),event->code,event->state));
+    if(target && target->handle(this,MKUINT(message,SEL_KEYPRESS),ptr)) return 1;
+    flags&=~FLAG_UPDATE;
+    switch(event->code){
+      case KEY_Right:
+      case KEY_KP_Right:
+        if(!(event->state&SHIFTMASK)){
+          handle(this,MKUINT(ID_DESELECT_ALL,SEL_COMMAND),NULL);
+          }
+        handle(this,MKUINT(ID_CURSOR_RIGHT,SEL_COMMAND),NULL);
+        if(event->state&SHIFTMASK){
+          handle(this,MKUINT(ID_EXTEND,SEL_COMMAND),NULL);
+          }
+        else{
+          handle(this,MKUINT(ID_MARK,SEL_COMMAND),NULL);
+          }
+        return 1;
+      case KEY_Left:
+      case KEY_KP_Left:
+        if(!(event->state&SHIFTMASK)){
+          handle(this,MKUINT(ID_DESELECT_ALL,SEL_COMMAND),NULL);
+          }
+        handle(this,MKUINT(ID_CURSOR_LEFT,SEL_COMMAND),NULL);
+        if(event->state&SHIFTMASK){
+          handle(this,MKUINT(ID_EXTEND,SEL_COMMAND),NULL);
+          }
+        else{
+          handle(this,MKUINT(ID_MARK,SEL_COMMAND),NULL);
+          }
+        return 1;
+      case KEY_Home:
+      case KEY_KP_Home:
+        if(!(event->state&SHIFTMASK)){
+          handle(this,MKUINT(ID_DESELECT_ALL,SEL_COMMAND),NULL);
+          }
+        handle(this,MKUINT(ID_CURSOR_HOME,SEL_COMMAND),NULL);
+        if(event->state&SHIFTMASK){
+          handle(this,MKUINT(ID_EXTEND,SEL_COMMAND),NULL);
+          }
+        else{
+          handle(this,MKUINT(ID_MARK,SEL_COMMAND),NULL);
+          }
+        return 1;
+      case KEY_End:
+      case KEY_KP_End:
+        if(!(event->state&SHIFTMASK)){
+          handle(this,MKUINT(ID_DESELECT_ALL,SEL_COMMAND),NULL);
+          }
+        handle(this,MKUINT(ID_CURSOR_END,SEL_COMMAND),NULL);
+        if(event->state&SHIFTMASK){
+          handle(this,MKUINT(ID_EXTEND,SEL_COMMAND),NULL);
+          }
+        else{
+          handle(this,MKUINT(ID_MARK,SEL_COMMAND),NULL);
+          }
+        return 1;
+      case KEY_Insert:
+      case KEY_KP_Insert:
+        if(event->state&CONTROLMASK){
+          handle(this,MKUINT(ID_COPY_SEL,SEL_COMMAND),NULL);
+          return 1;
+          }
+        else if(event->state&SHIFTMASK){
+          if(isEditable()){
+            handle(this,MKUINT(ID_PASTE_SEL,SEL_COMMAND),NULL);
+            }
+          else{
+            getApp()->beep();
+            }
+          return 1;
+          }
+        else{
+          handle(this,MKUINT(ID_TOGGLE_OVERSTRIKE,SEL_COMMAND),NULL);
+          }
+        return 1;
+      case KEY_Delete:
+      case KEY_KP_Delete:
+        if(isEditable()){
+          if(hasSelection())
+            handle(this,MKUINT(ID_DELETE_SEL,SEL_COMMAND),NULL);
+          else
+            handle(this,MKUINT(ID_DELETE,SEL_COMMAND),NULL);
+          }
+        else{
+          getApp()->beep();
+          }
+        return 1;
+      case KEY_BackSpace:
+        if(isEditable()){
+          if(hasSelection()){
+            handle(this,MKUINT(ID_DELETE_SEL,SEL_COMMAND),NULL);
+            }
+          else{
+            handle(this,MKUINT(ID_BACKSPACE,SEL_COMMAND),NULL);
+            }
+          }
+        else{
+          getApp()->beep();
+          }
+        return 1;
+      case KEY_Return:
+      case KEY_KP_Enter:
+        if(isEditable()){
+          flags|=FLAG_UPDATE;
+          flags&=~FLAG_CHANGED;
+          if(target){
+            target->handle(this,MKUINT(message,SEL_COMMAND),(void*)contents.text());
+            }
+          }
+        else{
+          getApp()->beep();
+          }
+        return 1;
+      case KEY_a:
+        if(!(event->state&CONTROLMASK)) goto ins;
+        handle(this,MKUINT(ID_SELECT_ALL,SEL_COMMAND),NULL);
+        return 1;
+      case KEY_x:
+        if(!(event->state&CONTROLMASK)) goto ins;
+        if(isEditable()){
+          handle(this,MKUINT(ID_CUT_SEL,SEL_COMMAND),NULL);
+          }
+        else{
+          getApp()->beep();
+          }
+        return 1;
+      case KEY_c:
+        if(!(event->state&CONTROLMASK)) goto ins;
         handle(this,MKUINT(ID_COPY_SEL,SEL_COMMAND),NULL);
         return 1;
-        }
-      else if(event->state&SHIFTMASK){
+      case KEY_v:
+        if(!(event->state&CONTROLMASK)) goto ins;
         if(isEditable()){
           handle(this,MKUINT(ID_PASTE_SEL,SEL_COMMAND),NULL);
           }
@@ -1429,98 +1534,24 @@ long FXTextField::onKeyPress(FXObject*,FXSelector,void* ptr){
           getApp()->beep();
           }
         return 1;
-        }
-      else{
-        handle(this,MKUINT(ID_TOGGLE_OVERSTRIKE,SEL_COMMAND),NULL);
-        }
-      return 1;
-    case KEY_Delete:
-    case KEY_KP_Delete:
-      if(isEditable()){
-        if(hasSelection())
-          handle(this,MKUINT(ID_DELETE_SEL,SEL_COMMAND),NULL);
-        else
-          handle(this,MKUINT(ID_DELETE,SEL_COMMAND),NULL);
-        }
-      else{
-        getApp()->beep();
-        }
-      return 1;
-    case KEY_BackSpace:
-      if(isEditable()){
-        if(hasSelection()){
-          handle(this,MKUINT(ID_DELETE_SEL,SEL_COMMAND),NULL);
-          }
-        else{
-          handle(this,MKUINT(ID_BACKSPACE,SEL_COMMAND),NULL);
-          }
-        }
-      else{
-        getApp()->beep();
-        }
-      return 1;
-    case KEY_Return:
-    case KEY_KP_Enter:
-      if(isEditable()){
-        flags|=FLAG_UPDATE;
-        flags&=~FLAG_CHANGED;
-        if(target){
-          target->handle(this,MKUINT(message,SEL_COMMAND),(void*)contents.text());
-          }
-        }
-      else{
-        getApp()->beep();
-        }
-      return 1;
-    default:
-      if(!(event->state&ALTMASK)){
-
-        // Handle Control Keys
-        if(event->state&CONTROLMASK){
-          switch(event->code){
-            case KEY_a:
-              handle(this,MKUINT(ID_SELECT_ALL,SEL_COMMAND),NULL);
-              return 1;
-            case KEY_x:
-              if(isEditable()){
-                handle(this,MKUINT(ID_CUT_SEL,SEL_COMMAND),NULL);
-                }
-              else{
-                getApp()->beep();
-                }
-              return 1;
-            case KEY_c:
-              handle(this,MKUINT(ID_COPY_SEL,SEL_COMMAND),NULL);
-              return 1;
-            case KEY_v:
-              if(isEditable()){
-                handle(this,MKUINT(ID_PASTE_SEL,SEL_COMMAND),NULL);
-                }
-              else{
-                getApp()->beep();
-                }
-              return 1;
+      default:
+ins:    if((event->state&(CONTROLMASK|ALTMASK)) || ((FXuchar)event->text[0]<32)) return 0;
+        if(isEditable()){
+          if(hasSelection()){
+            handle(this,MKUINT(ID_DELETE_SEL,SEL_COMMAND),NULL);
+            }
+          if(options&TEXTFIELD_OVERSTRIKE){
+            handle(this,MKUINT(ID_OVERST_STRING,SEL_COMMAND),(void*)event->text.text());
+            }
+          else{
+            handle(this,MKUINT(ID_INSERT_STRING,SEL_COMMAND),(void*)event->text.text());
             }
           }
-
-        // Handle Normal Keys
         else{
-          entry=fxkeyval(event->code,event->state);
-          if(' ' <= (FXuchar)entry){
-            if(isEditable()){
-              if(hasSelection()){
-                handle(this,MKUINT(ID_DELETE_SEL,SEL_COMMAND),NULL);
-                }
-              handle(this,MKUINT(ID_INSERT_CHAR,SEL_COMMAND),(void*)entry);
-              }
-            else{
-              getApp()->beep();
-              }
-            return 1;
-            }
+          getApp()->beep();
           }
-        }
-      return 0;
+        return 1;
+      }
     }
   return 0;
   }
@@ -1529,46 +1560,9 @@ long FXTextField::onKeyPress(FXObject*,FXSelector,void* ptr){
 // Key Release
 long FXTextField::onKeyRelease(FXObject*,FXSelector,void* ptr){
   FXEvent* event=(FXEvent*)ptr;
-  char entry;
-  if(!isEnabled()) return 0;
-  FXTRACE((200,"%s::onKeyRelease keysym=0x%04x state=%04x\n",getClassName(),event->code,event->state));
-  if(target && target->handle(this,MKUINT(message,SEL_KEYRELEASE),ptr)) return 1;
-  switch(event->code){
-    case KEY_Right:
-    case KEY_KP_Right:
-    case KEY_Left:
-    case KEY_KP_Left:
-    case KEY_Home:
-    case KEY_KP_Home:
-    case KEY_End:
-    case KEY_KP_End:
-    case KEY_Insert:
-    case KEY_KP_Insert:
-    case KEY_Delete:
-    case KEY_KP_Delete:
-    case KEY_BackSpace:
-    case KEY_Return:
-    case KEY_KP_Enter:
-      return 1;
-    default:
-      if(!(event->state&ALTMASK)){
-        if(event->state&CONTROLMASK){
-          switch(event->code){
-            case KEY_a:
-            case KEY_x:
-            case KEY_c:
-            case KEY_v:
-              return 1;
-            }
-          }
-        else{
-          entry=fxkeyval(event->code,event->state);
-          if(' ' <= (FXuchar)entry){
-            return 1;
-            }
-          }
-        }
-      return 0;
+  if(isEnabled()){
+    FXTRACE((200,"%s::onKeyRelease keysym=0x%04x state=%04x\n",getClassName(),event->code,event->state));
+    if(target && target->handle(this,MKUINT(message,SEL_KEYRELEASE),ptr)) return 1;
     }
   return 0;
   }
@@ -1615,10 +1609,14 @@ FXbool FXTextField::extendSelection(FXint pos){
   // Got a selection at all?
   if(anchor!=pos){
     types[0]=stringType;
-    if(!hasSelection()) acquireSelection(types,1);
+    if(!hasSelection()){
+      acquireSelection(types,1);
+      }
     }
   else{
-    releaseSelection();
+    if(hasSelection()){
+      releaseSelection();
+      }
     }
 
   update(border,border,width-(border<<1),height-(border<<1));
@@ -1643,22 +1641,28 @@ void FXTextField::setText(const FXString& text){
 
 // Set text color
 void FXTextField::setTextColor(FXColor clr){
-  textColor=clr;
-  update();
+  if(textColor!=clr){
+    textColor=clr;
+    update();
+    }
   }
 
 
 // Set select background color
 void FXTextField::setSelBackColor(FXColor clr){
-  selbackColor=clr;
-  update();
+  if(selbackColor!=clr){
+    selbackColor=clr;
+    update();
+    }
   }
 
 
 // Set selected text color
 void FXTextField::setSelTextColor(FXColor clr){
-  seltextColor=clr;
-  update();
+  if(seltextColor!=clr){
+    seltextColor=clr;
+    update();
+    }
   }
 
 
