@@ -3,7 +3,7 @@
 *                   T o g g l e    B u t t o n    O b j e c t                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXToggleButton.cpp,v 1.27 2001/05/24 18:58:53 jeroen Exp $               *
+* $Id: FXToggleButton.cpp,v 1.31.4.1 2003/06/20 19:02:07 fox Exp $               *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,20 +30,10 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
-#include "FXDrawable.h"
-#include "FXImage.h"
 #include "FXIcon.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
-#include "FXLabel.h"
 #include "FXToggleButton.h"
 
 
@@ -179,7 +169,7 @@ FXbool FXToggleButton::canFocus() const { return 1; }
 
 // Update value from a message
 long FXToggleButton::onCmdSetValue(FXObject*,FXSelector,void* ptr){
-  setState((FXint)(long)ptr);
+  setState((FXint)(FXuval)ptr);
   return 1;
   }
 
@@ -287,7 +277,7 @@ long FXToggleButton::onLeftBtnRelease(FXObject*,FXSelector,void* ptr){
     flags&=~FLAG_PRESSED;
     if(click){
       setState(!state);
-      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)state);
+      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(long)state);
       }
     return 1;
     }
@@ -332,7 +322,7 @@ long FXToggleButton::onKeyRelease(FXObject*,FXSelector,void* ptr){
       setState(!state);
       flags|=FLAG_UPDATE;
       flags&=~FLAG_PRESSED;
-      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)state);
+      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(long)state);
       return 1;
       }
     }
@@ -362,7 +352,7 @@ long FXToggleButton::onHotKeyRelease(FXObject*,FXSelector,void*){
     flags&=~FLAG_PRESSED;
     press(FALSE);
     setState(!state);
-    if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)state);
+    if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(long)state);
     }
   return 1;
   }
@@ -502,7 +492,7 @@ long FXToggleButton::onPaint(FXObject*,FXSelector,void* ptr){
       dc.setForeground(textColor);
       drawLabel(dc,altlabel,althotoff,tx,ty,tw,th);
       if(hasFocus()){
-        drawFocusRectangle(dc,border+2,border+2,width-2*border-4,height-2*border-4);
+        dc.drawFocusRectangle(border+2,border+2,width-2*border-4,height-2*border-4);
         }
       }
     else if(!label.empty()){
@@ -510,7 +500,7 @@ long FXToggleButton::onPaint(FXObject*,FXSelector,void* ptr){
       dc.setForeground(textColor);
       drawLabel(dc,label,hotoff,tx,ty,tw,th);
       if(hasFocus()){
-        drawFocusRectangle(dc,border+2,border+2,width-2*border-4,height-2*border-4);
+        dc.drawFocusRectangle(border+2,border+2,width-2*border-4,height-2*border-4);
         }
       }
     }
