@@ -3,7 +3,7 @@
 *                       T o o l b a r   T a b   O b j e c t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXToolbarTab.cpp,v 1.14 2001/05/10 18:33:31 jeroen Exp $                 *
+* $Id: FXToolbarTab.cpp,v 1.17 2002/01/18 22:43:07 jeroen Exp $                 *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,18 +30,10 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
 #include "FXFont.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
 #include "FXToolbarTab.h"
 
 
@@ -252,7 +244,7 @@ long FXToolbarTab::onLeftBtnPress(FXObject* sender,FXSelector sel,void* ptr){
     }
   return 0;
   }
-    
+
 
 // Released mouse button
 long FXToolbarTab::onLeftBtnRelease(FXObject* sender,FXSelector sel,void* ptr){
@@ -265,7 +257,7 @@ long FXToolbarTab::onLeftBtnRelease(FXObject* sender,FXSelector sel,void* ptr){
       update();
       if(click){
         collapse(!collapsed);
-        if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)collapsed);
+        if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(long)collapsed);
         }
       return 1;
       }
@@ -314,7 +306,7 @@ long FXToolbarTab::onKeyRelease(FXObject*,FXSelector,void* ptr){
       flags|=FLAG_UPDATE;
       flags&=~FLAG_PRESSED;
       collapse(!collapsed);
-      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)collapsed);
+      if(target) target->handle(this,MKUINT(message,SEL_COMMAND),(void*)(long)collapsed);
       return 1;
       }
     }
