@@ -3,7 +3,7 @@
 *                           T o o l t i p   W i d g e t                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXTooltip.cpp,v 1.20 2001/08/15 06:33:40 jeroen Exp $                    *
+* $Id: FXTooltip.cpp,v 1.22 2002/01/18 22:43:07 jeroen Exp $                    *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -29,23 +29,12 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
 #include "FXFont.h"
 #include "FXCursor.h"
-#include "FXDrawable.h"
-#include "FXWindow.h"
-#include "FXFrame.h"
-#include "FXComposite.h"
-#include "FXRootWindow.h"
-#include "FXShell.h"
 #include "FXTooltip.h"
 
 /*
@@ -250,7 +239,7 @@ long FXTooltip::onTipShow(FXObject*,FXSelector,void*){
       FXint timeoutms=getApp()->getTooltipTime();
       // Text length dependent tooltip display time;
       // Contributed by: leonard@hipgraphics.com
-      if(options&TOOLTIP_VARIABLE){       
+      if(options&TOOLTIP_VARIABLE){
         timeoutms=timeoutms/4+(timeoutms*label.length())/64;
         }
       timer=getApp()->addTimeout(timeoutms,this,ID_TIP_HIDE);
