@@ -3,7 +3,7 @@
 *                          T r e e L i s t   O b j e c t                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXTreeList.cpp,v 1.74 2001/08/23 16:24:54 jeroen Exp $                   *
+* $Id: FXTreeList.cpp,v 1.85.4.3 2003/03/03 16:12:41 fox Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,22 +30,12 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
 #include "FXFont.h"
-#include "FXDrawable.h"
-#include "FXImage.h"
 #include "FXIcon.h"
-#include "FXWindow.h"
-#include "FXComposite.h"
 #include "FXScrollbar.h"
-#include "FXScrollArea.h"
 #include "FXTreeList.h"
 
 
@@ -114,25 +104,12 @@ void FXTreeItem::draw(const FXTreeList* list,FXDC& dc,FXint x,FXint y,FXint,FXin
       }
     dc.drawText(x+2,y+font->getFontAscent()+2,label.text(),len);
     if(hasFocus()){
-      drawFocus(list,dc,x,y,tw,th);
+      dc.drawFocusRectangle(x+1,y+1,tw-2,th-2);
       }
     }
   }
 
 
-// Draw dotted rectangle for focus
-void FXTreeItem::drawFocus(const FXTreeList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const {
-  dc.setFillStyle(FILL_OPAQUESTIPPLED);
-  dc.setStipple(STIPPLE_GRAY,x,y);
-  dc.setForeground(list->getTextColor());
-  dc.setBackground(list->getBackColor());
-  dc.drawRectangle(x+1,y+1,w-3,h-3);
-  dc.setFillStyle(FILL_SOLID);
-  dc.setStipple(STIPPLE_NONE);
-  }
-
-
-
 // See if item got hit, and where:- 1 is icon, 2 is text
 FXint FXTreeItem::hitItem(const FXTreeList* list,FXint x,FXint y) const {
   register FXint oiw=0,ciw=0,oih=0,cih=0,tw=0,th=0,iw,ih,ix,iy,tx,ty,h;
@@ -445,6 +422,20 @@ void FXTreeList::detach(){
 FXbool FXTreeList::canFocus() const { return TRUE; }
 
 
+// Into focus chain
+void FXTreeList::setFocus(){
+  FXScrollArea::setFocus();
+  setDefault(TRUE);
+  }
+
+
+// Out of focus chain
+void FXTreeList::killFocus(){
+  FXScrollArea::killFocus();
+  setDefault(MAYBE);
+  }
+
+
 // Get default width
 FXint FXTreeList::getDefaultWidth(){
   return FXScrollArea::getDefaultWidth();
@@ -709,6 +700,20 @@ void FXTreeList::makeItemVisible(FXTreeItem* item){
   }
 
 
+// Return item width
+FXint FXTreeList::getItemWidth(const FXTreeItem* item) const {
+  if(!item){ fxerror("%s::getItemWidth: item is NULL.\n",getClassName()); }
+  return item->getWidth(this);
+  }
+
+
+// Return item height
+FXint FXTreeList::getItemHeight(const FXTreeItem* item) const {
+  if(!item){ fxerror("%s::getItemHeight: item is NULL.\n",getClassName()); }
+  return item->getHeight(this);
+  }
+
+
 // Get item at position x,y
 FXTreeItem* FXTreeList::getItemAt(FXint,FXint y) const {
   register FXTreeItem* item=firstitem;
@@ -761,7 +766,7 @@ FXint FXTreeList::hitItem(const FXTreeItem* item,FXint x,FXint y) const {
 
 // Repaint
 void FXTreeList::updateItem(FXTreeItem* item){
-  if(xid && item){
+  if(item){
     update(0,pos_y+item->y,content_w,item->getHeight(this));
     }
   }
@@ -980,7 +985,7 @@ long FXTreeList::onEnter(FXObject* sender,FXSelector sel,void* ptr){
 // Stop motion timer when leaving window
 long FXTreeList::onLeave(FXObject* sender,FXSelector sel,void* ptr){
   FXScrollArea::onLeave(sender,sel,ptr);
-  if(timer){getApp()->removeTimeout(timer);timer=NULL;}
+  if(timer){timer=getApp()->removeTimeout(timer);}
   cursoritem=NULL;
   return 1;
   }
@@ -1012,6 +1017,7 @@ long FXTreeList::onFocusOut(FXObject* sender,FXSelector sel,void* ptr){
 long FXTreeList::onPaint(FXObject*,FXSelector,void* ptr){
   FXEvent* event=(FXEvent*)ptr;
   FXTreeItem* item=firstitem;
+  FXTreeItem* p;
   FXint yh,xh,x,y,w,h,xp,hh;
   FXDCWindow dc(this,event);
   dc.setTextFont(font);
@@ -1034,11 +1040,11 @@ long FXTreeList::onPaint(FXObject*,FXSelector,void* ptr){
         yh=y+hh;
         xh=x-indent+(SIDE_SPACING/2);
         dc.setForeground(lineColor);
-        dc.setFillStyle(FILL_STIPPLED);
         dc.setStipple(STIPPLE_GRAY,pos_x&1,pos_y&1);
         if(options&TREELIST_SHOWS_LINES){                   // Connect items with lines
-          FXTreeItem* p=item->parent;
+          p=item->parent;
           xp=xh;
+          dc.setFillStyle(FILL_STIPPLED);
           while(p){
             xp-=(indent+p->getHeight(this)/2);
             if(p->next) dc.fillRectangle(xp,y,1,h);
@@ -1105,7 +1111,6 @@ long FXTreeList::onQueryTip(FXObject* sender,FXSelector,void*){
   FXint x,y; FXuint state;
   if((flags&FLAG_TIP) && !(options&TREELIST_AUTOSELECT)){   // No tip when autoselect!
     getCursorPosition(x,y,state);
-    FXTRACE((250,"%s::onQueryTip %p (%d,%d)\n",getClassName(),this,x,y));
     FXTreeItem *item=getItemAt(x,y);
     if(item){
       FXString string=item->getText();
@@ -1120,7 +1125,6 @@ long FXTreeList::onQueryTip(FXObject* sender,FXSelector,void*){
 // We were asked about status text
 long FXTreeList::onQueryHelp(FXObject* sender,FXSelector,void*){
   if(!help.empty() && (flags&FLAG_HELP)){
-    FXTRACE((200,"%s::onQueryHelp %p\n",getClassName(),this));
     sender->handle(this,MKUINT(ID_SETSTRINGVALUE,SEL_COMMAND),(void*)&help);
     return 1;
     }
@@ -1132,186 +1136,194 @@ long FXTreeList::onQueryHelp(FXObject* sender,FXSelector,void*){
 long FXTreeList::onKeyPress(FXObject*,FXSelector,void* ptr){
   FXEvent* event=(FXEvent*)ptr;
   FXTreeItem *item=currentitem;
-  char entry;
   flags&=~FLAG_TIP;
-  if(isEnabled()){
-    flags&=~FLAG_UPDATE;
-    if(target && target->handle(this,MKUINT(message,SEL_KEYPRESS),ptr)) return 1;
-    if(item==NULL) item=firstitem;
-    switch(event->code){
-      case KEY_Page_Up:
-      case KEY_KP_Page_Up:
-        lookup=FXString::null;
-        setPosition(pos_x,pos_y+verticalScrollbar()->getPage());
-        return 1;
-      case KEY_Page_Down:
-      case KEY_KP_Page_Down:
-        lookup=FXString::null;
-        setPosition(pos_x,pos_y-verticalScrollbar()->getPage());
-        return 1;
-      case KEY_Up:                          // Move up
-      case KEY_KP_Up:
-        if(item){
-          if(item->prev){
-            item=item->prev;
-            while(item->first && ((options&TREELIST_AUTOSELECT) || item->isExpanded())) item=item->last;
-            }
-          else if(item->parent){
-            item=item->parent;
-            }
+  if(!isEnabled()) return 0;
+  if(target && target->handle(this,MKUINT(message,SEL_KEYPRESS),ptr)) return 1;
+  if(item==NULL) item=firstitem;
+  switch(event->code){
+    case KEY_Control_L:
+    case KEY_Control_R:
+    case KEY_Shift_L:
+    case KEY_Shift_R:
+    case KEY_Alt_L:
+    case KEY_Alt_R:
+      if(flags&FLAG_DODRAG){handle(this,MKUINT(0,SEL_DRAGGED),ptr);}
+      return 1;
+    case KEY_Page_Up:
+    case KEY_KP_Page_Up:
+      lookup=FXString::null;
+      setPosition(pos_x,pos_y+verticalScrollbar()->getPage());
+      return 1;
+    case KEY_Page_Down:
+    case KEY_KP_Page_Down:
+      lookup=FXString::null;
+      setPosition(pos_x,pos_y-verticalScrollbar()->getPage());
+      return 1;
+    case KEY_Up:                          // Move up
+    case KEY_KP_Up:
+      if(item){
+        if(item->prev){
+          item=item->prev;
+          while(item->first && ((options&TREELIST_AUTOSELECT) || item->isExpanded())) item=item->last;
           }
-        goto hop;
-      case KEY_Down:                        // Move down
-      case KEY_KP_Down:
-        if(item){
-          if(item->first && ((options&TREELIST_AUTOSELECT) || item->isExpanded())){
-            item=item->first;
-            }
-          else{
-            while(!item->next && item->parent) item=item->parent;
-            item=item->next;
-            }
+        else if(item->parent){
+          item=item->parent;
           }
-        goto hop;
-      case KEY_Right:                       // Move right/down and open subtree
-      case KEY_KP_Right:
-        if(item){
-          if(!(options&TREELIST_AUTOSELECT) && !item->isExpanded() && ((item->state&FXTreeItem::HASITEMS) || item->first)){
-            expandTree(item,TRUE);
-            }
-          else if(item->first){
-            item=item->first;
-            }
-          else{
-            while(!item->next && item->parent) item=item->parent;
-            item=item->next;
-            }
+        }
+      goto hop;
+    case KEY_Down:                        // Move down
+    case KEY_KP_Down:
+      if(item){
+        if(item->first && ((options&TREELIST_AUTOSELECT) || item->isExpanded())){
+          item=item->first;
           }
-        goto hop;
-      case KEY_Left:                        // Move left/up and close subtree
-      case KEY_KP_Left:
-        if(item){
-          if(!(options&TREELIST_AUTOSELECT) && item->isExpanded() && ((item->state&FXTreeItem::HASITEMS) || item->first)){
-            collapseTree(item,TRUE);
-            }
-          else if(item->parent){
-            item=item->parent;
-            }
-          else if(item->prev){
-            item=item->prev;
-            }
+        else{
+          while(!item->next && item->parent) item=item->parent;
+          item=item->next;
           }
-        goto hop;
-      case KEY_Home:                        // Move to first
-      case KEY_KP_Home:
-        item=firstitem;
-        goto hop;
-      case KEY_End:                         // Move to last
-      case KEY_KP_End:
-        item=lastitem;
-        while(item){
-          if(item->last && ((options&TREELIST_AUTOSELECT) || item->isExpanded())){
-            item=item->last;
-            }
-          else if(item->next){
-            item=item->next;
-            }
-          else{
-            break;
-            }
+        }
+      goto hop;
+    case KEY_Right:                       // Move right/down and open subtree
+    case KEY_KP_Right:
+      if(item){
+        if(!(options&TREELIST_AUTOSELECT) && !item->isExpanded() && ((item->state&FXTreeItem::HASITEMS) || item->first)){
+          expandTree(item,TRUE);
           }
-hop:    lookup=FXString::null;
-        if(item){
-          setCurrentItem(item,TRUE);
-          makeItemVisible(item);
-          if((options&SELECT_MASK)==TREELIST_EXTENDEDSELECT){
-            if(item->isEnabled()){
-              if(event->state&SHIFTMASK){
-                if(anchoritem){
-                  selectItem(anchoritem,TRUE);
-                  extendSelection(item,TRUE);
-                  }
-                else{
-                  selectItem(item,TRUE);
-                  setAnchorItem(item);
-                  }
+        else if(item->first){
+          item=item->first;
+          }
+        else{
+          while(!item->next && item->parent) item=item->parent;
+          item=item->next;
+          }
+        }
+      goto hop;
+    case KEY_Left:                        // Move left/up and close subtree
+    case KEY_KP_Left:
+      if(item){
+        if(!(options&TREELIST_AUTOSELECT) && item->isExpanded() && ((item->state&FXTreeItem::HASITEMS) || item->first)){
+          collapseTree(item,TRUE);
+          }
+        else if(item->parent){
+          item=item->parent;
+          }
+        else if(item->prev){
+          item=item->prev;
+          }
+        }
+      goto hop;
+    case KEY_Home:                        // Move to first
+    case KEY_KP_Home:
+      item=firstitem;
+      goto hop;
+    case KEY_End:                         // Move to last
+    case KEY_KP_End:
+      item=lastitem;
+      while(item){
+        if(item->last && ((options&TREELIST_AUTOSELECT) || item->isExpanded())){
+          item=item->last;
+          }
+        else if(item->next){
+          item=item->next;
+          }
+        else{
+          break;
+          }
+        }
+hop:  lookup=FXString::null;
+      if(item){
+        setCurrentItem(item,TRUE);
+        makeItemVisible(item);
+        if((options&SELECT_MASK)==TREELIST_EXTENDEDSELECT){
+          if(item->isEnabled()){
+            if(event->state&SHIFTMASK){
+              if(anchoritem){
+                selectItem(anchoritem,TRUE);
+                extendSelection(item,TRUE);
                 }
-              else if(!(event->state&CONTROLMASK)){
-                killSelection(TRUE);
+              else{
                 selectItem(item,TRUE);
                 setAnchorItem(item);
                 }
               }
-            }
-          }
-        return 1;
-      case KEY_space:
-      case KEY_KP_Space:
-        lookup=FXString::null;
-        if(item && item->isEnabled()){
-          switch(options&SELECT_MASK){
-            case TREELIST_EXTENDEDSELECT:
-              if(event->state&SHIFTMASK){
-                if(anchoritem){
-                  selectItem(anchoritem,TRUE);
-                  extendSelection(item,TRUE);
-                  }
-                else{
-                  selectItem(item,TRUE);
-                  }
-                }
-              else if(event->state&CONTROLMASK){
-                toggleItem(item,TRUE);
-                }
-              else{
-                killSelection(TRUE);
-                selectItem(item,TRUE);
-                }
-              break;
-            case TREELIST_MULTIPLESELECT:
-            case TREELIST_SINGLESELECT:
-              toggleItem(item,TRUE);
-              break;
-            }
-          setAnchorItem(item);
-          }
-        return 1;
-      case KEY_Return:
-      case KEY_KP_Enter:
-        lookup=FXString::null;
-        return 1;
-      case KEY_Control_L:
-      case KEY_Control_R:
-      case KEY_Shift_L:
-      case KEY_Shift_R:
-      case KEY_Alt_L:
-      case KEY_Alt_R:
-        if(flags&FLAG_DODRAG){handle(this,MKUINT(0,SEL_DRAGGED),ptr);}
-        return 1;
-      default:
-        if(!(event->state&(CONTROLMASK|ALTMASK))){
-          entry=fxkeyval(event->code,event->state);
-          if(' '<=(FXuchar)entry){
-            lookup.append(entry);
-            if(lookuptimer) getApp()->removeTimeout(lookuptimer);
-            lookuptimer=getApp()->addTimeout(getApp()->getTypingSpeed(),this,ID_LOOKUPTIMER);
-            item=findItem(lookup,currentitem,SEARCH_FORWARD|SEARCH_WRAP|SEARCH_PREFIX);
-            if(item){
-              setCurrentItem(item,TRUE);
-              makeItemVisible(item);
-              if((options&SELECT_MASK)==TREELIST_EXTENDEDSELECT){
-                if(item->isEnabled()){
-                  killSelection(TRUE);
-                  selectItem(item,TRUE);
-                  }
-                }
+            else if(!(event->state&CONTROLMASK)){
+              killSelection(TRUE);
+              selectItem(item,TRUE);
               setAnchorItem(item);
               }
-            return 1;
             }
           }
-        break;
-      }
+        }
+      handle(this,MKUINT(0,SEL_CLICKED),(void*)currentitem);
+      if(currentitem && currentitem->isEnabled()){
+        handle(this,MKUINT(0,SEL_COMMAND),(void*)currentitem);
+        }
+      return 1;
+    case KEY_space:
+    case KEY_KP_Space:
+      lookup=FXString::null;
+      if(item && item->isEnabled()){
+        switch(options&SELECT_MASK){
+          case TREELIST_EXTENDEDSELECT:
+            if(event->state&SHIFTMASK){
+              if(anchoritem){
+                selectItem(anchoritem,TRUE);
+                extendSelection(item,TRUE);
+                }
+              else{
+                selectItem(item,TRUE);
+                }
+              }
+            else if(event->state&CONTROLMASK){
+              toggleItem(item,TRUE);
+              }
+            else{
+              killSelection(TRUE);
+              selectItem(item,TRUE);
+              }
+            break;
+          case TREELIST_MULTIPLESELECT:
+          case TREELIST_SINGLESELECT:
+            toggleItem(item,TRUE);
+            break;
+          }
+        setAnchorItem(item);
+        }
+      handle(this,MKUINT(0,SEL_CLICKED),(void*)currentitem);
+      if(currentitem && currentitem->isEnabled()){
+        handle(this,MKUINT(0,SEL_COMMAND),(void*)currentitem);
+        }
+      return 1;
+    case KEY_Return:
+    case KEY_KP_Enter:
+      lookup=FXString::null;
+      handle(this,MKUINT(0,SEL_DOUBLECLICKED),(void*)currentitem);
+      if(currentitem && currentitem->isEnabled()){
+        handle(this,MKUINT(0,SEL_COMMAND),(void*)currentitem);
+        }
+      return 1;
+    default:
+      if((event->state&(CONTROLMASK|ALTMASK)) || !isprint((FXuchar)event->text[0])) return 0;
+      lookup.append(event->text);
+      if(lookuptimer) getApp()->removeTimeout(lookuptimer);
+      lookuptimer=getApp()->addTimeout(getApp()->getTypingSpeed(),this,ID_LOOKUPTIMER);
+      item=findItem(lookup,currentitem,SEARCH_FORWARD|SEARCH_WRAP|SEARCH_PREFIX);
+      if(item){
+	setCurrentItem(item,TRUE);
+	makeItemVisible(item);
+	if((options&SELECT_MASK)==TREELIST_EXTENDEDSELECT){
+	  if(item->isEnabled()){
+	    killSelection(TRUE);
+	    selectItem(item,TRUE);
+	    }
+	  }
+	setAnchorItem(item);
+        }
+      handle(this,MKUINT(0,SEL_CLICKED),(void*)currentitem);
+      if(currentitem && currentitem->isEnabled()){
+	handle(this,MKUINT(0,SEL_COMMAND),(void*)currentitem);
+	}
+      return 1;
     }
   return 0;
   }
@@ -1320,74 +1332,17 @@ hop:    lookup=FXString::null;
 // Key Release
 long FXTreeList::onKeyRelease(FXObject*,FXSelector,void* ptr){
   FXEvent* event=(FXEvent*)ptr;
-  char entry;
-  if(isEnabled()){
-    flags|=FLAG_UPDATE;
-    if(target && target->handle(this,MKUINT(message,SEL_KEYRELEASE),ptr)) return 1;
-    switch(event->code){
-      case KEY_Page_Up:
-      case KEY_KP_Page_Up:
-      case KEY_Page_Down:
-      case KEY_KP_Page_Down:
-        return 1;
-      case KEY_Up:
-      case KEY_KP_Up:
-      case KEY_Down:
-      case KEY_KP_Down:
-      case KEY_Right:
-      case KEY_KP_Right:
-      case KEY_Left:
-      case KEY_KP_Left:
-      case KEY_Home:
-      case KEY_KP_Home:
-      case KEY_End:
-      case KEY_KP_End:
-        if((options&SELECT_MASK)==TREELIST_BROWSESELECT){
-          handle(this,MKUINT(0,SEL_CLICKED),(void*)currentitem);
-          if(currentitem && currentitem->isEnabled()){
-            handle(this,MKUINT(0,SEL_COMMAND),(void*)currentitem);
-            }
-          }
-        return 1;
-      case KEY_space:
-      case KEY_KP_Space:
-        if((options&SELECT_MASK)!=TREELIST_BROWSESELECT){
-          handle(this,MKUINT(0,SEL_CLICKED),(void*)currentitem);
-          if(currentitem && currentitem->isEnabled()){
-            handle(this,MKUINT(0,SEL_COMMAND),(void*)currentitem);
-            }
-          }
-        return 1;
-      case KEY_Return:
-      case KEY_KP_Enter:
-        handle(this,MKUINT(0,SEL_DOUBLECLICKED),(void*)currentitem);
-        if(currentitem && currentitem->isEnabled()){
-          handle(this,MKUINT(0,SEL_COMMAND),(void*)currentitem);
-          }
-        return 1;
-      case KEY_Shift_L:
-      case KEY_Shift_R:
-      case KEY_Control_L:
-      case KEY_Control_R:
-      case KEY_Alt_L:
-      case KEY_Alt_R:
-        if(flags&FLAG_DODRAG){handle(this,MKUINT(0,SEL_DRAGGED),ptr);}
-        return 1;
-      default:
-        if(!(event->state&(CONTROLMASK|ALTMASK))){
-          entry=fxkeyval(event->code,event->state);
-          if(' '<=(FXuchar)entry){
-            if((options&SELECT_MASK)==TREELIST_BROWSESELECT){
-              handle(this,MKUINT(0,SEL_CLICKED),(void*)currentitem);
-              if(currentitem && currentitem->isEnabled()){
-                handle(this,MKUINT(0,SEL_COMMAND),(void*)currentitem);
-                }
-              }
-            return 1;
-            }
-          }
-        break;
-      }
+  if(!isEnabled()) return 0;
+  if(target && target->handle(this,MKUINT(message,SEL_KEYRELEASE),ptr)) return 1;
+  switch(event->code){
+    case KEY_Shift_L:
+    case KEY_Shift_R:
+    case KEY_Control_L:
+    case KEY_Control_R:
+    case KEY_Alt_L:
+    case KEY_Alt_R:
+      if(flags&FLAG_DODRAG){handle(this,MKUINT(0,SEL_DRAGGED),ptr);}
+      return 1;
     }
   return 0;
   }
@@ -2236,10 +2191,22 @@ void FXTreeList::removeItem(FXTreeItem* item,FXbool notify){
     // Notify item will be deleted
     if(notify && target){target->handle(this,MKUINT(message,SEL_DELETED),(void*)item);}
 
-    // Adjust pointers
-    if(anchoritem==item){ anchoritem=(anchoritem->next ? anchoritem->next : anchoritem->prev); }
-    if(extentitem==item){ extentitem=(extentitem->next ? extentitem->next : extentitem->prev); }
-    if(currentitem==item){ currentitem=(currentitem->next ? currentitem->next : currentitem->prev); }
+    // Adjust pointers; suggested by Alan Ott <ott@acusoft.com>
+    if(anchoritem==item){
+      if(anchoritem->next) anchoritem=anchoritem->next;
+      else if(anchoritem->prev) anchoritem=anchoritem->prev;
+      else anchoritem=anchoritem->parent;
+      }
+    if(extentitem==item){
+      if(extentitem->next) extentitem=extentitem->next;
+      else if(extentitem->prev) extentitem=extentitem->prev;
+      else extentitem=extentitem->parent;
+      }
+    if(currentitem==item){
+      if(currentitem->next) currentitem=currentitem->next;
+      else if(currentitem->prev) currentitem=currentitem->prev;
+      else currentitem=currentitem->parent;
+      }
 
     // Remove item from list
     if(item->prev) item->prev->next=item->next; else if(item->parent) item->parent->first=item->next; else firstitem=item->next;
@@ -2280,22 +2247,6 @@ void FXTreeList::removeItems(FXTreeItem* fm,FXTreeItem* to,FXbool notify){
       }
     while(item!=to);
     }
-//   if(fm && to){
-//     FXTreeItem *item;
-//     if(fm->prev) fm->prev->next=to->next; else if(fm->parent) fm->parent->first=to->next; else firstitem=to->next;
-//     if(to->next) to->next->prev=fm->prev; else if(to->parent) to->parent->last=fm->prev; else lastitem=fm->prev;
-//     do{
-//       item=fm;
-//       if(currentitem==item) currentitem=NULL;
-//       if(anchoritem==item) anchoritem=NULL;
-//       if(extentitem==item) extentitem=NULL;
-//       removeItems(item->first,item->last,notify);
-//       fm=fm->next;
-//       delete item;
-//       }
-//     while(item!=to);
-//     recalc();
-//     }
   }
 
 
