@@ -3,7 +3,7 @@
 *                       T r e e  L i s t  B o x  O b j e c t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXTreeListBox.cpp,v 1.18 2001/06/06 16:49:56 jeroen Exp $                *
+* $Id: FXTreeListBox.cpp,v 1.23 2002/02/11 06:37:27 fox Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,29 +30,18 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
-#include "FXObjectList.h"
 #include "FXApp.h"
-#include "FXId.h"
-#include "FXDrawable.h"
 #include "FXFont.h"
-#include "FXDC.h"
 #include "FXWindow.h"
 #include "FXFrame.h"
 #include "FXLabel.h"
 #include "FXTextField.h"
 #include "FXButton.h"
 #include "FXMenuButton.h"
-#include "FXComposite.h"
-#include "FXPacker.h"
-#include "FXShell.h"
 #include "FXPopup.h"
 #include "FXScrollbar.h"
-#include "FXScrollArea.h"
 #include "FXTreeList.h"
 #include "FXTreeListBox.h"
 
@@ -192,7 +181,7 @@ void FXTreeListBox::layout(){
 
 // Forward GUI update of tree to target; but only if pane is not popped
 long FXTreeListBox::onUpdFmTree(FXObject*,FXSelector,void*){
-  return target && !pane->shown() && target->handle(this,MKUINT(message,SEL_UPDATE),NULL);
+  return target && !isPaneShown() && target->handle(this,MKUINT(message,SEL_UPDATE),NULL);
   }
 
 
@@ -271,6 +260,13 @@ long FXTreeListBox::onFocusDown(FXObject*,FXSelector,void*){
   }
 
 
+
+// Is the pane shown
+FXbool FXTreeListBox::isPaneShown() const {
+  return pane->shown();
+  }
+
+
 // Set font
 void FXTreeListBox::setFont(FXFont* fnt){
   if(!fnt){ fxerror("%s::setFont: NULL font specified.\n",getClassName()); }
@@ -397,6 +393,13 @@ void FXTreeListBox::clearItems(){
   }
 
 
+
+// Get item by name
+FXTreeItem* FXTreeListBox::findItem(const FXString& text,FXTreeItem* start,FXuint flags) const {
+  return tree->findItem(text,start,flags);
+  }
+
+
 // Is item current
 FXbool FXTreeListBox::isItemCurrent(const FXTreeItem* item) const {
   return tree->isItemCurrent(item);
