@@ -3,7 +3,7 @@
 *                       U R L   M a n i p u l a t i o n                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2000,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * Contributed by: Sean Hubbell                                                  *
 *********************************************************************************
@@ -21,7 +21,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXURL.cpp,v 1.13 2001/03/22 21:42:42 jeroen Exp $                        *
+* $Id: FXURL.cpp,v 1.15 2002/01/18 22:43:07 jeroen Exp $                        *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -92,7 +92,7 @@ FXString FXURL::fileToURL(const FXString& file){
 // Return filename from URL, empty if url is not a local file
 FXString FXURL::fileFromURL(const FXString& url){
 #ifndef WIN32
-  FXint s=0,t;
+  FXint t;
   if(comparecase("file:",url,5)==0){
     if(url[5]==PATHSEP && url[6]==PATHSEP){
       t=url.findf(PATHSEP,7);
