@@ -3,7 +3,7 @@
 *                            V i s u a l   C l a s s                            *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXVisual.cpp,v 1.37 2001/08/23 18:56:57 jeroen Exp $                     *
+* $Id: FXVisual.cpp,v 1.41.4.1 2003/04/30 03:38:37 fox Exp $                     *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,14 +30,10 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXObjectList.h"
 #include "FXApp.h"
-#include "FXId.h"
 #include "FXVisual.h"
 
 
@@ -232,11 +228,10 @@ static inline FXuint findnbits(FXPixel n){
   }
 
 
-// Apply gamma correction to an intensity value in [0..max].  Return the
-// new intensity value.
+// Apply gamma correction to an intensity value in [0..max].
 static FXuint gamma_adjust(FXdouble gamma,FXuint value,FXuint max){
   register FXdouble x=(FXdouble)value / (FXdouble)max;
-  return (FXuint) ((FXdouble)max * pow(x,1.0/gamma));
+  return (FXuint) (((FXdouble)max * pow(x,1.0/gamma))+0.5);
   }
 
 
@@ -935,7 +930,7 @@ void FXVisual::setupcolormap(){
     }
   else{
     if((flags&VISUAL_OWNCOLORMAP) || (visual!=DefaultVisual(DISPLAY(getApp()),DefaultScreen(DISPLAY(getApp()))))){
-      colormap=XCreateColormap(DISPLAY(getApp()),RootWindow(DISPLAY(getApp()),0),((Visual*)visual),AllocNone);
+      colormap=XCreateColormap(DISPLAY(getApp()),RootWindow(DISPLAY(getApp()),DefaultScreen(DISPLAY(getApp()))),((Visual*)visual),AllocNone);
       FXTRACE((150,"%s::create: allocate colormap\n",getClassName()));
       freemap=TRUE;
       }
@@ -1198,7 +1193,7 @@ void FXVisual::create(){
 
       // Check for palette support
       HDC hdc=GetDC(GetDesktopWindow());
-      if(GetDeviceCaps(hdc,RASTERCAPS)&RC_PALETTE!=0){
+      if((GetDeviceCaps(hdc,RASTERCAPS)&RC_PALETTE)!=0){
         depth=GetDeviceCaps(hdc,COLORRES);
         if(depth<=8){
           hPalette=createAllPurposePalette();   // Palette
