@@ -3,7 +3,7 @@
 *                            W i n d o w   O b j e c t                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * Major Contributions for Windows NT by Lyle Johnson                            *
 *********************************************************************************
@@ -21,7 +21,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXWindow.cpp,v 1.167 2001/08/29 04:12:48 jeroen Exp $                    *
+* $Id: FXWindow.cpp,v 1.192.4.4 2003/06/09 14:07:32 fox Exp $                    *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -32,19 +32,13 @@
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
-#include "FXDict.h"
-#include "FXSettings.h"
 #include "FXRegistry.h"
 #include "FXAccelTable.h"
 #include "FXObjectList.h"
 #include "FXApp.h"
-#include "FXId.h"
 #include "FXVisual.h"
-#include "FXDC.h"
 #include "FXDCWindow.h"
 #include "FXCursor.h"
-#include "FXDrawable.h"
 #include "FXWindow.h"
 #include "FXFrame.h"
 #include "FXComposite.h"
@@ -73,6 +67,12 @@
     after we're done [This would imply the CLIPBOARD type list would be the same as the
     XDND type list, which is probably OK].
   - Add URL jump text also.
+  - Can we call parent->recalc() in the constructor?
+  - Need other focus models:
+      o click to focus (like we have now)
+      o focus only by tabs and arrows (buttons should not move focus when clicking)
+      o point to focus (useful for canvas type widgets)
+    Mouse wheel should probably not cause focus changes...
 */
 
 #ifndef WIN32
@@ -102,6 +102,7 @@
 // Layout modes
 #define LAYOUT_MASK (LAYOUT_SIDE_MASK|LAYOUT_RIGHT|LAYOUT_CENTER_X|LAYOUT_BOTTOM|LAYOUT_CENTER_Y|LAYOUT_FIX_X|LAYOUT_FIX_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|LAYOUT_FILL_X|LAYOUT_FILL_Y)
 
+
 #define DISPLAY(app) ((Display*)((app)->display))
 
 /*******************************************************************************/
@@ -231,7 +232,7 @@ FXWindow::FXWindow(FXApp* a,FXVisual *vis):FXDrawable(a,1,1){
   xpos=0;
   ypos=0;
   backColor=0;
-  flags=FLAG_DIRTY|FLAG_SHOWN|FLAG_UPDATE|FLAG_RECALC|FLAG_ROOT;
+  flags=FLAG_DIRTY|FLAG_SHOWN|FLAG_UPDATE|FLAG_RECALC;
   options=LAYOUT_FIX_X|LAYOUT_FIX_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT;
   }
 
@@ -355,7 +356,8 @@ void FXWindow::load(FXStream& store){
 // Return a pointer to the shell window
 FXWindow* FXWindow::getShell() const {
   register FXWindow *win=(FXWindow*)this;
-  while(win && !(win->flags&FLAG_SHELL)) win=win->parent;
+  register FXWindow *p;
+  while((p=win->parent) && p->parent) win=p;
   return win;
   }
 
@@ -618,9 +620,8 @@ long FXWindow::onRightBtnRelease(FXObject*,FXSelector,void* ptr){
 
 
 // Mouse motion
-long FXWindow::onMotion(FXObject*,FXSelector,void*){
-//   return isEnabled() && target && target->handle(this,MKUINT(message,SEL_MOTION),ptr);
-  return 0;
+long FXWindow::onMotion(FXObject*,FXSelector,void* ptr){
+  return isEnabled() && target && target->handle(this,MKUINT(message,SEL_MOTION),ptr);
   }
 
 
@@ -883,11 +884,83 @@ void FXWindow::setFocus(){
 void FXWindow::killFocus(){
   if(parent && parent->focus==this){
     if(focus) focus->killFocus();
-    if(this->hasFocus()) handle(this,MKUINT(0,SEL_FOCUSOUT),NULL);
+    if(hasFocus()) handle(this,MKUINT(0,SEL_FOCUSOUT),NULL);
     parent->focus=NULL;
     }
   flags&=~FLAG_HELP;
-  flags|=FLAG_UPDATE;
+  }
+
+
+// Search widget tree for default window
+FXWindow* FXWindow::findDefault(FXWindow* window){
+  register FXWindow *win,*def;
+  if(window->flags&FLAG_DEFAULT) return window;
+  for(win=window->first; win; win=win->next){
+    if((def=findDefault(win))!=NULL) return def;
+    }
+  return NULL;
+  }
+
+
+// Search widget tree for initial window
+FXWindow* FXWindow::findInitial(FXWindow* window){
+  register FXWindow *win,*ini;
+  if(window->flags&FLAG_INITIAL) return window;
+  for(win=window->first; win; win=win->next){
+    if((ini=findInitial(win))!=NULL) return ini;
+    }
+  return NULL;
+  }
+
+
+// Make widget drawn as default
+void FXWindow::setDefault(FXbool enable){
+  register FXWindow *win;
+  switch(enable){
+    case FALSE:
+      flags&=~FLAG_DEFAULT;
+      break;
+    case TRUE:
+      if(!(flags&FLAG_DEFAULT)){
+        win=findDefault(getShell());
+        if(win) win->setDefault(FALSE);
+        flags|=FLAG_DEFAULT;
+        }
+      break;
+    case MAYBE:
+      if(flags&FLAG_DEFAULT){
+        flags&=~FLAG_DEFAULT;
+        win=findInitial(getShell());
+        if(win) win->setDefault(TRUE);
+        }
+      break;
+    }
+  }
+
+
+// Return true if widget is drawn as default
+FXbool FXWindow::isDefault() const {
+  return (flags&FLAG_DEFAULT)!=0;
+  }
+
+
+// Make this window the initial default window
+void FXWindow::setInitial(FXbool enable){
+  register FXWindow *win;
+  if((flags&FLAG_INITIAL) && !enable){
+    flags&=~FLAG_INITIAL;
+    }
+  if(!(flags&FLAG_INITIAL) && enable){
+    win=findInitial(getShell());
+    if(win) win->setInitial(FALSE);
+    flags|=FLAG_INITIAL;
+    }
+  }
+
+
+// Return true if this is the initial default window
+FXbool FXWindow::isInitial() const {
+  return (flags&FLAG_INITIAL)!=0;
   }
 
 
@@ -951,7 +1024,7 @@ void FXWindow::create(){
   if(!xid){
     if(getApp()->initialized){
       FXTRACE((100,"%s::create %p\n",getClassName(),this));
-      
+
 #ifndef WIN32
 
       XSetWindowAttributes wattr;
@@ -1061,7 +1134,7 @@ void FXWindow::create(){
 
       // Show if it was supposed to be
       if((flags&FLAG_SHOWN) && 0<width && 0<height) XMapWindow(DISPLAY(getApp()),xid);
-      
+
 #else
 
       // Gotta have a parent already created!
@@ -1085,22 +1158,22 @@ void FXWindow::create(){
       // Most windows use these style bits
       DWORD dwStyle=WS_CHILD|WS_VISIBLE|WS_CLIPSIBLINGS|WS_CLIPCHILDREN;
       DWORD dwExStyle=0;
-
+      dwExStyle|=WS_EX_NOPARENTNOTIFY;
       HWND hParent=(HWND)parent->id();
       if(flags&FLAG_SHELL){
         if(isMemberOf(FXMETACLASS(FXTopWindow))){
-          dwStyle=WS_OVERLAPPEDWINDOW;
+          dwStyle=WS_OVERLAPPEDWINDOW|WS_CLIPSIBLINGS|WS_CLIPCHILDREN;
           }
         else if(doesOverrideRedirect()){
           // To control window placement or control decoration, a window manager
           // often needs to redirect map or configure requests. Popup windows, however,
           // often need to be mapped without a window manager getting in the way.
-          dwStyle=WS_POPUP;
+          dwStyle=WS_POPUP|WS_CLIPSIBLINGS|WS_CLIPCHILDREN;
           dwExStyle=WS_EX_TOOLWINDOW;
           }
         else{
           // Other top-level shell windows (like dialogs)
-          dwStyle=WS_POPUP|WS_CAPTION;
+          dwStyle=WS_POPUP|WS_CAPTION|WS_CLIPSIBLINGS|WS_CLIPCHILDREN;
           dwExStyle=WS_EX_DLGMODALFRAME|WS_EX_TOOLWINDOW;
           // if(hParent==GetDesktopWindow() && getApp()->getMainWindow()!=0){
           // if(getApp()->getMainWindow()->id()) hParent=(HWND)getApp()->getMainWindow()->id();
@@ -1121,20 +1194,78 @@ void FXWindow::create(){
       // Uh-oh, we failed
       if(!xid){ fxerror("%s::create: unable to create window.\n",getClassName()); }
 
-      // Show if it was supposed to be
-      if(flags&FLAG_SHOWN) ShowWindow((HWND)xid,SW_SHOWNOACTIVATE);
-      
+      // Show if it was supposed to be.  Apparently, initial state
+      // is neither shown nor hidden, so an explicit hide is needed.
+      // Patch thanks to "Glenn Shen" <shen@hks.com>
+      if(flags&FLAG_SHOWN)
+        ShowWindow((HWND)xid,SW_SHOWNOACTIVATE);
+      else
+        ShowWindow((HWND)xid,SW_HIDE);
 #endif
       }
     }
   }
 
 
+/*
+// Attach to existing window; possibly, the window belongs to another application.
+void FXWindow::attach(FXID wnd){
+  if(!xid){
+    if(getApp()->initialized){
+      FXTRACE((100,"%s::attach %p\n",getClassName(),this));
+      // FIXME do more than this... but what?
+#ifndef WIN32
+
+      // Reparent under what WE think the parent is
+      XReparentWindow(DISPLAY(getApp()),wnd,parent->id(),0,0);
+
+      // Store for xid to C++ object mapping
+      XSaveContext(DISPLAY(getApp()),wnd,getApp()->wcontext,(XPointer)this);
+#else
+      // Reparent under what WE think the parent is
+      SetParent((HWND)wnd,(HWND)parent->id());
+
+      // Store for xid to C++ object mapping
+      SetWindowLong((HWND)wnd,0,(LONG)this);
+#endif
+      xid=x;
+      }
+    }
+  }
+*/
+
+
 // Detach window
 void FXWindow::detach(){
+
+  // Detach visual
   visual->detach();
+
+  // Detach default cursor
+  if(defaultCursor) defaultCursor->detach();
+
+  // Detach drag cursor
+  if(dragCursor) dragCursor->detach();
+
   if(xid){
-    FXTRACE((100,"%s::detach %p\n",getClassName(),this));
+    if(getApp()->initialized){
+      FXTRACE((100,"%s::detach %p\n",getClassName(),this));
+
+#ifndef WIN32
+
+      // Remove from xid to C++ object mapping
+      XDeleteContext(DISPLAY(getApp()),xid,getApp()->wcontext);
+#else
+
+      // Break binding between HWND and C++
+      SetWindowLong((HWND)xid,0,0);
+#endif
+      }
+
+    // No longer grabbed
+    if(getApp()->mouseGrabWindow==this) getApp()->mouseGrabWindow=NULL;
+    if(getApp()->keyboardGrabWindow==this) getApp()->keyboardGrabWindow=NULL;
+
     xid=0;
     }
   }
@@ -1145,7 +1276,7 @@ void FXWindow::destroy(){
   if(xid){
     if(getApp()->initialized){
       FXTRACE((100,"%s::destroy %p\n",getClassName(),this));
-      
+
 #ifndef WIN32
 
       // If colormap different, set WM_COLORMAP_WINDOWS property properly
@@ -1164,7 +1295,7 @@ void FXWindow::destroy(){
 
       // Remove from xid to C++ object mapping
       XDeleteContext(DISPLAY(getApp()),xid,getApp()->wcontext);
-      
+
 #else
 
       // Delete the XdndAware property
@@ -1177,14 +1308,14 @@ void FXWindow::destroy(){
 
       // Zap the window
       DestroyWindow((HWND)xid);
-      
+
 #endif
       }
 
     // No longer grabbed
     if(getApp()->mouseGrabWindow==this) getApp()->mouseGrabWindow=NULL;
     if(getApp()->keyboardGrabWindow==this) getApp()->keyboardGrabWindow=NULL;
-    
+
     xid=0;
     }
   }
@@ -1555,7 +1686,7 @@ FXbool FXWindow::releaseClipboard(){
 
 // Get pointer location (in window coordinates)
 FXint FXWindow::getCursorPosition(FXint& x,FXint& y,FXuint& buttons) const {
-  if(xid!=0){
+  if(xid){
 #ifndef WIN32
     Window dum; int rx,ry;
     return XQueryPointer(DISPLAY(getApp()),xid,&dum,&dum,&rx,&ry,&x,&y,&buttons);
@@ -1575,7 +1706,7 @@ FXint FXWindow::getCursorPosition(FXint& x,FXint& y,FXuint& buttons) const {
 // Set pointer location (in window coordinates)
 // Contributed by David Heath <dave@hipgraphics.com>
 FXint FXWindow::setCursorPosition(FXint x,FXint y){
-  if(xid!=0){
+  if(xid){
 #ifndef WIN32
     XWarpPointer(DISPLAY(getApp()),None,xid,0,0,0,0,x,y);
     return TRUE;
@@ -1671,7 +1802,7 @@ void FXWindow::repaint(FXint x,FXint y,FXint w,FXint h){
 
     // We toss out rectangles outside the visible area
     if(x>=width || y>=height || x+w<=0 || y+h<=0) return;
-    
+
     // Intersect with the window
     if(x<0){w+=x;x=0;}
     if(y<0){h+=y;y=0;}
@@ -1692,7 +1823,7 @@ void FXWindow::repaint(FXint x,FXint y,FXint w,FXint h){
       }
     }
   }
-      
+
 
 // If marked but not yet painted, paint the entire window
 void FXWindow::repaint(){
@@ -1702,6 +1833,7 @@ void FXWindow::repaint(){
 
 // Move window
 void FXWindow::move(FXint x,FXint y){
+  FXTRACE((200,"%s::move: x=%d y=%d\n",getClassName(),x,y));
   if((flags&FLAG_DIRTY)||(x!=xpos)||(y!=ypos)){
     xpos=x;
     ypos=y;
@@ -1712,7 +1844,7 @@ void FXWindow::move(FXint x,FXint y){
 #ifndef WIN32
       XMoveWindow(DISPLAY(getApp()),xid,x,y);
 #else
-      SetWindowPos((HWND)xid,NULL,x,y,0,0,SWP_NOSIZE|SWP_NOZORDER|SWP_NOACTIVATE);
+      SetWindowPos((HWND)xid,NULL,x,y,0,0,SWP_NOSIZE|SWP_NOZORDER|SWP_NOACTIVATE|SWP_NOOWNERZORDER);
 #endif
       if(flags&FLAG_DIRTY) layout();
       }
@@ -1722,13 +1854,16 @@ void FXWindow::move(FXint x,FXint y){
 
 // Move and resize
 void FXWindow::position(FXint x,FXint y,FXint w,FXint h){
-  FXTRACE((100,"%s::position: x=%d y=%d w=%d h=%d\n",getClassName(),x,y,w,h));
+  register FXint ow=width;
+  register FXint oh=height;
+  FXTRACE((200,"%s::position: x=%d y=%d w=%d h=%d\n",getClassName(),x,y,w,h));
   if(w<0) w=0;
   if(h<0) h=0;
-  FXbool resized=(w!=width)||(h!=height);
-  if((flags&FLAG_DIRTY)||(x!=xpos)||(y!=ypos)||resized){
+  if((flags&FLAG_DIRTY)||(x!=xpos)||(y!=ypos)||(w!=ow)||(h!=oh)){
     xpos=x;
     ypos=y;
+    width=w;
+    height=h;
     if(xid){
 
       // Alas, we have to generate some protocol here even if the placement
@@ -1736,28 +1871,22 @@ void FXWindow::position(FXint x,FXint y,FXint w,FXint h){
       // there are ways to change the placement w/o going through position()!
 #ifndef WIN32
       if(0<w && 0<h){
-        if((flags&FLAG_SHOWN) && (width<=0 || height<=0)){
+        if((flags&FLAG_SHOWN) && (ow<=0 || oh<=0)){
           XMapWindow(DISPLAY(getApp()),xid);
           }
         XMoveResizeWindow(DISPLAY(getApp()),xid,x,y,w,h);
         }
-      else if(0<width && 0<height){
+      else if(0<ow && 0<oh){
         XUnmapWindow(DISPLAY(getApp()),xid);
         }
 #else
-      SetWindowPos((HWND)xid,NULL,x,y,w,h,SWP_NOZORDER|SWP_NOACTIVATE);
+      SetWindowPos((HWND)xid,NULL,x,y,w,h,SWP_NOZORDER|SWP_NOACTIVATE|SWP_NOOWNERZORDER);
 #endif
-      width=w;
-      height=h;
 
       // We don't have to layout the interior of this widget unless
       // the size has changed or it was marked as dirty:- this is
       // a very good optimization as it's applied recursively!
-      if((flags&FLAG_DIRTY)||resized) layout();
-      }
-    else{
-      width=w;
-      height=h;
+      if((flags&FLAG_DIRTY)||(w!=ow)||(h!=oh)) layout();
       }
     }
   }
@@ -1765,35 +1894,34 @@ void FXWindow::position(FXint x,FXint y,FXint w,FXint h){
 
 // Resize
 void FXWindow::resize(FXint w,FXint h){
+  register FXint ow=width;
+  register FXint oh=height;
+  FXTRACE((200,"%s::resize: w=%d h=%d\n",getClassName(),w,h));
   if(w<0) w=0;
   if(h<0) h=0;
-  if((flags&FLAG_DIRTY)||(w!=width)||(h!=height)){
+  if((flags&FLAG_DIRTY)||(w!=ow)||(h!=oh)){
+    width=w;
+    height=h;
     if(xid){
 
       // Similar as for position(), we have to generate protocol here..
 #ifndef WIN32
       if(0<w && 0<h){
-        if((flags&FLAG_SHOWN) && (width<=0 || height<=0)){
+        if((flags&FLAG_SHOWN) && (ow<=0 || oh<=0)){
           XMapWindow(DISPLAY(getApp()),xid);
           }
         XResizeWindow(DISPLAY(getApp()),xid,w,h);
         }
-      else if(0<width && 0<height){
+      else if(0<ow && 0<oh){
         XUnmapWindow(DISPLAY(getApp()),xid);
         }
 #else
-      SetWindowPos((HWND)xid,NULL,0,0,w,h,SWP_NOMOVE|SWP_NOZORDER|SWP_NOACTIVATE);
+      SetWindowPos((HWND)xid,NULL,0,0,w,h,SWP_NOMOVE|SWP_NOZORDER|SWP_NOACTIVATE|SWP_NOOWNERZORDER);
 #endif
 
       // And of course the size has changed so layout is needed
-      width=w;
-      height=h;
       layout();
       }
-    else{
-      width=w;
-      height=h;
-      }
     }
   }
 
@@ -1803,7 +1931,7 @@ void FXWindow::resize(FXint w,FXint h){
 
 // Scroll rectangle x,y,w,h by a shift of dx,dy
 void FXWindow::scroll(FXint x,FXint y,FXint w,FXint h,FXint dx,FXint dy){
-  if(xid && (dx || dy)){
+  if(xid && 0<w && 0<h && (dx || dy)){
 
     // No overlap:- repaint the whole thing
     if((w<=FXABS(dx)) || (h<=FXABS(dy))){
@@ -1874,7 +2002,7 @@ void FXWindow::scroll(FXint x,FXint y,FXint w,FXint h,FXint dx,FXint dy){
 
 // Scroll rectangle x,y,w,h by a shift of dx,dy
 void FXWindow::scroll(FXint x,FXint y,FXint w,FXint h,FXint dx,FXint dy){
-  if(xid && (dx || dy)){
+  if(xid && 0<w && 0<h && (dx || dy)){
     RECT rect;
     DWORD flags=SW_INVALIDATE;
     rect.left=x;
@@ -1919,8 +2047,28 @@ void FXWindow::hide(){
     flags&=~FLAG_SHOWN;
     if(xid){
 #ifndef WIN32
+      if(getApp()->mouseGrabWindow==this){
+        XUngrabPointer(DISPLAY(getApp()),CurrentTime);
+        XFlush(DISPLAY(getApp()));
+        handle(this,MKUINT(0,SEL_UNGRABBED),&getApp()->event);
+        getApp()->mouseGrabWindow=NULL;
+        }
+      if(getApp()->keyboardGrabWindow==this){
+        XUngrabKeyboard(DISPLAY(getApp()),getApp()->event.time);
+        XFlush(DISPLAY(getApp()));
+        getApp()->keyboardGrabWindow=NULL;
+        }
       XUnmapWindow(DISPLAY(getApp()),xid);
 #else
+      if(getApp()->mouseGrabWindow==this){
+        ReleaseCapture();
+        SetCursor((HCURSOR)defaultCursor->id());
+        handle(this,MKUINT(0,SEL_UNGRABBED),&getApp()->event);
+        getApp()->mouseGrabWindow=NULL;
+        }
+      if(getApp()->keyboardGrabWindow==this){
+        getApp()->keyboardGrabWindow=NULL;
+        }
       ShowWindow((HWND)xid,SW_HIDE);
 #endif
       }
@@ -1935,7 +2083,7 @@ FXbool FXWindow::shown() const {
 
 
 // Reparent window under a new parent
-void FXWindow::reparent(FXComposite* newparent){
+void FXWindow::reparent(FXWindow* newparent){
   if(newparent==NULL){ fxerror("%s::reparent: NULL parent specified.\n",getClassName()); }
   if(parent==NULL){ fxerror("%s::reparent: cannot reparent root window.\n",getClassName()); }
   if(parent==getRoot() || newparent==getRoot()){ fxerror("%s::reparent: cannot reparent toplevel window.\n",getClassName()); }
@@ -1945,8 +2093,8 @@ void FXWindow::reparent(FXComposite* newparent){
     if(containsChild(newparent)){ fxerror("%s::reparent: new parent is child of window.\n",getClassName()); }
 
     // Both windows created or both non-created
-    if(xid && !newparent->xid){ fxerror("%s::reparent: new parent not created yet.\n",getClassName()); }
-    if(!xid && newparent->xid){ fxerror("%s::reparent: window not created yet.\n",getClassName()); }
+    if(xid && !newparent->id()){ fxerror("%s::reparent: new parent not created yet.\n",getClassName()); }
+    if(!xid && newparent->id()){ fxerror("%s::reparent: window not created yet.\n",getClassName()); }
 
     // Kill focus chain through this window
     killFocus();
@@ -1969,11 +2117,11 @@ void FXWindow::reparent(FXComposite* newparent){
     owner=parent;
 
     // Hook up to new window in server too
-    if(xid && parent->xid){
+    if(xid && parent->id()){
 #ifndef WIN32
-      XReparentWindow(DISPLAY(getApp()),xid,parent->xid,0,0);
+      XReparentWindow(DISPLAY(getApp()),xid,parent->id(),0,0);
 #else
-      SetParent((HWND)xid,(HWND)parent->xid);
+      SetParent((HWND)xid,(HWND)parent->id());
 #endif
       }
 
@@ -2071,15 +2219,15 @@ void FXWindow::lower(){
 // Get coordinates from another window (for symmetry)
 void FXWindow::translateCoordinatesFrom(FXint& tox,FXint& toy,const FXWindow* fromwindow,FXint fromx,FXint fromy) const {
   if(fromwindow==NULL){ fxerror("%s::translateCoordinatesFrom: from-window is NULL.\n",getClassName()); }
-  if(xid && fromwindow->xid){
+  if(xid && fromwindow->id()){
 #ifndef WIN32
     Window tmp;
-    XTranslateCoordinates(DISPLAY(getApp()),fromwindow->xid,xid,fromx,fromy,&tox,&toy,&tmp);
+    XTranslateCoordinates(DISPLAY(getApp()),fromwindow->id(),xid,fromx,fromy,&tox,&toy,&tmp);
 #else
     POINT pt;
     pt.x=fromx;
     pt.y=fromy;
-    ClientToScreen((HWND)fromwindow->xid,&pt);
+    ClientToScreen((HWND)fromwindow->id(),&pt);
     ScreenToClient((HWND)xid,&pt);
     tox=pt.x;
     toy=pt.y;
@@ -2091,16 +2239,16 @@ void FXWindow::translateCoordinatesFrom(FXint& tox,FXint& toy,const FXWindow* fr
 // Get coordinates to another window (for symmetry)
 void FXWindow::translateCoordinatesTo(FXint& tox,FXint& toy,const FXWindow* towindow,FXint fromx,FXint fromy) const {
   if(towindow==NULL){ fxerror("%s::translateCoordinatesTo: to-window is NULL.\n",getClassName()); }
-  if(xid && towindow->xid){
+  if(xid && towindow->id()){
 #ifndef WIN32
     Window tmp;
-    XTranslateCoordinates(DISPLAY(getApp()),xid,towindow->xid,fromx,fromy,&tox,&toy,&tmp);
+    XTranslateCoordinates(DISPLAY(getApp()),xid,towindow->id(),fromx,fromy,&tox,&toy,&tmp);
 #else
     POINT pt;
     pt.x=fromx;
     pt.y=fromy;
     ClientToScreen((HWND)xid,&pt);
-    ScreenToClient((HWND)towindow->xid,&pt);
+    ScreenToClient((HWND)towindow->id(),&pt);
     tox=pt.x;
     toy=pt.y;
 #endif
@@ -2123,7 +2271,6 @@ void FXWindow::grab(){
       fxwarning("%s::grab: grab failed!\n",getClassName());
       }
 #else
-    SetCapture((HWND)xid);
     SetCapture((HWND)xid);
     if(GetCapture()!=(HWND)xid){
       fxwarning("%s::grab: grab failed!\n",getClassName());
@@ -2238,7 +2385,7 @@ void FXWindow::setDragRectangle(FXint x,FXint y,FXint w,FXint h,FXbool wantupdat
   POINT pt;
   pt.x=x;
   pt.y=y;
-  ClientToScreen((HWND)parent->xid,&pt);
+  ClientToScreen((HWND)parent->id(),&pt);
   getApp()->xdndRect.x=(short)pt.x;
   getApp()->xdndRect.y=(short)pt.y;
 #endif
@@ -2561,7 +2708,7 @@ FXbool FXWindow::handleDrag(FXint x,FXint y,FXDragAction action){
     // Get drop window
     point.x=x;
     point.y=y;
-    window=WindowFromPoint(point);
+    window=WindowFromPoint(point);// FIXME this finds only enabled/visible windows
     while(window){
       version=(FXuint)GetProp(window,(LPCTSTR)MAKELONG(getApp()->xdndAware,0));
       if(version) break;
