@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: fxutils.cpp,v 1.71.4.4 2003/05/02 17:36:58 fox Exp $                         *
+* $Id: fxutils.cpp,v 1.71.4.6 2003/11/07 13:57:53 fox Exp $                         *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -62,70 +62,6 @@ FXuint fxrandom(FXuint& seed){
   }
 
 
-// Allocate memory
-FXint fxmalloc(void** ptr,unsigned long size){
-  *ptr=NULL;
-  if(size!=0){
-    if((*ptr=malloc(size))==NULL) return FALSE;
-    }
-  return TRUE;
-  }
-
-
-// Allocate cleaned memory
-FXint fxcalloc(void** ptr,unsigned long size){
-  *ptr=NULL;
-  if(size!=0){
-    if((*ptr=calloc(size,1))==NULL) return FALSE;
-    }
-  return TRUE;
-  }
-
-
-// Resize memory
-FXint fxresize(void** ptr,unsigned long size){
-  register void *p=NULL;
-  if(size!=0){
-    if((p=realloc(*ptr,size))==NULL) return FALSE;
-    }
-  else{
-    if(*ptr) free(*ptr);
-    }
-  *ptr=p;
-  return TRUE;
-  }
-
-
-// Allocate and initialize memory
-FXint fxmemdup(void** ptr,unsigned long size,const void* src){
-  *ptr=NULL;
-  if(size!=0 && src!=NULL){
-    if((*ptr=malloc(size))==NULL) return FALSE;
-    memcpy(*ptr,src,size);
-    }
-  return TRUE;
-  }
-
-
-// String duplicate
-FXchar *fxstrdup(const FXchar* str){
-  register FXchar *copy;
-  if(str!=NULL && (copy=(FXchar*)malloc(strlen(str)+1))!=NULL){
-    strcpy(copy,str);
-    return copy;
-    }
-  return NULL;
-  }
-
-
-// Free memory, resets ptr to NULL afterward
-void fxfree(void** ptr){
-  if(*ptr){
-    free(*ptr);
-    *ptr=NULL;
-    }
-  }
-
 #ifdef WIN32
 
 // Missing in CYGWIN
@@ -748,7 +684,7 @@ int fxpointsize_to_height(HDC hdc,unsigned size){
   pt.x=0;
   pt.y=(int)(size*cyDpi/72);
   DPtoLP(hdc,&pt,1);
-  return -(int)(fabs(pt.y)/10.0+0.5);
+  return -(int)(fabs((double)pt.y)/10.0+0.5);
   }
 
 
@@ -772,7 +708,7 @@ unsigned fxheight_to_pointsize(HDC hdc,int height){
   pt.x=0;
   pt.y=10*height;
   LPtoDP(hdc,&pt,1);
-  return (FXuint)(72*pt.y/cyDpi);
+  return (FXuint)(72.0*pt.y/cyDpi);
   }
 
 #endif
