@@ -5,7 +5,7 @@
 *********************************************************************************
 * Copyright (C) 1997 by Jeroen van der Zijp.   All Rights Reserved.             *
 *********************************************************************************
-* $Id: datatarget.cpp,v 1.27 2001/07/26 22:28:10 jeroen Exp $                   *
+* $Id: datatarget.cpp,v 1.28 2001/09/05 05:47:23 jeroen Exp $                   *
 ********************************************************************************/
 #include "fx.h"
 #include <stdio.h>
@@ -46,12 +46,14 @@ public:
   long onCmdTimer(FXObject*,FXSelector,void*);
   long onCmdQuit(FXObject*,FXSelector,void*);
   long onCmdProgress(FXObject*,FXSelector,void*);
+  long onCmdTextField(FXObject*,FXSelector,void*);
 public:
   DataTargetWindow(){}
 public:
   enum {
     ID_TIMER=FXMainWindow::ID_LAST,
     ID_PROGRESS,
+    ID_TEXTFIELD,
     ID_QUIT
     };
 public:
@@ -66,9 +68,10 @@ public:
 
 // Map
 FXDEFMAP(DataTargetWindow) DataTargetWindowMap[]={
-  FXMAPFUNC(SEL_TIMEOUT,DataTargetWindow::ID_TIMER,   DataTargetWindow::onCmdTimer),
-  FXMAPFUNC(SEL_SIGNAL, DataTargetWindow::ID_QUIT,    DataTargetWindow::onCmdQuit),
-  FXMAPFUNC(SEL_COMMAND,DataTargetWindow::ID_PROGRESS,DataTargetWindow::onCmdProgress),
+  FXMAPFUNC(SEL_TIMEOUT,DataTargetWindow::ID_TIMER,    DataTargetWindow::onCmdTimer),
+  FXMAPFUNC(SEL_SIGNAL, DataTargetWindow::ID_QUIT,     DataTargetWindow::onCmdQuit),
+  FXMAPFUNC(SEL_COMMAND,DataTargetWindow::ID_PROGRESS, DataTargetWindow::onCmdProgress),
+  FXMAPFUNC(SEL_COMMAND,DataTargetWindow::ID_TEXTFIELD,DataTargetWindow::onCmdTextField),
   };
 
 
@@ -228,6 +231,9 @@ DataTargetWindow::DataTargetWindow(FXApp* a):FXMainWindow(a,"Data Target Test",N
 
   // Install an accelerator
   getAccelTable()->addAccel(fxparseaccel("Ctl-Q"),getApp(),MKUINT(FXApp::ID_QUIT,SEL_COMMAND));
+
+  string_target.setTarget(this);
+  string_target.setSelector(ID_TEXTFIELD);
   }
 
 
@@ -265,6 +271,21 @@ long DataTargetWindow::onCmdProgress(FXObject*,FXSelector,void*){
   }
 
 
+long DataTargetWindow::onCmdTextField(FXObject*,FXSelector,void*){
+  FXString *list;
+  FXint count,i;
+  FXTRACE((100,"some_string=%s\n",some_string.text()));
+  count=FXFile::listFiles(list,some_string,"*",LIST_MATCHING_FILES|LIST_ALL_DIRS);
+  for(i=0; i<count; i++){
+    FXTRACE((100,"file[%d]=%s\n",i,list[i].text()));
+    }
+  delete [] list;
+  return 1;
+  }
+
+
+
+
 // Start
 void DataTargetWindow::create(){
 
