@@ -34,7 +34,7 @@ private:
   FXImage         *blue_nodither;
   FXBMPImage      *picture;                   // Complete picture
   FXFont          *font;                      // Font for text
-  
+
 protected:
   ImageWindow(){}
 
@@ -46,7 +46,7 @@ public:
   long onCmdRestore(FXObject*,FXSelector,void*);
 
 public:
-  
+
   // Messages for our class
   enum{
     ID_CANVAS=FXMainWindow::ID_LAST,
@@ -54,14 +54,17 @@ public:
     ID_RESTORE,
     ID_LAST
     };
-  
+
 public:
 
-  // ScribbleApp constructor
+  // ImageWindow constructor
   ImageWindow(FXApp* a);
-  
+
   // Initialize
   virtual void create();
+  
+  // ImageWindow destructor
+  virtual ~ImageWindow();
   };
 
 
@@ -82,7 +85,7 @@ FXIMPLEMENT(ImageWindow,FXMainWindow,ImageWindowMap,ARRAYNUMBER(ImageWindowMap))
 
 
 
-// Construct a ScribbleApp
+// Construct ImageWindow
 ImageWindow::ImageWindow(FXApp* a):FXMainWindow(a,"Image Application",NULL,NULL,DECOR_ALL,0,0,800,600){
   FXint x,y;
   FXVerticalFrame *canvasFrame;
@@ -90,15 +93,15 @@ ImageWindow::ImageWindow(FXApp* a):FXMainWindow(a,"Image Application",NULL,NULL,
   FXHorizontalFrame *contents;
 
   FXColorDialog *colordlg=new FXColorDialog(this,"Color Dialog");
-    
+
   contents=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0);
-  
+
   // LEFT pane to contain the canvas
   canvasFrame=new FXVerticalFrame(contents,FRAME_SUNKEN|LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_TOP|LAYOUT_LEFT,0,0,0,0,10,10,10,10);
-  
-    // Label above the canvas               
+
+    // Label above the canvas
     new FXLabel(canvasFrame,"Canvas Frame",NULL,JUSTIFY_CENTER_X|LAYOUT_FILL_X);
-  
+
     // Horizontal divider line
     new FXHorizontalSeparator(canvasFrame,SEPARATOR_GROOVE|LAYOUT_FILL_X);
 
@@ -109,43 +112,42 @@ ImageWindow::ImageWindow(FXApp* a):FXMainWindow(a,"Image Application",NULL,NULL,
   // RIGHT pane for the buttons
   buttonFrame=new FXVerticalFrame(contents,FRAME_SUNKEN|LAYOUT_FILL_Y|LAYOUT_TOP|LAYOUT_LEFT,0,0,0,0,10,10,10,10);
 
-    // Label above the buttons  
+    // Label above the buttons
     new FXLabel(buttonFrame,"Button Frame",NULL,JUSTIFY_CENTER_X|LAYOUT_FILL_X);
-    
+
     // Horizontal divider line
     new FXHorizontalSeparator(buttonFrame,SEPARATOR_RIDGE|LAYOUT_FILL_X);
 
     new FXLabel(buttonFrame,"&Background\nColor well",NULL,JUSTIFY_CENTER_X|LAYOUT_FILL_X);
     backwell=new FXColorWell(buttonFrame,FXRGB(255,255,255),this,ID_WELL,LAYOUT_CENTER_X|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,100,30);
-    
+
     new FXLabel(buttonFrame,"B&order\nColor well",NULL,JUSTIFY_CENTER_X|LAYOUT_FILL_X);
     borderwell=new FXColorWell(buttonFrame,FXRGB(0,0,0),this,ID_WELL,LAYOUT_CENTER_X|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,100,30);
-    
+
     new FXLabel(buttonFrame,"&Text\nColor well",NULL,JUSTIFY_CENTER_X|LAYOUT_FILL_X);
     textwell=new FXColorWell(buttonFrame,FXRGB(0,0,0),this,ID_WELL,LAYOUT_CENTER_X|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,100,30);
-    
+
     // Button to draw
     new FXButton(buttonFrame,"&Colors...\tPop the color dialog",NULL,colordlg,FXWindow::ID_SHOW,FRAME_THICK|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_TOP|LAYOUT_LEFT,0,0,0,0,10,10,5,5);
 
     // Button to draw
     new FXButton(buttonFrame,"Save Image...\tRead back image and save to file",NULL,this,ID_RESTORE,FRAME_THICK|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_TOP|LAYOUT_LEFT,0,0,0,0,10,10,5,5);
-    
+
     // Exit button
     new FXButton(buttonFrame,"E&xit\tQuit ImageApp",NULL,getApp(),FXApp::ID_QUIT,FRAME_THICK|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_TOP|LAYOUT_LEFT,0,0,0,0,10,10,5,5);
 
-    
   // Create images with dithering
   grey=new FXImage(getApp(),grey_ramp,IMAGE_DITHER|IMAGE_SHMI|IMAGE_SHMP,512,50);
   red=new FXImage(getApp(),red_ramp,IMAGE_DITHER|IMAGE_SHMI|IMAGE_SHMP,512,50);
   green=new FXImage(getApp(),green_ramp,IMAGE_DITHER|IMAGE_SHMI|IMAGE_SHMP,512,50);
   blue=new FXImage(getApp(),blue_ramp,IMAGE_DITHER|IMAGE_SHMI|IMAGE_SHMP,512,50);
-  
+
   // Create image with nearest color instead of dithering
   grey_nodither=new FXImage(getApp(),grey_ramp,IMAGE_NEAREST|IMAGE_SHMI|IMAGE_SHMP,512,50);
   red_nodither=new FXImage(getApp(),red_ramp,IMAGE_NEAREST|IMAGE_SHMI|IMAGE_SHMP,512,50);
   green_nodither=new FXImage(getApp(),green_ramp,IMAGE_NEAREST|IMAGE_SHMI|IMAGE_SHMP,512,50);
   blue_nodither=new FXImage(getApp(),blue_ramp,IMAGE_NEAREST|IMAGE_SHMI|IMAGE_SHMP,512,50);
-  
+
   // Result image
   picture=new FXBMPImage(getApp(),NULL,IMAGE_SHMI|IMAGE_SHMP,850,600);
   //picture=new FXBMPImage(getApp(),NULL,0,850,600);
@@ -173,22 +175,37 @@ ImageWindow::ImageWindow(FXApp* a):FXMainWindow(a,"Image Application",NULL,NULL,
       blue_ramp[3*(y*512+x)+2]=x/2;
       }
     }
-  
+
   // Make font
   font=new FXFont(getApp(),"times",36,FONTWEIGHT_BOLD);
-  
+
   // Make a tip
   new FXTooltip(getApp());
   }
-    
- 
 
-// Create and initialize 
+
+
+// Destroy ImageWindow
+ImageWindow::~ImageWindow(){
+  delete grey;
+  delete red;
+  delete green;
+  delete blue;
+  delete grey_nodither;
+  delete red_nodither;
+  delete green_nodither;
+  delete blue_nodither;
+  delete picture;
+  delete font;
+  }
+
+
+// Create and initialize
 void ImageWindow::create(){
 
   // Create the windows
   FXMainWindow::create();
-  
+
   // Create images
   grey->create();
   red->create();
@@ -198,18 +215,18 @@ void ImageWindow::create(){
   red_nodither->create();
   green_nodither->create();
   blue_nodither->create();
-  
+
   picture->create();
-  
+
   // Font too
   font->create();
-  
+
   // Make it appear
   show(PLACEMENT_SCREEN);
-  
+
   // First time repaint
   canvas->update();
-  
+
   }
 
 
@@ -217,11 +234,11 @@ void ImageWindow::create(){
 long ImageWindow::onCanvasRepaint(FXObject*,FXSelector,void* ptr){
   FXEvent *event=(FXEvent*)ptr;
   FXuint pat;
-  
+
   // We caused a redraw, so redo it all
   if(event->synthetic){
     FXDCWindow dc(picture);
-  
+
     // Erase the canvas, color comes from well
     dc.setForeground(backwell->getRGBA());
 
@@ -272,17 +289,17 @@ long ImageWindow::onCanvasRepaint(FXObject*,FXSelector,void* ptr){
     dc.drawText(540,420,"Blue",4);
     dc.drawText(540,540,"Patterns",8);
     }
-    
+
   // Now repaint the screen
   FXDCWindow sdc(canvas,event);
-  
+
   // Clear whole thing
   sdc.setForeground(backwell->getRGBA());
   sdc.fillRectangle(0,0,canvas->getWidth(),canvas->getHeight());
-  
+
   // Paint image
   sdc.drawImage(picture,0,0);
-  
+
   return 1;
   }
 
@@ -299,8 +316,8 @@ long ImageWindow::onCmdRestore(FXObject*,FXSelector,void*){
   FXFileDialog savedialog(this,"Save BMP");
   savedialog.setDirectory(".");
   if(savedialog.execute()){
-    FXFileStream outfile; 
-    if(outfile.open(savedialog.getFilename(),FXStreamSave)){   
+    FXFileStream outfile;
+    if(outfile.open(savedialog.getFilename(),FXStreamSave)){
       picture->restore();
       picture->savePixels(outfile);
       outfile.close();
@@ -315,16 +332,16 @@ int main(int argc,char *argv[]){
 
   // Make application
   FXApp application("Image","FoxText");
-  
+
   // Start app
   application.init(argc,argv);
-  
+
   // Make window
   new ImageWindow(&application);
-  
+
   // Create the application's windows
   application.create();
-  
+
   // Run the application
   return application.run();
   }
