@@ -5,18 +5,21 @@
 *********************************************************************************
 * Copyright (C) 2000 by Jeroen van der Zijp.   All Rights Reserved.             *
 *********************************************************************************
-* $Id: imageviewer.cpp,v 1.68 2001/08/21 22:37:58 jeroen Exp $                  *
+* $Id: imageviewer.cpp,v 1.75.4.1 2003/06/20 19:02:07 fox Exp $                  *
 ********************************************************************************/
 #include "fx.h"
 #ifdef HAVE_PNG_H
 #include "FXPNGImage.h"
 #endif
 #ifdef HAVE_JPEG_H
-#include "FXJPEGImage.h"
+#include "FXJPGImage.h"
 #endif
 #ifdef HAVE_TIFF_H
 #include "FXTIFImage.h"
 #endif
+#include "FXICOImage.h"
+#include "FXTGAImage.h"
+#include "FXRGBImage.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/stat.h>
@@ -98,8 +101,8 @@ public:
 
 
 /*******************************************************************************/
-  
-  
+
+
 // File Save
 const unsigned char filesave[]={
   0x47,0x49,0x46,0x38,0x37,0x61,0x10,0x00,0x10,0x00,0xf2,0x00,0x00,0xb2,0xc0,0xdc,
@@ -145,8 +148,8 @@ const unsigned char copy[]={
   0x49,0x45,0xa0,0x9b,0x32,0xeb,0x48,0xe3,0x71,0x43,0x02,0x8d,0x3a,0x92,0xb8,0x14,
   0xa5,0x9f,0xec,0x71,0x33,0x21,0x67,0x33,0x8b,0xf3,0x99,0x28,0x00,0x00,0x3b
   };
-  
-  
+
+
 // Paste
 const unsigned char paste[]={
   0x47,0x49,0x46,0x38,0x37,0x61,0x10,0x00,0x10,0x00,0xf2,0x00,0x00,0xb2,0xc0,0xdc,
@@ -188,17 +191,22 @@ const FXchar *patterns[]={
   "BMP Image",   "*.bmp",
   "XPM Image",   "*.xpm",
   "PCX Image",   "*.pcx",
+  "RGB Image",   "*.rgb",
 #ifdef HAVE_PNG_H
   "PNG Image",   "*.png",
 #endif
 #ifdef HAVE_JPEG_H
   "JPEG Image",  "*.jpg",
+#endif
+  "TARGA Image", "*.tga",
+#ifdef HAVE_JPEG_H
+  "TIFF Image",  "*.tif",
 #endif
   NULL
   };
 
 /*******************************************************************************/
-  
+
 // Map
 FXDEFMAP(ImageWindow) ImageWindowMap[]={
   FXMAPFUNC(SEL_COMMAND,       ImageWindow::ID_ABOUT,      ImageWindow::onCmdAbout),
@@ -235,7 +243,7 @@ FXIMPLEMENT(ImageWindow,FXMainWindow,ImageWindowMap,ARRAYNUMBER(ImageWindowMap))
 ImageWindow::ImageWindow(FXApp* a):FXMainWindow(a,"FOX Image Viewer: - untitled",NULL,NULL,DECOR_ALL,0,0,850,600,0,0){
   setTarget(this);
   setSelector(ID_TITLE);
-  
+
   // Make some icons
   fileopenicon=new FXGIFIcon(getApp(),fileopen);
   filesaveicon=new FXGIFIcon(getApp(),filesave);
@@ -244,75 +252,75 @@ ImageWindow::ImageWindow(FXApp* a):FXMainWindow(a,"FOX Image Viewer: - untitled"
   pasteicon=new FXGIFIcon(getApp(),paste);
   uplevelicon=new FXGIFIcon(getApp(),tbuplevel);
   paletteicon=new FXGIFIcon(getApp(),colorpal);
-    
+
   // Make color dialog
   FXColorDialog *colordlg=new FXColorDialog(this,"Color Dialog");
-  
+
   // Make menu bar
   menubar=new FXMenubar(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|FRAME_RAISED);
-  
+
   // Tool bar
   FXHorizontalFrame* toolbarcontainer=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X,0,0,0,0, 0,0,0,0, 0,0);
   new FXToolbarTab(toolbarcontainer,NULL,0,FRAME_RAISED);
   toolbar=new FXToolbar(toolbarcontainer,FRAME_RAISED|PACK_UNIFORM_WIDTH|LAYOUT_SIDE_TOP|LAYOUT_FILL_X,0,0,0,0, 4,4,4,4, 0,0);
-  
+
   // Status bar
   statusbar=new FXStatusbar(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|STATUSBAR_WITH_DRAGCORNER);
-  
+
   // File menu
   filemenu=new FXMenuPane(this);
   new FXMenuTitle(menubar,"&File",NULL,filemenu);
-    
+
   // Edit Menu
   editmenu=new FXMenuPane(this);
   new FXMenuTitle(menubar,"&Edit",NULL,editmenu);
-  
+
   // Edit Menu
   manipmenu=new FXMenuPane(this);
   new FXMenuTitle(menubar,"&Manipulation",NULL,manipmenu);
-  
+
   // View menu
   viewmenu=new FXMenuPane(this);
   new FXMenuTitle(menubar,"&View",NULL,viewmenu);
-    
+
   // Help menu
   helpmenu=new FXMenuPane(this);
   new FXMenuTitle(menubar,"&Help",NULL,helpmenu,LAYOUT_RIGHT);
 
   // Splitter
   splitter=new FXSplitter(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|SPLITTER_TRACKING|SPLITTER_VERTICAL|SPLITTER_REVERSED);
-  
+
   // Sunken border for image widget
   FXHorizontalFrame *imagebox=new FXHorizontalFrame(splitter,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0);
-  
+
   // Make image widget
   imageview=new FXImageView(imagebox,NULL,NULL,0,LAYOUT_FILL_X|LAYOUT_FILL_Y);
-    
+
   // Sunken border for file list
   filebox=new FXHorizontalFrame(splitter,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0);
-  
+
   // Make file list
   FXHorizontalFrame* fileframe=new FXHorizontalFrame(filebox,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0, 0,0);
   filelist=new FXFileList(fileframe,this,ID_FILELIST,LAYOUT_FILL_X|LAYOUT_FILL_Y|ICONLIST_MINI_ICONS|ICONLIST_AUTOSIZE);
   new FXButton(filebox,"\tUp one level\tGo up to higher directory.",uplevelicon,filelist,FXFileList::ID_DIRECTORY_UP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_Y);
-  
+
   // Toobar buttons: File manipulation
   new FXButton(toolbar,"&Open\tOpen Image\tOpen image file.",fileopenicon,this,ID_OPEN,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED);
   new FXButton(toolbar,"&Save\tSave Image\tSave image file.",filesaveicon,this,ID_SAVE,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED);
-  
+
   // Toobar buttons: Editing
   new FXButton(toolbar,"Cut\tCut",cuticon,NULL,0,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED);
   new FXButton(toolbar,"Copy\tCopy",copyicon,NULL,0,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED);
   new FXButton(toolbar,"Paste\tPaste",pasteicon,NULL,0,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED);
-  
+
   // Color
   new FXButton(toolbar,"&Colors\tColors\tDisplay color dialog.",paletteicon,colordlg,FXWindow::ID_SHOW,ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_RIGHT);
-  
+
   // File Menu entries
   new FXMenuCommand(filemenu,"&Open...\tCtl-O\tOpen image file.",fileopenicon,this,ID_OPEN);
   new FXMenuCommand(filemenu,"&Save...\tCtl-S\tSave image file.",filesaveicon,this,ID_SAVE);
   new FXMenuCommand(filemenu,"Dump",NULL,getApp(),FXApp::ID_DUMP);
-  
+
   // Recent file menu; this automatically hides if there are no files
   FXMenuSeparator* sep1=new FXMenuSeparator(filemenu);
   sep1->setTarget(&mrufiles);
@@ -331,8 +339,8 @@ ImageWindow::ImageWindow(FXApp* a):FXMainWindow(a,"FOX Image Viewer: - untitled"
   FXMenuSeparator* sep2=new FXMenuSeparator(filemenu);
   sep2->setTarget(&mrufiles);
   sep2->setSelector(FXRecentFiles::ID_ANYFILES);
-  new FXMenuCommand(filemenu,"&Quit\tCtl-Q",NULL,this,ID_QUIT,MENU_DEFAULT);
-  
+  new FXMenuCommand(filemenu,"&Quit\tCtl-Q",NULL,this,ID_QUIT);
+
   // Edit Menu entries
   new FXMenuCommand(editmenu,"&Undo\tCtl-Z\tUndo last change.");
   new FXMenuCommand(editmenu,"&Redo\tCtl-R\tRedo last undo.");
@@ -340,7 +348,7 @@ ImageWindow::ImageWindow(FXApp* a):FXMainWindow(a,"FOX Image Viewer: - untitled"
   new FXMenuCommand(editmenu,"C&ut\tCtl-X\tCut selection to clipboard.",cuticon,NULL,0);
   new FXMenuCommand(editmenu,"&Paste\tCtl-V\tPaste from clipboard.",pasteicon,NULL,0);
   new FXMenuCommand(editmenu,"&Delete\t\tDelete selection.",NULL,NULL,0);
-  
+
   // Manipulation Menu entries
   new FXMenuCommand(manipmenu,"Rotate 90\t\tRotate 90 degrees.",NULL,this,ID_ROTATE_90);
   new FXMenuCommand(manipmenu,"Rotate 180\t\tRotate 180 degrees.",NULL,this,ID_ROTATE_180);
@@ -349,7 +357,7 @@ ImageWindow::ImageWindow(FXApp* a):FXMainWindow(a,"FOX Image Viewer: - untitled"
   new FXMenuCommand(manipmenu,"Mirror Ver.\t\tMirror Vertically.",NULL,this,ID_MIRROR_VER);
   new FXMenuCommand(manipmenu,"Scale...\t\tScale image.",NULL,this,ID_SCALE);
   new FXMenuCommand(manipmenu,"Crop...\t\tCrop image.",NULL,this,ID_CROP);
-  
+
   // View Menu entries
   new FXMenuCommand(viewmenu,"File list\t\tDisplay file list.",NULL,filebox,FXWindow::ID_TOGGLESHOWN);
   new FXMenuCommand(viewmenu,"Show hidden files\t\tShow hidden files and directories.",NULL,filelist,FXFileList::ID_TOGGLE_HIDDEN);
@@ -365,13 +373,13 @@ ImageWindow::ImageWindow(FXApp* a):FXMainWindow(a,"FOX Image Viewer: - untitled"
   new FXMenuCommand(viewmenu,"Dock toolbar right\t\tDock the toolbar on the right.",NULL,toolbar,FXToolbar::ID_DOCK_RIGHT);
   new FXMenuCommand(viewmenu,"Dock toolbar bottom\t\tDock the toolbar on the bottom.",NULL,toolbar,FXToolbar::ID_DOCK_BOTTOM);
   new FXMenuCommand(viewmenu,"Status line\t\tDisplay status line.",NULL,statusbar,FXWindow::ID_TOGGLESHOWN);
-  
+
   // Help Menu entries
   new FXMenuCommand(helpmenu,"&About FOX...",NULL,this,ID_ABOUT,0);
-  
+
   // Make a tool tip
   new FXTooltip(getApp(),TOOLTIP_NORMAL);
-  
+
   // Recent files
   mrufiles.setTarget(this);
   mrufiles.setSelector(ID_RECENTFILE);
@@ -379,7 +387,7 @@ ImageWindow::ImageWindow(FXApp* a):FXMainWindow(a,"FOX Image Viewer: - untitled"
   // Initialize file name
   filename="untitled";
   }
-  
+
 
 // Clean up
 ImageWindow::~ImageWindow(){
@@ -388,7 +396,7 @@ ImageWindow::~ImageWindow(){
   delete manipmenu;
   delete helpmenu;
   delete viewmenu;
-  delete fileopenicon;       
+  delete fileopenicon;
   delete filesaveicon;
   delete cuticon;
   delete copyicon;
@@ -401,7 +409,7 @@ ImageWindow::~ImageWindow(){
 // About box
 long ImageWindow::onCmdAbout(FXObject*,FXSelector,void*){
   FXMessageBox about(this,"About Image Viewer","Image Viewer demonstrates the FOX ImageView widget.\n\nUsing the FOX C++ GUI Library (http://www.fox-toolkit.org)\n\nCopyright (C) 2000,2001 Jeroen van der Zijp (jeroen@fox-toolkit.org)",NULL,MBOX_OK|DECOR_TITLE|DECOR_BORDER);
-  about.execute();  
+  about.execute();
   return 1;
   }
 
@@ -415,36 +423,45 @@ FXbool ImageWindow::loadimage(const FXString& file){
     img=new FXGIFImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
     }
   else if(comparecase(ext,"bmp")==0){
-    img=new FXBMPImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);                
+    img=new FXBMPImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
     }
   else if(comparecase(ext,"xpm")==0){
-    img=new FXXPMImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);                
+    img=new FXXPMImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
     }
   else if(comparecase(ext,"pcx")==0){
-    img=new FXPCXImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);                
+    img=new FXPCXImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
+    }
+  else if(comparecase(ext,"ico")==0){
+    img=new FXICOImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
+    }
+  else if(comparecase(ext,"tga")==0){
+    img=new FXTGAImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
+    }
+  else if(comparecase(ext,"rgb")==0){
+    img=new FXRGBImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
     }
 #ifdef HAVE_PNG_H
   else if(comparecase(ext,"png")==0){
-    img=new FXPNGImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);                
+    img=new FXPNGImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
     }
 #endif
 #ifdef HAVE_JPEG_H
-  if(comparecase(ext,"jpg")==0){
-    img=new FXJPEGImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);                
+  else if(comparecase(ext,"jpg")==0){
+    img=new FXJPGImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
     }
 #endif
 #ifdef HAVE_TIFF_H
-  if(comparecase(ext,"tif")==0 || comparecase(ext,"tiff")==0){
-    img=new FXTIFImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);                
+  else if(comparecase(ext,"tif")==0 || comparecase(ext,"tiff")==0){
+    img=new FXTIFImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
     }
 #endif
-  
+
   // Perhaps failed
   if(img==NULL){
     FXMessageBox::error(this,MBOX_OK,"Error Loading Image","Unsupported type: %s",ext.text());
     return FALSE;
     }
-  
+
   // Load it
   FXFileStream stream;
   if(stream.open(file,FXStreamLoad)){
@@ -464,7 +481,7 @@ FXbool ImageWindow::loadimage(const FXString& file){
 // Save file
 FXbool ImageWindow::saveimage(const FXString& file){
   FXImage *img;
-  FXFileStream stream; 
+  FXFileStream stream;
   if(stream.open(file,FXStreamSave)){
     getApp()->beginWaitCursor();
     img=imageview->getImage();///// We may want to save in another format...
@@ -511,19 +528,19 @@ long ImageWindow::onCmdSave(FXObject*,FXSelector,void*){
 // Quit
 long ImageWindow::onCmdQuit(FXObject*,FXSelector,void*){
   FXTRACE((100,"Quit\n"));
-  
+
   // Write new window size back to registry
   getApp()->reg().writeIntEntry("SETTINGS","x",getX());
   getApp()->reg().writeIntEntry("SETTINGS","y",getY());
   getApp()->reg().writeIntEntry("SETTINGS","width",getWidth());
   getApp()->reg().writeIntEntry("SETTINGS","height",getHeight());
-  
+
   // Width of tree
   getApp()->reg().writeIntEntry("SETTINGS","fileheight",filebox->getHeight());
-  
+
   // Was file box shown
   getApp()->reg().writeIntEntry("SETTINGS","filesshown",filebox->shown());
-  
+
   FXString dir=filelist->getDirectory();
   getApp()->reg().writeStringEntry("SETTINGS","directory",dir.text());
 
@@ -554,7 +571,7 @@ long ImageWindow::onCmdRecentFile(FXObject*,FXSelector,void* ptr){
 
 // Command from the tree list
 long ImageWindow::onCmdFileList(FXObject*,FXSelector,void* ptr){
-  FXint index=(FXint)(long)ptr;
+  FXint index=(FXint)(FXival)ptr;
   if(0<=index){
     if(filelist->isItemDirectory(index)){
       filelist->setDirectory(filelist->getItemPathname(index));
@@ -585,9 +602,9 @@ long ImageWindow::onCmdRotate(FXObject*,FXSelector sel,void*){
 
 // Update image
 long ImageWindow::onUpdImage(FXObject* sender,FXSelector,void*){
-  if(imageview->getImage()) 
+  if(imageview->getImage())
     sender->handle(this,MKUINT(FXWindow::ID_ENABLE,SEL_COMMAND),NULL);
-  else 
+  else
     sender->handle(this,MKUINT(FXWindow::ID_DISABLE,SEL_COMMAND),NULL);
   return 1;
   }
@@ -666,13 +683,13 @@ long ImageWindow::onCmdCrop(FXObject*,FXSelector,void*){
 void ImageWindow::create(){
   FXint ww,hh,xx,yy,fh,fs;
   FXString dir;
-  
+
   // Get size
   xx=getApp()->reg().readIntEntry("SETTINGS","x",600);
   yy=getApp()->reg().readIntEntry("SETTINGS","y",400);
   ww=getApp()->reg().readIntEntry("SETTINGS","width",600);
   hh=getApp()->reg().readIntEntry("SETTINGS","height",400);
-  
+
   fh=getApp()->reg().readIntEntry("SETTINGS","fileheight",100);
   fs=getApp()->reg().readIntEntry("SETTINGS","filesshown",TRUE);
 
@@ -700,19 +717,19 @@ int main(int argc,char *argv[]){
 
   // Make application
   FXApp application("ImageViewer","FoxTest");
-  
+
   // Open display
   application.init(argc,argv);
 
   // Make window
   ImageWindow* window=new ImageWindow(&application);
-  
+
   // Handle interrupt to save stuff nicely
   application.addSignal(SIGINT,window,ImageWindow::ID_QUIT);
 
   // Create it
   application.create();
-  
+
   // Passed image file?
   if(argc>1) window->loadimage(argv[1]);
 
